***********************************************************************
***********************************************************************
*                       NMSSMCALC version 5.2
*          (complex) NMSSM Higgs masses and decays CALCulator
***********************************************************************
***********************************************************************
* This program package includes a F95 routine for the calculation of
c the one-loop and two-loop (up to O(alpha_t alpha_s + alpha_t^2)
c corrected NMSSM Higgs boson masses in the real or the complex NMSSM.
c It is called CalcMasses.F (1-loop, 2-loop O(alpha_t alpha_s)),
c CalcMasses_atat.F (2-loop O(alpha_t^2)) and linked to a modified 
c version of HDECAY which calculates the decay widths and branching
c ratios of the Higgs bosons of the real or the complex NMSSM. In 
c case of the CP-conserving NMSSM the F77 routine to be linked is 
c called BHDECAY (Beyond Minimal supersymmetric HDECAY). In case of
c the CP-violating NMSSM the F77 routine to be linked is called 
c BHDECAY_C. More details on these two major parts of the 
c package can be found in CalcMasses.F and BHDECAY.f or BHDECAY_C.f, 
c respectively.
c
c
c If no input file is specified in the command line (first argument)
c the standard file 'inp.dat' is used. This file has to follow SLHA
c conventions. Note that we have extended the SLHA conventions to the
c case of a complex NMSSM, as these have not been specified so far.
c
c Last modification:  July 2023

      program NMSSMCALC

      implicit none

      character*120 output_spec, output_dec, input
      logical exist_file
      logical MHpmInput,CPcon,mQrun,slhaswitch
      logical mainrun,calcmasseserror
      integer EDMswitch,AMMswitch,HHHswitch,EWPOswitch
      integer SDCswitch

      COMMON/SWITCH/MHpmInput,CPcon,mQrun,slhaswitch
      COMMON/calcerror/mainrun,calcmasseserror
      common /EDMselec/ EDMswitch
      common /AMMselec/ AMMswitch  
      common /HHHselec/ HHHswitch         
      common /EWPOselec/ EWPOswitch
      common /SDECAYselec/ SDCswitch

      print*
      print*, '*******************************************************'
     .        ,'**************'
      print*, ' NMSSMCALC version 5.2'
      print*, ' This program calculates the two-loop corrected NMSSM Hi
     .ggs boson '
      print*, ' masses and the Higgs decay widths and branching ratios,'
      print*, 'together with EDMs, electron/muon Anomalous Magnetic Depole Moment,
     . W-mass'
      print*, 'in the (complex) NMSSM.  '
      print*,''
      print*, ' If you use this program then cite:'
      print*,''
      print*, ' J. Baglio, R.Grober, M. Muhlleitner, D.T. Nhung, H. Rzeh
     .ak, '
      print*, ' M. Spira, J. Streicher and K. Walz, '
      print*, ' Comput.Phys.Commun. 185 (2014) 12, [arXiv:1312.4788 [hep
     .-ph]].'
      print*,''
      print*, ' K. Ender, T. Graf, M. Mühlleitner, H. Rzehak, Phys. Rev.'
      print*, ' D85 (2012)075024'
      print*,''
      print*, ' T. Graf, R. Gröber, M. Mühlleitner, H. Rzehak, K. Walz,'
      print*, ' JHEP 1210 (2012) 122'	
      print*,''
      print*, ' M. Mühlleitner, D.T. Nhung, H. Rzehak, K. Walz,'  
      print*, ' JHEP 1505 (2015) 128'
      print*,'' 
      print*, ' S.F. King, M. Muhlleitner, R. Nevzorov and K. Walz, '
      print*, ' Nucl. Phys. B901 (2015) 526.'
      print*,''
      print*, ' T.N. Dao, R. Gröber, M. Krause, M. Mühlleitner, H. Rzehak,'
      print*, ' JHEP 08 (2019) 114'
      print*,''
      print*, ' T.N. Dao, M. Gabelmann, M. Mühlleitner, H. Rzehak,' 
      print*, ' JHEP 09 (2021) 193'
      print*,''
      print*, ' T.N. Dao, D.N. Le, M. Mühlleitner'
      print*, ' Eur.Phys.J.C 82 (2022) 10, 954'
      print*,''
      print*, ' T.N. Dao, M. Gabelmann, M. Mühlleitner'
      print*, ' arXiv:2308.04059'
      print*,''
      print*, ' A. Djouadi, J. Kalinowski, M. Spira,'
      print*, ' Comput.Phys.Commun.108 (1998) 56'
      print*,''
      print*, ' A. Djouadi, J. Kalinowski, Margarete Muhlleitner, M. Spira,'
      print*, ' Comput.Phys.Commun. 238 (2019) 214'	
      print*, '*******************************************************'
     .        ,'**************'
      print*

c checking which input file to use   
c either input file is given on command line (first argument),
c or the default file named 'inp.dat' is used
      
      call getarg(1,input)

      inquire(file=input, exist=exist_file)
      if(exist_file) then
      print*, '* Reading from slha-input file ',input
      print*
      else
      print*, '* Input file provided in command line does not exist.'
      inquire(File='inp.dat', exist=exist_file)
        if(exist_file) then
        print*, '  Using standard input file inp.dat.'
        print*
        input='inp.dat'
        else
        print*, '  Standard input file inp.dat was deleted.'
        print*, '  Progam terminated...'
        print*
        call exit
        end if
      end if

c checking which output file to use for the SLHA spectrum file
c either output file given on command line (second argument)
c or the default file named 'slha.in' is used
      
      call getarg(2,output_spec)
      
      if(output_spec.eq.'') then
      print*, '* No spectrum output file specified in command line'
      print*, '  Spectrum output written to default slha.in.'
      print*
      output_spec='slha.in'
      else
      print*, '* Spectrum output written to ',output_spec
      print*
      end if

c checking which output file to use for the SLHA spectrum file
c either output file given on command line (second argument)
c or the default file named 'slha.in' is used
      
      call getarg(3,output_dec)
      
      if(output_dec.eq.'') then
      print*, '* No decay output file specified in command line'
      print*, '  Decay output written to default slha_decay.out.'
      print*
      output_dec='slha_decay.out'
      else
      print*, '* Decay output written to ',output_dec
      print*
      end if

c-- call to Mass calculation subroutine
      mainrun=.TRUE.
      calcmasseserror=.FALSE.

      call CalcMasses(input,output_spec)
      mainrun=.FALSE.
c-- call to Decays calculation subroutine

      if(CPcon) then
c         call BHDECAY(output_spec,output_dec)
      elseif(.not.CPcon) then    
         call BHDECAY_C(output_spec,output_dec)
      endif

      if(HHHswitch.eq.1) then
      call CALC_HHHeff(output_dec,CPcon)      
      end if  
              
      if(EDMswitch.eq.1 .OR. EDMswitch.eq.2) then
      call CALC_EDMS(output_dec)
      end if

      if(AMMswitch.eq.1 .OR. AMMswitch.eq.2) then
      call CALC_AMMS(output_dec)      
      end if 
      
      if(EWPOswitch.ge.1) then
      call WMass(output_dec)
      call NMSSMDeltaRho(output_dec,1)
      call NMSSMDeltaRho(output_dec,3)
      endif
 
c-- terminate

      end program
