c                Last modification on June 2021  by MMM
C ======================================================================
C ======================== BHDECAY_C VERSION 2.00 ======================
C ======================================================================
C ======================================================================
C === SUBROUTINE BHDECAY_C FOR COMPLEX HIGGS DECAYS WITHIN THE NMSSM ===
C ======================================================================
C  This subroutine calculates the Higgs decay widths and branching 
C  ratios within the complex NMSSM. It is part of the program package
C  NMSSMCALC. Its structure and the structure of the supplementary 
C  files is orientated along the files of the Fortran package HDECAY, 
C  which calculates the SM and MSSM Higgs boson decays and branching 
C  ratios. The program will continuously be updated to include the 
C  newest developments. 
C ======================================================================
C ======================================================================
C
C                    ********************************
C                    * Based on HDECAY version 6.10 *
C                    ********************************
C
C  This subroutine calculates the total decay widths and the branching 
C  ratios of the of the neutral and charged Higgs bosons of the 
C  Next-to-Minimal-Supersymmetric Extension of the Standard Model
C  (NMSSM) in the CP-violating case.
C
C  Notation: 
C  H1, H2, H3, H4, H5 = The neutral NMSSM Higgs bosons ordered in 
C                       ascending mass,
C                       i.e. M_H1 < M_H2 < M_H3 < M_H4 < M_H5
C  H+, H-     = charged Higgs bosons
C
C  It includes:
C
C - All the decay channels which are kinematically allowed. 
C
C - All QCD corrections to the fermionic and gluonic decay modes.
C   Most of these corrections are mapped into running masses in a
C   consistent way with some freedom for including higher order terms. 
C
C - Below-threshold three-body decays with off-shell top quarks. 
C
C - Double off-shell decays: H1,H2 --> W*W*,Z*Z* --> 4 fermions,
C   which could be important for Higgs masses close to MW or MZ.
C
C - All the decays into CHARGINOS, NEUTRALINOS, SLEPTONS 
C   and SQUARKS (with mixing in the stop and sbottom sectors). 
C
C - Chargino, slepton and squark loops in the 2 photon decays and squark
C   loops in the gluonic decays (including QCD corrections). 
C
C  ===================================================================
C  This program package has been written by J. Baglio, R. Grober, 
C  M. Muhlleitner, Dao Thi Nhung, H. Rzehak, M. Spira, J. Streicher and
C  K. Walz. For details on how to use the program package  
c  see:
C  Comput.Phys.Commun. 185 (2014) 12, 3372-3391. For any question,
C  comment, suggestion or complaint, please contact us at:
C
C                         nmssmcalc@itp.kit.edu
C
C ============================= INPUT FIlES ============================
C  The program package needs 2 input files: bhdecay.in and slha.in
C
C  The file slha.in must be in the SLHA format and inlcudes the NMSSM 
C  Higgs and SUSY particle masses and mixing angles, the soft SUSY 
C  breaking scalar masses and trilinear couplings, in particular also 
C  the NMSSM specific parameters lambda, kappa, Akappa, Alambda and 
C  mu_effective. The file is obtained by running CalcMasses.F which
C  provides the NMSSM Higgs boson masses at one-loop level in the 
C  CP-conserving and the CP-violating case. It can, however, also be 
c  created from any CP-violating NMSSM spectrum calculator providing an 
C  output file in the SLHA format.  
C
C  The homepage of the program package NMSSMCALC is given by:
C
C  http://www-itp.particle.uni-karlsruhe.de/~maggie/NMSSMCALC
C
C  The input file bhdecay.in includes the following parameters:
C
C VTB:      CKM PARAMETER |V_TB|
C VTS:      CKM PARAMETER |V_TS|
C VTD:      CKM PARAMETER |V_TD|
C VCB:      CKM PARAMETER |V_CB|
C VCS:      CKM PARAMETER |V_CS|
C VCD:      CKM PARAMETER |V_CD|
C VUB:      CKM PARAMETER |V_UB|
C VUS:      CKM PARAMETER |V_US|
C VUD:      CKM PARAMETER |V_UD|
C NNLO (M): =0: USE O(ALPHA_S) FORMULA FOR POLE MASS --> MSBAR MASS
C           =1: USE O(ALPHA_S**2) FORMULA FOR POLE MASS --> MSBAR MASS
C
C ON-SHELL: =0: INCLUDE OFF_SHELL DECAYS H_i --> T*T*, 
C               H_i --> W-*H+,Z*H_j, H+ --> W*H_i, T*B, T*S, T*D
C           =1: EXCLUDE THE OFF-SHELL DECAYS ABOVE
C
C ON-SH-WZ: =0: INCLUDE DOUBLE OFF-SHELL PAIR DECAYS PHI --> W*W*,Z*Z*
C           =-1: INCLUDE DOUBLE OFF-SHELL PAIR DECAYS PHI --> W*W*,Z*Z*
C               BELOW THRESHOLD, BUT ON-SHELL PAIR DECAYS ABOVE
C           =1: INCLUDE ONLY SINGLE OFF-SHELL DECAYS PHI --> W*W,Z*Z
C                BELOW THRESHOLD, BUT ON-SHELL PAIR DECAYS ABOVE
C
C OFF-SUSY: =0: INCLUDE DECAYS (AND LOOPS) INTO SUPERSYMMETRIC PARTICLES
C           =1: EXCLUDE DECAYS (AND LOOPS) INTO SUPERSYMMETRIC PARTICLES
C
C NF-GG:    NUMBER OF LIGHT FLAVORS INCLUDED IN THE GLUONIC DECAYS 
C            PHI --> GG* --> GQQ (3,4 OR 5)
C
C ==================================================================== c
C =============== BEGINNING OF THE MAIN SUBROUTINE =================== c
C ==================================================================== c
#include "def.h"

      subroutine BHDECAY_C(input,output)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

      character*120 input, output
      logical MHpmInput,CPcon,mQrun,phasetest,slhaswitch,difnan

      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
c      COMMON/FLAGS_HDEC/INDIDEC
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      COMMON/DAVID/QSUSY1,QSUSY2,LOOP
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      COMMON /SWITCH/MHpmInput,CPcon,mQrun,slhaswitch

      print*,''
      print*,'**********************************************************
     .***********'
      print*,' 2/ Calculation of the Higgs decay widths and branching ra
     .tios'
      print*,' in the CP-violating NMSSM.'
      print*,'**********************************************************
     .***********'

      call read_cnmssm(tgbet,input)
       
      call hdec_cnmssm(tgbet)

      call write_cnmssm(tgbet,output)

 9999  CONTINUE

!       STOP
      END

c ==================================================================== c
c ========== reads in the input files bhdecay.in and slha.in ========= c
c ==================================================================== c

      subroutine read_cnmssm(tgbet,input)
      implicit double precision (a-h,o-z)
      PARAMETER(KK=6,NI=87,ninlha=22)
c
      character*120 input
c
      double precision minval(1:20),smval(1:24),massval(1:50),
     .                 nmixval(5,5),umixval(2,2),vmixval(2,2),
     .                 stopmixval(2,2),sbotmixval(2,2),staumixval(2,2),
     .                 hmixval(1:10),gaugeval(1:3),msoftval(1:100),
     .                 auval(3,3),adval(3,3),aeval(3,3),yuval(3,3),
     .                 ydval(3,3),yeval(3,3),qvalue(1:20),extval(0:100),
     .                 m_softval(1:100),cmplxv(1:10)
      double precision imnmixval(5,5),imumixval(2,2),imvmixval(2,2),
     .                 imstopmixval(2,2),imsbotmixval(2,2),
     .                 imstaumixval(2,2),imextval(0:100),
     .                 immsoftval(1:100)
      double precision nmhmixval(5,5),slhahmix(5,5)
      double precision slhaneut(1:5),slhaxneut(1:5),slhachar(1:2),
     .                 slhaxchar(1:2),
     .                 slhau(2,2),slhav(2,2),slhaz(5,5),
     .                 slhast(2),slhasb(2),slhasu(2),slhasd(2),
     .                 slhase(2),slhasl(2),slhasn(2),slhasnl(2),
     .                 warning(1:10)
      double precision vckmval(4)
      double precision slhauim(2,2),slhavim(2,2),slhazim(5,5)
      double precision slhastmix(2,2),slhasbmix(2,2),slhastaumix(2,2),
     .                 slhastmixim(2,2),slhasbmixim(2,2),
     .                 slhastaumixim(2,2)
      integer   imod(1:2)
      integer check(1:34)
      double precision mbmsbar,mbl,mbu
      logical MHpmInput,CPcon,mQrun,phasetest,slhaswitch
      character spinfo1*100,spinfo2*100,mincom(1:20)*20,
     .          extcom(0:100)*20,softcom(1:100)*20,hmixcom(1:10)*20,
     .          m_softcom(0:100)*20,
     .          imextcom(0:100)*20,imsoftcom(1:100)*20,
     .          cmplxvcom(1:10)*20
      integer modselval(15)
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      dimension gmn(5),xmn(5),gmc(2),gmst(2),gmsb(2),gmsl(2),
     .          gmsu(2),gmsd(2),gmse(2),gmsn(2),gmsnl(2)
c-- to be checked?
      dimension ac1(2,2),ac2(2,2),ac3(2,2),ac4(2,2),ac5(2,2),
     .          an1(5,5),an2(5,5),an3(5,5),an4(5,5),an5(5,5),
     .          acnl(2,5),acnr(2,5) 
c -------------- common block given by read_leshouches -------------- c
      COMMON/SLHA_leshouches0_NMSSM/spinfo1,spinfo2,modselval
      COMMON/SLHA_leshouches1_NMSSM/extcom,mincom,softcom,hmixcom
      COMMON/SLHA_leshouches1_CNMSSM/imextcom,imsoftcom,cmplxvcom
      COMMON/SLHA_leshouches2_NMSSM/minval,extval,smval,massval,
     .                   nmixval,umixval,vmixval,stopmixval,sbotmixval,
     .                   staumixval,hmixval,gaugeval,msoftval,auval,
     .                   adval,aeval,yuval,ydval,yeval,qvalue,imod
      COMMON/SLHA_leshouches2_CNMSSM/cmplxv
      COMMON/SLHA_leshouches3_CNMSSM/nmhmixval
      COMMON/SLHA_leshouches4_CNMSSM/imextval,imnmixval,imumixval,
     .     imvmixval,imstopmixval,imsbotmixval,imstaumixval,immsoftval
      COMMON/SLHA_checkval_CNMSSM/check
      COMMON/SLHA_leshouches3_HDEC/vckmval
c -------------------------------------------------------------------- c
      COMMON/SD_scaleofewsb/scaleofewsb
c -------------- common blocks needed in HDECAY subroutines ---------- c
      COMMON/SLHA_m1_HDEC/am1
      COMMON/SLHA_gaug_CNMSSM/slhaneut,slhaxneut,slhachar,slhau,slhav,
     .                      slhaz,slhaxchar,slhauim,slhavim,slhazim
      COMMON/SLHA_sfer_CNMSSM/slhast,slhasb,slhasu,slhasd,slhase,slhasl,
     .                 slhasn,slhasnl,slhastmix,slhasbmix,slhastaumix,
     .                 slhastmixim,slhasbmixim,slhastaumixim
      COMMON/SLHA_hmass_CNMSSM/slhamh1,slhamh2,slhamh3,slhamh4,slhamh5,
     .     slhamc
      COMMON/SLHA_hmix_CNMSSM/slhahmix
      COMMON/SLHAVAL_HDEC/g1ew,g2ew
      COMMON/MASSES_HDEC/AMS,AMC,AMB,AMT
      COMMON/STRANGE_HDEC/AMSB
      COMMON/PARAM_HDEC/GF,ALPH,AMTAU,AMMUON,AMZ,AMW
      COMMON/CKMPAR_HDEC/VTB,VTS,VTD,VCB,VCS,VCD,VUB,VUS,VUD
      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
      COMMON/BREAKSCALE_HDEC/SUSYSCALE
      COMMON/BREAK_CNMSSM/AMEL,AMER,AMSQ,AMUR,AMDR,AL,AU,AD,Alambda,
     .     Akappa,AMU,AM2,ALIM,AUIM,ADIM,APHIU,XPHIGLU
      COMMON/EXTPAR_NMSSM/xlambdapar,xkappa,Alam,Akap,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      COMMON/EXTPAR_CNMSSM_IM/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      COMMON/BREAKGLU_HDEC/AMGLU
      COMMON/SFER1ST_HDEC/AMQL1,AMUR1,AMDR1,AMEL1,AMER1
      COMMON/GLUINO_CNMSSM/amgluino,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      COMMON/WZWDTH_HDEC/GAMC0,GAMT0,GAMT1,GAMW,GAMZ
      COMMON/COUP_CNMSSM/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      COMMON/ALS_HDEC/XLAMBDA,AMC0,AMB0,AMT0,N0
      COMMON/FLAG_HDEC/IHIGGS,NNLO
      COMMON/FERMIOPHOBIC_NMSSM/IFERMPHOB
      COMMON/MODEL_NMSSM/IMODEL
      COMMON/ONSHELL_NMSSM/IONSH,IONWZ,IOFSUSY
      COMMON/OLDFASH_NMSSM/NFGG
      COMMON/SMASS_NMSSM/GMN,XMN,GMC,GMST,GMSB,GMSL,GMSU,GMSD,GMSE,GMSN,
     .     GMSNL
c      COMMON/FLAGS_HDEC/INDIDEC
      COMMON/VEV_NMSSM/vewsb
c maggie changed 14/3/12
      COMMON/RUNCOUPTEST/iruncoup
c end maggie changed 14/3/12
      COMMON/M1M2VALUES_CNMSSM/am1realval,am1imval,am2realval,am2imval
c --------------- common block from CalcMasses.F --------------------- c
      COMMON /SWITCH/MHpmInput,CPcon,mQrun,slhaswitch
c NhungDao added for EWQCD correction
#include "bh_EWNMSSM.in"
      character str1*100,str2*100
c end NhungDao added
      unlikely = -123456789D0

      PI = 4*DATAN(1D0)

      OPEN(NI,FILE='bhdecay.in')

c      READ(NI,101)IHIGGS
c      READ(NI,100)ALSMZ
c      READ(NI,100)AMS
c      READ(NI,100)AMC
c      READ(NI,100)AMB
c      READ(NI,100)AMT
c      READ(NI,100)AMTAU
c      READ(NI,100)AMMUON
c      READ(NI,100)ALPH
c      READ(NI,100)GF
c      READ(NI,100)GAMW
c      READ(NI,100)GAMZ
c      READ(NI,100)AMZ
c      READ(NI,100)AMW
      READ(NI,100)VTB
      READ(NI,100)VTS
      READ(NI,100)VTD
      READ(NI,100)VCB
      READ(NI,100)VCS
      READ(NI,100)VCD
      READ(NI,100)VUB
      READ(NI,100)VUS
      READ(NI,100)VUD
      READ(NI,101)NNLO
      READ(NI,101)IONSH
      READ(NI,101)IONWZ
c      READ(NI,101)IPOLE
      READ(NI,101)IOFSUSY
c      READ(NI,101)INDIDEC
      READ(NI,101)NFGG
c NhungDao added for two-loop corrections to the Higgs trilinear couplings
      READ(NI,10)str2
c decay of neutral Higgs bosons
      READ(NI,101)iewh
c      print*, "iewh",iewh
      islhai = 1
      islhao = 1

      ihiggs = 7
      gamw = 2.08856D0
      gamz = 2.49581D0
      alph = 137.0359997D0

c      cw2calc = amw**2/amz**2
c      sw2calc = 1-cw2calc
c      cwcalc  = dsqrt(cw2calc)
c      swcalc  = dsqrt(sw2calc)
c      vewsb = 1.D0/dsqrt(dsqrt(2.D0)*gf)
c      g2ew = 2*amw/vewsb
c      g1ew = g2ew*swcalc/cwcalc

      if(ihiggs.eq.0) then
         print*,'Attention: You have set ihiggs=0. If you want to calcul
     .ate NMSSM Higgs boson decays you have to set ihiggs to a value bet
     .ween 1 and 7.'
      end if

c -- initialization of the check array --
      do i1=1,34,1
         check(i1) = 0
      end do

      open(ninlha,file=input)
      call SLHA_read_leshouches_NMSSM(ninlha)
      close(ninlha)

c -- G_F --
         if(smval(2).ne.0.D0) then
            GF = smval(2)
         else
            print*,'Attention the value for G_F is not set. It has to be
     . given.'
         endif
c -- the strong coupling constant alphas_MSbar at the scale MZ --
         if(smval(3).ne.0.D0) then
            alsmz = smval(3)
         else
            print*,'Attention the value for alphas_MSbar at the scale MZ
     . is not set. It has to be given.'
         endif
         alphasmzms = alsmz
c -- Z pole mass --
         if(smval(4).ne.0.D0) then
            AMZ = smval(4)
         else
            print*,'Attention the value for MZ is not set. It has to be 
     .given.'
         endif
c -- W pole mass --
         if(massval(1).ne.0.D0) then
            AMW = massval(1)
         else
            print*,'Attention the value for MW is not set. It has to be 
     .given.'
         endif

c -- the weak mixing angle -- 
      cw2calc = amw**2/amz**2
      sw2calc = 1-cw2calc
      cwcalc  = dsqrt(cw2calc)
      swcalc  = dsqrt(sw2calc)
      vewsb = 1.D0/dsqrt(dsqrt(2.D0)*gf)
      g2ew = 2*amw/vewsb
      g1ew = g2ew*swcalc/cwcalc

c -- the MSbar couplings g1,g2 at the scale Q --
         if(gaugeval(1).ne.0.D0) then
            g1ew  = gaugeval(1)
         endif
         if(gaugeval(2).ne.0.D0) then
            g2ew  = gaugeval(2)*(1-gaugeval(2)**2/96/pi**2*2)
         endif

c         cw2calc = amw**2/amz**2
c         sw2calc = 1-cw2calc
c         cwcalc  = dsqrt(cw2calc)
c         swcalc  = dsqrt(sw2calc)
c -- in case the gauge couplings are not given at the scale Q --
         if(gaugeval(1).eq.0.D0.or.gaugeval(2).eq.0.D0) then
c -- v at the scale Q --         
          if(smval(2).eq.0.D0.and.hmixval(3).ne.unlikely) then
           vewsb = hmixval(3)
           gf = 1/dsqrt(2.D0)/vewsb**2
          else
           vewsb = 1.D0/dsqrt(dsqrt(2.D0)*gf)
          endif
          g2ew = 2*amw/vewsb
          g1ew = g2ew*swcalc/cwcalc
         endif
c -- the scale Q at which the couplings are given --
         if(extval(0).ne.unlikely.and.extval(0).ne.-1.D0) then
            scaleofewsb = extval(0)
            ewsbscale = scaleofewsb
         else
            qvalsum = 0.D0
            isum    = 0
            do i=1,20,1
               qvalsum = qvalsum + qvalue(i)
               if(qvalue(i).ne.0.D0) then
                  isum = isum + 1
               endif
            end do

            if(isum.ne.0) then
               scaleofewsb = qvalsum/dble(isum)
            else
               warning(1) = 1.D0
               print*,'The scaleofewsb and hence also susyscale are not 
     .given.'
            endif
            ewsbscale   = scaleofewsb
         endif
         SUSYSCALE = scaleofewsb

c -- CKM mixing matrix --

      if(vckmval(1).ne.unlikely) then
         vus = vckmval(1)
         vud = 1.D0 - vckmval(1)**2/2.D0
         vcd = dabs(vckmval(1))
         vcs = 1.D0 - vckmval(1)**2/2.D0
         if(vckmval(2).ne.unlikely) then
            vcb = vckmval(1)**2*vckmval(2)
            vts = vckmval(1)**2*vckmval(2)
            if(vckmval(3).ne.unlikely.and.vckmval(4).ne.unlikely) then
               vub = vckmval(1)**3*vckmval(2)*
     .              dsqrt(vckmval(3)**2+vckmval(4)**2)
               vtd = vckmval(1)**3*vckmval(2)*
     .              dsqrt((1.D0-vckmval(3))**2+vckmval(4)**2) 
               vtb = dsqrt(1.D0-vts**2-vtd**2)
            endif
         endif
         rvub= vub/vcb
      endif

c -- neutralino and chargino masses --

         slhaneut(1) =dabs(massval(28))
         slhaneut(2) =dabs(massval(29))
         slhaneut(3) =dabs(massval(30))
         slhaneut(4) =dabs(massval(31))
         slhaneut(5) =dabs(massval(36))
         slhaxneut(1)=massval(28)
         slhaxneut(2)=massval(29)
         slhaxneut(3)=massval(30)
         slhaxneut(4)=massval(31)
         slhaxneut(5)=massval(36)
         slhachar(1) =dabs(massval(32))
         slhachar(2) =dabs(massval(33))
         slhaxchar(1) =massval(32)
         slhaxchar(2) =massval(33)

c -- the chargino and neutralino mixing matrix elements --
      do i=1,2,1
         do j=1,2,1
            slhau(i,j)=umixval(i,j)
            slhauim(i,j)=imumixval(i,j)
            slhav(i,j)=vmixval(i,j)
            slhavim(i,j)=imvmixval(i,j)
         end do
      end do
      do i=1,5,1
         do j=1,5,1
            slhaz(i,j)=nmixval(i,j)
            slhazim(i,j)=imnmixval(i,j)
         end do
      end do

c -- sfermion masses --

      slhast(1) = massval(16)
      slhast(2) = massval(17)
      slhasb(1) = massval(14)
      slhasb(2) = massval(15)

      slhasu(1) = massval(8)
      slhasu(2) = massval(9)
      slhasd(1) = massval(10)
      slhasd(2) = massval(11)

      slhase(1) = massval(18)
      slhase(2) = massval(19)
      slhasl(1) = massval(24)
      slhasl(2) = massval(25)

      slhasn(1) = massval(20)
      slhasn(2) = 1.D15
      slhasnl(1) = massval(26)
      slhasnl(2) = 1.D15

c -- the sfermions mixing matrices --
      do i=1,2
         do j=1,2
            slhastmix(i,j)=stopmixval(i,j)
            slhastmixim(i,j)=imstopmixval(i,j)
            slhasbmix(i,j)=sbotmixval(i,j)
            slhasbmixim(i,j)=imsbotmixval(i,j)
            slhastaumix(i,j)=staumixval(i,j)
            slhastaumixim(i,j)=imstaumixval(i,j)
         enddo
      enddo

c -- the gluino mass --

      if(massval(27).ne.0.D0) then
         amgluino = massval(27)
      else
         amgluino = dsqrt(msoftval(3)**2*immsoftval(3)**2)
      endif

      if(imextval(3).ne.0.d0) then
         if(extval(3).ne.0.d0) then
            xphiglu = datan(imextval(3)/extval(3))
         else
            print*,"contradiction between RE(M3) and IM(M3) value"
            stop
         endif
      endif

c -- the NMSSM Higgs masses --

      slhamh1 = massval(2)
      slhamh2 = massval(34)
      slhamh3 = massval(3)
      slhamc  = massval(5)

      slhamh4 = massval(35)
      if(massval(4).ne.0.D0) then
         slhamh5 = massval(4)
      elseif(extval(26).ne.unlikely) then
         slhamh5 = extval(26)
      elseif(extval(24).ne.unlikely) then
         slhamh5 = dsqrt(extval(24))
      endif

      amh1 = slhamh1
      amh2 = slhamh2
      amh3 = slhamh3
      amch = slhamc
      amh4 = slhamh4
      amh5 = slhamh5

c -- DRbar value of tanbeta at the scale Q --

      if(hmixval(2).ne.unlikely) then
         TGBET = hmixval(2)
      else
         tgbet = extval(25)
      endif
      b = datan(tgbet)

c -- the NMSSM Higgs mixing matrix elements --
      do i=1,5,1
         do j=1,5,1
            slhahmix(i,j)=nmhmixval(i,j)
         end do
      end do

      do i=1,5,1
         cpevodd=slhahmix(i,1)**2+slhahmix(i,2)**2+slhahmix(i,3)**2
      end do

c -- the fermion pole masses --

      if(smval(6).ne.0.D0) then
         AMT = smval(6)
         else
            print*,'Attention the value for mt is not set. It has to be 
     .given.'
      endif
      if(smval(24).ne.0.D0) then
         AMC = smval(24)
         else
            print*,'Attention the value for mc is not set. It has to be 
     .given.'
      endif
      if(smval(7).ne.0.D0) then
         AMTAU = smval(7)
         else
            print*,'Attention the value for mtau is not set. It has to b
     .e given.'
      endif
      if(smval(23).ne.0.D0) then
         AMS = smval(23)
         else
            print*,'Attention the value for ms is not set. It has to be 
     .given.'
      endif
      if(smval(13).ne.0.D0) then
         AMMUON = smval(13)
         else
            print*,'Attention the value for mmuon is not set. It has to 
     . be given.'
      endif

c -- the mass mb(mb)_MSbar --
      if(smval(5).ne.0.D0) then
         mbmsbar = smval(5)
      else
         print*,'Attention the value for mbMSbar(mb) is not set. It has 
     .to be given.'
      endif

      fmt = amt
      fmtau = amtau
      fms = ams
      fmc = amc
c -- calculation of the mb pole mass from mb(mb)_MSbar --
      if(smval(5).ne.0.D0) then
       del = 1.d-10
       mbl = mbmsbar
       mbu = 2*mbmsbar
       fmb = (mbl+mbu)/2
       amsb = ams
       amc0=amc
       amt0=amt
       acc=1.d-8
       nloop=3
11     amb=fmb
       amb0=amb
       xlambda=xitla_hdec(nloop,alsmz,acc)
       n0=5
       call alsini_hdec(acc)
c      xmb = runm_hdec(fmb,5)
       xmb = runm_hdec(mbmsbar,5)
       if(xmb.eq.mbmsbar)then
        mbl = fmb
        mbu = fmb
       elseif(xmb.gt.mbmsbar)then
        mbu = fmb
       else
        mbl = fmb
       endif
       fmb = (mbl+mbu)/2
       if(dabs(xmb/mbmsbar-1).gt.del) goto 11
      endif
      amb = fmb


c      print*,'amw,amz,gamw,gamz,ihiggs',amw,amz,gamw,gamz,ihiggs
c      print*,'alsmz',alsmz
c      print*,'s,c,b,t,tau,mu',ams,amc,amb,amt,amtau,ammuon
c      print*,'alph,gf',alph,Gf

c -- If no DRbar value at the scale Q has been given for tanbeta --

      if(hmixval(2).eq.unlikely) then
         if(extval(25).ne.0.D0.and.extval(25).ne.unlikely) then
            TGBET = extval(25)
         elseif(minval(3).ne.0.D0.and.minval(3).ne.unlikely) then
            TGBET = minval(3)
         endif
      endif

c -- The soft SUSY breaking parameters: DRbar values at the scale Q --

      do i=1,100,1
         m_softval(i) = unlikely
      end do

      do i=1,99,1
         if(msoftval(i).ne.unlikely) then
            m_softval(i) = msoftval(i)
            m_softcom(i) = softcom(i)
         elseif(extval(i).ne.unlikely) then
            m_softval(i) = extval(i)
            m_softcom(i) = extcom(i)
         endif
      end do

      if(auval(3,3).ne.unlikely) then
         AU=auval(3,3)
      elseif(extval(11).ne.unlikely) then
         AU=extval(11)
         AUIM=imextval(11)
      else
         print*,'Attention: A_top has not been given.'
      endif
      if(adval(3,3).ne.unlikely) then
         AD=adval(3,3)
      elseif(extval(12).ne.unlikely) then
         AD=extval(12)
         ADIM=imextval(12)
      else
         print*,'Attention: A_bottom has not been given.'
      endif
      if(aeval(3,3).ne.unlikely) then
         AL=aeval(3,3)
      elseif(extval(13).ne.unlikely) then
         AL=extval(13)
         ALIM=imextval(13)
      else
         print*,'Attention: A_tau has not been given.'
      endif

c The NMSSM parameters at the scale Q = M_input

      if(extval(61).ne.unlikely) then
         xlambdapar = extval(61)
      endif
      if(imextval(61).ne.unlikely) then
         xlambdaparim = imextval(61)
      endif
      if(extval(62).ne.unlikely) then
         xkappa = extval(62)
      endif
      if(imextval(62).ne.unlikely) then
         xkappaim = imextval(62)
      endif
      if(extval(63).ne.unlikely) then
         Alam = extval(63)
      endif
      if(imextval(63).ne.unlikely) then
         Alamim = imextval(63)
      endif
      if(extval(64).ne.unlikely) then
         Akap = extval(64)
      endif
      if(imextval(64).ne.unlikely) then
         Akapim = imextval(64)
      endif
      if(extval(65).ne.unlikely) then
         xlamvs = extval(65)
      endif
      if(imextval(65).ne.unlikely) then
         xlamvsim = imextval(65)
      endif
      if(extval(66).ne.unlikely) then
         xif = extval(66)
      endif
      if(imextval(66).ne.unlikely) then
         xifim = imextval(66)
      endif
      if(extval(67).ne.unlikely) then
         xis = extval(67)
      endif
      if(imextval(67).ne.unlikely) then
         xisim = imextval(67)
      endif
      if(extval(68).ne.unlikely) then
         xmuprime = extval(68)
      endif
      if(imextval(68).ne.unlikely) then
         xmuprimeim = imextval(68)
      endif
      if(extval(69).ne.unlikely) then
         amsph2 = extval(69)
      endif
      if(imextval(69).ne.unlikely) then
         amsph2im = imextval(69)
      endif
      if(extval(70).ne.unlikely) then
         amsh2 = extval(70)
      endif
      if(imextval(70).ne.unlikely) then
         amsh2im = imextval(70)
      endif
      if(cmplxv(3).ne.unlikely) then
         xphiu = cmplxv(3)
      endif

      Alambda = Alam
      Akappa = Akap
      aphiu = xphiu

      amu = xlamvs

c The soft SUSY breaking parameters M1, M2 in the MS_bar scheme 
      am1msbar = m_softval(1)
     .     *(1.D0+g1ew**2/16.D0/pi**2*0.D0)
      am2msbar = m_softval(2)
     .     *(1.D0+g2ew**2/16.D0/pi**2*2.D0)

      if(am1msbar.ne.0.d0) then 
         am1 = am1msbar
      else
         print*,'Problem: M1 not given.'
      endif
     
      if(am2msbar.ne.0.d0) then
         AM2 = am2msbar
      else
         print*,'Problem: M2 not given.'
      endif

      am1realval = msoftval(1)
      am1imval   = immsoftval(1)
      am2realval = msoftval(2)
      am2imval   = immsoftval(2)

      if(m_softval(31).ne.unlikely.and.m_softval(32).ne.unlikely) then
         if(m_softval(31).ne.0.D0.and.m_softval(32).ne.0.D0) then
            AMEL1 = (m_softval(31)+m_softval(32))/2.D0
         elseif(m_softval(31).ne.0.D0) then
            AMEL1 = m_softval(31)
         elseif(m_softval(32).ne.0.D0) then
            AMEL1 = m_softval(32)
         else
            AMEL1 = 0.D0
         endif
      elseif(m_softval(31).ne.unlikely) then
         AMEL1 = m_softval(31)
      elseif(m_softval(32).ne.unlikely) then
         AMEL1 = m_softval(32)
      endif

      if(m_softval(34).ne.unlikely.and.m_softval(35).ne.unlikely) then
         if(m_softval(34).ne.0.D0.and.m_softval(35).ne.0.D0) then
            AMER1 = (m_softval(34)+m_softval(35))/2.D0
         elseif(m_softval(34).ne.0.D0) then
            AMER1 = m_softval(34)
         elseif(m_softval(35).ne.0.D0) then
            AMER1 = m_softval(35)
         else
            AMER1 = 0.D0
         endif
      elseif(m_softval(34).ne.unlikely) then
         AMER1 = m_softval(34)
      elseif(m_softval(35).ne.unlikely) then
         AMER1 = m_softval(35)
      endif

      if(m_softval(41).ne.unlikely.and.m_softval(42).ne.unlikely) then
         if(m_softval(41).ne.0.D0.and.m_softval(42).ne.0.D0) then
            AMQL1 = (m_softval(41)+m_softval(42))/2.D0
         elseif(m_softval(41).ne.0.D0) then
            AMQL1 = m_softval(41)
         elseif(m_softval(42).ne.0.D0) then
            AMQL1 = m_softval(42)
         else
            AMQL1 = 0.D0
         endif
      elseif(m_softval(41).ne.unlikely) then
         AMQL1 = m_softval(41)
      elseif(m_softval(42).ne.unlikely) then
         AMQL1 = m_softval(42)
      endif

      if(m_softval(44).ne.unlikely.and.m_softval(45).ne.unlikely) then
         if(m_softval(44).ne.0.D0.and.m_softval(45).ne.0.D0) then
            AMUR1 = (m_softval(44)+m_softval(45))/2.D0
         elseif(m_softval(44).ne.0.D0) then
            AMUR1 = m_softval(44)
         elseif(m_softval(45).ne.0.D0) then
            AMUR1 = m_softval(45)
         else
            AMUR1 = 0.D0
         endif
      elseif(m_softval(44).ne.unlikely) then
         AMUR1 = m_softval(44)
      elseif(m_softval(45).ne.unlikely) then
         AMUR1 = m_softval(45)
      endif

      if(m_softval(47).ne.unlikely.and.m_softval(48).ne.unlikely) then
         if(m_softval(47).ne.0.D0.and.m_softval(48).ne.0.D0) then
            AMDR1 = (m_softval(47)+m_softval(48))/2.D0
         elseif(m_softval(47).ne.0.D0) then
            AMDR1 = m_softval(47)
         elseif(m_softval(48).ne.0.D0) then
            AMDR1 = m_softval(48)
         else
            AMDR1 = 0.D0
         endif
      elseif(m_softval(47).ne.unlikely) then
         AMDR1 = m_softval(47)
      elseif(m_softval(48).ne.unlikely) then
         AMDR1 = m_softval(48)
      endif

      if(m_softval(33).ne.unlikely) then
         AMEL = m_softval(33)
      endif
      if(m_softval(36).ne.unlikely) then
         AMER = m_softval(36)
      endif
      if(m_softval(43).ne.unlikely) then
         AMSQ = m_softval(43)
      endif
      if(m_softval(46).ne.unlikely) then
         AMUR = m_softval(46)
      endif
      if(m_softval(49).ne.unlikely) then
         AMDR = m_softval(49)
      endif

c --- further parameter settings --- c

      b = datan(tgbet)
      amglu = amgluino

      if(rvub.ne.0.D0) then
         vub=rvub*vcb
      endif
      alph=1.d0/alph
      amsb = ams

      amc0=amc
      amb0=amb
      amt0=amt
      acc=1.d-8
      nloop=3
      xlambda=xitla_hdec(nloop,alsmz,acc)
      n0=5

      CALL ALSINI_HDEC(ACC)
C--DECOUPLING THE TOP QUARK FROM ALPHAS
      AMT0=3.D8

C--INITIALIZE COEFFICIENTS FOR POLYLOGARITHMS
      NBER = 18
      CALL BERNINI_HDEC(NBER)

C--CHECK NFGG
      IF(NFGG.GT.5.OR.NFGG.LT.3)THEN
       WRITE(6,*)'NF-GG NOT VALID. TAKING THE DEFAULT NF-GG = 3....'
       NFGG = 3
      ENDIF


100   FORMAT(10X,G30.20)
c NhungDao changed here
101   FORMAT(10X,I10)
c end NhungDao changed
7     FORMAT(A11,I7)
8     FORMAT(A11,I4)
9     FORMAT(A11,G15.8)
c MMM changed 25/7/19
10    FORMAT(A200)
c end MMM changed 25/7/19
      CLOSE(NI)

      RETURN

      END

c ==================================================================== c
c ==== writes out all important parameters, the NMSSM Higgs decay ==== c
c ==== widths and branching ratios in the SLHA format ================ c
c ==================================================================== c

      subroutine write_cnmssm(tgbet,output)
      implicit double precision (a-h,o-z)
      parameter (nout=44,nout2=45)
      dimension gmn(5),xmn(5),gmc(2),gmst(2),gmsb(2),gmsl(2),
     .          gmsu(2),gmsd(2),gmse(2),gmsn(2),gmsnl(2)
      dimension h1brsc(2,2),h1brsn(5,5),h2brsc(2,2),h2brsn(5,5),
     .     h3brsc(2,2),h3brsn(5,5),h4brsc(2,2),h4brsn(5,5),
     .     h5brsc(2,2),h5brsn(5,5),h2brst(2,2),
     .     h2brsb(2,2),h3brst(2,2),h3brsb(2,2)
      dimension hcbrsuc(2,5),hcbrstbc(2,2)
      dimension ac1(2,2),ac2(2,2),ac3(2,2),ac4(2,2),ac5(2,2),
     .          an1(5,5),an2(5,5),an3(5,5),an4(5,5),an5(5,5),
     .          acnl(2,5),acnr(2,5)
      dimension h1brsn1(5,5),h2brsn1(5,5),h3brsn1(5,5),h4brsn1(5,5),
     .     h5brsn1(5,5)
      character*120 output
      double precision nmhmixval(5,5),slhahmix(5,5)
      double precision minval(1:20),smval(1:24),massval(1:50),
     .                 nmixval(5,5),umixval(2,2),vmixval(2,2),
     .                 stopmixval(2,2),sbotmixval(2,2),staumixval(2,2),
     .                 hmixval(1:10),gaugeval(1:3),msoftval(1:100),
     .                 auval(3,3),adval(3,3),aeval(3,3),yuval(3,3),
     .                 ydval(3,3),yeval(3,3),qvalue(1:20),extval(0:100),
     .                 m_softval(1:100),cmplxv(1:10)
      double precision imnmixval(5,5),imumixval(2,2),imvmixval(2,2),
     .                 imstopmixval(2,2),imsbotmixval(2,2),
     .                 imstaumixval(2,2),imextval(0:100),
     .                 immsoftval(1:100)
      double precision slhaneut(1:5),slhaxneut(1:5),slhachar(1:2),
     .                 slhaxchar(1:2),
     .                 slhau(2,2),slhav(2,2),slhaz(5,5),
     .                 slhast(2),slhasb(2),slhasu(2),slhasd(2),
     .                 slhase(2),slhasl(2),slhasn(2),slhasnl(2),
     .                 warning(1:10)
      double precision slhauim(2,2),slhavim(2,2),slhazim(5,5)
      double precision slhastmix(2,2),slhasbmix(2,2),slhastaumix(2,2),
     .                 slhastmixim(2,2),slhasbmixim(2,2),
     .                 slhastaumixim(2,2)    
      double precision vckmval(4)  
      integer   imod(1:2)
      integer check(1:34)
      double precision mbmsbar,mbl,mbu
      character spinfo1*100,spinfo2*100,mincom(1:20)*20,
     .          extcom(0:100)*20,softcom(1:100)*20,hmixcom(1:10)*20,
     .          m_softcom(1:100)*20,
     .          imextcom(0:100)*20,imsoftcom(1:100)*20,
     .          cmplxvcom(1:10)*20
      integer modselval(15)
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      double precision whitotc(5)
      double precision brhigggc(5),brhigmmc(5),brhigllc(5),brhigssc(5),
     .     brhigccc(5),brhigbbc(5),brhigttc(5),brhiggac(5),brhigzgac(5),
     .     brhigwwc(5),brhigzzc(5),brhigtohpwmc(5)
      double precision brhitohjhkc(5,5,5),brhitohjzc(5,5),
     .     brwhigchc(5,2,2),brwhignec(5,5,5),brwhigchtc(5),
     .     brwhignetc(5),brwhigsltc(5),brwhigsqc(5),brwhigsqtc(5),
     .     brwhigslnlc(5),brwhigslnltauc(5),brwhigslelc(5),
     .     brwhigslerc(5),brwhigsqulc(5),brwhigsqurc(5),brwhigsqdlc(5),
     .     brwhigsqdrc(5),brwhigstc(5,2,2),brwhigsbc(5,2,2),
     .     brwhigstauc(5,2,2)
      double precision cj(5)
      double precision ghit(5),ghib(5),gait(5),gaib(5),ghivv(5),
     .                 ghihpwm(5),gaihpwm(5),gzhihj(5,5),ghihjhk(5,5,5),
     .                 ghipm(5)
      COMMON/MASSES_HDEC/AMS,AMC,AMB,AMT
      COMMON/STRANGE_HDEC/AMSB
      COMMON/PARAM_HDEC/GF,ALPH,AMTAU,AMMUON,AMZ,AMW
      COMMON/CKMPAR_HDEC/VTB,VTS,VTD,VCB,VCS,VCD,VUB,VUS,VUD
      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
      COMMON/BREAK_CNMSSM/AMEL,AMER,AMSQ,AMUR,AMDR,AL,AU,AD,Alam,Akap,
     .     AMU,AM2,ALIM,AUIM,ADIM,APHIU,XPHIGLU
      COMMON/BREAKGLU_HDEC/AMGLU
      COMMON/SFER1ST_HDEC/AMQL1,AMUR1,AMDR1,AMEL1,AMER1
      COMMON/GLUINO_CNMSSM/amgluino,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      COMMON/WZWDTH_HDEC/GAMC0,GAMT0,GAMT1,GAMW,GAMZ
      COMMON/COUP_CNMSSM/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      COMMON/ALS_HDEC/XLAMBDA,AMC0,AMB0,AMT0,N0
      COMMON/FLAG_HDEC/IHIGGS,NNLO
      COMMON/MODEL_NMSSM/IMODEL
      COMMON/ONSHELL_NMSSM/IONSH,IONWZ,IOFSUSY
      COMMON/OLDFASH_NMSSM/NFGG
      COMMON/WIDTHH1_CNMSSM/H1BRB,H1BRL,H1BRM,H1BRS,H1BRC,H1BRT,H1BRG,
     .     H1BRGA,H1BRZGA,H1BRW,H1BRZ,H1BRHW,H1WDTH
      COMMON/WIDTHH2_CNMSSM/H2BRB,H2BRL,H2BRM,H2BRS,H2BRC,H2BRT,H2BRG,
     .     H2BRGA,H2BRZGA,H2BRW,H2BRZ,H2BRH1H1,H2BRH1Z,H2BRHW,H2WDTH
      COMMON/WIDTHH3_CNMSSM/H3BRB,H3BRL,H3BRM,H3BRS,H3BRC,H3BRT,H3BRG,
     .     H3BRGA,H3BRZGA,H3BRW,H3BRZ,H3BRH1H1,H3BRH1H2,H3BRH2H2,
     .     H3BRH1Z,H3BRH2Z,H3BRHW,H3WDTH
      COMMON/WIDTHH4_CNMSSM/H4BRB,H4BRL,H4BRM,H4BRS,H4BRC,H4BRT,H4BRG,
     .     H4BRGA,H4BRZGA,H4BRW,H4BRZ,H4BRH1H1,H4BRH1H2,H4BRH1H3,
     .     H4BRH2H2,H4BRH2H3,H4BRH3H3,H4BRH1Z,H4BRH2Z,H4BRH3Z,
     .     H4BRHW,H4WDTH
      COMMON/WIDTHH5_CNMSSM/H5BRB,H5BRL,H5BRM,H5BRS,H5BRC,H5BRT,H5BRG,
     .     H5BRGA,H5BRZGA,H5BRW,H5BRZ,H5BRH1H1,H5BRH1H2,H5BRH1H3,
     .     H5BRH1H4,H5BRH2H2,H5BRH2H3,H5BRH2H4,H5BRH3H3,H5BRH3H4,
     .     H5BRH4H4,H5BRH1Z,H5BRH2Z,H5BRH3Z,H5BRH4Z,H5BRHW,H5WDTH
      COMMON/WIDTHHI_CNMSSM/BRHIGBBC,BRHIGLLC,BRHIGMMC,BRHIGSSC,
     .     BRHIGCCC,BRHIGTTC,BRHIGGGC,BRHIGGAC,BRHIGZGAC,BRHIGWWC,
     .     BRHIGZZC,BRHIGTOHPWMC,BRHITOHJHKC,BRHITOHJZC,WHITOTC
      COMMON/WISUSYHI_CNMSSM/BRWHIGCHC,BRWHIGNEC,BRWHIGSLNLC,
     .     BRWHIGSLNLTAUC,BRWHIGSLELC,BRWHIGSLERC,BRWHIGSQULC,
     .     BRWHIGSQURC,BRWHIGSQDLC,BRWHIGSQDRC,BRWHIGSTC,BRWHIGSBC,
     .     BRWHIGSTAUC
      COMMON/WIDTHHC_CNMSSM/HCBRBC,HCBRLC,HCBRMC,HCBRBUC,HCBRSC,HCBRCC,
     .     HCBRTC,HCBRWH1C,HCBRWH2C,HCBRWH3C,HCBRWH4C,HCBRWH5C,HCBRDC,
     .     HCBRDTC,HCBRSTC,HCWDTHC
      COMMON/WISUSYHC_CNMSSM/HCBRSUC,HCBRCNTC,HCBRSLC,HCBRSQC,HCBRSTBC,
     .     HCBRSQTC
      COMMON/WISFERHC_CNMSSM/BHCSL00C,BHCSL11C,BHCSL21C,BHCSQC
      COMMON/WISUSY_CNMSSM/H1BRSC,H1BRSN,H2BRSC,H2BRSN,H3BRSC,H3BRSN,
     .     H4BRSC,H4BRSN,H5BRSC,H5BRSN,HCBRSU,H1BRCHT,H2BRCHT,
     .     H3BRCHT,H4BRCHT,H5BRCHT,H1BRNET,H2BRNET,H3BRNET,H4BRNET,
     .     H5BRNET,HCBRCNT,H1BRSL,H2BRSL,H3BRSL,H4BRSL,H5BRSL,HCBRSL,
     .     H2BRSQ,H2BRST,H2BRSB,H2BRSQT,H3BRSQ,H3BRST,H3BRSB,H3BRSQT,
     .     HCBRSQ,H1BRSQ,H1BRSQT
      COMMON/WISFER_CNMSSM/BH1SLNL,BH1SLEL,BH1SLER,BH1SQUL,BH1SQUR,
     .     BH1SQDL,BH1SQDR,BH1ST(2,2),BH1SB(2,2),BH1STAU(2,2),BH2SLNL,
     .     BH2SLEL,BH2SLER,BH2SQUL,BH2SQUR,BH2SQDL,BH2SQDR,BH2ST(2,2),
     .     BH2SB(2,2),BH2STAU(2,2),BH3SLNL,BH3SLEL,BH3SLER,BH3SQUL,
     .     BH3SQUR,BH3SQDL,BH3SQDR,BH3ST(2,2),BH3SB(2,2),BH3STAU(2,2),
     .     BH4SLNL,BH4SLEL,BH4SLER,BH4SQUL,BH4SQUR,BH4SQDL,BH4SQDR,
     .     BH4ST(2,2),BH4SB(2,2),BH4STAU(2,2),BH5SLNL,BH5SLEL,BH5SLER,
     .     BH5SQUL,BH5SQUR,BH5SQDL,BH5SQDR,BH5ST(2,2),BH5SB(2,2),
     .     BH5STAU(2,2),
     .     BH1SLNLTAU,BH2SLNLTAU,BH3SLNLTAU,BH4SLNLTAU,BH5SLNLTAU
      COMMON/SMASS_NMSSM/GMN,XMN,GMC,GMST,GMSB,GMSL,GMSU,GMSD,GMSE,
     .     GMSN,GMSNL
c      COMMON/FLAGS_HDEC/INDIDEC
c -------------- common block given by read_leshouches -------------- c
      COMMON/SLHA_leshouches0_NMSSM/spinfo1,spinfo2,modselval
      COMMON/SLHA_leshouches1_NMSSM/extcom,mincom,softcom,hmixcom
      COMMON/SLHA_leshouches1_CNMSSM/imextcom,imsoftcom,cmplxvcom
      COMMON/SLHA_leshouches2_NMSSM/minval,extval,smval,massval,
     .                   nmixval,umixval,vmixval,stopmixval,sbotmixval,
     .                   staumixval,hmixval,gaugeval,msoftval,auval,
     .                   adval,aeval,yuval,ydval,yeval,qvalue,imod
      COMMON/SLHA_leshouches2_CNMSSM/cmplxv
      COMMON/SLHA_leshouches3_CNMSSM/nmhmixval
      COMMON/SLHA_leshouches4_CNMSSM/imextval,imnmixval,imumixval,
     .     imvmixval,imstopmixval,imsbotmixval,imstaumixval,immsoftval
      COMMON/SLHA_checkval_CNMSSM/check
      COMMON/SLHA_leshouches3_HDEC/vckmval
c -------------------------------------------------------------------- c
      COMMON/SD_scaleofewsb/scaleofewsb
c -------------- common blocks needed in HDECAY subroutines ---------- c
      COMMON/SLHA_m1_HDEC/am1
      COMMON/SLHA_gaug_CNMSSM/slhaneut,slhaxneut,slhachar,slhau,slhav,
     .                      slhaz,slhaxchar,slhauim,slhavim,slhazim
      COMMON/SLHA_sfer_CNMSSM/slhast,slhasb,slhasu,slhasd,slhase,slhasl,
     .                 slhasn,slhasnl,slhastmix,slhasbmix,slhastaumix,
     .                 slhastmixim,slhasbmixim,slhastaumixim
      COMMON/SLHA_hmass_CNMSSM/slhamh1,slhamh2,slhamh3,slhamh4,slhamh5,
     .     slhamc
      COMMON/GAUGINOMIX_CNMSSM/ZZ(5,5),UU(2,2),VV(2,2),ZZIM(5,5),
     .     UUIM(2,2),VVIM(2,2)
      COMMON/SLHAVAL_HDEC/g1ew,g2ew
      COMMON/M1M2VALUES_CNMSSM/am1realval,am1imval,am2realval,am2imval
      COMMON/GLUONCOUP/cj
      COMMON/SHORTCOUPL2_CNMSSM/ghit,ghib,gait,gaib,ghivv,ghihpwm,
     .     gaihpwm,gzhihj,ghihjhk,ghipm
      integer idH(5)
#include "bh_EWNMSSM.in"
      PI = 4*DATAN(1D0)

      open(nout,file=output)

      id =1
      idb=-1
      iu =2
      iub=-2
      is =3
      isb=-3
      ic =4
      icb=-4
      ib =5
      ibb=-5
      it =6
      itb=-6
      
      ie   =11
      ine  =12
      imu  =13
      inmu =14
      itau =15
      intau=16
      
      ih1=25
      ih2=35
      ih3=36
      ih4=45
      ih5=46
      ihc=37
      igl=21
      iga=22
      iz =23
      iwc=24
      
      isdl=1000001
      isdr=2000001
      isul=1000002
      isur=2000002
      issl=1000003
      issr=2000003
      iscl=1000004
      iscr=2000004
      isb1=1000005
      isb2=2000005
      ist1=1000006
      ist2=2000006
      
      iglo=1000021
      in1 =1000022
      in2 =1000023
      in3 =1000025
      in4 =1000035
      in5 =1000045
      ic1 =1000024
      ic2 =1000037
      
      intau1=1000016 
      intau2=2000016 
      inel  =1000012
      iner  =2000012
      inmul =1000014
      inmur =2000014
      
      isell =1000011
      iselr =2000011
      ismul =1000013
      ismur =2000013
      istau1=1000015
      istau2=2000015
      
c ----------------------------------- c
c Information about the program       c
c ----------------------------------- c

      write(nout,105)
      write(nout,51) 'PRINFO','Program information'
      write(nout,61) 1,'NMSSMCALC  # program name'
      write(nout,61) 2,'5.2        # version number'  
          
c ----------------------------------- c
c Information about the decay program c
c ----------------------------------- c

      write(nout,105)
      write(nout,51) 'DCINFO','Decay Program information'
      write(nout,61) 1,'BHDECAY_C  # decay calculator'
      write(nout,61) 2,'2.00       # version number'

c ----------------------------------------------------------------- c
c The program information: Which spectrum calculator has been used. c
c ----------------------------------------------------------------- c

      if(check(22).eq.1) then
         write(nout,105)
         write(nout,51) 'SPINFO','Spectrum calculator information'
         write(nout,61) 1,spinfo1(1:50)
         write(nout,61) 2,spinfo2(1:50)
      endif

c ------------------------------------------------ c
c Information on the model which has been selected c
c ------------------------------------------------ c

      write(nout,105)
      write(nout,51) 'MODSEL','Model selection'
      write(nout,62) 3,1,'# complex NMSSM'
      write(nout,62) 5,2,'# CP-violating'
      write(nout,62) 6,modselval(6),'# loop level 1: one 2: two O(alpha_t 
     .alpha_s) 3: two O(alpha_t alpha_s + alpha_t^2) 4: two 
     .O((alpha_t+alpha_lambda+alpha_kappa)^2+alpha_t alpha_s)'
      write(nout,62) 7,modselval(7),'# for top/stop sector: 1: DRbar sche
     .me no gauge running; 2: DRbar w/ gauge running 3: OS scheme'
      write(nout,62) 8,modselval(8),'# 0: MHpm as Input,
     . 1: Alambda as Input'
      write(nout,62) 10,modselval(10),'# 0: no EDMs calculated (default),
     . 1: EDMs calculated, 2: detailed output'
      write(nout,62) 11,modselval(11),'# 0: no AMMs calculated (default),
     . 1: AMMs calculated, 2: detailed output'  
      write(nout,62) 12,modselval(12),'# 0: no effective HHH couplings calculated,
     .  1: effective HHH couplings calculated'    
      write(nout,62) 13,modselval(13),'# 0: no loop-corrected W-mass calculated,
     .  1: loop-corrected W-mass calculated in OS scheme'             

c ----------------------- c
c The SM input parameters c
c ----------------------- c

c -- calculation of mb(mb)_MSbar from the mb pole mass --
      del = 1.d-8
      rmb0 = amb
444   rmb = rmb0
      rmb0 = runm_hdec(rmb,5)
      if(dabs(rmb0/rmb-1).gt.del)goto 444
      rmb = rmb0
      alsmz = alphas_hdec(amz,3)
      write(nout,105)
      write(nout,51) 'SMINPUTS','Standard Model inputs'
      write(nout,52) 1,smval(1),'1/alpha_em'
      write(nout,52) 2,gf,'G_F [GeV^-2]'
      write(nout,52) 3,alsmz,'alpha_S(M_Z)^MSbar'
      write(nout,52) 4,amz,'M_Z pole mass'
      write(nout,52) 5,rmb,'m_b^MS(mb)'
      write(nout,52) 6,amt,'m_t pole mass'
      write(nout,52) 7,amtau,'m_tau pole mass'

c ------------------------------------------------ c
c Input parameters for minimal/default SUSY models c
c ------------------------------------------------ c

      if(check(3).eq.1) then
         write(nout,105)
         write(nout,51) 'MINPAR','Input parameters - minimal models'
         unlikely = -123456789D0
         do ii=1,20,1
            if(minval(ii).ne.unlikely) then
               write(nout,52) ii,minval(ii),mincom(ii)
            endif
         end do
      endif

      if(check(33).eq.1) then
         write(nout,105)
         write(nout,51) 'CMPLX','Complex phase phi_u'
         write(nout,52) 3,cmplxv(3),cmplxvcom(3)
      end if

c ------------------------------------------------------------------- c
c Optional input parameters for non-minimal/non-universal SUSY models c
c ------------------------------------------------------------------- c

      if(check(4).eq.1) then
         write(nout,105)
         write(nout,51) 'EXTPAR','Input parameters - non-minimal models'
         unlikely = -123456789D0
         do ii=1,100,1
            if(extval(ii-1).ne.unlikely) then
               write(nout,52) ii-1,extval(ii-1),extcom(ii-1)
            endif
         end do
      endif

      if(check(25).eq.1) then
         write(nout,105)
         write(nout,51) 'IMEXTPAR',
     .        'Input parameters - non-minimal models (imaginary part)'
         unlikely = -123456789D0
         do ii=1,100,1
            if(imextval(ii-1).ne.unlikely) then
               write(nout,52) ii-1,imextval(ii-1),imextcom(ii-1)
            endif
         end do
      endif

c ----------------- c
c The mass spectrum c
c ----------------- c

      write(nout,105)
      write(nout,51) 'MASS','Mass Spectrum'
      write(nout,50) 'PDG code           mass       particle'
      write(nout,52) iwc,amw,'W+'
      write(nout,52) ih1,amh1,'H1'
      write(nout,52) ih2,amh2,'H2'
      write(nout,52) ih3,amh3,'H3'
      write(nout,52) ih4,amh4,'H4'
      write(nout,52) ih5,amh5,'H5'
      write(nout,52) ihc,amch,'H+-'
      write(nout,52) ib,amb,
     .'b-quark pole mass calculated from mb(mb)_Msbar'
      if(modselval(7).lt.3) then
        write(nout,52) it,massval(37),'m_t^DR'
      endif
      write(nout,52) isdl,gmsd(1),'~d_L'
      write(nout,52) isdr,gmsd(2),'~d_R'
      write(nout,52) isul,gmsu(1),'~u_L'
      write(nout,52) isur,gmsu(2),'~u_R'
      write(nout,52) issl,gmsd(1),'~s_L'
      write(nout,52) issr,gmsd(2),'~s_R'
      write(nout,52) iscl,gmsu(1),'~c_L'
      write(nout,52) iscr,gmsu(2),'~c_R'
      write(nout,52) isb1,GMSB(1),'~b_1'
      write(nout,52) isb2,GMSB(2),'~b_2'
      write(nout,52) ist1,GMST(1),'~t_1'
      write(nout,52) ist2,GMST(2),'~t_2'
      write(nout,52) isell,GMSE(1),'~e_L'
      write(nout,52) iselr,GMSE(2),'~e_R'
      write(nout,52) inel,GMSN(1),'~nu_eL'
      write(nout,52) ismul,GMSE(1),'~mu_L'
      write(nout,52) ismur,GMSE(2),'~mu_R'
      write(nout,52) inmul,GMSN(1),'~nu_muL'
      write(nout,52) istau1,GMSL(1),'~tau_1'
      write(nout,52) istau2,GMSL(2),'~tau_2'
      write(nout,52) intau1,GMSNL(1),'~nu_tauL'
      write(nout,52) iglo,amgluino,'~g'
      write(nout,52) in1,xmn(1),'~chi_10'
      write(nout,52) in2,xmn(2),'~chi_20'
      write(nout,52) in3,xmn(3),'~chi_30'
      write(nout,52) in4,xmn(4),'~chi_40'
      write(nout,52) in5,xmn(5),'~chi_50'
      write(nout,52) ic1,gmc(1),'~chi_1+'
      write(nout,52) ic2,gmc(2),'~chi_2+'
      
      write(nout,105)
      write(nout,51) 'DMASS','Theoreticalerror'
      write(nout,52) ih1,3d0,'H1'
      write(nout,52) ih2,3d0,'H2'
      write(nout,52) ih3,3d0,'H3'
      write(nout,52) ih4,3d0,'H4'
      write(nout,52) ih5,3d0,'H5'
      write(nout,52) ihc,3d0,'Hc'

c ------------------------------------------------------------------- c
c The neutralino mixing matrix ZN and the chargino mixing matrices    c
c ZU,ZV                                                               c
c ------------------------------------------------------------------- c

      write(nout,105)
      write(nout,51) 'NMNMIX','Real part of the Neutralino Mixing Matrix
     .'
      write(nout,53) 1,1,zz(1,1),'Re(ZN)(11)'
      write(nout,53) 1,2,zz(1,2),'Re(ZN)(12)'
      write(nout,53) 1,3,zz(1,3),'Re(ZN)(13)'
      write(nout,53) 1,4,zz(1,4),'Re(ZN)(14)'
      write(nout,53) 1,5,zz(1,5),'Re(ZN)(15)'
      write(nout,53) 2,1,zz(2,1),'Re(ZN)(21)'
      write(nout,53) 2,2,zz(2,2),'Re(ZN)(22)'
      write(nout,53) 2,3,zz(2,3),'Re(ZN)(23)'
      write(nout,53) 2,4,zz(2,4),'Re(ZN)(24)'
      write(nout,53) 2,5,zz(2,5),'Re(ZN)(25)'
      write(nout,53) 3,1,zz(3,1),'Re(ZN)(31)'
      write(nout,53) 3,2,zz(3,2),'Re(ZN)(32)'
      write(nout,53) 3,3,zz(3,3),'Re(ZN)(33)'
      write(nout,53) 3,4,zz(3,4),'Re(ZN)(34)'
      write(nout,53) 3,5,zz(3,5),'Re(ZN)(35)'
      write(nout,53) 4,1,zz(4,1),'Re(ZN)(41)'
      write(nout,53) 4,2,zz(4,2),'Re(ZN)(42)'
      write(nout,53) 4,3,zz(4,3),'Re(ZN)(43)'
      write(nout,53) 4,4,zz(4,4),'Re(ZN)(44)'
      write(nout,53) 4,5,zz(4,5),'Re(ZN)(45)'
      write(nout,53) 5,1,zz(5,1),'Re(ZN)(51)'
      write(nout,53) 5,2,zz(5,2),'Re(ZN)(52)'
      write(nout,53) 5,3,zz(5,3),'Re(ZN)(53)'
      write(nout,53) 5,4,zz(5,4),'Re(ZN)(54)'
      write(nout,53) 5,5,zz(5,5),'Re(ZN)(55)'

      write(nout,105)
      write(nout,51) 'IMNMNMIX',
     .     'Imaginary part of the neutralino Mixing Matrix'
      write(nout,53) 1,1,zzim(1,1),'Im(ZN)(11)'
      write(nout,53) 1,2,zzim(1,2),'Im(ZN)(12)'
      write(nout,53) 1,3,zzim(1,3),'Im(ZN)(13)'
      write(nout,53) 1,4,zzim(1,4),'Im(ZN)(14)'
      write(nout,53) 1,5,zzim(1,5),'Im(ZN)(15)'
      write(nout,53) 2,1,zzim(2,1),'Im(ZN)(21)'
      write(nout,53) 2,2,zzim(2,2),'Im(ZN)(22)'
      write(nout,53) 2,3,zzim(2,3),'Im(ZN)(23)'
      write(nout,53) 2,4,zzim(2,4),'Im(ZN)(24)'
      write(nout,53) 2,5,zzim(2,5),'Im(ZN)(25)'
      write(nout,53) 3,1,zzim(3,1),'Im(ZN)(31)'
      write(nout,53) 3,2,zzim(3,2),'Im(ZN)(32)'
      write(nout,53) 3,3,zzim(3,3),'Im(ZN)(33)'
      write(nout,53) 3,4,zzim(3,4),'Im(ZN)(34)'
      write(nout,53) 3,5,zzim(3,5),'Im(ZN)(35)'
      write(nout,53) 4,1,zzim(4,1),'Im(ZN)(41)'
      write(nout,53) 4,2,zzim(4,2),'Im(ZN)(42)'
      write(nout,53) 4,3,zzim(4,3),'Im(ZN)(43)'
      write(nout,53) 4,4,zzim(4,4),'Im(ZN)(44)'
      write(nout,53) 4,5,zzim(4,5),'Im(ZN)(45)'
      write(nout,53) 5,1,zzim(5,1),'Im(ZN)(51)'
      write(nout,53) 5,2,zzim(5,2),'Im(ZN)(52)'
      write(nout,53) 5,3,zzim(5,3),'Im(ZN)(53)'
      write(nout,53) 5,4,zzim(5,4),'Im(ZN)(54)'
      write(nout,53) 5,5,zzim(5,5),'Im(ZN)(55)'

      write(nout,105)
      write(nout,51) 'UMIX','Real part of the Chargino Mixing Matrix U'
      write(nout,53) 1,1,uu(1,1),'Re(U)(11)'
      write(nout,53) 1,2,uu(1,2),'Re(U)(12)'
      write(nout,53) 2,1,uu(2,1),'Re(U)(21)'
      write(nout,53) 2,2,uu(2,2),'Re(U)(22)'

      write(nout,105)
      write(nout,51) 'IMUMIX',
     .     'Imaginary part of the chargino Mixing Matrix U'
      write(nout,53) 1,1,uuim(1,1),'Im(U)(11)'
      write(nout,53) 1,2,uuim(1,2),'Im(U)(12)'
      write(nout,53) 2,1,uuim(2,1),'Im(U)(21)'
      write(nout,53) 2,2,uuim(2,2),'Im(U)(22)'

      write(nout,105)
      write(nout,51) 'VMIX','Real part of the Chargino Mixing Matrix V'
      write(nout,53) 1,1,vv(1,1),'Re(V)(11)'
      write(nout,53) 1,2,vv(1,2),'Re(V)(12)'
      write(nout,53) 2,1,vv(2,1),'Re(V)(21)'
      write(nout,53) 2,2,vv(2,2),'Re(V)(22)'

      write(nout,105)
      write(nout,51) 'IMVMIX',
     .     'Imaginary part of the chargino Mixing Matrix V'
      write(nout,53) 1,1,vvim(1,1),'Im(V)(11)'
      write(nout,53) 1,2,vvim(1,2),'Im(V)(12)'
      write(nout,53) 2,1,vvim(2,1),'Im(V)(21)'
      write(nout,53) 2,2,vvim(2,2),'Im(V)(22)'

c ------------------------------------------ c
c The stop, sbottom and stau mixing matrices c
c ------------------------------------------ c

      write(nout,105)
      write(nout,51) 'STOPMIX','Real part of the Stop Mixing Matrix'
      write(nout,53) 1,1,slhastmix(1,1),'Re(ZU)(11)'
      write(nout,53) 1,2,slhastmix(1,2),'Re(ZU)(12)'
      write(nout,53) 2,1,slhastmix(2,1),'Re(ZU)(21)'
      write(nout,53) 2,2,slhastmix(2,2),'Re(ZU)(22)'

      write(nout,105)
      write(nout,51) 'IMSTOPMIX',
     .     'Imaginary part of the Stop Mixing Matrix'
      write(nout,53) 1,1,slhastmixim(1,1),'Im(ZU)(11)'
      write(nout,53) 1,2,slhastmixim(1,2),'Im(ZU)(12)'
      write(nout,53) 2,1,slhastmixim(2,1),'Im(ZU)(21)'
      write(nout,53) 2,2,slhastmixim(2,2),'Im(ZU)(22)'

      write(nout,105)
      write(nout,51) 'SBOTMIX','Real part of the Sbottom Mixing Matrix'
      write(nout,53) 1,1,slhasbmix(1,1),'Re(ZD)(11)'
      write(nout,53) 1,2,slhasbmix(1,2),'Re(ZD)(12)'
      write(nout,53) 2,1,slhasbmix(2,1),'Re(ZD)(21)'
      write(nout,53) 2,2,slhasbmix(2,2),'Re(ZD)(22)'

      write(nout,105)
      write(nout,51) 'IMSBOTMIX',
     .     'Imaginary part of the Sbottom Mixing Matrix'
      write(nout,53) 1,1,slhasbmixim(1,1),'Im(ZD)(11)'
      write(nout,53) 1,2,slhasbmixim(1,2),'Im(ZD)(12)'
      write(nout,53) 2,1,slhasbmixim(2,1),'Im(ZD)(21)'
      write(nout,53) 2,2,slhasbmixim(2,2),'Im(ZD)(22)'

      write(nout,105)
      write(nout,51) 'STAUMIX','Real part of the Stau Mixing Matrix'
      write(nout,53) 1,1,slhastaumix(1,1),'Re(ZE)(11)'
      write(nout,53) 1,2,slhastaumix(1,2),'Re(ZE)(12)'
      write(nout,53) 2,1,slhastaumix(2,1),'Re(ZE)(21)'
      write(nout,53) 2,2,slhastaumix(2,2),'Re(ZE)(22)'

      write(nout,105)
      write(nout,51) 'IMSTAUMIX',
     .     'Imaginary part of the Stau Mixing Matrix'
      write(nout,53) 1,1,slhastaumixim(1,1),'Im(ZE)(11)'
      write(nout,53) 1,2,slhastaumixim(1,2),'Im(ZE)(12)'
      write(nout,53) 2,1,slhastaumixim(2,1),'Im(ZE)(21)'
      write(nout,53) 2,2,slhastaumixim(2,2),'Im(ZE)(22)'

c ------------------------------------------------------------------- c
c The angle alpha in the Higgs sector and the Higgs mixing parameters c
c ------------------------------------------------------------------- c

      amudrbar = AMU/(1.D0+g1ew**2/16.D0/pi**2*3.D0/5.D0+
     .                 g2ew**2/16.D0/pi**2*3.D0/4.D0)
      if(qvalue(1).ne.0.d0)then
       qq = qvalue(1)
      else
       qq = amt
      endif
      write(nout,105)
      write(nout,54) 'HMIX Q=',qq,'DRbar Higgs Parameters'
      write(nout,52) 1,amudrbar,'|mu|(Q)'
      write(nout,52) 2,tgbet,'tanbeta(Q)'

      write(nout,105)
      write(nout,51) 'NMHMIXC','Neutral Higgs mixing matrix ZH'
      write(nout,53) 1,1,nmhmixval(1,1),'ZH_11'
      write(nout,53) 1,2,nmhmixval(1,2),'ZH_12'
      write(nout,53) 1,3,nmhmixval(1,3),'ZH_13'
      write(nout,53) 1,4,nmhmixval(1,4),'ZH_14'
      write(nout,53) 1,5,nmhmixval(1,5),'ZH_15'
      write(nout,53) 2,1,nmhmixval(2,1),'ZH_21'
      write(nout,53) 2,2,nmhmixval(2,2),'ZH_22'
      write(nout,53) 2,3,nmhmixval(2,3),'ZH_23'
      write(nout,53) 2,4,nmhmixval(2,4),'ZH_24'
      write(nout,53) 2,5,nmhmixval(2,5),'ZH_25'
      write(nout,53) 3,1,nmhmixval(3,1),'ZH_31'
      write(nout,53) 3,2,nmhmixval(3,2),'ZH_32'
      write(nout,53) 3,3,nmhmixval(3,3),'ZH_33'
      write(nout,53) 3,4,nmhmixval(3,4),'ZH_34'
      write(nout,53) 3,5,nmhmixval(3,5),'ZH_35'
      write(nout,53) 4,1,nmhmixval(4,1),'ZH_41'
      write(nout,53) 4,2,nmhmixval(4,2),'ZH_42'
      write(nout,53) 4,3,nmhmixval(4,3),'ZH_43'
      write(nout,53) 4,4,nmhmixval(4,4),'ZH_44'
      write(nout,53) 4,5,nmhmixval(4,5),'ZH_45'
      write(nout,53) 5,1,nmhmixval(5,1),'ZH_51'
      write(nout,53) 5,2,nmhmixval(5,2),'ZH_52'
      write(nout,53) 5,3,nmhmixval(5,3),'ZH_53'
      write(nout,53) 5,4,nmhmixval(5,4),'ZH_54'
      write(nout,53) 5,5,nmhmixval(5,5),'ZH_55'
      write(nout,105)
      write(nout,51) 'ReZFacH','Real part of Neutral Higgs Zfactor'
      do i=1,5
      do j=1,5
      write(nout,123) i,j,DBLE(ZHfac(i,j)),'Re_ZFH',i,j
      end do
      end do
      write(nout,105)
      write(nout,51) 'ImZFacH','Imarginary part of Neutral Higgs Zfactor'
      do i=1,5
      do j=1,5
      write(nout,123) i,j,DIMAG(ZHfac(i,j)),'Im_ZFH',i,j
      end do
      end do

c --------------------- c
c The CKM mixing matrix c
c --------------------- c

      unlikely = -123456789D0
      r0 = 0.132d0
      e0 = 0.341d0
      fac1 = r0/dsqrt(r0**2+e0**2)
      fac2 = e0/dsqrt(r0**2+e0**2)
      if(vckmval(1).eq.unlikely)vckmval(1) = vus
      if(vckmval(2).eq.unlikely)vckmval(2) = vcb/vus**2
      if(vckmval(3).eq.unlikely)vckmval(3) = fac1*vub/vus/vcb
      if(vckmval(4).eq.unlikely)vckmval(4) = fac2*vub/vus/vcb
      write(nout,105)
      write(nout,51) 'VCKMIN','CKM mixing'
      write(nout,52) 1,vckmval(1),'lambda'
      write(nout,52) 2,vckmval(2),'A'
      write(nout,52) 3,vckmval(3),'rhobar'
      write(nout,52) 4,vckmval(4),'etabar'

c ------------------- c
c The gauge couplings c
c ------------------- c
 
      if(qvalue(2).ne.0.d0)then
       write(nout,105)
       write(nout,54) 'GAUGE Q=',qvalue(2),'The gauge couplings'
       if(gaugeval(1).ne.0.D0) then
          write(nout,55) 1,gaugeval(1),'gprime(Q) DRbar'
       endif
       if(gaugeval(2).ne.0.D0) then
          write(nout,55) 2,gaugeval(2),'g(Q) DRbar'
       endif
      endif

c ------------------------------------- c
c The trilinear couplings Au, Ad and Ae c
c ------------------------------------- c

      qq = amt
      if(qvalue(4).ne.0.d0) qq = qvalue(4)
      write(nout,105)
      if(auval(3,3).eq.unlikely.and.extval(11).ne.unlikely) then
         write(nout,54) 'AU Q=',extval(0),'The trilinear couplings'
      else
         write(nout,54) 'AU Q=',qq,'The trilinear couplings'
      endif
      unlikely = -123456789D0
      if(auval(1,1).ne.unlikely) then
         write(nout,53) 1,1,auval(1,1),'A_u(Q) DRbar'
      endif
      if(auval(2,2).ne.unlikely) then
         write(nout,53) 2,2,auval(2,2),'A_c(Q) DRbar'
      endif
      if(auval(3,3).ne.unlikely) then
         write(nout,53) 3,3,auval(3,3),'A_t(Q) DRbar'
      else
         write(nout,53) 3,3,au,'A_t(Q) DRbar'
      endif
      qq = amt
      if(qvalue(5).ne.0.d0)qq = qvalue(5)
      write(nout,105)
      if(adval(3,3).eq.unlikely.and.extval(12).ne.unlikely) then
         write(nout,54) 'AD Q=',extval(0),'The trilinear couplings'
      else
         write(nout,54) 'AD Q=',qq,'The trilinear couplings'
      endif
      if(adval(1,1).ne.unlikely) then
         write(nout,53) 1,1,adval(1,1),'A_d(Q) DRbar'
      endif
      if(adval(2,2).ne.unlikely) then
         write(nout,53) 2,2,adval(2,2),'A_s(Q) DRbar'
      endif
      if(adval(3,3).ne.unlikely) then
         write(nout,53) 3,3,adval(3,3),'A_b(Q) DRbar'
      else
         write(nout,53) 3,3,ad,'A_b(Q) DRbar'
      endif

      qq = amt
      if(qvalue(6).ne.0.d0)qq = qvalue(6)
      write(nout,105)
      if(aeval(3,3).eq.unlikely.and.extval(13).ne.unlikely) then
         write(nout,54) 'AE Q=',extval(0),'The trilinear couplings'
      else
         write(nout,54) 'AE Q=',qq,'The trilinear couplings'
      endif
      if(aeval(1,1).ne.unlikely) then
         write(nout,53) 1,1,aeval(1,1),'A_e(Q) DRbar'
      endif
      if(aeval(2,2).ne.unlikely) then
         write(nout,53) 2,2,aeval(2,2),'A_mu(Q) DRbar'
      endif
      if(aeval(3,3).ne.unlikely) then
         write(nout,53) 3,3,aeval(3,3),'A_tau(Q) DRbar'
      else
         write(nout,53) 3,3,al,'A_tau(Q) DRbar'
      endif

c ----------------------------- c
c The soft SUSY breaking masses c
c ----------------------------- c

      if(check(15).eq.1) then
         write(nout,105)
         write(nout,54) 'MSOFT Q=',scaleofewsb,'The real parts of the sof
     .t SUSY breaking masses at the scale Q'
         unlikely = -123456789D0
         do ii=1,99,1
            if(msoftval(ii).ne.unlikely) then
               if(ii.ne.11.and.ii.ne.12.and.ii.ne.13.and.ii.ne.23.and.
     .            ii.ne.24.and.ii.ne.25.and.ii.ne.26) then
                  write(nout,52) ii,msoftval(ii),softcom(ii)
               endif
            endif
         end do
      else
         write(nout,105)
         write(nout,54) 'MSOFT Q=',scaleofewsb,'The real parts of the sof
     .t SUSY breaking masses at the scale Q'
         cw=amw/amz
         sw=dsqrt(1-cw**2)
         tw=sw/cw
         am1=5.D0/3.D0*tw**2*am2
         am2=am2/(1.D0+g2ew**2/16.D0/pi**2*2.D0)
         write(nout,52) 1,am1realval,'M_1(Q)'
         write(nout,52) 2,am2realval,'M_2(Q)'
         write(nout,52) 31,amel1,'AMEL1'
         write(nout,52) 33,amel,'AMEL'
         write(nout,52) 34,amer1,'AMER1'
         write(nout,52) 36,amer,'AMER'
         write(nout,52) 41,amql1,'AMQL1'
         write(nout,52) 43,amsq,'AMSQ'
         write(nout,52) 44,amur1,'AMUR1'
         write(nout,52) 46,amur,'AMUR'
         write(nout,52) 47,amdr1,'AMDR1'
         write(nout,52) 49,amdr,'AMDR'
      endif

      if(check(32).eq.1) then
         write(nout,105)
         write(nout,54) 'IMMSOFT Q=',scaleofewsb,'The imaginary parts of 
     .the soft SUSY breaking masses at the scale Q'
         unlikely = -123456789D0
         do ii=1,3,1
            if(immsoftval(ii).ne.unlikely) then
               if(ii.ne.11.and.ii.ne.12.and.ii.ne.13.and.ii.ne.23.and.
     .            ii.ne.24.and.ii.ne.25.and.ii.ne.26) then
                  write(nout,52) ii,immsoftval(ii),imsoftcom(ii)
               endif
            endif
         end do
      endif

c --------------------------------------------------- c
c Higgs boson total decay widths and branching ratios c
c --------------------------------------------------- c

c --------- c
c Hi decays c
c --------- c

      do i=1,5,1
         write(nout,105)

c --- H1 decays --- c
      if(i.eq.1) then
         write(nout,105)

      if(whitotc(i).ne.0.D0) then
      write(nout,99)
c --- corrected 21/1/2014
      write(nout,100) 25,whitotc(1),'H1 decays'
c --- end corrected 21/1/2014

      write(nout,101)
      if(brhigbbc(i).ne.0.D0) then
      write(nout,102) brhigbbc(i),2,ib,ibb,'BR(H1-> b       bb     )'
      endif
      if(brhigllc(i).ne.0.D0) then
      write(nout,102) brhigllc(i),2,-itau,itau,'BR(H1-> tau+    tau-   )
     .'
      endif
      if(brhigmmc(i).ne.0.D0) then
      write(nout,102) brhigmmc(i),2,-imu,imu,'BR(H1-> mu+     mu-    )'
      endif
      if(brhigssc(i).ne.0.D0) then
      write(nout,102) brhigssc(i),2,is,isb  ,'BR(H1-> s       sb     )'
      endif
      if(brhigccc(i).ne.0.D0) then
      write(nout,102) brhigccc(i),2,ic,icb  ,'BR(H1-> c       cb     )'
      endif
      if(brhigttc(i).ne.0.D0) then
      write(nout,102) brhigttc(i),2,it,itb  ,'BR(H1-> t       tb     )' 
      endif
      if(brhigggc(i).ne.0.D0) then
      write(nout,102) brhigggc(i),2,igl,igl ,'BR(H1-> g       g      )' 
      endif
      if(brhiggac(i).ne.0.D0) then
      write(nout,102) brhiggac(i),2,iga,iga ,'BR(H1-> gam     gam    )' 
      endif
      if(brhigzgac(i).ne.0.D0) then
      write(nout,102) brhigzgac(i),2,iz,iga ,'BR(H1-> Z       gam    )' 
      endif
      if(brhigwwc(i).ne.0.D0) then
      write(nout,102) brhigwwc(i),2,iwc,-iwc,'BR(H1-> W+      W-     )' 
      endif
      if(brhigzzc(i).ne.0.D0) then
      write(nout,102) brhigzzc(i),2,iz,iz   ,'BR(H1-> Z       Z      )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,-iwc,ihc,'BR(H1-> W-      H
     .+     )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,iwc,-ihc,'BR(H1-> W+      H
     .-     )' 
      endif
      if(brwhigchc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,1),2,ic1,-ic1,'BR(H1-> ~chi_1+ ~chi_
     .1-)' 
      endif
      if(brwhigchc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,2),2,ic2,-ic2,'BR(H1-> ~chi_2+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,2),2,ic1,-ic2,'BR(H1-> ~chi_1+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,1),2,ic2,-ic1,'BR(H1-> ~chi_2+ ~chi_
     .1-)' 
      endif
      brwhignec(i,1,2) = 2.D0*brwhignec(i,1,2)
      brwhignec(i,1,3) = 2.D0*brwhignec(i,1,3)
      brwhignec(i,1,4) = 2.D0*brwhignec(i,1,4)
      brwhignec(i,1,5) = 2.D0*brwhignec(i,1,5)
      brwhignec(i,2,3) = 2.D0*brwhignec(i,2,3)
      brwhignec(i,2,4) = 2.D0*brwhignec(i,2,4)
      brwhignec(i,2,5) = 2.D0*brwhignec(i,2,5)
      brwhignec(i,3,4) = 2.D0*brwhignec(i,3,4)
      brwhignec(i,3,5) = 2.D0*brwhignec(i,3,5)
      brwhignec(i,4,5) = 2.D0*brwhignec(i,4,5)
      if(brwhignec(i,1,1).ne.0.D0) then
      write(nout,102) brwhignec(i,1,1),2,in1,in1 ,'BR(H1-> ~chi_10 ~chi_
     .10)' 
      endif
      if(brwhignec(i,1,2).ne.0.D0) then
      write(nout,102) brwhignec(i,1,2),2,in1,in2 ,'BR(H1-> ~chi_10 ~chi_
     .20)' 
      endif
      if(brwhignec(i,1,3).ne.0.D0) then
      write(nout,102) brwhignec(i,1,3),2,in1,in3 ,'BR(H1-> ~chi_10 ~chi_
     .30)' 
      endif
      if(brwhignec(i,1,4).ne.0.D0) then
      write(nout,102) brwhignec(i,1,4),2,in1,in4 ,'BR(H1-> ~chi_10 ~chi_
     .40)' 
      endif
      if(brwhignec(i,1,5).ne.0.D0) then
      write(nout,102) brwhignec(i,1,5),2,in1,in5 ,'BR(H1-> ~chi_10 ~chi_
     .50)' 
      endif
      if(brwhignec(i,2,2).ne.0.D0) then
      write(nout,102) brwhignec(i,2,2),2,in2,in2 ,'BR(H1-> ~chi_20 ~chi_
     .20)' 
      endif
      if(brwhignec(i,2,3).ne.0.D0) then
      write(nout,102) brwhignec(i,2,3),2,in2,in3 ,'BR(H1-> ~chi_20 ~chi_
     .30)' 
      endif
      if(brwhignec(i,2,4).ne.0.D0) then
      write(nout,102) brwhignec(i,2,4),2,in2,in4 ,'BR(H1-> ~chi_20 ~chi_
     .40)' 
      endif
      if(brwhignec(i,2,5).ne.0.D0) then
      write(nout,102) brwhignec(i,2,5),2,in2,in5 ,'BR(H1-> ~chi_20 ~chi_
     .50)' 
      endif
      if(brwhignec(i,3,3).ne.0.D0) then
      write(nout,102) brwhignec(i,3,3),2,in3,in3 ,'BR(H1-> ~chi_30 ~chi_
     .30)' 
      endif
      if(brwhignec(i,3,4).ne.0.D0) then
      write(nout,102) brwhignec(i,3,4),2,in3,in4 ,'BR(H1-> ~chi_30 ~chi_
     .40)' 
      endif
      if(brwhignec(i,3,5).ne.0.D0) then
      write(nout,102) brwhignec(i,3,5),2,in3,in5 ,'BR(H1-> ~chi_30 ~chi_
     .50)' 
      endif
      if(brwhignec(i,4,4).ne.0.D0) then
      write(nout,102) brwhignec(i,4,4),2,in4,in4 ,'BR(H1-> ~chi_40 ~chi_
     .40)' 
      endif
      if(brwhignec(i,4,5).ne.0.D0) then
      write(nout,102) brwhignec(i,4,5),2,in4,in5 ,'BR(H1-> ~chi_40 ~chi_
     .50)' 
      endif
      bhislnl1 = brwhigslnlc(i)/2.D0
      bhislnl3 = brwhigslnltauc(i)
      bhislel1 = brwhigslelc(i)/2.D0
      bhisler1 = brwhigslerc(i)/2.D0
      bhisqul1 = brwhigsqulc(i)/2.d0
      bhisqur1 = brwhigsqurc(i)/2.d0
      bhisqdl1 = brwhigsqdlc(i)/2.d0
      bhisqdr1 = brwhigsqdrc(i)/2.d0
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,isul,-isul  ,'BR(H1-> ~u_L    ~u_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,isur,-isur  ,'BR(H1-> ~u_R    ~u_R*  )'
      endif
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,iscl,-iscl  ,'BR(H1-> ~c_L    ~c_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,iscr,-iscr  ,'BR(H1-> ~c_R    ~c_R*  )'
      endif
      if(brwhigstc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,1),2,ist1,-ist1,'BR(H1-> ~t_1    ~t_
     .1*  )'
      endif
      if(brwhigstc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,2),2,ist2,-ist2,'BR(H1-> ~t_2    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,2),2,ist1,-ist2,'BR(H1-> ~t_1    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,1),2,ist2,-ist1,'BR(H1-> ~t_2    ~t_
     .1*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,isdl,-isdl  ,'BR(H1-> ~d_L    ~d_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,isdr,-isdr  ,'BR(H1-> ~d_R    ~d_R*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,issl,-issl  ,'BR(H1-> ~s_L    ~s_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,issr,-issr  ,'BR(H1-> ~s_R    ~s_R*  )'
      endif
      if(brwhigsbc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,1),2,isb1,-isb1,'BR(H1-> ~b_1    ~b_
     .1*  )'
      endif
      if(brwhigsbc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,2),2,isb2,-isb2,'BR(H1-> ~b_2    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,2),2,isb1,-isb2,'BR(H1-> ~b_1    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,1),2,isb2,-isb1,'BR(H1-> ~b_2    ~b_
     .1*  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,isell,-isell,'BR(H1-> ~e_L-   ~e_L+  )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,iselr,-iselr,'BR(H1-> ~e_R-   ~e_R+  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,ismul,-ismul,'BR(H1-> ~mu_L-  ~mu_L+ )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,ismur,-ismur,'BR(H1-> ~mu_R-  ~mu_R+ )'
      endif
      if(brwhigstauc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,1),2,istau1,-istau1,'BR(H1-> ~tau_
     .1- ~tau_1+)'
      endif
      if(brwhigstauc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,2),2,istau2,-istau2,'BR(H1-> ~tau_
     .2- ~tau_2+)'
      endif
      if(brwhigstauc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,2),2,istau1,-istau2,'BR(H1-> ~tau_
     .1- ~tau_2+)'
      endif
      if(brwhigstauc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,1),2,istau2,-istau1,'BR(H1-> ~tau_
     .2- ~tau_1+)'
      endif
      if(bhislnl1.ne.0.D0) then
      write(nout,102) bhislnl1,2,inel,-inel  ,'BR(H1-> ~nu_eL  ~nu_eL*  
     . )'
      write(nout,102) bhislnl1,2,inmul,-inmul,'BR(H1-> ~nu_muL ~nu_muL* 
     . )'
      endif
      if(bhislnl3.ne.0.D0) then
      write(nout,102) bhislnl3,2,intau1,-intau1,'BR(H1-> ~nu_tauL ~nu_ta
     .uL*)'
      endif

      elseif(whitotc(1).eq.0.D0) then
      write(nout,99)
c --- corrected 21/1/2014
      write(nout,100) 25,0.000000000E+00,'H1 decays'
c --- end corrected 21/1/2014

      endif

c --- H2 decays --- c

      elseif(i.eq.2) then         
         write(nout,105)

      if(whitotc(i).ne.0.D0) then
      write(nout,99)
      write(nout,100) 35,whitotc(2),'H2 decays'

      write(nout,101)
      if(brhigbbc(i).ne.0.D0) then
      write(nout,102) brhigbbc(i),2,ib,ibb,'BR(H2-> b       bb     )'
      endif
      if(brhigllc(i).ne.0.D0) then
      write(nout,102) brhigllc(i),2,-itau,itau,'BR(H2-> tau+    tau-   )
     .'
      endif
      if(brhigmmc(i).ne.0.D0) then
      write(nout,102) brhigmmc(i),2,-imu,imu,'BR(H2-> mu+     mu-    )'
      endif
      if(brhigssc(i).ne.0.D0) then
      write(nout,102) brhigssc(i),2,is,isb  ,'BR(H2-> s       sb     )'
      endif
      if(brhigccc(i).ne.0.D0) then
      write(nout,102) brhigccc(i),2,ic,icb  ,'BR(H2-> c       cb     )'
      endif
      if(brhigttc(i).ne.0.D0) then
      write(nout,102) brhigttc(i),2,it,itb  ,'BR(H2-> t       tb     )' 
      endif
      if(brhigggc(i).ne.0.D0) then
      write(nout,102) brhigggc(i),2,igl,igl ,'BR(H2-> g       g      )' 
      endif
      if(brhiggac(i).ne.0.D0) then
      write(nout,102) brhiggac(i),2,iga,iga ,'BR(H2-> gam     gam    )' 
      endif
      if(brhigzgac(i).ne.0.D0) then
      write(nout,102) brhigzgac(i),2,iz,iga ,'BR(H2-> Z       gam    )' 
      endif
      if(brhigwwc(i).ne.0.D0) then
      write(nout,102) brhigwwc(i),2,iwc,-iwc,'BR(H2-> W+      W-     )' 
      endif
      if(brhigzzc(i).ne.0.D0) then
      write(nout,102) brhigzzc(i),2,iz,iz   ,'BR(H2-> Z       Z      )' 
      endif
      if(brhitohjzc(i,1).ne.0.D0) then
      write(nout,102) brhitohjzc(i,1),2,iz,ih1,'BR(H2-> Z       H1     )
     .' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,-iwc,ihc,'BR(H2-> W-      H
     .+     )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,iwc,-ihc,'BR(H2-> W+      H
     .-     )' 
      endif
      if(brhitohjhkc(2,1,1).ne.0.D0) then
      write(nout,102) brhitohjhkc(2,1,1),2,ih1,ih1,'BR(H2-> H1      H1  
     .   )' 
      endif
      if(brwhigchc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,1),2,ic1,-ic1,'BR(H2-> ~chi_1+ ~chi_
     .1-)' 
      endif
      if(brwhigchc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,2),2,ic2,-ic2,'BR(H2-> ~chi_2+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,2),2,ic1,-ic2,'BR(H2-> ~chi_1+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,1),2,ic2,-ic1,'BR(H2-> ~chi_2+ ~chi_
     .1-)' 
      endif
      brwhignec(i,1,2) = 2.D0*brwhignec(i,1,2)
      brwhignec(i,1,3) = 2.D0*brwhignec(i,1,3)
      brwhignec(i,1,4) = 2.D0*brwhignec(i,1,4)
      brwhignec(i,1,5) = 2.D0*brwhignec(i,1,5)
      brwhignec(i,2,3) = 2.D0*brwhignec(i,2,3)
      brwhignec(i,2,4) = 2.D0*brwhignec(i,2,4)
      brwhignec(i,2,5) = 2.D0*brwhignec(i,2,5)
      brwhignec(i,3,4) = 2.D0*brwhignec(i,3,4)
      brwhignec(i,3,5) = 2.D0*brwhignec(i,3,5)
      brwhignec(i,4,5) = 2.D0*brwhignec(i,4,5)
      if(brwhignec(i,1,1).ne.0.D0) then
      write(nout,102) brwhignec(i,1,1),2,in1,in1 ,'BR(H2-> ~chi_10 ~chi_
     .10)' 
      endif
      if(brwhignec(i,1,2).ne.0.D0) then
      write(nout,102) brwhignec(i,1,2),2,in1,in2 ,'BR(H2-> ~chi_10 ~chi_
     .20)' 
      endif
      if(brwhignec(i,1,3).ne.0.D0) then
      write(nout,102) brwhignec(i,1,3),2,in1,in3 ,'BR(H2-> ~chi_10 ~chi_
     .30)' 
      endif
      if(brwhignec(i,1,4).ne.0.D0) then
      write(nout,102) brwhignec(i,1,4),2,in1,in4 ,'BR(H2-> ~chi_10 ~chi_
     .40)' 
      endif
      if(brwhignec(i,1,5).ne.0.D0) then
      write(nout,102) brwhignec(i,1,5),2,in1,in5 ,'BR(H2-> ~chi_10 ~chi_
     .50)' 
      endif
      if(brwhignec(i,2,2).ne.0.D0) then
      write(nout,102) brwhignec(i,2,2),2,in2,in2 ,'BR(H2-> ~chi_20 ~chi_
     .20)' 
      endif
      if(brwhignec(i,2,3).ne.0.D0) then
      write(nout,102) brwhignec(i,2,3),2,in2,in3 ,'BR(H2-> ~chi_20 ~chi_
     .30)' 
      endif
      if(brwhignec(i,2,4).ne.0.D0) then
      write(nout,102) brwhignec(i,2,4),2,in2,in4 ,'BR(H2-> ~chi_20 ~chi_
     .40)' 
      endif
      if(brwhignec(i,2,5).ne.0.D0) then
      write(nout,102) brwhignec(i,2,5),2,in2,in5 ,'BR(H2-> ~chi_20 ~chi_
     .50)' 
      endif
      if(brwhignec(i,3,3).ne.0.D0) then
      write(nout,102) brwhignec(i,3,3),2,in3,in3 ,'BR(H2-> ~chi_30 ~chi_
     .30)' 
      endif
      if(brwhignec(i,3,4).ne.0.D0) then
      write(nout,102) brwhignec(i,3,4),2,in3,in4 ,'BR(H2-> ~chi_30 ~chi_
     .40)' 
      endif
      if(brwhignec(i,3,5).ne.0.D0) then
      write(nout,102) brwhignec(i,3,5),2,in3,in5 ,'BR(H2-> ~chi_30 ~chi_
     .50)' 
      endif
      if(brwhignec(i,4,4).ne.0.D0) then
      write(nout,102) brwhignec(i,4,4),2,in4,in4 ,'BR(H2-> ~chi_40 ~chi_
     .40)' 
      endif
      if(brwhignec(i,4,5).ne.0.D0) then
      write(nout,102) brwhignec(i,4,5),2,in4,in5 ,'BR(H2-> ~chi_40 ~chi_
     .50)' 
      endif
      bhislnl1 = brwhigslnlc(i)/2.D0
      bhislnl3 = brwhigslnltauc(i)
      bhislel1 = brwhigslelc(i)/2.D0
      bhisler1 = brwhigslerc(i)/2.D0
      bhisqul1 = brwhigsqulc(i)/2.d0
      bhisqur1 = brwhigsqurc(i)/2.d0
      bhisqdl1 = brwhigsqdlc(i)/2.d0
      bhisqdr1 = brwhigsqdrc(i)/2.d0
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,isul,-isul  ,'BR(H2-> ~u_L    ~u_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,isur,-isur  ,'BR(H2-> ~u_R    ~u_R*  )'
      endif
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,iscl,-iscl  ,'BR(H2-> ~c_L    ~c_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,iscr,-iscr  ,'BR(H2-> ~c_R    ~c_R*  )'
      endif
      if(brwhigstc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,1),2,ist1,-ist1,'BR(H2-> ~t_1    ~t_
     .1*  )'
      endif
      if(brwhigstc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,2),2,ist2,-ist2,'BR(H2-> ~t_2    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,2),2,ist1,-ist2,'BR(H2-> ~t_1    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,1),2,ist2,-ist1,'BR(H2-> ~t_2    ~t_
     .1*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,isdl,-isdl  ,'BR(H2-> ~d_L    ~d_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,isdr,-isdr  ,'BR(H2-> ~d_R    ~d_R*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,issl,-issl  ,'BR(H2-> ~s_L    ~s_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,issr,-issr  ,'BR(H2-> ~s_R    ~s_R*  )'
      endif
      if(brwhigsbc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,1),2,isb1,-isb1,'BR(H2-> ~b_1    ~b_
     .1*  )'
      endif
      if(brwhigsbc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,2),2,isb2,-isb2,'BR(H2-> ~b_2    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,2),2,isb1,-isb2,'BR(H2-> ~b_1    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,1),2,isb2,-isb1,'BR(H2-> ~b_2    ~b_
     .1*  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,isell,-isell,'BR(H2-> ~e_L-   ~e_L+  )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,iselr,-iselr,'BR(H2-> ~e_R-   ~e_R+  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,ismul,-ismul,'BR(H2-> ~mu_L-  ~mu_L+ )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,ismur,-ismur,'BR(H2-> ~mu_R-  ~mu_R+ )'
      endif
      if(brwhigstauc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,1),2,istau1,-istau1,'BR(H2-> ~tau_
     .1- ~tau_1+)'
      endif
      if(brwhigstauc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,2),2,istau2,-istau2,'BR(H2-> ~tau_
     .2- ~tau_2+)'
      endif
      if(brwhigstauc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,2),2,istau1,-istau2,'BR(H2-> ~tau_
     .1- ~tau_2+)'
      endif
      if(brwhigstauc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,1),2,istau2,-istau1,'BR(H2-> ~tau_
     .2- ~tau_1+)'
      endif
      if(bhislnl1.ne.0.D0) then
      write(nout,102) bhislnl1,2,inel,-inel  ,'BR(H2-> ~nu_eL  ~nu_eL*  
     . )'
      write(nout,102) bhislnl1,2,inmul,-inmul,'BR(H2-> ~nu_muL ~nu_muL* 
     . )'
      endif
      if(bhislnl3.ne.0.D0) then
      write(nout,102) bhislnl3,2,intau1,-intau1,'BR(H2-> ~nu_tauL ~nu_ta
     .uL*)'
      endif

      elseif(whitotc(2).eq.0.D0) then
      write(nout,99)
      write(nout,100) 35,0.000000000E+00,'H2 decays'

      endif

c --- H3 decays --- c

      elseif(i.eq.3) then
         write(nout,105)

      if(whitotc(i).ne.0.D0) then
      write(nout,99)
      write(nout,100) 36,whitotc(3),'H3 decays'

      write(nout,101)
      if(brhigbbc(i).ne.0.D0) then
      write(nout,102) brhigbbc(i),2,ib,ibb,'BR(H3-> b       bb     )'
      endif
      if(brhigllc(i).ne.0.D0) then
      write(nout,102) brhigllc(i),2,-itau,itau,'BR(H3-> tau+    tau-   )
     .'
      endif
      if(brhigmmc(i).ne.0.D0) then
      write(nout,102) brhigmmc(i),2,-imu,imu,'BR(H3-> mu+     mu-    )'
      endif
      if(brhigssc(i).ne.0.D0) then
      write(nout,102) brhigssc(i),2,is,isb  ,'BR(H3-> s       sb     )'
      endif
      if(brhigccc(i).ne.0.D0) then
      write(nout,102) brhigccc(i),2,ic,icb  ,'BR(H3-> c       cb     )'
      endif
      if(brhigttc(i).ne.0.D0) then
      write(nout,102) brhigttc(i),2,it,itb  ,'BR(H3-> t       tb     )' 
      endif
      if(brhigggc(i).ne.0.D0) then
      write(nout,102) brhigggc(i),2,igl,igl ,'BR(H3-> g       g      )' 
      endif
      if(brhiggac(i).ne.0.D0) then
      write(nout,102) brhiggac(i),2,iga,iga ,'BR(H3-> gam     gam    )' 
      endif
      if(brhigzgac(i).ne.0.D0) then
      write(nout,102) brhigzgac(i),2,iz,iga ,'BR(H3-> Z       gam    )' 
      endif
      if(brhigwwc(i).ne.0.D0) then
      write(nout,102) brhigwwc(i),2,iwc,-iwc,'BR(H3-> W+      W-     )' 
      endif
      if(brhigzzc(i).ne.0.D0) then
      write(nout,102) brhigzzc(i),2,iz,iz   ,'BR(H3-> Z       Z      )' 
      endif
      if(brhitohjzc(i,1).ne.0.D0) then
      write(nout,102) brhitohjzc(i,1),2,iz,ih1,'BR(H3-> Z       H1     )
     .' 
      endif
      if(brhitohjzc(i,2).ne.0.D0) then
      write(nout,102) brhitohjzc(i,2),2,iz,ih2,'BR(H3-> Z       H2     )
     .' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,-iwc,ihc,'BR(H3-> W-      H
     .+     )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,iwc,-ihc,'BR(H3-> W+      H
     .-     )' 
      endif
      if(brhitohjhkc(3,1,1).ne.0.D0) then
      write(nout,102) brhitohjhkc(3,1,1),2,ih1,ih1,'BR(H3-> H1      H1  
     .   )' 
      endif
      if(brhitohjhkc(3,1,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(3,1,2),2,ih1,ih2,'BR(H3-> H1      H2  
     .   )' 
      endif
      if(brhitohjhkc(3,2,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(3,2,2),2,ih2,ih2,'BR(H3-> H2      H2  
     .   )' 
      endif
      if(brwhigchc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,1),2,ic1,-ic1,'BR(H3-> ~chi_1+ ~chi_
     .1-)' 
      endif
      if(brwhigchc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,2),2,ic2,-ic2,'BR(H3-> ~chi_2+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,2),2,ic1,-ic2,'BR(H3-> ~chi_1+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,1),2,ic2,-ic1,'BR(H3-> ~chi_2+ ~chi_
     .1-)' 
      endif
      brwhignec(i,1,2) = 2.D0*brwhignec(i,1,2)
      brwhignec(i,1,3) = 2.D0*brwhignec(i,1,3)
      brwhignec(i,1,4) = 2.D0*brwhignec(i,1,4)
      brwhignec(i,1,5) = 2.D0*brwhignec(i,1,5)
      brwhignec(i,2,3) = 2.D0*brwhignec(i,2,3)
      brwhignec(i,2,4) = 2.D0*brwhignec(i,2,4)
      brwhignec(i,2,5) = 2.D0*brwhignec(i,2,5)
      brwhignec(i,3,4) = 2.D0*brwhignec(i,3,4)
      brwhignec(i,3,5) = 2.D0*brwhignec(i,3,5)
      brwhignec(i,4,5) = 2.D0*brwhignec(i,4,5)
      if(brwhignec(i,1,1).ne.0.D0) then
      write(nout,102) brwhignec(i,1,1),2,in1,in1 ,'BR(H3-> ~chi_10 ~chi_
     .10)' 
      endif
      if(brwhignec(i,1,2).ne.0.D0) then
      write(nout,102) brwhignec(i,1,2),2,in1,in2 ,'BR(H3-> ~chi_10 ~chi_
     .20)' 
      endif
      if(brwhignec(i,1,3).ne.0.D0) then
      write(nout,102) brwhignec(i,1,3),2,in1,in3 ,'BR(H3-> ~chi_10 ~chi_
     .30)' 
      endif
      if(brwhignec(i,1,4).ne.0.D0) then
      write(nout,102) brwhignec(i,1,4),2,in1,in4 ,'BR(H3-> ~chi_10 ~chi_
     .40)' 
      endif
      if(brwhignec(i,1,5).ne.0.D0) then
      write(nout,102) brwhignec(i,1,5),2,in1,in5 ,'BR(H3-> ~chi_10 ~chi_
     .50)' 
      endif
      if(brwhignec(i,2,2).ne.0.D0) then
      write(nout,102) brwhignec(i,2,2),2,in2,in2 ,'BR(H3-> ~chi_20 ~chi_
     .20)' 
      endif
      if(brwhignec(i,2,3).ne.0.D0) then
      write(nout,102) brwhignec(i,2,3),2,in2,in3 ,'BR(H3-> ~chi_20 ~chi_
     .30)' 
      endif
      if(brwhignec(i,2,4).ne.0.D0) then
      write(nout,102) brwhignec(i,2,4),2,in2,in4 ,'BR(H3-> ~chi_20 ~chi_
     .40)' 
      endif
      if(brwhignec(i,2,5).ne.0.D0) then
      write(nout,102) brwhignec(i,2,5),2,in2,in5 ,'BR(H3-> ~chi_20 ~chi_
     .50)' 
      endif
      if(brwhignec(i,3,3).ne.0.D0) then
      write(nout,102) brwhignec(i,3,3),2,in3,in3 ,'BR(H3-> ~chi_30 ~chi_
     .30)' 
      endif
      if(brwhignec(i,3,4).ne.0.D0) then
      write(nout,102) brwhignec(i,3,4),2,in3,in4 ,'BR(H3-> ~chi_30 ~chi_
     .40)' 
      endif
      if(brwhignec(i,3,5).ne.0.D0) then
      write(nout,102) brwhignec(i,3,5),2,in3,in5 ,'BR(H3-> ~chi_30 ~chi_
     .50)' 
      endif
      if(brwhignec(i,4,4).ne.0.D0) then
      write(nout,102) brwhignec(i,4,4),2,in4,in4 ,'BR(H3-> ~chi_40 ~chi_
     .40)' 
      endif
      if(brwhignec(i,4,5).ne.0.D0) then
      write(nout,102) brwhignec(i,4,5),2,in4,in5 ,'BR(H3-> ~chi_40 ~chi_
     .50)' 
      endif
      bhislnl1 = brwhigslnlc(i)/2.D0
      bhislnl3 = brwhigslnltauc(i)
      bhislel1 = brwhigslelc(i)/2.D0
      bhisler1 = brwhigslerc(i)/2.D0
      bhisqul1 = brwhigsqulc(i)/2.d0
      bhisqur1 = brwhigsqurc(i)/2.d0
      bhisqdl1 = brwhigsqdlc(i)/2.d0
      bhisqdr1 = brwhigsqdrc(i)/2.d0
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,isul,-isul  ,'BR(H3-> ~u_L    ~u_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,isur,-isur  ,'BR(H3-> ~u_R    ~u_R*  )'
      endif
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,iscl,-iscl  ,'BR(H3-> ~c_L    ~c_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,iscr,-iscr  ,'BR(H3-> ~c_R    ~c_R*  )'
      endif
      if(brwhigstc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,1),2,ist1,-ist1,'BR(H3-> ~t_1    ~t_
     .1*  )'
      endif
      if(brwhigstc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,2),2,ist2,-ist2,'BR(H3-> ~t_2    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,2),2,ist1,-ist2,'BR(H3-> ~t_1    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,1),2,ist2,-ist1,'BR(H3-> ~t_2    ~t_
     .1*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,isdl,-isdl  ,'BR(H3-> ~d_L    ~d_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,isdr,-isdr  ,'BR(H3-> ~d_R    ~d_R*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,issl,-issl  ,'BR(H3-> ~s_L    ~s_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,issr,-issr  ,'BR(H3-> ~s_R    ~s_R*  )'
      endif
      if(brwhigsbc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,1),2,isb1,-isb1,'BR(H3-> ~b_1    ~b_
     .1*  )'
      endif
      if(brwhigsbc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,2),2,isb2,-isb2,'BR(H3-> ~b_2    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,2),2,isb1,-isb2,'BR(H3-> ~b_1    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,1),2,isb2,-isb1,'BR(H3-> ~b_2    ~b_
     .1*  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,isell,-isell,'BR(H3-> ~e_L-   ~e_L+  )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,iselr,-iselr,'BR(H3-> ~e_R-   ~e_R+  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,ismul,-ismul,'BR(H3-> ~mu_L-  ~mu_L+ )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,ismur,-ismur,'BR(H3-> ~mu_R-  ~mu_R+ )'
      endif
      if(brwhigstauc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,1),2,istau1,-istau1,'BR(H3-> ~tau_
     .1- ~tau_1+)'
      endif
      if(brwhigstauc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,2),2,istau2,-istau2,'BR(H3-> ~tau_
     .2- ~tau_2+)'
      endif
      if(brwhigstauc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,2),2,istau1,-istau2,'BR(H3-> ~tau_
     .1- ~tau_2+)'
      endif
      if(brwhigstauc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,1),2,istau2,-istau1,'BR(H3-> ~tau_
     .2- ~tau_1+)'
      endif
      if(bhislnl1.ne.0.D0) then
      write(nout,102) bhislnl1,2,inel,-inel  ,'BR(H3-> ~nu_eL  ~nu_eL*  
     . )'
      write(nout,102) bhislnl1,2,inmul,-inmul,'BR(H3-> ~nu_muL ~nu_muL* 
     . )'
      endif
      if(bhislnl3.ne.0.D0) then
      write(nout,102) bhislnl3,2,intau1,-intau1,'BR(H3-> ~nu_tauL ~nu_ta
     .uL*)'
      endif

      elseif(whitotc(3).eq.0.D0) then
      write(nout,99)
      write(nout,100) 36,0.000000000E+00,'H3 decays'

      endif

c --- H4 decays --- c

      elseif(i.eq.4) then
         write(nout,105)

      if(whitotc(i).ne.0.D0) then
      write(nout,99)
      write(nout,100) 45,whitotc(4),'H4 decays'

      write(nout,101)
      if(brhigbbc(i).ne.0.D0) then
      write(nout,102) brhigbbc(i),2,ib,ibb,'BR(H4-> b       bb     )'
      endif
      if(brhigllc(i).ne.0.D0) then
      write(nout,102) brhigllc(i),2,-itau,itau,'BR(H4-> tau+    tau-   )
     .'
      endif
      if(brhigmmc(i).ne.0.D0) then
      write(nout,102) brhigmmc(i),2,-imu,imu,'BR(H4-> mu+     mu-    )'
      endif
      if(brhigssc(i).ne.0.D0) then
      write(nout,102) brhigssc(i),2,is,isb  ,'BR(H4-> s       sb     )'
      endif
      if(brhigccc(i).ne.0.D0) then
      write(nout,102) brhigccc(i),2,ic,icb  ,'BR(H4-> c       cb     )'
      endif
      if(brhigttc(i).ne.0.D0) then
      write(nout,102) brhigttc(i),2,it,itb  ,'BR(H4-> t       tb     )' 
      endif
      if(brhigggc(i).ne.0.D0) then
      write(nout,102) brhigggc(i),2,igl,igl ,'BR(H4-> g       g      )' 
      endif
      if(brhiggac(i).ne.0.D0) then
      write(nout,102) brhiggac(i),2,iga,iga ,'BR(H4-> gam     gam    )' 
      endif
      if(brhigzgac(i).ne.0.D0) then
      write(nout,102) brhigzgac(i),2,iz,iga ,'BR(H4-> Z       gam    )' 
      endif
      if(brhigwwc(i).ne.0.D0) then
      write(nout,102) brhigwwc(i),2,iwc,-iwc,'BR(H4-> W+      W-     )' 
      endif
      if(brhigzzc(i).ne.0.D0) then
      write(nout,102) brhigzzc(i),2,iz,iz   ,'BR(H4-> Z       Z      )' 
      endif
      if(brhitohjzc(i,1).ne.0.D0) then
      write(nout,102) brhitohjzc(i,1),2,iz,ih1,'BR(H4-> Z       H1     )
     .' 
      endif
      if(brhitohjzc(i,2).ne.0.D0) then
      write(nout,102) brhitohjzc(i,2),2,iz,ih2,'BR(H4-> Z       H2     )
     .' 
      endif
      if(brhitohjzc(i,3).ne.0.D0) then
      write(nout,102) brhitohjzc(i,3),2,iz,ih3,'BR(H4-> Z       H3     )
     .' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,-iwc,ihc,'BR(H4-> W-      H
     .+     )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,iwc,-ihc,'BR(H4-> W+      H
     .-     )' 
      endif
      if(brhitohjhkc(4,1,1).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,1,1),2,ih1,ih1,'BR(H4-> H1      H1  
     .   )' 
      endif
      if(brhitohjhkc(4,1,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,1,2),2,ih1,ih2,'BR(H4-> H1      H2  
     .   )' 
      endif
      if(brhitohjhkc(4,1,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,1,3),2,ih1,ih3,'BR(H4-> H1      H3  
     .   )' 
      endif
      if(brhitohjhkc(4,2,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,2,2),2,ih2,ih2,'BR(H4-> H2      H2  
     .   )' 
      endif
      if(brhitohjhkc(4,2,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,2,3),2,ih2,ih3,'BR(H4-> H2      H3  
     .   )' 
      endif
      if(brhitohjhkc(4,3,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(4,3,3),2,ih3,ih3,'BR(H4-> H3      H3  
     .   )' 
      endif
      if(brwhigchc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,1),2,ic1,-ic1,'BR(H4-> ~chi_1+ ~chi_
     .1-)' 
      endif
      if(brwhigchc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,2),2,ic2,-ic2,'BR(H4-> ~chi_2+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,2),2,ic1,-ic2,'BR(H4-> ~chi_1+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,1),2,ic2,-ic1,'BR(H4-> ~chi_2+ ~chi_
     .1-)' 
      endif
      brwhignec(i,1,2) = 2.D0*brwhignec(i,1,2)
      brwhignec(i,1,3) = 2.D0*brwhignec(i,1,3)
      brwhignec(i,1,4) = 2.D0*brwhignec(i,1,4)
      brwhignec(i,1,5) = 2.D0*brwhignec(i,1,5)
      brwhignec(i,2,3) = 2.D0*brwhignec(i,2,3)
      brwhignec(i,2,4) = 2.D0*brwhignec(i,2,4)
      brwhignec(i,2,5) = 2.D0*brwhignec(i,2,5)
      brwhignec(i,3,4) = 2.D0*brwhignec(i,3,4)
      brwhignec(i,3,5) = 2.D0*brwhignec(i,3,5)
      brwhignec(i,4,5) = 2.D0*brwhignec(i,4,5)
      if(brwhignec(i,1,1).ne.0.D0) then
      write(nout,102) brwhignec(i,1,1),2,in1,in1 ,'BR(H4-> ~chi_10 ~chi_
     .10)' 
      endif
      if(brwhignec(i,1,2).ne.0.D0) then
      write(nout,102) brwhignec(i,1,2),2,in1,in2 ,'BR(H4-> ~chi_10 ~chi_
     .20)' 
      endif
      if(brwhignec(i,1,3).ne.0.D0) then
      write(nout,102) brwhignec(i,1,3),2,in1,in3 ,'BR(H4-> ~chi_10 ~chi_
     .30)' 
      endif
      if(brwhignec(i,1,4).ne.0.D0) then
      write(nout,102) brwhignec(i,1,4),2,in1,in4 ,'BR(H4-> ~chi_10 ~chi_
     .40)' 
      endif
      if(brwhignec(i,1,5).ne.0.D0) then
      write(nout,102) brwhignec(i,1,5),2,in1,in5 ,'BR(H4-> ~chi_10 ~chi_
     .50)' 
      endif
      if(brwhignec(i,2,2).ne.0.D0) then
      write(nout,102) brwhignec(i,2,2),2,in2,in2 ,'BR(H4-> ~chi_20 ~chi_
     .20)' 
      endif
      if(brwhignec(i,2,3).ne.0.D0) then
      write(nout,102) brwhignec(i,2,3),2,in2,in3 ,'BR(H4-> ~chi_20 ~chi_
     .30)' 
      endif
      if(brwhignec(i,2,4).ne.0.D0) then
      write(nout,102) brwhignec(i,2,4),2,in2,in4 ,'BR(H4-> ~chi_20 ~chi_
     .40)' 
      endif
      if(brwhignec(i,2,5).ne.0.D0) then
      write(nout,102) brwhignec(i,2,5),2,in2,in5 ,'BR(H4-> ~chi_20 ~chi_
     .50)' 
      endif
      if(brwhignec(i,3,3).ne.0.D0) then
      write(nout,102) brwhignec(i,3,3),2,in3,in3 ,'BR(H4-> ~chi_30 ~chi_
     .30)' 
      endif
      if(brwhignec(i,3,4).ne.0.D0) then
      write(nout,102) brwhignec(i,3,4),2,in3,in4 ,'BR(H4-> ~chi_30 ~chi_
     .40)' 
      endif
      if(brwhignec(i,3,5).ne.0.D0) then
      write(nout,102) brwhignec(i,3,5),2,in3,in5 ,'BR(H4-> ~chi_30 ~chi_
     .50)' 
      endif
      if(brwhignec(i,4,4).ne.0.D0) then
      write(nout,102) brwhignec(i,4,4),2,in4,in4 ,'BR(H4-> ~chi_40 ~chi_
     .40)' 
      endif
      if(brwhignec(i,4,5).ne.0.D0) then
      write(nout,102) brwhignec(i,4,5),2,in4,in5 ,'BR(H4-> ~chi_40 ~chi_
     .50)' 
      endif
      bhislnl1 = brwhigslnlc(i)/2.D0
      bhislnl3 = brwhigslnltauc(i)
      bhislel1 = brwhigslelc(i)/2.D0
      bhisler1 = brwhigslerc(i)/2.D0
      bhisqul1 = brwhigsqulc(i)/2.d0
      bhisqur1 = brwhigsqurc(i)/2.d0
      bhisqdl1 = brwhigsqdlc(i)/2.d0
      bhisqdr1 = brwhigsqdrc(i)/2.d0
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,isul,-isul  ,'BR(H4-> ~u_L    ~u_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,isur,-isur  ,'BR(H4-> ~u_R    ~u_R*  )'
      endif
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,iscl,-iscl  ,'BR(H4-> ~c_L    ~c_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,iscr,-iscr  ,'BR(H4-> ~c_R    ~c_R*  )'
      endif
      if(brwhigstc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,1),2,ist1,-ist1,'BR(H4-> ~t_1    ~t_
     .1*  )'
      endif
      if(brwhigstc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,2),2,ist2,-ist2,'BR(H4-> ~t_2    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,2),2,ist1,-ist2,'BR(H4-> ~t_1    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,1),2,ist2,-ist1,'BR(H4-> ~t_2    ~t_
     .1*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,isdl,-isdl  ,'BR(H4-> ~d_L    ~d_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,isdr,-isdr  ,'BR(H4-> ~d_R    ~d_R*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,issl,-issl  ,'BR(H4-> ~s_L    ~s_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,issr,-issr  ,'BR(H4-> ~s_R    ~s_R*  )'
      endif
      if(brwhigsbc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,1),2,isb1,-isb1,'BR(H4-> ~b_1    ~b_
     .1*  )'
      endif
      if(brwhigsbc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,2),2,isb2,-isb2,'BR(H4-> ~b_2    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,2),2,isb1,-isb2,'BR(H4-> ~b_1    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,1),2,isb2,-isb1,'BR(H4-> ~b_2    ~b_
     .1*  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,isell,-isell,'BR(H4-> ~e_L-   ~e_L+  )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,iselr,-iselr,'BR(H4-> ~e_R-   ~e_R+  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,ismul,-ismul,'BR(H4-> ~mu_L-  ~mu_L+ )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,ismur,-ismur,'BR(H4-> ~mu_R-  ~mu_R+ )'
      endif
      if(brwhigstauc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,1),2,istau1,-istau1,'BR(H4-> ~tau_
     .1- ~tau_1+)'
      endif
      if(brwhigstauc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,2),2,istau2,-istau2,'BR(H4-> ~tau_
     .2- ~tau_2+)'
      endif
      if(brwhigstauc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,2),2,istau1,-istau2,'BR(H4-> ~tau_
     .1- ~tau_2+)'
      endif
      if(brwhigstauc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,1),2,istau2,-istau1,'BR(H4-> ~tau_
     .2- ~tau_1+)'
      endif
      if(bhislnl1.ne.0.D0) then
      write(nout,102) bhislnl1,2,inel,-inel  ,'BR(H4-> ~nu_eL  ~nu_eL*  
     . )'
      write(nout,102) bhislnl1,2,inmul,-inmul,'BR(H4-> ~nu_muL ~nu_muL* 
     . )'
      endif
      if(bhislnl3.ne.0.D0) then
      write(nout,102) bhislnl3,2,intau1,-intau1,'BR(H4-> ~nu_tauL ~nu_ta
     .uL*)'
      endif

      elseif(whitotc(4).eq.0.D0) then
      write(nout,99)
      write(nout,100) 45,0.000000000E+00,'H4 decays'

      endif

c --- H5 decays --- c

      elseif(i.eq.5) then
         write(nout,105)

      if(whitotc(i).ne.0.D0) then
      write(nout,99)
      write(nout,100) 46,whitotc(5),'H5 decays'

      write(nout,101)
      if(brhigbbc(i).ne.0.D0) then
      write(nout,102) brhigbbc(i),2,ib,ibb,'BR(H5-> b       bb     )'
      endif
      if(brhigllc(i).ne.0.D0) then
      write(nout,102) brhigllc(i),2,-itau,itau,'BR(H5-> tau+    tau-   )
     .'
      endif
      if(brhigmmc(i).ne.0.D0) then
      write(nout,102) brhigmmc(i),2,-imu,imu,'BR(H5-> mu+     mu-    )'
      endif
      if(brhigssc(i).ne.0.D0) then
      write(nout,102) brhigssc(i),2,is,isb  ,'BR(H5-> s       sb     )'
      endif
      if(brhigccc(i).ne.0.D0) then
      write(nout,102) brhigccc(i),2,ic,icb  ,'BR(H5-> c       cb     )'
      endif
      if(brhigttc(i).ne.0.D0) then
      write(nout,102) brhigttc(i),2,it,itb  ,'BR(H5-> t       tb     )' 
      endif
      if(brhigggc(i).ne.0.D0) then
      write(nout,102) brhigggc(i),2,igl,igl ,'BR(H5-> g       g      )' 
      endif
      if(brhiggac(i).ne.0.D0) then
      write(nout,102) brhiggac(i),2,iga,iga ,'BR(H5-> gam     gam    )' 
      endif
      if(brhigzgac(i).ne.0.D0) then
      write(nout,102) brhigzgac(i),2,iz,iga ,'BR(H5-> Z       gam    )' 
      endif
      if(brhigwwc(i).ne.0.D0) then
      write(nout,102) brhigwwc(i),2,iwc,-iwc,'BR(H5-> W+      W-     )' 
      endif
      if(brhigzzc(i).ne.0.D0) then
      write(nout,102) brhigzzc(i),2,iz,iz   ,'BR(H5-> Z       Z      )' 
      endif
      if(brhitohjzc(i,1).ne.0.D0) then
      write(nout,102) brhitohjzc(i,1),2,iz,ih1,'BR(H5-> Z       H1     )
     .' 
      endif
      if(brhitohjzc(i,2).ne.0.D0) then
      write(nout,102) brhitohjzc(i,2),2,iz,ih2,'BR(H5-> Z       H2     )
     .' 
      endif
      if(brhitohjzc(i,3).ne.0.D0) then
      write(nout,102) brhitohjzc(i,3),2,iz,ih3,'BR(H5-> Z       H3     )
     .' 
      endif
      if(brhitohjzc(i,4).ne.0.D0) then
      write(nout,102) brhitohjzc(i,4),2,iz,ih4,'BR(H5-> Z       H4     )
     .' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,-iwc,ihc,'BR(H5-> W-      H
     .+     )' 
      endif
      if(brhigtohpwmc(i).ne.0.D0) then
      write(nout,102) brhigtohpwmc(i)/2.D0,2,iwc,-ihc,'BR(H5-> W+      H
     .-     )' 
      endif
      if(brhitohjhkc(5,1,1).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,1,1),2,ih1,ih1,'BR(H5-> H1      H1  
     .   )' 
      endif
      if(brhitohjhkc(5,1,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,1,2),2,ih1,ih2,'BR(H5-> H1      H2  
     .   )' 
      endif
      if(brhitohjhkc(5,1,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,1,3),2,ih1,ih3,'BR(H5-> H1      H3  
     .   )' 
      endif
      if(brhitohjhkc(5,1,4).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,1,4),2,ih1,ih4,'BR(H5-> H1      H4  
     .   )' 
      endif
      if(brhitohjhkc(5,2,2).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,2,2),2,ih2,ih2,'BR(H5-> H2      H2  
     .   )' 
      endif
      if(brhitohjhkc(5,2,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,2,3),2,ih2,ih3,'BR(H5-> H2      H3  
     .   )' 
      endif
      if(brhitohjhkc(5,2,4).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,2,4),2,ih2,ih4,'BR(H5-> H2      H4  
     .   )' 
      endif
      if(brhitohjhkc(5,3,3).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,3,3),2,ih3,ih3,'BR(H5-> H3      H3  
     .   )' 
      endif
      if(brhitohjhkc(5,3,4).ne.0.D0) then
      write(nout,102) brhitohjhkc(5,3,4),2,ih3,ih4,'BR(H5-> H3      H4  
     .   )' 
      endif
      if(brwhigchc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,1),2,ic1,-ic1,'BR(H5-> ~chi_1+ ~chi_
     .1-)' 
      endif
      if(brwhigchc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,2),2,ic2,-ic2,'BR(H5-> ~chi_2+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigchc(i,1,2),2,ic1,-ic2,'BR(H5-> ~chi_1+ ~chi_
     .2-)' 
      endif
      if(brwhigchc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigchc(i,2,1),2,ic2,-ic1,'BR(H5-> ~chi_2+ ~chi_
     .1-)' 
      endif
      brwhignec(i,1,2) = 2.D0*brwhignec(i,1,2)
      brwhignec(i,1,3) = 2.D0*brwhignec(i,1,3)
      brwhignec(i,1,4) = 2.D0*brwhignec(i,1,4)
      brwhignec(i,1,5) = 2.D0*brwhignec(i,1,5)
      brwhignec(i,2,3) = 2.D0*brwhignec(i,2,3)
      brwhignec(i,2,4) = 2.D0*brwhignec(i,2,4)
      brwhignec(i,2,5) = 2.D0*brwhignec(i,2,5)
      brwhignec(i,3,4) = 2.D0*brwhignec(i,3,4)
      brwhignec(i,3,5) = 2.D0*brwhignec(i,3,5)
      brwhignec(i,4,5) = 2.D0*brwhignec(i,4,5)
      if(brwhignec(i,1,1).ne.0.D0) then
      write(nout,102) brwhignec(i,1,1),2,in1,in1 ,'BR(H5-> ~chi_10 ~chi_
     .10)' 
      endif
      if(brwhignec(i,1,2).ne.0.D0) then
      write(nout,102) brwhignec(i,1,2),2,in1,in2 ,'BR(H5-> ~chi_10 ~chi_
     .20)' 
      endif
      if(brwhignec(i,1,3).ne.0.D0) then
      write(nout,102) brwhignec(i,1,3),2,in1,in3 ,'BR(H5-> ~chi_10 ~chi_
     .30)' 
      endif
      if(brwhignec(i,1,4).ne.0.D0) then
      write(nout,102) brwhignec(i,1,4),2,in1,in4 ,'BR(H5-> ~chi_10 ~chi_
     .40)' 
      endif
      if(brwhignec(i,1,5).ne.0.D0) then
      write(nout,102) brwhignec(i,1,5),2,in1,in5 ,'BR(H5-> ~chi_10 ~chi_
     .50)' 
      endif
      if(brwhignec(i,2,2).ne.0.D0) then
      write(nout,102) brwhignec(i,2,2),2,in2,in2 ,'BR(H5-> ~chi_20 ~chi_
     .20)' 
      endif
      if(brwhignec(i,2,3).ne.0.D0) then
      write(nout,102) brwhignec(i,2,3),2,in2,in3 ,'BR(H5-> ~chi_20 ~chi_
     .30)' 
      endif
      if(brwhignec(i,2,4).ne.0.D0) then
      write(nout,102) brwhignec(i,2,4),2,in2,in4 ,'BR(H5-> ~chi_20 ~chi_
     .40)' 
      endif
      if(brwhignec(i,2,5).ne.0.D0) then
      write(nout,102) brwhignec(i,2,5),2,in2,in5 ,'BR(H5-> ~chi_20 ~chi_
     .50)' 
      endif
      if(brwhignec(i,3,3).ne.0.D0) then
      write(nout,102) brwhignec(i,3,3),2,in3,in3 ,'BR(H5-> ~chi_30 ~chi_
     .30)' 
      endif
      if(brwhignec(i,3,4).ne.0.D0) then
      write(nout,102) brwhignec(i,3,4),2,in3,in4 ,'BR(H5-> ~chi_30 ~chi_
     .40)' 
      endif
      if(brwhignec(i,3,5).ne.0.D0) then
      write(nout,102) brwhignec(i,3,5),2,in3,in5 ,'BR(H5-> ~chi_30 ~chi_
     .50)' 
      endif
      if(brwhignec(i,4,4).ne.0.D0) then
      write(nout,102) brwhignec(i,4,4),2,in4,in4 ,'BR(H5-> ~chi_40 ~chi_
     .40)' 
      endif
      if(brwhignec(i,4,5).ne.0.D0) then
      write(nout,102) brwhignec(i,4,5),2,in4,in5 ,'BR(H5-> ~chi_40 ~chi_
     .50)' 
      endif
      bhislnl1 = brwhigslnlc(i)/2.D0
      bhislnl3 = brwhigslnltauc(i)
      bhislel1 = brwhigslelc(i)/2.D0
      bhisler1 = brwhigslerc(i)/2.D0
      bhisqul1 = brwhigsqulc(i)/2.d0
      bhisqur1 = brwhigsqurc(i)/2.d0
      bhisqdl1 = brwhigsqdlc(i)/2.d0
      bhisqdr1 = brwhigsqdrc(i)/2.d0
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,isul,-isul  ,'BR(H5-> ~u_L    ~u_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,isur,-isur  ,'BR(H5-> ~u_R    ~u_R*  )'
      endif
      if(bhisqul1.ne.0.D0) then
      write(nout,102) bhisqul1,2,iscl,-iscl  ,'BR(H5-> ~c_L    ~c_L*  )'
      endif
      if(bhisqur1.ne.0.D0) then
      write(nout,102) bhisqur1,2,iscr,-iscr  ,'BR(H5-> ~c_R    ~c_R*  )'
      endif
      if(brwhigstc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,1),2,ist1,-ist1,'BR(H5-> ~t_1    ~t_
     .1*  )'
      endif
      if(brwhigstc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,2),2,ist2,-ist2,'BR(H5-> ~t_2    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstc(i,1,2),2,ist1,-ist2,'BR(H5-> ~t_1    ~t_
     .2*  )'
      endif
      if(brwhigstc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstc(i,2,1),2,ist2,-ist1,'BR(H5-> ~t_2    ~t_
     .1*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,isdl,-isdl  ,'BR(H5-> ~d_L    ~d_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,isdr,-isdr  ,'BR(H5-> ~d_R    ~d_R*  )'
      endif
      if(bhisqdl1.ne.0.D0) then
      write(nout,102) bhisqdl1,2,issl,-issl  ,'BR(H5-> ~s_L    ~s_L*  )'
      endif
      if(bhisqdr1.ne.0.D0) then
      write(nout,102) bhisqdr1,2,issr,-issr  ,'BR(H5-> ~s_R    ~s_R*  )'
      endif
      if(brwhigsbc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,1),2,isb1,-isb1,'BR(H5-> ~b_1    ~b_
     .1*  )'
      endif
      if(brwhigsbc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,2),2,isb2,-isb2,'BR(H5-> ~b_2    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigsbc(i,1,2),2,isb1,-isb2,'BR(H5-> ~b_1    ~b_
     .2*  )'
      endif
      if(brwhigsbc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigsbc(i,2,1),2,isb2,-isb1,'BR(H5-> ~b_2    ~b_
     .1*  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,isell,-isell,'BR(H5-> ~e_L-   ~e_L+  )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,iselr,-iselr,'BR(H5-> ~e_R-   ~e_R+  )'
      endif
      if(bhislel1.ne.0.D0) then
      write(nout,102) bhislel1,2,ismul,-ismul,'BR(H5-> ~mu_L-  ~mu_L+ )'
      endif
      if(bhisler1.ne.0.D0) then
      write(nout,102) bhisler1,2,ismur,-ismur,'BR(H5-> ~mu_R-  ~mu_R+ )'
      endif
      if(brwhigstauc(i,1,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,1),2,istau1,-istau1,'BR(H5-> ~tau_
     .1- ~tau_1+)'
      endif
      if(brwhigstauc(i,2,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,2),2,istau2,-istau2,'BR(H5-> ~tau_
     .2- ~tau_2+)'
      endif
      if(brwhigstauc(i,1,2).ne.0.D0) then
      write(nout,102) brwhigstauc(i,1,2),2,istau1,-istau2,'BR(H5-> ~tau_
     .1- ~tau_2+)'
      endif
      if(brwhigstauc(i,2,1).ne.0.D0) then
      write(nout,102) brwhigstauc(i,2,1),2,istau2,-istau1,'BR(H5-> ~tau_
     .2- ~tau_1+)'
      endif
      if(bhislnl1.ne.0.D0) then
      write(nout,102) bhislnl1,2,inel,-inel  ,'BR(H5-> ~nu_eL  ~nu_eL*  
     . )'
      write(nout,102) bhislnl1,2,inmul,-inmul,'BR(H5-> ~nu_muL ~nu_muL* 
     . )'
      endif
      if(bhislnl3.ne.0.D0) then
      write(nout,102) bhislnl3,2,intau1,-intau1,'BR(H5-> ~nu_tauL ~nu_ta
     .uL*)'
      endif

      elseif(whitotc(5).eq.0.D0) then
      write(nout,99)
      write(nout,100) 46,0.000000000E+00,'H5 decays'

      endif

c ----------------- c

      endif

      end do

c --------- c
c H+ decays c
c --------- c

      if(hcwdthc.ne.0.D0) then
      write(nout,99)
      write(nout,100) 37,hcwdthc,'H+ decays'

      write(nout,101)
      if(hcbrbc.ne.0.D0) then
      write(nout,102) hcbrbc,2,ic,ibb       ,'BR(H+ -> c       bb     )'
      endif
      if(hcbrlc.ne.0.D0) then
      write(nout,102) hcbrlc,2,-itau,intau  ,'BR(H+ -> tau+    nu_tau )'
      endif
      if(hcbrmc.ne.0.D0) then
      write(nout,102) hcbrmc,2,-imu,inmu    ,'BR(H+ -> mu+     nu_mu  )'
      endif
      if(hcbrbuc.ne.0.D0) then
      write(nout,102) hcbrbuc,2,iu,ibb      ,'BR(H+ -> u       bb     )'
      endif
      if(hcbrsc.ne.0.D0) then
      write(nout,102) hcbrsc,2,iu,isb       ,'BR(H+ -> u       sb     )'
      endif
      if(hcbrcc.ne.0.D0) then
      write(nout,102) hcbrcc,2,ic,isb       ,'BR(H+ -> c       sb     )'
      endif
      if(hcbrdc.ne.0.D0) then
      write(nout,102) hcbrdc,2,ic,idb       ,'BR(H+ -> c       db     )'
      endif
      if(hcbrdtc.ne.0.D0) then
      write(nout,102) hcbrdtc,2,it,idb      ,'BR(H+ -> t       db     )'
      endif
      if(hcbrstc.ne.0.D0) then
      write(nout,102) hcbrstc,2,it,isb      ,'BR(H+ -> t       sb     )'
      endif
      if(hcbrtc.ne.0.D0) then
      write(nout,102) hcbrtc,2,it,ibb       ,'BR(H+ -> t       bb     )'
      endif
      if(hcbrwh1c.ne.0.D0) then
      write(nout,102) hcbrwh1c,2,iwc,ih1    ,'BR(H+ -> W+      H1     )'
      endif
      if(hcbrwh2c.ne.0.D0) then
      write(nout,102) hcbrwh2c,2,iwc,ih2    ,'BR(H+ -> W+      H2     )'
      endif
      if(hcbrwh3c.ne.0.D0) then
      write(nout,102) hcbrwh3c,2,iwc,ih3    ,'BR(H+ -> W+      H3     )'
      endif
      if(hcbrwh4c.ne.0.D0) then
      write(nout,102) hcbrwh4c,2,iwc,ih4    ,'BR(H+ -> W+      H4     )'
      endif
      if(hcbrwh5c.ne.0.D0) then
      write(nout,102) hcbrwh5c,2,iwc,ih5    ,'BR(H+ -> W+      H5     )'
      endif
      if(hcbrsuc(1,1).ne.0.D0) then
      write(nout,102) hcbrsuc(1,1),2,ic1,in1 ,'BR(H+ -> ~chi_1+ ~chi_10)
     .'
      endif
      if(hcbrsuc(1,2).ne.0.D0) then
      write(nout,102) hcbrsuc(1,2),2,ic1,in2 ,'BR(H+ -> ~chi_1+ ~chi_20)
     .'
      endif
      if(hcbrsuc(1,3).ne.0.D0) then
      write(nout,102) hcbrsuc(1,3),2,ic1,in3 ,'BR(H+ -> ~chi_1+ ~chi_30)
     .'
      endif
      if(hcbrsuc(1,4).ne.0.D0) then
      write(nout,102) hcbrsuc(1,4),2,ic1,in4 ,'BR(H+ -> ~chi_1+ ~chi_40)
     .'
      endif
      if(hcbrsuc(1,5).ne.0.D0) then
      write(nout,102) hcbrsuc(1,5),2,ic1,in5 ,'BR(H+ -> ~chi_1+ ~chi_50)
     .'
      endif
      if(hcbrsuc(2,1).ne.0.D0) then
      write(nout,102) hcbrsuc(2,1),2,ic2,in1 ,'BR(H+ -> ~chi_2+ ~chi_10)
     .'
      endif
      if(hcbrsuc(2,2).ne.0.D0) then
      write(nout,102) hcbrsuc(2,2),2,ic2,in2 ,'BR(H+ -> ~chi_2+ ~chi_20)
     .'
      endif
      if(hcbrsuc(2,3).ne.0.D0) then
      write(nout,102) hcbrsuc(2,3),2,ic2,in3 ,'BR(H+ -> ~chi_2+ ~chi_30)
     .'
      endif
      if(hcbrsuc(2,4).ne.0.D0) then
      write(nout,102) hcbrsuc(2,4),2,ic2,in4 ,'BR(H+ -> ~chi_2+ ~chi_40)
     .'
      endif
      if(hcbrsuc(2,5).ne.0.D0) then
      write(nout,102) hcbrsuc(2,5),2,ic2,in5 ,'BR(H+ -> ~chi_2+ ~chi_50)
     .'
      endif
      bhcsl02=bhcsl00c/2.D0
      if(bhcsl02.ne.0.D0) then
      write(nout,102) bhcsl02,2,-isell,inel ,'BR(H+ -> ~e_L+   ~nu_eL )'
      write(nout,102) bhcsl02,2,-ismul,inmul,'BR(H+ -> ~mu_L+  ~nu_muL)'
      endif
      if(bhcsl11c.ne.0.D0) then
      write(nout,102) bhcsl11c,2,-istau1,intau1,'BR(H+ -> ~tau_1+ ~nu_ta
     .uL)'
      endif
      if(bhcsl21c.ne.0.D0) then
      write(nout,102) bhcsl21c,2,-istau2,intau1,'BR(H+ -> ~tau_2+ ~nu_ta
     .uL)'
      endif
      hcbrsq1=hcbrsqc/2.D0
      if(hcbrsq1.ne.0.D0) then
      write(nout,102) hcbrsq1,2,isul,-isdl  ,'BR(H+ -> ~u_L    ~d_L*  )'
      write(nout,102) hcbrsq1,2,iscl,-issl  ,'BR(H+ -> ~c_L    ~s_L*  )'
      endif
      if(hcbrstbc(1,1).ne.0.D0) then
      write(nout,102) hcbrstbc(1,1),2,ist1,-isb1,'BR(H+ -> ~t_1    ~b_1*
     . )'
      endif
      if(hcbrstbc(2,2).ne.0.D0) then
      write(nout,102) hcbrstbc(2,2),2,ist2,-isb2,'BR(H+ -> ~t_2    ~b_2*
     . )'
      endif
      if(hcbrstbc(1,2).ne.0.D0) then
      write(nout,102) hcbrstbc(1,2),2,ist1,-isb2,'BR(H+ -> ~t_1    ~b_2*
     . )'
      endif
      if(hcbrstbc(2,1).ne.0.D0) then
      write(nout,102) hcbrstbc(2,1),2,ist2,-isb1,'BR(H+ -> ~t_2    ~b_1*
     . )'
      endif

      elseif(hcwdthc.eq.0.D0) then
      write(nout,99)
      write(nout,100) 37,0.000000000E+00,'H+ decays'

      endif

c -------------------------------------------------------------------- c
c ---------- c
c Top decays c
c ---------- c

      write(nout,105)

      if(gamt1.ne.0.D0) then
      write(nout,99)
      write(nout,100) 6,gamt1,'top decays'

      write(nout,101)
      if(gamt0.ne.0.D0) then
       write(nout,102) gamt0/gamt1,2,ib,iwc,'BR(t -> b       W+    )'
      endif
      if(gamt1-gamt0.ne.0.D0) then
       write(nout,102) (gamt1-gamt0)/gamt1,2,ib,ihc,
     .                                      'BR(t -> b       H+    )'
      endif

      elseif(gamt1.eq.0.D0) then
      write(nout,99)
      write(nout,100) 6,0.000000000E+00,'top decays'

      endif
      
      
C     HiggsBounds Blocks
      write(nout,105)
      write(nout,105)
      write(nout,51) 'HiggsCouplingsFermions', 
     .               'extra Block for HiggsBounds'
      write(nout,111)
      write(nout,112) gh1b,ga1b,3,25,5,5,
     .                'H1-b-b coupling normalized to SM'
      write(nout,112) gh2b,ga2b,3,35,5,5,
     .                'H2-b-b coupling normalized to SM'
      write(nout,112) gh3b,ga3b,3,36,5,5,
     .                'H3-b-b coupling normalized to SM'
      write(nout,112) gh4b,ga4b,3,45,5,5,
     .                'H4-b-b coupling normalized to SM'
      write(nout,112) gh5b,ga5b,3,46,5,5,
     .                'H5-b-b coupling normalized to SM'

      write(nout,105)
      write(nout,112) gh1t,ga1t,3,25,6,6,
     .                'H1-t-t coupling normalized to SM'
      write(nout,112) gh2t,ga2t,3,35,6,6,
     .                'H2-t-t coupling normalized to SM'
      write(nout,112) gh3t,ga3t,3,36,6,6,
     .                'H3-t-t coupling normalized to SM'
      write(nout,112) gh4t,ga4t,3,45,6,6,
     .                'H4-t-t coupling normalized to SM'
      write(nout,112) gh5t,ga5t,3,46,6,6,
     .                'H5-t-t coupling normalized to SM'

      write(nout,105)
      write(nout,112) gh1b,ga1b,3,25,15,15,
     .                'H1-tau-tau coupling normalized to SM'
      write(nout,112) gh2b,ga2b,3,35,15,15,
     .                'H2-tau-tau coupling normalized to SM'
      write(nout,112) gh3b,ga3b,3,36,15,15,
     .                'H3-tau-tau coupling normalized to SM'
      write(nout,112) gh4b,ga4b,3,45,15,15,
     .                'H4-tau-tau coupling normalized to SM'
      write(nout,112) gh5b,ga5b,3,46,15,15,
     .                'H5-tau-tau coupling normalized to SM'

      write(nout,105)
      write(nout,105)
      write(nout,51) 'HiggsCouplingsBosons', 
     .               'extra Block for HiggsBounds'
      write(nout,113) gh1vv,3,25,24,24,
     .                'H1-W-W coupling normalized to SM'
      write(nout,113) gh2vv,3,35,24,24,
     .                'H2-W-W coupling normalized to SM'
      write(nout,113) gh3vv,3,36,24,24,
     .                'H3-W-W coupling normalized to SM'
      write(nout,113) gh4vv,3,45,24,24,
     .                'H4-W-W coupling normalized to SM'
      write(nout,113) gh5vv,3,46,24,24,
     .                'H5-W-W coupling normalized to SM'
      write(nout,105)
      write(nout,113) gh1vv,3,25,23,23,
     .                'H1-Z-Z coupling normalized to SM'
      write(nout,113) gh2vv,3,35,23,23,
     .                'H2-Z-Z coupling normalized to SM'
      write(nout,113) gh3vv,3,36,23,23,
     .                'H3-Z-Z coupling normalized to SM'
      write(nout,113) gh4vv,3,45,23,23,
     .                'H4-Z-Z coupling normalized to SM'
      write(nout,113) gh5vv,3,46,23,23,
     .                'H5-Z-Z coupling normalized to SM'
      write(nout,105)
      write(nout,113) cj(1),3,25,21,21,
     .                'H1-gluon-gluon coupling normalized to SM'
      write(nout,113) cj(2),3,35,21,21,
     .                'H2-gluon-gluon coupling normalized to SM'
      write(nout,113) cj(3),3,36,21,21,
     .                'H3-gluon-gluon coupling normalized to SM'
      write(nout,113) cj(4),3,45,21,21,
     .                'H4-gluon-gluon coupling normalized to SM'
      write(nout,113) cj(5),3,46,21,21,
     .                'H5-gluon-gluon coupling normalized to SM'
      write(nout,105)
      write(nout,113) gzhihj(1,1),3,25,25,23,
     .                'H1-H1-Z coupling normalized to SM'
      write(nout,113) gzhihj(1,2),3,25,35,23,
     .                'H1-H2-Z coupling normalized to SM'
      write(nout,113) gzhihj(1,3),3,25,36,23,
     .                'H1-H3-Z coupling normalized to SM'
      write(nout,113) gzhihj(1,4),3,25,45,23,
     .                'H1-H4-Z coupling normalized to SM'
      write(nout,113) gzhihj(1,5),3,25,46,23,
     .                'H1-H5-Z coupling normalized to SM'
      write(nout,113) gzhihj(2,2),3,35,35,23,
     .                'H2-H2-Z coupling normalized to SM'
      write(nout,113) gzhihj(2,3),3,35,36,23,
     .                'H2-H3-Z coupling normalized to SM'
      write(nout,113) gzhihj(2,4),3,35,45,23,
     .                'H2-H4-Z coupling normalized to SM'
      write(nout,113) gzhihj(2,5),3,35,46,23,
     .                'H2-H5-Z coupling normalized to SM'
      write(nout,113) gzhihj(3,3),3,36,36,23,
     .                'H3-H3-Z coupling normalized to SM'
      write(nout,113) gzhihj(3,4),3,36,45,23,
     .                'H3-H4-Z coupling normalized to SM'
      write(nout,113) gzhihj(3,5),3,36,46,23,
     .                'H3-H5-Z coupling normalized to SM'
      write(nout,113) gzhihj(4,4),3,45,45,23,
     .                'H4-H4-Z coupling normalized to SM'
      write(nout,113) gzhihj(4,5),3,45,46,23,
     .                'H4-H5-Z coupling normalized to SM'
      write(nout,113) gzhihj(5,5),3,46,46,23,
     .                'H5-H5-Z coupling normalized to SM'
      write(nout,105) 
      write(nout,114) 0d0,4,25,21,21,23,
     .                'H1-gluon-gluon-Z coupling'
      write(nout,114) 0d0,4,35,21,21,23,
     .                'H2-gluon-gluon-Z coupling'
      write(nout,114) 0d0,4,36,21,21,23,
     .                'H3-gluon-gluon-Z coupling'
      write(nout,114) 0d0,4,45,21,21,23,
     .                'H4-gluon-gluon-Z coupling'
      write(nout,114) 0d0,4,46,21,21,23,
     .                'H5-gluon-gluon-Z coupling'
      write(nout,105)
     
c -------------------------------------------------------------------- c

 49   format('#',1x,A,E16.8)
 50   format('#',1x,A)
 51   format('BLOCK',1x,A,2x,'#',1x,A)
 551  format(1x,A,2x,'#',1x,A)
 52   format(1x,I9,3x,1P,E16.8,0P,3x,'#',1x,A)
 552  format(2x,E16.8,0P,3x,A)
 53   format(1x,I2,1x,I2,3x,1P,E16.8,0P,3x,'#',1x,A)
 54   format('BLOCK',1x,A,1P,E16.8,2x,'#',1x,A)
 554  format(2x,A,1P,E16.8,2x,1x,A)
 55   format(1x,I5,3x,1P,E16.8,0P,3x,'#',1x,A)
 56   format(1x,I4,3x,'#',1x,A,E16.8)
 57   format(1x,I5,3x,1P,E16.8,0P,3x,'#',1x,A,E16.8)
 58   format(1x,I2,1x,I2,3x,'#',1x,A)
 59   format(1x,I2,1x,I2,3x,1P,E16.8,0P,3x,'#',1x,A,E16.8)
 60   format(9x,1P,E16.8,0P,3x,'#',1x,A)
 61   format(1x,I5,3x,A)
 661  format(2x,A)
 62   format(1x,I5,1x,I5,3x,A)
 662  format(2x,A)
 63   format(1x,I5,3x,A,1x,'#',1x,A)

 99   format('#',9x,'PDG',12x,'Width')
 100  format('DECAY',1x,I9,3x,1P,E16.8,0P,3x,'#',1x,A)
 101  format('#',10x,'BR',9x,'NDA',6x,'ID1',7x,'ID2')
 102  format(3x,1P,E16.8,0P,3x,I2,3x,(I9,1x),(I9,1x),2x,'#',1x,A)
 103  format('#',11x,'BR',9x,'NDA',6x,'ID1',7x,'ID2',7x,'ID3')
 107  format('#',11x,'BR',9x,'NDA',6x,'ID1',7x,'ID2',7x,'ID3',7x,'ID4')
 104  format(3x,1P,E16.8,0P,3x,I2,3x,(I9,1x),(I9,1x),(I9,1x),2x,'#',
     .1x,A)
 106  format(3x,1P,E16.8,0P,3x,I2,3x,(I9,1x),(I9,1x),(I9,1x),(I9,1x),
     .2x,'#',1x,A)
 108  format(E16.8,2x,E16.8,2x,E16.8,2x,E16.8)
 105  format('#') 
 111  format('#',2x,'ScalarNormEffCoupSq',2x,'PseudoSNormEffCoupSq',6x,
     .       'NP',3x,'IP1',3x,'IP2',3x,'IP3')
 112  format(1x,E16.8,6x,E16.8,10x,I2,4x,I2,4x,I2,4x,I2,4x,'#',1x,A)
 113  format(1x,E16.8,10x,I2,4x,I2,4x,I2,4x,I2,4x,'#',1x,A) 
 114  format(1x,E16.8,10x,I2,4x,I2,4x,I2,4x,I2,4x,I2,4x,'#',1x,A)
 115  format(1x,E16.8,1x,E16.8,1x,E16.8,1x,E16.8,3x,I2,2x,I2,2x,I2,2X,'#',1x,A,I1,A,I1,A,I1," coupling" ) 
 116  format('#',A,9x,A,12x,A,9x,A,3x,A,2x,A,2x,A)  
 123  format(1x,I2,1x,I2,3x,1P,E16.8,0P,3x,'#',1x,A,'(',I1,',',I1,')')

      close(nout)
      close(nout2)

      return
      end

c ==================================================================== c
c ======= subroutine for the complex NMSSM Higgs boson decays ======== c
c ==================================================================== c

      subroutine hdec_cnmssm(tgbet)

      implicit double precision (a-h,o-z)
      character outputfile*100
      double precision lamb_hdec
      integer k,i,j
      complex*16 cfacq_hdec,cfacsq_hdec
      complex*16 ach1,ach2,ach3,ach4,ach5,aach1,aach2,aach3,aach4,
     .     aach5,acnl,acnr
      complex*16 xghpm
      complex*16 ghcen,ghctb,ghcelne,ghcud,gh1elel,
     .     gh1nene,gh1uu,gh1dd,gh1ee,gh1tt,
     .     gh1bb,gh2elel,gh2nene,gh2uu,gh2dd,
     .     gh2ee,gh2tt,gh2bb,gh3elel,gh3nene,
     .     gh3uu,gh3dd,gh3ee,gh3tt,gh3bb,
     .     gh4elel,gh4nene,gh4uu,gh4dd,gh4ee,
     .     gh4tt,gh4bb,gh5elel,gh5nene,gh5uu,
     .     gh5dd,gh5ee,gh5tt,gh5bb
c      complex*16 xgh1s,xgh2s,xgh3s,xgh4s,xgh5s,xgh1b,xgh2b,xgh3b,
c     .     xgh4b,xgh5b,xga1s,xga2s,xga3s,xga4s,xga5s,xga1b,xga2b,
c     .     xga3b,xga4b,xga5b
      complex*16 ghitt(5,2,2),ghibb(5,2,2),ghiee(5,2,2),
     .     ghiuu(5,2,2),ghidd(5,2,2),ghielel(5,2,2),ghinene(5,2,2)
      double precision slhahmix(5,5),ghit(5),gait(5),ghib(5),gaib(5),
     .     ghivv(5),ghihpwm(5),gaihpwm(5),gzhihj(5,5),ghihjhk(5,5,5),
     .     ghipm(5)
      double precision ghibv(5),gaibv(5),ghivvv(5),ghihpwmv(5),
     .     gaihpwmv(5),ghitv(5),gaitv(5),amhiv(5)
      double precision htoh(5),hitohjhk(5,5,5),hitohjhko(5,5,5),
     .     hitohhoff(5),whitot(5),hitohjz(5,5),htohz(5),hihw(5),
     .     higmm(5),errhitohjhko(5,5,5)
      complex*16 achi(5,2,2),aachi(5,2,2)
      complex*16 xghis(5),xgais(5),xghib(5),xgaib(5),xghigm(5),
     .     xgaigm(5),xghigb(5),xgaigb(5)
      double precision amhi(5)
      double precision higggc(5),higmmc(5),higllc(5),higssc(5),
     .     higccc(5),higbbc(5),higttc(5),higgac(5),higzgac(5),
     .     higwwc(5),higzzc(5)
      double precision whigchc(5,2,2),whigchtc(5)
      double precision whignec(5,5,5),whignetc(5)
      double precision whigslelc(5),whigslerc(5),whigslnlc(5),
     .     whigslnltauc(5),whigstauc(5,2,2),whigsltc(5)
      double precision whigsqulc(5),whigsqurc(5),whigsqdlc(5),
     .     whigsqdrc(5),whigsqc(5)
      double precision whigstc(5,2,2),whigsbc(5,2,2),whigsttc(5),
     .     whigsbbc(5),whigsqtc(5)
      double precision brhigggc(5),brhigmmc(5),brhigllc(5),brhigssc(5),
     .     brhigccc(5),brhigbbc(5),brhigttc(5),brhiggac(5),brhigzgac(5),
     .     brhigwwc(5),brhigzzc(5),brhigtohpwmc(5)
      double precision brhitohjhkc(5,5,5),brhitohjzc(5,5),
     .     brwhigchc(5,2,2),brwhignec(5,5,5),brwhigchtc(5),
     .     brwhignetc(5),brwhigsltc(5),brwhigsqc(5),brwhigsqtc(5),
     .     brwhigslnlc(5),brwhigslnltauc(5),brwhigslelc(5),
     .     brwhigslerc(5),brwhigsqulc(5),brwhigsqurc(5),brwhigsqdlc(5),
     .     brwhigsqdrc(5),brwhigstc(5,2,2),brwhigsbc(5,2,2),
     .     brwhigstauc(5,2,2)
      double precision whitotc(5)
      dimension xx(4),yy(4)
      dimension amchar(2),amneut(5),xmneut(5),ach1(2,2),ach2(2,2),
     .     ach3(2,2),ach4(2,2),ach5(2,2),
     .     acnl(2,5),acnr(2,5),aach1(2,2),aach2(2,2),aach3(2,2),
     .     aach4(2,2),aach5(2,2),anh1Rre(5,5),anh2Rre(5,5),anh3Rre(5,5),
     .     anh4Rre(5,5),anh5Rre(5,5),anh1Rim(5,5),anh2Rim(5,5),
     .     anh3Rim(5,5),anh4Rim(5,5),anh5Rim(5,5),anh1Lre(5,5),
     .     anh2Lre(5,5),anh3Lre(5,5),anh4Lre(5,5),anh5Lre(5,5),
     .     anh1Lim(5,5),anh2Lim(5,5),anh3Lim(5,5),anh4Lim(5,5),
     .     anh5Lim(5,5)
      dimension anhiRre(5,5,5),anhiLre(5,5,5),anhiRim(5,5,5),
     .     anhiLim(5,5,5)
      dimension amst(2),amsb(2),amsl(2),amsu(2),amsd(2),amse(2),amsn(2),
     .     ghcen(2,2),ghctb(2,2),ghcelne(2,2),ghcud(2,2),gh1elel(2,2),
     .     gh1nene(2,2),gh1uu(2,2),gh1dd(2,2),gh1ee(2,2),gh1tt(2,2),
     .     gh1bb(2,2),gh2elel(2,2),gh2nene(2,2),gh2uu(2,2),gh2dd(2,2),
     .     gh2ee(2,2),gh2tt(2,2),gh2bb(2,2),gh3elel(2,2),gh3nene(2,2),
     .     gh3uu(2,2),gh3dd(2,2),gh3ee(2,2),gh3tt(2,2),gh3bb(2,2),
     .     gh4elel(2,2),gh4nene(2,2),gh4uu(2,2),gh4dd(2,2),gh4ee(2,2),
     .     gh4tt(2,2),gh4bb(2,2),gh5elel(2,2),gh5nene(2,2),gh5uu(2,2),
     .     gh5dd(2,2),gh5ee(2,2),gh5tt(2,2),gh5bb(2,2),amsnl(2)
      dimension h1brsc(2,2),h1brsn(5,5),h2brsc(2,2),h2brsn(5,5),
     .     h3brsc(2,2),h3brsn(5,5),h4brsc(2,2),h4brsn(5,5),
     .     h5brsc(2,2),h5brsn(5,5),h2brst(2,2),
     .     h2brsb(2,2),h3brst(2,2),h3brsb(2,2)
      dimension hcbrsuc(2,5),hcbrstbc(2,2)
      dimension wh1ch(2,2),wh1ne(5,5),wh2ch(2,2),wh2ne(5,5),
     .     wh3ch(2,2),wh3ne(5,5),wh4ch(2,2),wh4ne(5,5),wh5ch(2,2),
     .     wh5ne(5,5),whccn(2,5),wh2st(2,2),wh2sb(2,2),wh2stau(2,2),
     .     whcstb(2,2),wh1st(2,2),wh1sb(2,2),wh1stau(2,2),wh3st(2,2),
     .     wh3sb(2,2),wh3stau(2,2),wh4st(2,2),wh4sb(2,2),wh4stau(2,2),
     .     wh5st(2,2),wh5sb(2,2),wh5stau(2,2)
      dimension slhaneut(5),slhaxneut(5),slhachar(2),slhau(2,2),
     .          slhav(2,2),slhaz(5,5),xmchar(2)
      dimension slhauim(2,2),slhavim(2,2),slhazim(5,5)
      complex*16 cf,cg,ci1,ci2,ca,cb,ctt,ctb,ctc,ctw,clt,clb,clw,
     .           cat,cab,cac,caw,cah,cth,clh,cx1,cx2,cax1,cax2,ctl,cal,
     .           csl,csq,csb1,csb2,cst1,cst2,csl1,csl2,
     .           cxl,cxq,cxb1,cxb2,cxt1,cxt2,cxl1,cxl2,clc,cle
      complex*16 caat,caab,caac,caal,caax1,caax2
      complex*16 csel,cser,csul,csur,csdl,csdr,
     .           cxel,cxer,cxul,cxur,cxdl,cxdr
      complex*16 cat0,cab0,cac0,cxul0,cxur0,cxdl0,cxdr0,cxb10,cxb20,
     .           cxt10,cxt20
      complex*16 cttp,ctbp,ctep,cltp,clbp,clep,catp,cabp,caep
      complex*16 yh1tt,yh1bb,yh2tt,yh2bb,yh3tt,yh3bb,
     .     yh4tt,yh4bb,yh5tt,yh5bb
     
      double precision cj(5),cja(5),ci(5)
      complex*16 cxt,cxc,cxb,cxat,cxac,cxab
      complex*16 catc,cabc,cacc
      logical calcmasseserror,mainrun

      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
      COMMON/HMASSR_NMSSM/AMLR,AMHR
      COMMON/CHIMASS_HDEC/AMCHI
      COMMON/MASSES_HDEC/AMS,AMC,AMB,AMT
      COMMON/ALS_HDEC/XLAMBDA,AMC0,AMB0,AMT0,N0
      COMMON/PARAM_HDEC/GF,ALPH,AMTAU,AMMUON,AMZ,AMW
      COMMON/CKMPAR_HDEC/VTB,VTS,VTD,VCB,VCS,VCD,VUB,VUS,VUD
      COMMON/BREAK_CNMSSM/AMEL,AMER,AMSQ,AMUR,AMDR,AL,AT,AB,Alam,Akap,
     .     AMU,AM2,ALIM,ATIM,ABIM,APHIU,XPHIGLU
      COMMON/BREAKGLU_HDEC/AMGLU
      COMMON/WZWDTH_HDEC/GAMC0,GAMT0,GAMT1,GAMW,GAMZ
      COMMON/ONSHELL_NMSSM/IONSH,IONWZ,IOFSUSY
      COMMON/OLDFASH_NMSSM/NFGG
      COMMON/FLAG_HDEC/IHIGGS,NNLO
      COMMON/FERMIOPHOBIC_NMSSM/IFERMPHOB
      COMMON/WIDTHH1_CNMSSM/H1BRB,H1BRL,H1BRM,H1BRS,H1BRC,H1BRT,H1BRG,
     .     H1BRGA,H1BRZGA,H1BRW,H1BRZ,H1BRHW,H1WDTH
      COMMON/WIDTHH2_CNMSSM/H2BRB,H2BRL,H2BRM,H2BRS,H2BRC,H2BRT,H2BRG,
     .     H2BRGA,H2BRZGA,H2BRW,H2BRZ,H2BRH1H1,H2BRH1Z,H2BRHW,H2WDTH
      COMMON/WIDTHH3_CNMSSM/H3BRB,H3BRL,H3BRM,H3BRS,H3BRC,H3BRT,H3BRG,
     .     H3BRGA,H3BRZGA,H3BRW,H3BRZ,H3BRH1H1,H3BRH1H2,H3BRH2H2,
     .     H3BRH1Z,H3BRH2Z,H3BRHW,H3WDTH
      COMMON/WIDTHH4_CNMSSM/H4BRB,H4BRL,H4BRM,H4BRS,H4BRC,H4BRT,H4BRG,
     .     H4BRGA,H4BRZGA,H4BRW,H4BRZ,H4BRH1H1,H4BRH1H2,H4BRH1H3,
     .     H4BRH2H2,H4BRH2H3,H4BRH3H3,H4BRH1Z,H4BRH2Z,H4BRH3Z,
     .     H4BRHW,H4WDTH
      COMMON/WIDTHH5_CNMSSM/H5BRB,H5BRL,H5BRM,H5BRS,H5BRC,H5BRT,H5BRG,
     .     H5BRGA,H5BRZGA,H5BRW,H5BRZ,H5BRH1H1,H5BRH1H2,H5BRH1H3,
     .     H5BRH1H4,H5BRH2H2,H5BRH2H3,H5BRH2H4,H5BRH3H3,H5BRH3H4,
     .     H5BRH4H4,H5BRH1Z,H5BRH2Z,H5BRH3Z,H5BRH4Z,H5BRHW,H5WDTH
      COMMON/WIDTHHI_CNMSSM/BRHIGBBC,BRHIGLLC,BRHIGMMC,BRHIGSSC,
     .     BRHIGCCC,BRHIGTTC,BRHIGGGC,BRHIGGAC,BRHIGZGAC,BRHIGWWC,
     .     BRHIGZZC,BRHIGTOHPWMC,BRHITOHJHKC,BRHITOHJZC,WHITOTC
      COMMON/WISUSYHI_CNMSSM/BRWHIGCHC,BRWHIGNEC,BRWHIGSLNLC,
     .     BRWHIGSLNLTAUC,BRWHIGSLELC,BRWHIGSLERC,BRWHIGSQULC,
     .     BRWHIGSQURC,BRWHIGSQDLC,BRWHIGSQDRC,BRWHIGSTC,BRWHIGSBC,
     .     BRWHIGSTAUC
      COMMON/WIDTHHC_CNMSSM/HCBRBC,HCBRLC,HCBRMC,HCBRBUC,HCBRSC,HCBRCC,
     .     HCBRTC,HCBRWH1C,HCBRWH2C,HCBRWH3C,HCBRWH4C,HCBRWH5C,HCBRDC,
     .     HCBRDTC,HCBRSTC,HCWDTHC
      COMMON/WISUSYHC_CNMSSM/HCBRSUC,HCBRCNTC,HCBRSLC,HCBRSQC,HCBRSTBC,
     .     HCBRSQTC
      COMMON/WISFERHC_CNMSSM/BHCSL00C,BHCSL11C,BHCSL21C,BHCSQC
      COMMON/WISUSY_CNMSSM/H1BRSC,H1BRSN,H2BRSC,H2BRSN,H3BRSC,H3BRSN,
     .     H4BRSC,H4BRSN,H5BRSC,H5BRSN,HCBRSU,H1BRCHT,H2BRCHT,
     .     H3BRCHT,H4BRCHT,H5BRCHT,H1BRNET,H2BRNET,H3BRNET,H4BRNET,
     .     H5BRNET,HCBRCNT,H1BRSL,H2BRSL,H3BRSL,H4BRSL,H5BRSL,HCBRSL,
     .     H2BRSQ,H2BRST,H2BRSB,H2BRSQT,H3BRSQ,H3BRST,H3BRSB,H3BRSQT,
     .     HCBRSQ,H1BRSQ,H1BRSQT
      COMMON/WISFER_CNMSSM/BH1SLNL,BH1SLEL,BH1SLER,BH1SQUL,BH1SQUR,
     .     BH1SQDL,BH1SQDR,BH1ST(2,2),BH1SB(2,2),BH1STAU(2,2),BH2SLNL,
     .     BH2SLEL,BH2SLER,BH2SQUL,BH2SQUR,BH2SQDL,BH2SQDR,BH2ST(2,2),
     .     BH2SB(2,2),BH2STAU(2,2),BH3SLNL,BH3SLEL,BH3SLER,BH3SQUL,
     .     BH3SQUR,BH3SQDL,BH3SQDR,BH3ST(2,2),BH3SB(2,2),BH3STAU(2,2),
     .     BH4SLNL,BH4SLEL,BH4SLER,BH4SQUL,BH4SQUR,BH4SQDL,BH4SQDR,
     .     BH4ST(2,2),BH4SB(2,2),BH4STAU(2,2),BH5SLNL,BH5SLEL,BH5SLER,
     .     BH5SQUL,BH5SQUR,BH5SQDL,BH5SQDR,BH5ST(2,2),BH5SB(2,2),
     .     BH5STAU(2,2),
     .     BH1SLNLTAU,BH2SLNLTAU,BH3SLNLTAU,BH4SLNLTAU,BH5SLNLTAU
      COMMON/SMASS_NMSSM/AMNEUT,XMNEUT,AMCHAR,AMST,AMSB,AMSL,
     .              AMSU,AMSD,AMSE,AMSN,AMSNL
      COMMON/COUP_CNMSSM/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      COMMON/SLHA_gaug_CNMSSM/slhaneut,slhaxneut,slhachar,slhau,slhav,
     .                      slhaz,xmchar,slhauim,slhavim,slhazim
      COMMON/SHORTCOUPL1_CNMSSM/ghitt,ghibb,ghiee,ghiuu,ghidd,ghielel,
     .     ghinene
      COMMON/SHORTCOUPL2_CNMSSM/ghit,ghib,gait,gaib,ghivv,ghihpwm,
     .     gaihpwm,gzhihj,ghihjhk,ghipm
      COMMON/SHORTCOUPL3_CNMSSM/achi,aachi,anhiRre,anhiLre,anhiRim,
     .     anhiLim
      COMMON/calcerror/mainrun,calcmasseserror
c -------------------------------------------------------------------- c
      COMMON/DAVID/QSUSY1,QSUSY2,LOOP
      COMMON/SQNLO_CNMSSM/ymsb(2),ysbmix(2,2),ysbmixim(2,2),yh1bb(2,2),
     .     yh2bb(2,2),yh3bb(2,2),yh4bb(2,2),yh5bb(2,2),ymst(2),
     .     ystmix(2,2),ystmixim(2,2),yh1tt(2,2),yh2tt(2,2),yh3tt(2,2),
     .     yh4tt(2,2),yh5tt(2,2)
      COMMON/GLUONCOUP/cj      
c -------------------------------------------------------------------- c
c NhungDao added for EWQCD correction
      double precision chiyy(5),chizy(5)
      COMMON/GAMMACOUP/chiyy,chizy
      double precision MTRE,MBRE,MSUT(6),MSDT(6),MSU1L(6),MSD1L(6),MSe1L(6)
     &                 ,MSv1L(3)
      common /SQuark_loopmass/MTRE,MBRE,MSUT,MSDT,MSU1L,MSD1L,MSe1L,MSv1L
      double precision MChi1L(5),MCha1L(2),MchaT(2),MchiT(5)
      common/NEUCHA1Lmass/MChi1L,MCha1L,MchaT,MchiT
      logical MHpmInput,CPcon,mQrun,phasetest,slhaswitch
      COMMON /SWITCH/MHpmInput,CPcon,mQrun,slhaswitch
      double precision Qs
      common /scale/ Qs
      integer HHHswitch
      common /HHHselec/ HHHswitch       
#include "bh_EWNMSSM.in"
      hvv(x,y)= gf/(4.d0*pi*dsqrt(2.d0))*x**3/2.d0*beta_hdec(y)
     .            *(1.d0-4.d0*y+12.d0*y**2)
      aff(x,y)= gf/(4*pi*dsqrt(2.d0))*x**3*y*(beta_hdec(y))
      hff(x,y)= gf/(4*pi*dsqrt(2.d0))*x**3*y*(beta_hdec(y))**3
      cff(z,tb,x,y)= gf/(4*pi*dsqrt(2.d0))*z**3*lamb_hdec(x,y)
     .              *((1.d0-x-y)*(x*tb**2+y/tb**2)-4.d0*x*y)
      hv(v)=3.d0*(1.d0-8.d0*v+20.d0*v**2)/dsqrt((4.d0*v-1.d0))
     .      *dacos((3.d0*v-1.d0)/2.d0/dsqrt(v**3))
     .      -(1.d0-v)*(47.d0/2.d0*v-13.d0/2.d0+1.d0/v)
     .      -3.d0/2.d0*(1.d0-6.d0*v+4.d0*v**2)*dlog(v)
      HVH(X,Y)=0.25D0*( (1-X)*(-2+4*X-2*X**2+9*Y+9*X*Y-6*Y**2)
     .        /(3*Y)-2*(1-X-X**2+X**3-3*Y-2*X*Y-3*X**2*Y+3*Y**2
     .        +3*X*Y**2-Y**3)*(-PI/2- DATAN((1-2*X+X**2-Y-X*Y)/
     .         ((1-X)*DSQRT(-1.D0+2*X+2*Y-(X-Y)**2))))/DSQRT(-1.D0
     .         +2*X-(X-Y)**2+2*Y)-(1+X**2-2*Y-2*X*Y+Y**2)*DLOG(X))
      qcd0(x) = (1+x**2)*(4*sp_hdec((1-x)/(1+x))+2*sp_hdec((x-1)/(x+1))
     .        - 3*dlog((1+x)/(1-x))*dlog(2/(1+x))
     .        - 2*dlog((1+x)/(1-x))*dlog(x))
     .        - 3*x*dlog(4/(1-x**2)) - 4*x*dlog(x)
      hqcdm(x)=qcd0(x)/x+(3+34*x**2-13*x**4)/16/x**3*dlog((1+x)/(1-x))
     .        + 3.d0/8/x**2*(7*x**2-1)
      aqcdm(x)=qcd0(x)/x + (19+2*x**2+3*x**4)/16/x*dlog((1+x)/(1-x))
     .        + 3.d0/8*(7-x**2)
      hqcd(x)=(4.d0/3*hqcdm(beta_hdec(x))
     .        +2*(4.d0/3-dlog(x))*(1-10*x)/(1-4*x))*ash/pi
     .       + (29.14671d0 + x*(-93.72459d0+12)
     .         +ratcoup*(1.570d0 - 2*dlog(higtop)/3
     .                                     + dlog(x)**2/9))*(ash/pi)**2
     .       + (164.14d0 - 25.77d0*5 + 0.259d0*5**2)*(ash/pi)**3
     .       +(39.34d0-220.9d0*5+9.685d0*5**2-0.0205d0*5**3)*(ash/pi)**4
      aqcd(x)=(4.d0/3*aqcdm(beta_hdec(x))
     .        +2*(4.d0/3-dlog(x))*(1-6*x)/(1-4*x))*ash/pi
     .       + (29.14671d0 +raatcoup*(23/6.d0 - dlog(higtop)
     .                                  +dlog(x)**2/6))*(ash/pi)**2
     .     + (164.14d0 - 25.77d0*5 + 0.259d0*5**2)*(ash/pi)**3
     .     +(39.34d0-220.9d0*5+9.685d0*5**2-0.0205d0*5**3)*(ash/pi)**4
      qcdh(x)=1.d0+hqcd(x)
      qcda(x)=1.d0+aqcd(x)
      tqcdh(x)=1.d0+4.d0/3*hqcdm(beta_hdec(x))*ash/pi
      tqcda(x)=1.d0+4.d0/3*aqcdm(beta_hdec(x))*ash/pi
      qcdc(x,y)=1.d0+4/3.d0*ash/pi*(9/4.d0 + (3-2*x+2*y)/4*dlog(x/y)
     .         +((1.5d0-x-y)*lamb_hdec(x,y)**2+5*x*y)/2/lamb_hdec(x,y)
     .         /(1-x-y)*dlog(xi_hdec(x,y)*xi_hdec(y,x))
     .         + bij_hdec(x,y))
     .         + ash/pi*(2*(4/3.d0-dlog(x))
     .         - (x*2*(4/3.d0-dlog(x)) + y*2*(4/3.d0-dlog(y)))/(1-x-y)
     .         - (x*2*(4/3.d0-dlog(x))*(1-x+y)
     .           +y*2*(4/3.d0-dlog(y))*(1+x-y))/lamb_hdec(x,y)**2)
      qcdci(x,y)=1.d0+4/3.d0*ash/pi*(3 + (y-x)/2*dlog(x/y)
     .         +(2*(1-x-y)+lamb_hdec(x,y)**2)/2/lamb_hdec(x,y)
     .         *dlog(xi_hdec(x,y)*xi_hdec(y,x))
     .         + bij_hdec(x,y))
     .         + ash/pi*(2*(4/3.d0-dlog(x)) + 2*(4/3.d0-dlog(y))
     .         - (x*2*(4/3.d0-dlog(x))*(1-x+y)
     .           +y*2*(4/3.d0-dlog(y))*(1+x-y))/lamb_hdec(x,y)**2)
      qcdcm(x,y)=1.d0+4/3.d0*ash/pi*(9/4.d0 + (3-2*x+2*y)/4*dlog(x/y)
     .         +((1.5d0-x-y)*lamb_hdec(x,y)**2+5*x*y)/2/lamb_hdec(x,y)
     .         /(1-x-y)*dlog(4*x*y/(1-x-y+lamb_hdec(x,y))**2)
     .         + bij_hdec(x,y))
      qcdcmi(x,y)=1.d0+4/3.d0*ash/pi*(3 + (y-x)/2*dlog(x/y)
     .         +(2*(1-x-y)+lamb_hdec(x,y)**2)/2/lamb_hdec(x,y)
     .         *dlog(4*x*y/(1-x-y+lamb_hdec(x,y))**2)
     .         + bij_hdec(x,y))
c----------------------------------------------------------------------
c--running x Yukawa coupling
      QCDCM1(X,Y)=1.D0+4/3.D0*ASH/PI*(9/4.D0 + (3-2*X+2*Y)/4*DLOG(X/Y)
     .         +((1.5D0-X-Y)*LAMB_HDEC(X,Y)**2+5*X*Y)/2/LAMB_HDEC(X,Y)
     .         /(1-X-Y)*DLOG(4*X*Y/(1-X-Y+LAMB_HDEC(X,Y))**2)
     .         + BIJ_HDEC(X,Y))
     .         + ASH/PI*(2*(4/3.D0-DLOG(X)))
      QCDCMI1(X,Y)=1.D0+4/3.D0*ASH/PI*(3 + (Y-X)/2*DLOG(X/Y)
     .         +(2*(1-X-Y)+LAMB_HDEC(X,Y)**2)/2/LAMB_HDEC(X,Y)
     .         *DLOG(4*X*Y/(1-X-Y+LAMB_HDEC(X,Y))**2)
     .         + BIJ_HDEC(X,Y))
     .         + ASH/PI*(2*(4/3.D0-DLOG(X)))
c----------------------------------------------------------------------
      cqcd(z,tb,x,y,r)= gf/(4*pi*dsqrt(2.d0))*z**3*lamb_hdec(x,y)
     .              *((1.d0-x-y)*(x*tb**2*r**2*qcdc(x,y)
     .                           +y/tb**2*qcdc(y,x))
     .               -4.d0*x*y*qcdci(x,y))
      CQCDM(Z,TB,X,Y,R)= GF/(4*PI*DSQRT(2.D0))*Z**3*LAMB_HDEC(X,Y)
     .              *((1.D0-X-Y)*(X*TB**2*R**2*QCDCM1(X,Y)
     .                           +Y/TB**2*QCDCM(Y,X))
     .               -4.D0*X*Y*R*QCDCMI1(X,Y))
      elw(amh,amf,qf,acf)=alph/pi*3.d0/2*qf**2
     .                              *(3.d0/2-dlog(amh**2/amf**2))
     .      +gf/8/dsqrt(2.d0)/pi**2*(acf*amt**2
     .        +amw**2*(3*dlog(cs)/ss-5)+amz**2*(0.5d0
     .          -3*(1-4*ss*dabs(qf))**2))
      cf(ca) = -cdlog(-(1+cdsqrt(1-ca))/(1-cdsqrt(1-ca)))**2/4
      cg(ca) = cdsqrt(1-ca)/2*cdlog(-(1+cdsqrt(1-ca))/(1-cdsqrt(1-ca)))
      ci1(ca,cb) = ca*cb/2/(ca-cb)
     .           + ca**2*cb**2/2/(ca-cb)**2*(cf(ca)-cf(cb))
     .           + ca**2*cb/(ca-cb)**2*(cg(ca)-cg(cb))
      ci2(ca,cb) = -ca*cb/2/(ca-cb)*(cf(ca)-cf(cb))
      hggqcd(asg,nf)=1.d0+asg/pi*(95.d0/4.d0-nf*7.d0/6.d0)
      hggqcd2(asg,nf,amh,amt)=1.D0+ASG/PI*(95.D0/4.D0-NF*7.D0/6.D0)
     . +(ASG/PI)**2*(149533/288.D0-363/8.D0*ZETA2-495/8.D0*ZETA3
     .              +19/8.D0*DLOG(AMH**2/AMT**2)
     . +NF*(-4157/72.D0+11/2.D0*ZETA2+5/4.D0*ZETA3
     . +2/3.D0*DLOG(AMH**2/AMT**2))
     . +NF**2*(127/108.D0-1/6.D0*ZETA2))
     . +(ASG/PI)**3*(467.683620788D0+122.440972222D0*DLOG(AMH**2/AMT**2)
     .              +10.9409722222D0*DLOG(AMH**2/AMT**2)**2)
      sggqcd(asg)=asg/pi*7.D0/2.D0
      aggqcd(asg,nf)=1.d0+asg/pi*(97.d0/4.d0-nf*7.d0/6.d0)
      aggqcd2(asg,nf,ama,amt)=1.d0+asg/pi*(97.d0/4.d0-nf*7.d0/6.d0)
     . +(asg/pi)**2*(237311/864.d0-529/24.d0*zeta2-445/8.d0*zeta3
     . +5*dlog(ama**2/amt**2))
      hffself(amh)=1.d0+gf*amh**2/16.d0/pi**2/dsqrt(2.d0)*2.117203d0
     .            -(gf*amh**2/16.d0/pi**2/dsqrt(2.d0))**2*32.6567d0
      hvvself(amh)=1.d0+gf*amh**2/16.d0/pi**2/dsqrt(2.d0)*2.800952d0
     .            +(gf*amh**2/16.d0/pi**2/dsqrt(2.d0))**2*62.0308d0
      WTOP(X,ASG,NF)=ASG/PI*(-2/3.D0*(PI**2+2*SP_HDEC(X)-2*SP_HDEC(1-X)
     .               +(4*X*(1-X-2*X**2)*DLOG(X)
     .                +2*(1-X)**2*(5+4*X)*DLOG(1-X)
     .                -(1-X)*(5+9*X-6*X**2))
     .               /2/(1-X)**2/(1+2*X)))
     .       + (ASG/2/PI)**2*(-110.4176D0+7.978D0*NF)
      chtop(x)=8/3.d0*(sp_hdec(1-x)-x/2/(1-x)*dlog(x)
     .        + dlog(x)*dlog(1-x)/2+(1-2.5d0*x)/2/x*dlog(1-x)-pi**2/3
     .        +9/8.d0)
      chtop1(x)=8/3.d0*(sp_hdec(1-x)-x/2/(1-x)*dlog(x)
     .        + dlog(x)*dlog(1-x)/2+(1-2.5d0*x)/2/x*dlog(1-x)-pi**2/3
     .        +17/8.d0)
!nhung added call for looptools library when EW corrected added
#ifdef HHHDECAYHO
       if(iewh.gt.0)then
        call ltini
        call setDelta(0D0)
        call setMUDIM(QS**2)
       endif
       if(HHHswitch.eq.1) then       
       call HHHTL_calc()
       endif
#endif
c --- some parameter settings --- c

      pi=4d0*datan(1d0)
      ss=1.d0-(amw/amz)**2
      cs=1.d0-ss

      zeta2 = pi**2/6
      zeta3 = 1.202056903159594d0
      zeta4 = pi**4/90
      zeta5 = 1.03692775514337d0

      if(ihiggs.ne.0) then
         call susycp_cnmssm(tgbet)
      endif

c--decoupling the top quark from alphas

      amt0=3.D8

c--top quark decay width
      GAMT0 = GF*AMT**3/8/DSQRT(2D0)/PI*VTB**2
     .      * LAMB_HDEC(AMB**2/AMT**2,AMW**2/AMT**2)
     .      * ((1-AMW**2/AMT**2)*(1+2*AMW**2/AMT**2)
     .         -AMB**2/AMT**2*(2-AMW**2/AMT**2-AMB**2/AMT**2))
     .      * (1+WTOP(AMW**2/AMT**2,ALPHAS_HDEC(AMT,3),5))

c      if(ihiggs.ne.0.and.amt.gt.amch+amb)then
c       tsc = (amsq+amur+amdr)/3
c       bsc = (amsq+amur+amdr)/3
c
c       rmt = amt
c       rmb = amb
c
c       call sfermion_nmssm(amst,amsb,amsl,amsu,amsd,amse,amsn,amsnl,
c     .      gh1ee,gh1tt,gh1bb,gh1elel,gh1nene,gh1uu,gh1dd,gh2ee,gh2tt,
c     .      gh2bb,gh2elel,gh2nene,gh2uu,gh2dd,gh3ee,gh3tt,gh3bb,gh3elelc,
c     .      gh3nene,gh3uu,gh3dd,gha1ee,gha1tt,gha1bb,gha2ee,gha2tt,
c     .      gha2bb,ghcen,ghctb,ghcelne,ghcud,al,at,ab,rmt,rmb)

c       loop  = 2
c       qsusy = 1
c       qsusy1 = qsusy
c       qsusy2 = qsusy
c       call botsusy_nmssm_hdec(gh1b,gh2b,gh3b,ga1b,ga2b,xgh1b,xgh2b,
c     .     xgh3b,xga1b,xga2b,xghpm,tgbet,qsusy,loop)
c       ymb = runm_hdec(amt,5)
c       gamt1 = gf*amt**3/8/dsqrt(2d0)/pi*VTB**2
c     .      * lamb_hdec(amb**2/amt**2,amch**2/amt**2)
c     .      * (1.d0/tgbet**2*(1+amb**2/amt**2-amch**2/amt**2)
c     .      * (1+alphas_hdec(amt,3)/pi*chtop(amch**2/amt**2))
c     .        +(ymb/amt)**2*xghpm**2*(1+amb**2/amt**2-amch**2/amt**2)
c     .      * (1+alphas_hdec(amt,3)/pi*chtop1(amch**2/amt**2))
c     .      + 4*ymb**2/amt**2*xghpm*1.D0/tgbet)
c      else
c       gamt1 = 0
c      endif
c      gamt1 = gamt0+gamt1
      gamt1 = gamt0

c      print*,''
c      print*,'top quark width',gamt1
c      print*,''

c ========================= NMSSM Higgs bosons ======================= c

      call gaugino_cnmssm(amu,am2,b,amchar,amneut,xmneut,ach1,ach2,ach3,
     .     ach4,ach5,aach1,aach2,aach3,aach4,aach5,anh1Rre,anh2Rre,
     .     anh3Rre,anh4Rre,anh5Rre,anh1Rim,anh2Rim,anh3Rim,anh4Rim,
     .     anh5Rim,anh1Lre,anh2Lre,anh3Lre,anh4Lre,anh5Lre,anh1Lim,
     .     anh2Lim,anh3Lim,anh4Lim,anh5Lim,acnl,acnr)

      tsc = (amsq+amur+amdr)/3
      bsc = (amsq+amur+amdr)/3

      call sfermion_cnmssm(amst,amsb,amsl,amsu,amsd,amse,amsn,amsnl,
     .     gh1ee,gh1tt,gh1bb,gh1elel,gh1nene,gh1uu,gh1dd,gh2ee,gh2tt,
     .     gh2bb,gh2elel,gh2nene,gh2uu,gh2dd,gh3ee,gh3tt,gh3bb,gh3elel,
     .     gh3nene,gh3uu,gh3dd,gh4ee,gh4tt,gh4bb,gh4elel,gh4nene,
     .     gh4uu,gh4dd,gh5ee,gh5tt,gh5bb,gh5elel,gh5nene,gh5uu,gh5dd,
     .     ghcen,ghctb,ghcelne,ghcud,al,at,ab,alim,atim,abim,aphiu)

      QSUSY = 1
      LOOP = 2

      QSUSY1 = QSUSY
      QSUSY2 = QSUSY

      amhi(1) = amh1
      amhi(2) = amh2
      amhi(3) = amh3
      amhi(4) = amh4
      amhi(5) = amh5

c ==================================================================== c
c                       NMSSM Higgs Boson Decays
c ==================================================================== c

c ==================================================================== c
c ------------------------ Charged Higgs decays ---------------------- c
c ==================================================================== c

      tb=tgbet
c --- running masses --- c

      rms = runm_hdec(amch,3)
      rmc = runm_hdec(amch,4)
      rmb = runm_hdec(amch,5)
      rmt = runm_hdec(amch,6)
      ash=alphas_hdec(amch,3)

c --- partial widths --- c

c      print*,'Charged Higgs decays'

c H+ ---> mu nmu
      xgh1m = ghib(1)
      xgh2m = ghib(2)
      xgh3m = ghib(3)
      xgh4m = ghib(4)
      xgh5m = ghib(5)
      xga1m = gaib(1)
      xga2m = gaib(2)
      xga3m = gaib(3)
      xga4m = gaib(4)
      xga5m = gaib(5)
      xghpm = tgbet*(1.d0,0.d0)
      if(iofsusy.eq.0) then
       call staususy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,0)
      endif

      if(amch.le.ammuon) then
       hmn = 0
      else
         hmn=cff(amch,cdabs(xghpm),(ammuon/amch)**2,0.d0)
      endif

c      print*,'hmn',hmn,cdabs(xghpm)

c  H+ ---> tau ntau
      xgh1m = ghib(1)
      xgh2m = ghib(2)
      xgh3m = ghib(3)
      xgh4m = ghib(4)
      xgh5m = ghib(5)
      xga1m = gaib(1)
      xga2m = gaib(2)
      xga3m = gaib(3)
      xga4m = gaib(4)
      xga5m = gaib(5)
      xghpm = tgbet*(1.d0,0.d0)
      if(iofsusy.eq.0) then
       call staususy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,1)
      endif

      if(amch.le.amtau) then
         hln = 0
      else
         hln=cff(amch,cdabs(xghpm),(amtau/amch)**2,0.d0)
      endif

c      print*,'hln',hln,cdabs(xghpm)

c  H+ ---> su
      eps = 1.d-12
      ratx = 1.d0
      xgh1s = ghib(1)
      xgh2s = ghib(2)
      xgh3s = ghib(3)
      xgh4s = ghib(4)
      xgh5s = ghib(5)
      xga1s = gaib(1)
      xga2s = gaib(2)
      xga3s = gaib(3)
      xga4s = gaib(4)
      xga5s = gaib(5)
      if(iofsusy.eq.0) then
         call strsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,0)
         if(cdabs(xghpm).eq.tgbet) then
            ratx = 1.d0
         else
            ratx=cdabs(xghpm)/tgbet
         endif
      endif
      if(amch.le.ams+eps) then
       hsu = 0
      else
       hsu1=3.d0*vus**2*cqcdm(amch,tb,(ams/amch)**2,eps,ratx)
       hsu2=3.d0*vus**2*cqcd(amch,tb,(rms/amch)**2,eps,ratx)
       if(hsu2.lt.0.d0) hsu2 = 0
       rat = ams/amch
       hsu = qqint_hdec(rat,hsu1,hsu2)
      endif

c      print*,'hsu',hsu,ratx

c  H+ ---> cs
      ratx = rms/ams
      raty = 1.D0
      eps = 1.d-12
      xgh1m = ghib(1)
      xgh2m = ghib(2)
      xgh3m = ghib(3)
      xgh4m = ghib(4)
      xgh5m = ghib(5)
      xga1m = gaib(1)
      xga2m = gaib(2)
      xga3m = gaib(3)
      xga4m = gaib(4)
      xga5m = gaib(5)
      if(iofsusy.eq.0) then
         call strsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,0)
         if(cdabs(xghpm).eq.tgbet) then
            ratx = rms/ams
            raty = 1.d0
         else
            ratx = rms/ams*cdabs(xghpm)/tgbet
            raty = cdabs(xghpm)/tgbet
         endif
      endif

      if(amch.le.ams+amc) then
       hsc = 0
      else
       hsc1=3.d0*cqcdm(amch,tb,(ams/amch)**2,(amc/amch)**2,ratx)*vcs**2
       hsc2=3.d0*cqcd(amch,tb,(rms/amch)**2,(rmc/amch)**2,raty)*vcs**2
       if(hsc2.lt.0.d0) hsc2 = 0
       rat = (ams+amc)/amch
       hsc = qqint_hdec(rat,hsc1,hsc2)
      endif

c      print*,'hsc',hsc

c  H+ ---> cd
      ratx = 1
      eps = 1d-12
      if(amch.le.amc) then
       hcd = 0
      else
       hcd1=3.d0*cqcdm(amch,tb,eps,(amc/amch)**2,ratx)*vcd**2
       hcd2=3.d0*cqcd(amch,tb,eps,(rmc/amch)**2,ratx)*vcd**2
       if(hcd2.lt.0.d0) hcd2 = 0
       rat = (eps+amc)/amch
       hcd = qqint_hdec(rat,hcd1,hcd2)
      endif

c      print*,'hcd',hcd

c  H+ ---> cb
      ratx = 1
      qq = amb
      susy = 0
      xgh1b = ghib(1)
      xgh2b = ghib(2)
      xgh3b = ghib(3)
      xgh4b = ghib(4)
      xgh5b = ghib(5)
      xga1b = gaib(1)
      xga2b = gaib(2)
      xga3b = gaib(3)
      xga4b = gaib(4)
      xga5b = gaib(5)
      xhpm = tgbet
c     ssusy = amch
      ssusy = (amsb(1)+amsb(2)+amglu)/3*qsusy
      as0 = alphas_hdec(ssusy,3)

      if(iofsusy.eq.0) then
         call botsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1b,
     .        xgh2b,xgh3b,xgh4b,xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,
     .        xghpm,tgbet,qsusy,loop)
      endif
      if(cdabs(xghpm).eq.tgbet) then
       ratx = 1.d0
      else
       ratx = cdabs(xghpm/tgbet)
      endif
      if(amch.le.amb+amc) then
       hbc = 0
      else
       hbc1=3.d0*vcb**2*cqcdm(amch,tb,(amb/amch)**2,(amc/amch)**2,ratx)
       hbc2=3.d0*vcb**2*cqcd(amch,tb,(rmb/amch)**2,(rmc/amch)**2,ratx)
       if(hbc2.lt.0.d0) hbc2 = 0
       rat = (amb+amc)/amch
       hbc = qqint_hdec(rat,hbc1,hbc2)
      endif

c      print*,'hbc',hbc

c  H+ ---> bu
      eps = 1.d-12
      if(amch.le.amb+eps) then
       hbu = 0
      else
       hbu1=3.d0*vub**2*cqcdm(amch,tb,(amb/amch)**2,eps,ratx)
       hbu2=3.d0*vub**2*cqcd(amch,tb,(rmb/amch)**2,eps,ratx)
       if(hbu2.lt.0.d0) hbu2 = 0
       rat = amb/amch
       hbu = qqint_hdec(rat,hbu1,hbu2)
      endif

c      print*,'hbu',hbu

c  H+ ---> td
      eps = 1.d-12
      if(ionsh.eq.0)then
       dld=2d0
       dlu=2d0
       xm1 = amt-dld
       xm2 = amt+dlu
       if (amch.le.amw) then
        hdt=0.d0
       elseif (amch.le.xm1) then
        factb=3.d0*gf**2*amch*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(amch,amt,eps,amw,tgbet,ctt0)
        hdt=vtd**2*factb*ctt0
       elseif (amch.le.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        factb=3.d0*gf**2*xx(1)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(1),amt,eps,amw,tgbet,ctt0)
        yy(1)=vtd**2*factb*ctt0
        factb=3.d0*gf**2*xx(2)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(2),amt,eps,amw,tgbet,ctt0)
        yy(2)=vtd**2*factb*ctt0
        xmb = runm_hdec(xx(3),5)
        xmt = runm_hdec(xx(3),6)
        xyz2 = 3.d0*cqcd(xx(3),tb,(eps/xx(3))**2,(xmt/xx(3))**2,ratx)
        if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(3),tb,(eps/xx(3))**2,(amt/xx(3))**2,ratx)
        rat = (amt)/xx(3)
        yy(3) = vtd**2*qqint_hdec(rat,xyz1,xyz2)
        xmb = runm_hdec(xx(4),5)
        xmt = runm_hdec(xx(4),6)
        xyz2 = 3.d0*cqcd(xx(4),tb,(eps/xx(4))**2,(xmt/xx(4))**2,ratx)
       if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(4),tb,(eps/xx(4))**2,(amt/xx(4))**2,ratx)
        rat = (amt)/xx(4)
        yy(4) = vtd**2*qqint_hdec(rat,xyz1,xyz2)
        hdt = fint_hdec(amch,xx,yy)
       else
        hdt2=3.d0*vtd**2*cqcd(amch,tb,(eps/amch)**2,(rmt/amch)**2,ratx)
        if(hdt2.lt.0.d0) hdt2 = 0
        hdt1=3.d0*vtd**2*cqcdm(amch,tb,(eps/amch)**2,(amt/amch)**2,ratx)
        rat = (amt)/amch
        hdt = qqint_hdec(rat,hdt1,hdt2)
       endif
      else
       if (amch.le.amt) then
        hdt=0.d0
       else
        hdt2=3.d0*vtd**2*cqcd(amch,tb,eps,(rmt/amch)**2,ratx)
        if(hdt2.lt.0.d0) hdt2 = 0
        hdt1=3.d0*vtd**2*cqcdm(amch,tb,eps,(amt/amch)**2,ratx)
        rat = (amt)/amch
        hdt = qqint_hdec(rat,hdt1,hdt2)
       endif
      endif

c      print*,'hdt',hdt

c  H+ --> ts
      eps = 1.d-12
      ratx = rms/ams
      raty = 1
      if(iofsusy.eq.0) then
         call strsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,0)
         ratx = rms/ams*cdabs(xghpm)/tgbet
         raty = cdabs(xghpm)/tgbet
      endif
      if(ionsh.eq.0)then
       dld=2d0
       dlu=2d0
       xm1 = amt+ams-dld
       xm2 = amt+ams+dlu
       if (amch.le.amw+2*ams) then
        hst=0.d0
       elseif (amch.le.xm1) then
        factb=3.d0*gf**2*amch*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(amch,amt,eps,amw,tgbet,ctt0)
        hst=vts**2*factb*ctt0
       elseif (amch.le.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        factb=3.d0*gf**2*xx(1)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(1),amt,eps,amw,tgbet,ctt0)
        yy(1)=vts**2*factb*ctt0
        factb=3.d0*gf**2*xx(2)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(2),amt,eps,amw,tgbet,ctt0)
        yy(2)=vts**2*factb*ctt0
        xms = runm_hdec(xx(3),3)
        xmt = runm_hdec(xx(3),6)
        xyz2 = 3.d0*cqcd(xx(3),tb,(xms/xx(3))**2,(xmt/xx(3))**2,raty)
        if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(3),tb,(ams/xx(3))**2,(amt/xx(3))**2,ratx)
        rat = (ams+amt)/xx(3)
        yy(3) = vts**2*qqint_hdec(rat,xyz1,xyz2)
        xms = runm_hdec(xx(4),3)
        xmt = runm_hdec(xx(4),6)
        xyz2 = 3.d0*cqcd(xx(4),tb,(xms/xx(4))**2,(xmt/xx(4))**2,raty)
        if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(4),tb,(ams/xx(4))**2,(amt/xx(4))**2,ratx)
        rat = (ams+amt)/xx(4)
        yy(4) = vts**2*qqint_hdec(rat,xyz1,xyz2)
        hst = fint_hdec(amch,xx,yy)
       else
        hst2=3.d0*vts**2*cqcd(amch,tb,(rms/amch)**2,(rmt/amch)**2,raty)
        if(hst2.lt.0.d0) hst2 = 0
        hst1=3.d0*vts**2*cqcdm(amch,tb,(ams/amch)**2,(amt/amch)**2,ratx)
        rat = (ams+amt)/amch
        hst = qqint_hdec(rat,hst1,hst2)
       endif
      else
       if (amch.le.amt+ams) then
        hst=0.d0
       else
        hst2=3.d0*vts**2*cqcd(amch,tb,(rms/amch)**2,(rmt/amch)**2,raty)
        if(hst2.lt.0.d0) hst2 = 0
        hst1=3.d0*vts**2*cqcdm(amch,tb,(ams/amch)**2,(amt/amch)**2,ratx)
        rat = (ams+amt)/amch
        hst = qqint_hdec(rat,hst1,hst2)
       endif
      endif

c      print*,'hst',hst

c  H+ ---> tb
      ratx = rmb/amb
      raty = 1
      xghpm = tgbet*(1.d0,0.d0)
      if(iofsusy.eq.0) then
         call botsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1b,
     .        xgh2b,xgh3b,xgh4b,xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,
     .        xghpm,tgbet,qsusy,loop)
       ratx = rmb/amb*cdabs(xghpm)/tgbet
       raty = cdabs(xghpm)/tgbet
      endif
      if(ionsh.eq.0)then
       dld=2d0
       dlu=2d0
       xm1 = amt+amb-dld
       xm2 = amt+amb+dlu
       if (amch.le.amw+2*amb) then
        hbt=0.d0
       elseif (amch.le.xm1) then
        factb=3.d0*gf**2*amch*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(amch,amt,amb,amw,tgbet,ctt0)
        hbt=vtb**2*factb*ctt0
       elseif (amch.le.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        factb=3.d0*gf**2*xx(1)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(1),amt,amb,amw,tgbet,ctt0)
        yy(1)=VTB**2*factb*ctt0
        factb=3.d0*gf**2*xx(2)*amt**4/32.d0/pi**3/tb**2
        call ctott_hdec(xx(2),amt,amb,amw,tgbet,ctt0)
        yy(2)=VTB**2*factb*ctt0
        xmb = runm_hdec(xx(3),5)
        xmt = runm_hdec(xx(3),6)
        xyz2 = 3.d0*cqcd(xx(3),tb,(xmb/xx(3))**2,(xmt/xx(3))**2,raty)
        if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(3),tb,(amb/xx(3))**2,(amt/xx(3))**2,ratx)
        rat = (amb+amt)/xx(3)
        yy(3) = VTB**2*qqint_hdec(rat,xyz1,xyz2)
        xmb = runm_hdec(xx(4),5)
        xmt = runm_hdec(xx(4),6)
        xyz2 = 3.d0*cqcd(xx(4),tb,(xmb/xx(4))**2,(xmt/xx(4))**2,raty)
        if(xyz2.lt.0.d0) xyz2 = 0
        xyz1 = 3.d0*cqcdm(xx(4),tb,(amb/xx(4))**2,(amt/xx(4))**2,ratx)
        rat = (amb+amt)/xx(4)
        yy(4) = VTB**2*qqint_hdec(rat,xyz1,xyz2)
        hbt = fint_hdec(amch,xx,yy)
       else
        hbt2=3.d0*vtb**2*cqcd(amch,tb,(rmb/amch)**2,(rmt/amch)**2,raty)
        if(hbt2.lt.0.d0) hbt2 = 0
        hbt1=3.d0*vtb**2*cqcdm(amch,tb,(amb/amch)**2,(amt/amch)**2,ratx)
        rat = (amb+amt)/amch
        hbt = qqint_hdec(rat,hbt1,hbt2)
       endif
      else
       if (amch.le.amt+amb) then
        hbt=0.d0
       else
        hbt2=3.d0*vtb**2*cqcd(amch,tb,(rmb/amch)**2,(rmt/amch)**2,raty)
        if(hbt2.lt.0.d0) hbt2 = 0
        hbt1=3.d0*vtb**2*cqcdm(amch,tb,(amb/amch)**2,(amt/amch)**2,ratx)
        rat = (amb+amt)/amch
        hbt = qqint_hdec(rat,hbt1,hbt2)
       endif
      endif

c      print*,'hbt',hbt

c  H+ ---> W H1
      if(ionsh.eq.0)then
       dld=3d0
       dlu=5d0
       xm1 = amw+amh1-dld
       xm2 = amw+amh1+dlu
       if (amch.lt.amh1) then
        hwh=0
       elseif (amch.le.xm1) then
        if(amch.le.dabs(amw-amh1))then
         hwh=0
        else
           hwh=9.d0*gf**2/16.d0/pi**3*amw**4*amch*
     .          (gh1hpwm**2+ga1hpwm**2)	
     .          *hvh((amh1/amch)**2,(amw/amch)**2)
        endif
       elseif (amch.lt.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        yy(1) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(1)
     .         *hvh((amh1/xx(1))**2,(amw/xx(1))**2)
        yy(2) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(2)
     .         *hvh((amh1/xx(2))**2,(amw/xx(2))**2)
        cwh=lamb_hdec(amh1**2/xx(3)**2,amw**2/xx(3)**2)
     .     *lamb_hdec(xx(3)**2/amw**2,amh1**2/amw**2)**2
        yy(3)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*cwh
        cwh=lamb_hdec(amh1**2/xx(4)**2,amw**2/xx(4)**2)
     .     *lamb_hdec(xx(4)**2/amw**2,amh1**2/amw**2)**2
        yy(4)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*cwh
        hwh = fint_hdec(amch,xx,yy)*(gh1hpwm**2+ga1hpwm**2)
       else
        cwh=lamb_hdec(amh1**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh1**2/amw**2)**2
        hwh=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh1hpwm**2+ga1hpwm**2)*cwh
       endif
      else
       if (amch.lt.amw+amh1) then
        hwh=0
       else
        cwh=lamb_hdec(amh1**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh1**2/amw**2)**2
        hwh=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh1hpwm**2+ga1hpwm**2)*cwh
       endif
      endif

c      print*,'hwh1',hwh

c  H+ ---> W H2

      if(ionsh.eq.0)then
       dld=3d0
       dlu=5d0
       xm1 = amw+amh2-dld
       xm2 = amw+amh2+dlu
       if (amch.lt.amh2) then
        hwh2=0
       elseif (amch.le.xm1) then
        if(amch.le.dabs(amw-amh2))then
         hwh2=0
        else
           hwh2=9.d0*gf**2/16.d0/pi**3*amw**4*amch*
     .          (gh2hpwm**2+ga2hpwm**2)	
     .          *hvh((amh2/amch)**2,(amw/amch)**2)
        endif
       elseif (amch.lt.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        yy(1) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(1)
     .         *hvh((amh2/xx(1))**2,(amw/xx(1))**2)
        yy(2) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(2)
     .         *hvh((amh2/xx(2))**2,(amw/xx(2))**2)
        cwh=lamb_hdec(amh2**2/xx(3)**2,amw**2/xx(3)**2)
     .     *lamb_hdec(xx(3)**2/amw**2,amh2**2/amw**2)**2
        yy(3)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*cwh
        cwh=lamb_hdec(amh2**2/xx(4)**2,amw**2/xx(4)**2)
     .     *lamb_hdec(xx(4)**2/amw**2,amh2**2/amw**2)**2
        yy(4)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*cwh
        hwh2 = fint_hdec(amch,xx,yy)*(gh2hpwm**2+ga2hpwm**2)
       else
        cwh=lamb_hdec(amh2**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh2**2/amw**2)**2
        hwh2=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh2hpwm**2+ga2hpwm**2)*cwh
       endif
      else
       if (amch.lt.amw+amh2) then
        hwh2=0
       else
        cwh=lamb_hdec(amh2**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh2**2/amw**2)**2
        hwh2=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*(
     .       gh2hpwm**2+ga2hpwm**2)*cwh
       endif
      endif

c      print*,'hwh2',hwh2

c  H+ ---> W H3

c Maggie changed 14/1/2019 (amh2 -> amh3)
c Mistake found by Nhung      
      if(ionsh.eq.0)then
       dld=3d0
       dlu=5d0
       xm1 = amw+amh3-dld
       xm2 = amw+amh3+dlu
       if (amch.lt.amh3) then
        hwh3=0
       elseif (amch.le.xm1) then
        if(amch.le.dabs(amw-amh3))then
         hwh3=0
        else
           hwh3=9.d0*gf**2/16.d0/pi**3*amw**4*amch*
     .          (gh3hpwm**2+ga3hpwm**2)	
     .          *hvh((amh3/amch)**2,(amw/amch)**2)
        endif
       elseif (amch.lt.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        yy(1) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(1)
     .         *hvh((amh3/xx(1))**2,(amw/xx(1))**2)
        yy(2) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(2)
     .         *hvh((amh3/xx(2))**2,(amw/xx(2))**2)
        cwh=lamb_hdec(amh3**2/xx(3)**2,amw**2/xx(3)**2)
     .     *lamb_hdec(xx(3)**2/amw**2,amh3**2/amw**2)**2
        yy(3)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*cwh
        cwh=lamb_hdec(amh3**2/xx(4)**2,amw**2/xx(4)**2)
     .     *lamb_hdec(xx(4)**2/amw**2,amh3**2/amw**2)**2
        yy(4)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*cwh
        hwh3 = fint_hdec(amch,xx,yy)*(gh3hpwm**2+ga3hpwm**2)
       else
        cwh=lamb_hdec(amh3**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh3**2/amw**2)**2
        hwh3=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh3hpwm**2+ga3hpwm**2)*cwh
       endif
      else
       if (amch.lt.amw+amh3) then
        hwh3=0
       else
        cwh=lamb_hdec(amh3**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh3**2/amw**2)**2
        hwh3=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*(
     .       gh3hpwm**2+ga3hpwm**2)*cwh
       endif
      endif

c      print*,'hwh3',hwh3
c end Maggie changed 14/1/2019
      
c  H+ ---> W H4

      if(ionsh.eq.0)then
       dld=3d0
       dlu=5d0
       xm1 = amw+amh4-dld
       xm2 = amw+amh4+dlu
       if (amch.lt.amh4) then
        hwh4=0
       elseif (amch.le.xm1) then
        if(amch.le.dabs(amw-amh4))then
         hwh4=0
        else
           hwh4=9.d0*gf**2/16.d0/pi**3*amw**4*amch*
     .          (gh4hpwm**2+ga4hpwm**2)	
     .          *hvh((amh4/amch)**2,(amw/amch)**2)
        endif
       elseif (amch.lt.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        yy(1) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(1)
     .         *hvh((amh4/xx(1))**2,(amw/xx(1))**2)
        yy(2) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(2)
     .         *hvh((amh4/xx(2))**2,(amw/xx(2))**2)
        cwh=lamb_hdec(amh4**2/xx(3)**2,amw**2/xx(3)**2)
     .     *lamb_hdec(xx(3)**2/amw**2,amh4**2/amw**2)**2
        yy(3)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*cwh
        cwh=lamb_hdec(amh4**2/xx(4)**2,amw**2/xx(4)**2)
     .     *lamb_hdec(xx(4)**2/amw**2,amh4**2/amw**2)**2
        yy(4)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*cwh
        hwh4 = fint_hdec(amch,xx,yy)*(gh4hpwm**2+ga4hpwm**2)
       else
        cwh=lamb_hdec(amh4**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh4**2/amw**2)**2
        hwh4=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh4hpwm**2+ga4hpwm**2)*cwh
       endif
      else
       if (amch.lt.amw+amh4) then
        hwh4=0
       else
        cwh=lamb_hdec(amh4**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh4**2/amw**2)**2
        hwh4=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*(
     .       gh4hpwm**2+ga4hpwm**2)*cwh
       endif
      endif

c      print*,'hwh4',hwh4

c  H+ ---> W H5

      if(ionsh.eq.0)then
       dld=3d0
       dlu=5d0
       xm1 = amw+amh5-dld
       xm2 = amw+amh5+dlu
       if (amch.lt.amh5) then
        hwh5=0
       elseif (amch.le.xm1) then
        if(amch.le.dabs(amw-amh5))then
         hwh5=0
        else
           hwh5=9.d0*gf**2/16.d0/pi**3*amw**4*amch*
     .          (gh5hpwm**2+ga5hpwm**2)	
     .          *hvh((amh5/amch)**2,(amw/amch)**2)
        endif
       elseif (amch.lt.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        yy(1) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(1)
     .         *hvh((amh5/xx(1))**2,(amw/xx(1))**2)
        yy(2) = 9.d0*gf**2/16.d0/pi**3*amw**4*xx(2)
     .         *hvh((amh5/xx(2))**2,(amw/xx(2))**2)
        cwh=lamb_hdec(amh5**2/xx(3)**2,amw**2/xx(3)**2)
     .     *lamb_hdec(xx(3)**2/amw**2,amh5**2/amw**2)**2
        yy(3)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*cwh
        cwh=lamb_hdec(amh5**2/xx(4)**2,amw**2/xx(4)**2)
     .     *lamb_hdec(xx(4)**2/amw**2,amh5**2/amw**2)**2
        yy(4)=gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*cwh
        hwh5 = fint_hdec(amch,xx,yy)*(gh5hpwm**2+ga5hpwm**2)
       else
        cwh=lamb_hdec(amh5**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh5**2/amw**2)**2
        hwh5=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*
     .       (gh5hpwm**2+ga5hpwm**2)*cwh
       endif
      else
       if (amch.lt.amw+amh5) then
        hwh5=0
       else
        cwh=lamb_hdec(amh5**2/amch**2,amw**2/amch**2)
     .     *lamb_hdec(amch**2/amw**2,amh5**2/amw**2)**2
        hwh5=gf/8.d0/dsqrt(2d0)/pi*amw**4/amch*(
     .       gh5hpwm**2+ga5hpwm**2)*cwh
       endif
      endif

c      print*,'hwh5',hwh5

c ============================ SUSY decays =========================== c
      if(iofsusy.eq.0) then

c  H+ ---> charginos+neutralinos

      do  i=1,2
      do  j=1,5
      if (amch.gt.amchar(i)+amneut(j)) then
         whccn(i,j)=gf*amw**2/(2*pi*dsqrt(2.d0))/amch
     .        *lamb_hdec(amchar(i)**2/amch**2,amneut(j)**2/amch**2)*(
     .        (cdabs(acnl(i,j))**2+cdabs(acnr(i,j))**2)*
     .        (amch**2-amchar(i)**2-xmneut(j)**2)-
     .        2.d0*(acnl(i,j)*dconjg(acnr(i,j))+dconjg(acnl(i,j))*
     .        acnr(i,j))*xmchar(i)*xmneut(j) )
      else
      whccn(i,j)=0.d0
      endif
      enddo
      enddo

      whccnt=whccn(1,1)+whccn(1,2)+whccn(1,3)+whccn(1,4)+whccn(1,5)
     .      +whccn(2,1)+whccn(2,2)+whccn(2,3)+whccn(2,4)+whccn(2,5)

c      print*,'whccnt',whccnt

c  H+ ---> sleptons 

      if (amch.gt.amse(1)+amsn(1)) then
      whcsl00=2*gf/2.d0/dsqrt(2d0)/pi*amw**4/amch*cdabs(ghcelne(1,1))**2
     .     *lamb_hdec(amse(1)**2/amch**2,amsn(1)**2/amch**2)
      else 
      whcsl00=0.d0
      endif

      if (amch.gt.amsl(1)+amsnl(1)) then
      whcsl11=gf/2.d0/dsqrt(2d0)/pi*amw**4/amch*cdabs(ghcen(1,1))**2
     .     *lamb_hdec(amsl(1)**2/amch**2,amsnl(1)**2/amch**2)
      else 
      whcsl11=0.d0
      endif

      if (amch.gt.amsl(2)+amsnl(1)) then
      whcsl21=gf/2.d0/dsqrt(2d0)/pi*amw**4/amch*cdabs(ghcen(1,2))**2
     .     *lamb_hdec(amsl(2)**2/amch**2,amsnl(1)**2/amch**2)
      else 
      whcsl21=0.d0
      endif

      whcslt=whcsl00+whcsl11+whcsl21

c      print*,'whcslt',whcslt

c  H+ ---> squarks 

      if (amch.gt.amsu(1)+amsd(1)) then
      whcsq=6*gf*amw**4/2.d0/dsqrt(2d0)/pi*cdabs(ghcud(1,1))**2
     .     *lamb_hdec(amsu(1)**2/amch**2,amsd(1)**2/amch**2)/amch
      else 
      whcsq=0.d0
      endif

      do  i=1,2
      do  j=1,2
      if(amch.gt.amst(i)+amsb(j)) then
      whcstb(i,j)=3*gf*amw**4/2.d0/dsqrt(2.d0)/pi*cdabs(ghctb(i,j))**2
     .      *lamb_hdec(amst(i)**2/amch**2,amsb(j)**2/amch**2)/amch
      else
      whcstb(i,j)=0.d0
      endif

      enddo
      enddo

      whcsqt=whcsq+whcstb(1,1)+whcstb(1,2)+whcstb(2,1)+whcstb(2,2) 

c      print*,'whcsqt',whcsqt

      else 
      whccnt=0.d0
      whcslt=0.d0
      whcsqt=0.d0
c -- change thanks to elzbieta richter-was -- c
      do i=1,2
       do j=1,2
        whcstb(i,j)=0.d0
       enddo
      enddo
      do i=1,2
       do j=1,4
        whccn(i,j)=0.d0
       enddo
      enddo
      endif

c  =================  total width and branching ratios =============== c

      wtot=hln+hmn+hsu+hbu+hsc+hcd+hbc+hbt+hwh+hwh2+hwh3+hwh4+hwh5+
     .     whccnt+whcslt+whcsqt+hdt+hst

      hcbrlc=hln/wtot
      hcbrmc=hmn/wtot
      hcbrsc=hsu/wtot
      hcbrbuc=hbu/wtot
      hcbrcc=hsc/wtot
      hcbrdc=hcd/wtot
      hcbrbc=hbc/wtot
      hcbrtc=hbt/wtot
      hcbrdtc = hdt/wtot
      hcbrstc = hst/wtot
      hcbrwh1c=hwh/wtot
      hcbrwh2c=hwh2/wtot
      hcbrwh3c=hwh3/wtot
      hcbrwh4c=hwh4/wtot
      hcbrwh5c=hwh5/wtot
      do  i=1,2
      do  j=1,5
      hcbrsuc(i,j)=whccn(i,j)/wtot
      enddo
      enddo
      hcbrcntc=whccnt/wtot
      hcbrslc=whcslt/wtot 
      hcbrsqc=whcsq/wtot 
      hcbrsqtc=whcsqt/wtot 
      do  i=1,2
      do  j=1,2
      hcbrstbc(i,j)=whcstb(i,j)/wtot
      enddo
      enddo

      bhcsl00c = whcsl00/wtot
      bhcsl11c = whcsl11/wtot
      bhcsl21c = whcsl21/wtot
      bhcsqc = whcsq/wtot

      hcwdthc=wtot

      gamc0 = wtot

c      print*,'total width',hcwdthc
c      print*,''

c ==================================================================== c
c ------------------ Neutral NMSSM Higgs boson decays  --------------  c
c ==================================================================== c

c      print*,''
c      print*,'Neutral Higgs decays'

      do i=1,5,1

c --- running masses ---
      rms = runm_hdec(amhi(i),3)
      rmc = runm_hdec(amhi(i),4)
      rmb = runm_hdec(amhi(i),5)
      rmt = runm_hdec(amhi(i),6)

      if(ghit(i).eq.ghib(i)) then
         ratcoup=1.d0
      else
         ratcoup = ghit(i)/ghib(i)
      endif
      if(gait(i).eq.gaib(i)) then
         raatcoup=1.d0
      else
         raatcoup = gait(i)/gaib(i)
      endif
      higtop = amhi(i)**2/amt**2

      ash=alphas_hdec(amhi(i),3)
      amc0=1.d8
      amb0=2.d8
      as3=alphas_hdec(amhi(i),3)
      amc0=amc
      as4=alphas_hdec(amhi(i),3)
      amb0=amb

c --- partial widths --- c
c Hi ---> g g (i=1,...,5)

       eps=1.d-8
       nfext = 3
       asg = as3
       ctt = 4*amt**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctb = 4*amb**2/amhi(i)**2*dcmplx(1d0,-eps)
       cat = 2*ctt*(1+(1-ctt)*cf(ctt))*ghit(i)
       cab = 2*ctb*(1+(1-ctb)*cf(ctb))*ghib(i)
       ctc = 4*amc**2/amhi(i)**2*dcmplx(1d0,-eps)
       cac = 2*ctc*(1+(1-ctc)*cf(ctc))*ghit(i)
       catc= 2*ctt*(1+(1-ctt)*cf(ctt))
       cabc= 2*ctb*(1+(1-ctb)*cf(ctb))
       cacc= 2*ctc*(1+(1-ctc)*cf(ctc))

       caat = 2.D0*ctt*cf(ctt)*gait(i)
       caab = 2.D0*ctb*cf(ctb)*gaib(i)
       caac = 2.D0*ctc*cf(ctc)*gait(i)
C
       if(iofsusy.eq.0) then 
       csb1= 4*amsb(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
       csb2= 4*amsb(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
       cst1= 4*amst(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
       cst2= 4*amst(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
       cxb1=-amz**2/amsb(1)**2*csb1*(1-csb1*cf(csb1))*ghibb(i,1,1)
       cxb2=-amz**2/amsb(2)**2*csb2*(1-csb2*cf(csb2))*ghibb(i,2,2)
       cxt1=-amz**2/amst(1)**2*cst1*(1-cst1*cf(cst1))*ghitt(i,1,1)
       cxt2=-amz**2/amst(2)**2*cst2*(1-cst2*cf(cst2))*ghitt(i,2,2)

       csul = 4*amsu(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
       csur = 4*amsu(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
       csdl = 4*amsd(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
       csdr = 4*amsd(2)**2/amhi(i)**2*dcmplx(1d0,-eps)

       cxul=-2*amz**2/amsu(1)**2*csul*(1-csul*cf(csul))*ghiuu(i,1,1)
       cxur=-2*amz**2/amsu(2)**2*csur*(1-csur*cf(csur))*ghiuu(i,2,2)
       cxdl=-2*amz**2/amsd(1)**2*csdl*(1-csdl*cf(csdl))*ghidd(i,1,1)
       cxdr=-2*amz**2/amsd(2)**2*csdr*(1-csdr*cf(csdr))*ghidd(i,2,2) 

       else
       cxb1=0.d0 
       cxb2=0.d0 
       cxt1=0.d0 
       cxt2=0.d0 

       cxul=0.d0 
       cxur=0.d0 
       cxdl=0.d0 
       cxdr=0.d0 
       endif

       fqcd=hggqcd(asg,nfext)
       fqcdh=fqcd
       sqcd=sggqcd(asg)
       xfac = cdabs(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .             +cxul+cxur+cxdl+cxdr)**2*fqcd
     .      + dreal(dconjg(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .                    +cxul+cxur+cxdl+cxdr)
     .             *(cxb1+cxb2+cxt1+cxt2+cxul+cxur+cxdl+cxdr))*sqcd

       fqcd=aggqcd(asg,nfext)
       xfac = xfac + cdabs(caat+caab+caac)**2*fqcd
       hgg=hvv(amhi(i),0.D0)*(asg/pi)**2*xfac/8

        cj(i)=(sqrt(abs(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .             +cxul+cxur+cxdl+cxdr)**2+
     .        Realpart(CONJG(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .                    +cxul+cxur+cxdl+cxdr)
     .             *(cxb1+cxb2+cxt1+cxt2+cxul+cxur+cxdl+cxdr))*sqcd/fqcdh)
     .         +abs(caat+caab+caac))/
     .     (cdabs(catc+cacc+cabc))

c       print*,'Hi->gg, i',hgg,i

c  Hi ---> g g* ---> g cc  to be added to Hi ---> cc
       nfext = 4
       asg = as4
       fqcd=hggqcd(asg,nfext)
       sqcd=sggqcd(asg)
       xfac = cdabs(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .             +cxul+cxur+cxdl+cxdr)**2*fqcd
     .      + dreal(dconjg(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .                    +cxul+cxur+cxdl+cxdr)
     .             *(cxb1+cxb2+cxt1+cxt2+cxul+cxur+cxdl+cxdr))*sqcd
       fqcd=aggqcd(asg,nfext)
       xfac = xfac + cdabs(caat+caab+caac)**2*fqcd
       dcc=hvv(amhi(i),0.D0)*(asg/pi)**2*xfac/8 - hgg

c       print*,'dcc, i',dcc,i

c  Hi ---> g g* ---> g bb  to be added to Hi ---> bb
       nfext = 5
       asg = ash
       fqcd=hggqcd(asg,nfext)
       sqcd=sggqcd(asg)
       xfac = cdabs(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .             +cxul+cxur+cxdl+cxdr)**2*fqcd
     .      + dreal(dconjg(cat+cab+cac+cxb1+cxb2+cxt1+cxt2
     .                    +cxul+cxur+cxdl+cxdr)
     .             *(cxb1+cxb2+cxt1+cxt2+cxul+cxur+cxdl+cxdr))*sqcd
       fqcd=aggqcd(asg,nfext)
       xfac = xfac + cdabs(caat+caab+caac)**2*fqcd
       dbb=hvv(amhi(i),0.D0)*(asg/pi)**2*xfac/8 - hgg - dcc
       hgg=hvv(amhi(i),0.D0)*(asg/pi)**2*xfac/8

c       print*,'dbb,hgg,i',dbb,hgg,i

c  Hi ---> g g: full NNNLO corrections to top loops for nf=5
       fqcd0=hggqcd(asg,5)
       fqcd=hggqcd2(asg,5,amhi(i),amt)
       xfac = cdabs(cat+cab)**2*(fqcd-fqcd0)
       fqcd0=aggqcd(asg,5)
       fqcd=aggqcd2(asg,5,amhi(i),amt)
       xfac = xfac + cdabs(caat+caab+caac)**2*(fqcd-fqcd0)
       hgg=hgg+hvv(amhi(i),0.D0)*(asg/pi)**2*xfac/8

      if(nfgg.eq.3)then
       hgg = hgg - dbb - dcc
      elseif(nfgg.eq.4)then
       hgg = hgg - dbb
       dcc = 0
      else
       dcc = 0
       dbb = 0
      endif

      higggc(i) = hgg

c      print*,'hgg',hgg,i

c  Hi ---> mu mu
      xgh1m = ghib(1)
      xgh2m = ghib(2)
      xgh3m = ghib(3)
      xgh4m = ghib(4)
      xgh5m = ghib(5)
      xga1m = gaib(1)
      xga2m = gaib(2)
      xga3m = gaib(3)
      xga4m = gaib(4)
      xga5m = gaib(5)
      xghpm = tgbet*(1.D0,0.D0)
      if(iofsusy.eq.0) then
       call staususy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1m,
     .        xgh2m,xgh3m,xgh4m,xgh5m,xga1m,xga2m,xga3m,xga4m,xga5m,
     .        xghpm,tgbet,qsusy,0)
      endif
      xghigm(1) = xgh1m
      xghigm(2) = xgh2m
      xghigm(3) = xgh3m
      xghigm(4) = xgh4m
      xghigm(5) = xgh5m
      xgaigm(1) = xga1m
      xgaigm(2) = xga2m
      xgaigm(3) = xga3m
      xgaigm(4) = xga4m
      xgaigm(5) = xga5m

      if(amhi(i).le.2*ammuon) then
       hmm = 0
      else
       hmm=hff(amhi(i),(ammuon/amhi(i))**2)*xghigm(i)**2 +
     .        aff(amhi(i),(ammuon/amhi(i))**2)*xgaigm(i)**2
      endif

      higmmc(i) = hmm

c      print*,'hmm',hmm,i

c  Hi ---> tau tau
      xgh1b = ghib(1)
      xgh2b = ghib(2)
      xgh3b = ghib(3)
      xgh4b = ghib(4)
      xgh5b = ghib(5)
      xga1b = gaib(1)
      xga2b = gaib(2)
      xga3b = gaib(3)
      xga4b = gaib(4)
      xga5b = gaib(5)
      xghpm = tgbet*(1.D0,0.D0)
      if(iofsusy.eq.0) then
       call staususy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1b,
     .        xgh2b,xgh3b,xgh4b,xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,
     .        xghpm,tgbet,qsusy,1)
      endif
      xghigb(1) = xgh1b
      xghigb(2) = xgh2b
      xghigb(3) = xgh3b
      xghigb(4) = xgh4b
      xghigb(5) = xgh5b
      xgaigb(1) = xga1b
      xgaigb(2) = xga2b
      xgaigb(3) = xga3b
      xgaigb(4) = xga4b
      xgaigb(5) = xga5b

      if(amhi(i).le.2*amtau) then
       hll = 0
      else
      hll=hff(amhi(i),(amtau/amhi(i))**2)*xghigb(i)**2 +
     .        aff(amhi(i),(amtau/amhi(i))**2)*xgaigb(i)**2
      endif

c      print*,'hll',hll,i

      higllc(i) = hll

c  Hi ---> ss
      xgh1b = ghib(1)
      xgh2b = ghib(2)
      xgh3b = ghib(3)
      xgh4b = ghib(4)
      xgh5b = ghib(5)
      xga1b = gaib(1)
      xga2b = gaib(2)
      xga3b = gaib(3)
      xga4b = gaib(4)
      xga5b = gaib(5)
      xghpm = tgbet*(1.D0,0.D0)

      if(iofsusy.eq.0) then
       call strsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1b,
     .        xgh2b,xgh3b,xgh4b,xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,
     .        xghpm,tgbet,qsusy,0)
      endif

      xghis(1) = xgh1b
      xghis(2) = xgh2b
      xghis(3) = xgh3b
      xghis(4) = xgh4b
      xghis(5) = xgh5b
      xgais(1) = xga1b
      xgais(2) = xga2b
      xgais(3) = xga3b
      xgais(4) = xga4b
      xgais(5) = xga5b

      if(amhi(i).le.2*ams) then
       hss = 0
      else
         hs1=3.d0*hff(amhi(i),(ams/amhi(i))**2)
     .        *cdabs(xghis(i))**2
     .        *tqcdh(ams**2/amhi(i)**2)
         hs2=3.d0*hff(amhi(i),(rms/amhi(i))**2)*cdabs(xghis(i))**2
     .        *qcdh(rms**2/amhi(i)**2)
         if(hs2.lt.0.d0) hs2 = 0
         rat = 2*ams/amhi(i)
         hss = qqint_hdec(rat,hs1,hs2)
         hs1=3.d0*aff(amhi(i),(ams/amhi(i))**2)
     .        *cdabs(xgais(i))**2
     .        *tqcda(ams**2/amhi(i)**2)
         hs2=3.d0*aff(amhi(i),(rms/amhi(i))**2)*cdabs(xgais(i))**2
     .        *qcda(rms**2/amhi(i)**2)
         if(hs2.lt.0.d0) hs2 = 0
         hss = qqint_hdec(rat,hs1,hs2)+hss
      endif

      higssc(i) = hss

c      print*,'hss',higssc(i),i

c  Hi --> cc
      ratcoup = 1.d0
      raatcoup = 1.d0
      if(amhi(i).le.2*amc) then
       hcc = 0
      else
         hc1=3.d0*hff(amhi(i),(amc/amhi(i))**2)
     .        *ghit(i)**2
     .        *tqcdh(amc**2/amhi(i)**2)
         hc2=3.d0*hff(amhi(i),(rmc/amhi(i))**2)*ghit(i)**2
     .        *qcdh(rmc**2/amhi(i)**2)
     .        + dcc
         if(hc2.lt.0.d0) hc2 = 0
         rat = 2*amc/amhi(i)
         hcc = qqint_hdec(rat,hc1,hc2)
         hc1=3.d0*aff(amhi(i),(amc/amhi(i))**2)
     .        *gait(i)**2
     .        *tqcda(amc**2/amhi(i)**2)
         hc2=3.d0*aff(amhi(i),(rmc/amhi(i))**2)
     .        *gait(i)**2
     .        *qcda(rmc**2/amhi(i)**2)
         if(hc2.lt.0.d0) hc2 = 0
         hcc = qqint_hdec(rat,hc1,hc2)+hcc
      endif

      higccc(i) = hcc

c      print*,'hcc',hcc,i

c  Hi ---> bb
      xgh1b = ghib(1)
      xgh2b = ghib(2)
      xgh3b = ghib(3)
      xgh4b = ghib(4)
      xgh5b = ghib(5)
      xga1b = gaib(1)
      xga2b = gaib(2)
      xga3b = gaib(3)
      xga4b = gaib(4)
      xga5b = gaib(5)
      xghpm = tgbet*(1.D0,0.D0)
      qq = amb
      susy = 0
      ssusy = (amsb(1)+amsb(2)+amglu)/3*qsusy
      as0 = alphas_hdec(ssusy,3)
      if(iofsusy.eq.0) then
         call botsusy_cnmssm_hdec(ghib(1),ghib(2),ghib(3),ghib(4),
     .        ghib(5),gaib(1),gaib(2),gaib(3),gaib(4),gaib(5),xgh1b,
     .        xgh2b,xgh3b,xgh4b,xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,
     .        xghpm,tgbet,qsusy,loop)
      endif
      xghib(1) = xgh1b
      xghib(2) = xgh2b
      xghib(3) = xgh3b
      xghib(4) = xgh4b
      xghib(5) = xgh5b
      xgaib(1) = xga1b
      xgaib(2) = xga2b
      xgaib(3) = xga3b
      xgaib(4) = xga4b
      xgaib(5) = xga5b
      ratcoup = ghit(i)/cdabs(xghib(i))
      raatcoup = gait(i)/cdabs(xgaib(i))

      if(amhi(i).le.2*amb) then
       hbb = 0
      else
       hb1=3.d0*hff(amhi(i),(amb/amhi(i))**2)
     .    *(cdabs(xghib(i))**2+cdabs(xghib(i)*ghib(i)*susy))
     .    *tqcdh(amb**2/amhi(i)**2)
       hb2=3.d0*hff(amhi(i),(rmb/amhi(i))**2)
     .    *(cdabs(xghib(i))**2+cdabs(xghib(i)*ghib(i)*susy))
     .    *qcdh(rmb**2/amhi(i)**2)
     .   + dbb
       if(hb2.lt.0.d0) hb2 = 0
       rat = 2*amb/amhi(i)
       hbb = qqint_hdec(rat,hb1,hb2)
       hb1=3.d0*aff(amhi(i),(amb/amhi(i))**2)
     .    *(cdabs(xgaib(i))**2+cdabs(xgaib(i)*gaib(i)*susy))
     .    *tqcda(amb**2/amhi(i)**2)
       hb2=3.d0*aff(amhi(i),(rmb/amhi(i))**2)
     .    *(cdabs(xgaib(i))**2+cdabs(xgaib(i)*gaib(i)*susy))
     .    *qcda(rmb**2/amhi(i)**2)
     .    + dbb
       if(hb2.lt.0.d0) hb2 = 0
       hbb = qqint_hdec(rat,hb1,hb2)+hbb
      endif

      higbbc(i) = hbb

c      print*,'hbb',hbb,i

c  Hi ---> tt
      ratcoup = 0.d0
      raatcoup = 0.d0
      if(ionsh.eq.0)then
         dld=3d0
         dlu=5d0
         xm1 = 2d0*amt-dld
         xm2 = 2d0*amt+dlu
         if (amhi(i).le.amt+amw+amb) then
            htt=0.d0
         elseif (amhi(i).le.xm1) then
            factt=6.d0*gf**2*amhi(i)**3*amt**2/2.d0/128.d0/pi**3
            CALL HTOTT_CNMSSM(amhi(i),amt,amb,amw,amch,tb,ghit(i),
     .           gait(i),ghib(i),gaib(i),ghivv(i),ghihpwm(i),gaihpwm(i),
     .           htt0)
            htt=factt*htt0
         elseif (amhi(i).le.xm2) then
            xx(1) = xm1-1d0
            xx(2) = xm1
            xx(3) = xm2
            xx(4) = xm2+1d0
            
            outputfile = 'interpolhitt_1.dat'
            call MHpmfromMHi(xx(1),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)   
            factt=6.d0*gf**2*xx(1)**3*amt**2/2.d0/128.d0/pi**3
            CALL HTOTT_CNMSSM(amhi(1),amt,amb,amw,amch,tb,ghitv(1),
     .           gaitv(1),ghibv(1),gaibv(1),ghivvv(1),ghihpwmv(1),
     .           gaihpwmv(1),htt0)
            yy(1)=factt*htt0

            outputfile = 'interpolhitt_2.dat'
            call MHpmfromMHi(xx(2),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)   
            factt=6.d0*gf**2*xx(2)**3*amt**2/2.d0/128.d0/pi**3
            CALL HTOTT_CNMSSM(amhi(2),amt,amb,amw,amch,tb,ghitv(2),
     .           gaitv(2),ghibv(2),gaibv(2),ghivvv(2),ghihpwmv(2),
     .           gaihpwmv(2),htt0)
            yy(2)=factt*htt0

            outputfile = 'interpolhitt_3.dat'
            call MHpmfromMHi(xx(3),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)   
            xmt = runm_hdec(xx(3),6)
            ht1=3.d0*hff(xx(3),(amt/xx(3))**2)*ghitv(i)**2
     .           *tqcdh(amt**2/xx(3)**2)
            ht2=3.d0*hff(xx(3),(xmt/xx(3))**2)*ghitv(i)**2
     .           *qcdh(xmt**2/xx(3)**2)
            if(ht2.lt.0.d0) ht2 = 0
            rat = 2*amt/xx(3)
            yy(3) = qqint_hdec(rat,ht1,ht2)
            ht1=3.d0*aff(xx(3),(amt/xx(3))**2)*gaitv(i)**2
     .           *tqcda(amt**2/xx(3)**2)
            ht2=3.d0*aff(xx(3),(rmt/xx(3))**2)*gaitv(i)**2
     .           *qcda(rmt**2/xx(3)**2)
            if(ht2.lt.0.d0) ht2 = 0
            yy(3) = qqint_hdec(rat,ht1,ht2)+yy(3)

            outputfile = 'interpolhitt_4.dat'
            call MHpmfromMHi(xx(4),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)   
            xmt = runm_hdec(xx(4),6)
            ht1=3.d0*hff(xx(4),(amt/xx(4))**2)*ghitv(i)**2
     .           *tqcdh(amt**2/xx(4)**2)
            ht2=3.d0*hff(xx(4),(xmt/xx(4))**2)*ghitv(i)**2
     .           *qcdh(xmt**2/xx(4)**2)
            if(ht2.lt.0.d0) ht2 = 0
            rat = 2*amt/xx(4)
            yy(4) = qqint_hdec(rat,ht1,ht2)
            ht1=3.d0*aff(xx(4),(amt/xx(4))**2)*gaitv(i)**2
     .           *tqcda(amt**2/xx(4)**2)
            ht2=3.d0*aff(xx(4),(rmt/xx(4))**2)*gaitv(i)**2
     .           *qcda(rmt**2/xx(4)**2)
            if(ht2.lt.0.d0) ht2 = 0
            yy(4) = qqint_hdec(rat,ht1,ht2)+yy(4)

            htt=fint_hdec(amhi(i),xx,yy)
            end if
            end if
            end if
            end if
         else
            ht1=3.D0*hff(amhi(i),(amt/amhi(i))**2)*ghit(i)**2
     .           *tqcdh(amt**2/amhi(i)**2)
            ht2=3.D0*hff(amhi(i),(rmt/amhi(i))**2)*ghit(i)**2
     .           *qcdh(rmt**2/amhi(i)**2)
            if(ht2.lt.0.d0) ht2 = 0
            rat = 2*amt/amhi(i)
            htt = qqint_hdec(rat,ht1,ht2)
            ht1=3.d0*aff(amhi(i),(amt/amhi(i))**2)*gait(i)**2
     .           *tqcda(amt**2/amhi(i)**2)
            ht2=3.d0*aff(amhi(i),(rmt/amhi(i))**2)*gait(i)**2
     .           *qcda(rmt**2/amhi(i)**2)
            if(ht2.lt.0.d0) ht2 = 0
            htt = qqint_hdec(rat,ht1,ht2)+htt
         endif
         
         if(calcmasseserror) then
           calcmasseserror=.FALSE.
           print*, 'Error in off-shell decay Hi -> tt. i=',i
           print*, 'Off-shell decay turned off'
           if (amhi(i).le.2*amt) then
             htt=0.d0
           else
             ht1=3.D0*hff(amhi(i),(amt/amhi(i))**2)*ghit(i)**2
     .           *tqcdh(amt**2/amhi(i)**2)
             ht2=3.D0*hff(amhi(i),(rmt/amhi(i))**2)*ghit(i)**2
     .           *qcdh(rmt**2/amhi(i)**2)
             if(ht2.lt.0.d0) ht2 = 0
             rat = 2*amt/amhi(i)
             htt = qqint_hdec(rat,ht1,ht2)
             ht1=3.d0*aff(amhi(i),(amt/amhi(i))**2)*gait(i)**2
     .           *tqcda(amt**2/amhi(i)**2)
             ht2=3.d0*aff(amhi(i),(rmt/amhi(i))**2)*gait(i)**2
     .           *qcda(rmt**2/amhi(i)**2)
             if(ht2.lt.0.d0) ht2 = 0
             htt = qqint_hdec(rat,ht1,ht2)+htt
           endif
         end if
      else
         if (amhi(i).le.2*amt) then
            htt=0.d0
         else
            ht1=3.D0*hff(amhi(i),(amt/amhi(i))**2)*ghit(i)**2
     .           *tqcdh(amt**2/amhi(i)**2)
            ht2=3.D0*hff(amhi(i),(rmt/amhi(i))**2)*ghit(i)**2
     .           *qcdh(rmt**2/amhi(i)**2)
            if(ht2.lt.0.d0) ht2 = 0
            rat = 2*amt/amhi(i)
            htt = qqint_hdec(rat,ht1,ht2)
            ht1=3.d0*aff(amhi(i),(amt/amhi(i))**2)*gait(i)**2
     .           *tqcda(amt**2/amhi(i)**2)
            ht2=3.d0*aff(amhi(i),(rmt/amhi(i))**2)*gait(i)**2
     .           *qcda(rmt**2/amhi(i)**2)
            if(ht2.lt.0.d0) ht2 = 0
            htt = qqint_hdec(rat,ht1,ht2)+htt
         endif
      endif

      higttc(i) = htt

c      print*,'htt',htt,i

c  Hi ---> gamma gamma
       eps=1.d-8
       xrmc = runm_hdec(amhi(i)/2,4)*amc/runm_hdec(amc,4)
       xrmb = runm_hdec(amhi(i)/2,5)*amb/runm_hdec(amb,5)
       xrmt = runm_hdec(amhi(i)/2,6)*amt/runm_hdec(amt,6)
       ctt = 4*xrmt**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctb = 4*xrmb**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctc = 4*xrmc**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctl = 4*amtau**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctw = 4*amw**2/amhi(i)**2*dcmplx(1d0,-eps)
       cth = 4*amch**2/amhi(i)**2*dcmplx(1d0,-eps)
       cat = 4/3d0 * 2*ctt*(1+(1-ctt)*cf(ctt))*ghit(i)
     .     * cfacq_hdec(0,amhi(i),xrmt)
       cab = 1/3d0 * 2*ctb*(1+(1-ctb)*cf(ctb))*ghib(i)
     .     * cfacq_hdec(0,amhi(i),xrmb)
       cac = 4/3d0 * 2*ctc*(1+(1-ctc)*cf(ctc))*ghit(i)
     .     * cfacq_hdec(0,amhi(i),xrmc)
       cal = 1.d0  * 2*ctl*(1+(1-ctl)*cf(ctl))*ghib(i)
       caw = -(2+3*ctw+3*ctw*(2-ctw)*cf(ctw))*ghivv(i)
       cah = -amz**2/2/amch**2*cth*(1-cth*cf(cth))*ghipm(i)

       caat = 4/3d0 * ctt*cf(ctt)*gait(i)
     .     * cfacq_hdec(1,amhi(i),xrmt)
       caab = 1/3d0 * ctb*cf(ctb)*gaib(i)
     .     * cfacq_hdec(1,amhi(i),xrmb)
       caac = 4/3d0 * ctc*cf(ctc)*gait(i)
     .     * cfacq_hdec(1,amhi(i),xrmc)
       caal = 1.d0  * ctl*cf(ctl)*gaib(i)

       if(iofsusy.eq.0) then 
        rmsu1 = runms_hdec(amhi(i)/2,amsu(1))
        rmsu2 = runms_hdec(amhi(i)/2,amsu(2))
        rmsd1 = runms_hdec(amhi(i)/2,amsd(1))
        rmsd2 = runms_hdec(amhi(i)/2,amsd(2))
        rmsb1 = runms_hdec(amhi(i)/2,amsb(1))
        rmsb2 = runms_hdec(amhi(i)/2,amsb(2))
        rmst1 = runms_hdec(amhi(i)/2,amst(1))
        rmst2 = runms_hdec(amhi(i)/2,amst(2))
        cx1 = 4*amchar(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
        cx2 = 4*amchar(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
        csb1= 4*rmsb1**2/amhi(i)**2*dcmplx(1d0,-eps)
        csb2= 4*rmsb2**2/amhi(i)**2*dcmplx(1d0,-eps)
        cst1= 4*rmst1**2/amhi(i)**2*dcmplx(1d0,-eps)
        cst2= 4*rmst2**2/amhi(i)**2*dcmplx(1d0,-eps)
        csl1= 4*amsl(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
        csl2= 4*amsl(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
        cax1= amw/xmchar(1) * 2*cx1*(1+(1-cx1)*cf(cx1))*achi(i,1,1) 
        cax2= amw/xmchar(2) * 2*cx2*(1+(1-cx2)*cf(cx2))*achi(i,2,2)

        caax1= amw/xmchar(1) * cx1*cf(cx1) * aachi(i,1,1)*
     .       dcmplx(eps,1.d0)
        caax2= amw/xmchar(2) * cx2*cf(cx2) * aachi(i,2,2)*
     .       dcmplx(eps,1.d0) 

        csel = 4*amse(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
        cser = 4*amse(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
        csul = 4*rmsu1**2/amhi(i)**2*dcmplx(1d0,-eps)
        csur = 4*rmsu2**2/amhi(i)**2*dcmplx(1d0,-eps)
        csdl = 4*rmsd1**2/amhi(i)**2*dcmplx(1d0,-eps)
        csdr = 4*rmsd2**2/amhi(i)**2*dcmplx(1d0,-eps)

        cxel=-2*amz**2/amse(1)**2*csel*(1-csel*cf(csel))*ghielel(i,1,1)
        cxer=-2*amz**2/amse(2)**2*cser*(1-cser*cf(cser))*ghielel(i,2,2)
        cxul=-2*4.D0/3.D0*amz**2/amsu(1)**2*csul*(1-csul*cf(csul))*
     .       ghiuu(i,1,1)* cfacsq_hdec(amhi(i),rmsu1)
        cxur=-2*4.D0/3.D0*amz**2/amsu(2)**2*csur*(1-csur*cf(csur))*
     .       ghiuu(i,2,2)* cfacsq_hdec(amhi(i),rmsu2)
        cxdl=-2/3.d0*amz**2/amsd(1)**2*csdl*(1-csdl*cf(csdl))*
     .       ghidd(i,1,1)* cfacsq_hdec(amhi(i),rmsd1)
        cxdr=-2/3.d0*amz**2/amsd(2)**2*csdr*(1-csdr*cf(csdr))*
     .       ghidd(i,2,2)* cfacsq_hdec(amhi(i),rmsd2)

        cxb1=-1/3d0*amz**2/amsb(1)**2*csb1*(1-csb1*cf(csb1))*
     .       ghibb(i,1,1)*cfacsq_hdec(amhi(i),rmsb1)
        cxb2=-1/3d0*amz**2/amsb(2)**2*csb2*(1-csb2*cf(csb2))*
     .       ghibb(i,2,2)*cfacsq_hdec(amhi(i),rmsb2)
        cxt1=-4/3d0*amz**2/amst(1)**2*cst1*(1-cst1*cf(cst1))*
     .       ghitt(i,1,1)*cfacsq_hdec(amhi(i),rmst1)
        cxt2=-4/3d0*amz**2/amst(2)**2*cst2*(1-cst2*cf(cst2))*
     .       ghitt(i,2,2)*cfacsq_hdec(amhi(i),rmst2)

        csl1= 4*amsl(1)**2/amhi(i)**2*dcmplx(1d0,-eps)
        csl2= 4*amsl(2)**2/amhi(i)**2*dcmplx(1d0,-eps)
        cxl1=      -amz**2/amsl(1)**2*csl1*(1-csl1*cf(csl1))*
     .       ghiee(i,1,1)
        cxl2=      -amz**2/amsl(2)**2*csl2*(1-csl2*cf(csl2))*
     .       ghiee(i,2,2)

        xfac = cdabs(cat+cab+cac+cal+caw+cah+cax1+cax2
     .      +  cxel+cxer+cxul+cxur+cxdl+cxdr
     .      +  cxb1+cxb2+cxt1+cxt2+cxl1+cxl2)**2
     .      + 4.d0*cdabs(caat+caab+caac+caal+caax1+caax2)**2
       else 
        xfac = cdabs(cat+cab+cac+cal+caw+cah)**2
     .         + 4.d0*cdabs(caat+caab+caac+caal)**2
       endif
       hga=hvv(amhi(i),0.D0)*(alph/pi)**2/16.D0*xfac

       higgac(i) = hga

c       print*,'hga',hga,i

c  Hi ---> Z gamma
c- Gamma=Gamma(CP-odd part) + Gamma(CP-even part)
      if(amhi(i).le.amz)then
       hzga=0
      else
       ts = ss/cs
       ft = -3*2D0/3*(1-4*2D0/3*ss)/dsqrt(ss*cs)*ghit(i)
       fb = 3*1D0/3*(-1+4*1D0/3*ss)/dsqrt(ss*cs)*ghib(i)
       fc = -3*2d0/3*(1-4*2d0/3*ss)/dsqrt(ss*cs)*ghit(i)
       fl = (-1+4*ss)/dsqrt(ss*cs)*ghib(i)
       eps=1.D-8
       ctt = 4*amt**2/amhi(i)**2*dcmplx(1D0,-eps)
       ctb = 4*amb**2/amhi(i)**2*dcmplx(1D0,-eps)
       ctc = 4*amc**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctl = 4*amtau**2/amhi(i)**2*dcmplx(1d0,-eps)
       ctw = 4*amw**2/amhi(i)**2*dcmplx(1D0,-eps)
       cth = 4*amch**2/amhi(i)**2*dcmplx(1D0,-eps)
       clt = 4*amt**2/amz**2*dcmplx(1D0,-eps)
       clb = 4*amb**2/amz**2*dcmplx(1D0,-eps)
       clc = 4*amc**2/amz**2*dcmplx(1d0,-eps)
       cle = 4*amtau**2/amz**2*dcmplx(1d0,-eps)
       clw = 4*amw**2/amz**2*dcmplx(1D0,-eps)
       clh = 4*amch**2/amz**2*dcmplx(1D0,-eps)
       cat = ft*(ci1(ctt,clt) - ci2(ctt,clt))
       cab = fb*(ci1(ctb,clb) - ci2(ctb,clb))
       cac = fc*(ci1(ctc,clc) - ci2(ctc,clc))
       cal = fl*(ci1(ctl,cle) - ci2(ctl,cle))
       caw = -1/dsqrt(ts)*(4*(3-ts)*ci2(ctw,clw)
     .     + ((1+2/ctw)*ts - (5+2/ctw))*ci1(ctw,clw))*ghivv(i)
       cah = (1-2*ss)/dsqrt(ss*cs)*amz**2/2/amch**2*ci1(cth,clh)*
     .      ghipm(i)
       ft = -3*2d0/3*(1-4*2d0/3*ss)/dsqrt(ss*cs)*gait(i)
       fb = 3*1d0/3*(-1+4*1d0/3*ss)/dsqrt(ss*cs)*gaib(i)
       fc = -3*2d0/3*(1-4*2d0/3*ss)/dsqrt(ss*cs)*gait(i)
       fl = (-1+4*ss)/dsqrt(ss*cs)*gaib(i)
       caat = ft*(- ci2(ctt,clt))
       caab = fb*(- ci2(ctb,clb))
       caac = fc*(- ci2(ctc,clc))
       caal = fl*(- ci2(ctl,cle))
       xfac = cdabs(cat+cab+caw+cah+cac+cal)**2
     .       +cdabs(caat+caab+caac+caal)**2
       acoup = dsqrt(2d0)*gf*amz**2*ss*cs/pi**2
       hzga = gf/(4.d0*pi*dsqrt(2.d0))*amhi(i)**3*(alph/pi)*acoup/16.d0
     .        *xfac*(1-amz**2/amhi(i)**2)**3
      endif

      higzgac(i) = hzga

c      print*,'hzga',hzga,i

c Hi ---> W W

      if(ionwz.eq.0)then
       call htovv_hdec(0,amhi(i),amw,gamw,htww)
       hww = 3D0/2D0*gf*amw**4/dsqrt(2d0)/pi/amhi(i)**3*htww*ghivv(i)**2
      elseif(ionwz.eq.-1)then
       dld=2D0
       dlu=2D0
       xm1 = 2D0*amw-dld
       xm2 = 2D0*amw+dlu
       if (amhi(i).le.xm1) then
        call htovv_hdec(0,amhi(i),amw,gamw,htww)
        hww = 3D0/2D0*gf*amw**4/dsqrt(2D0)/pi/amhi(i)**3*htww*
     .       ghivv(i)**2
       elseif (amhi(i).le.xm2) then
        xx(1) = xm1-1D0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1D0
        call htovv_hdec(0,xx(1),amw,gamw,htww)
        yy(1)=3d0/2d0*gf*amw**4/dsqrt(2d0)/pi/xx(1)**3*htww
        call htovv_hdec(0,xx(2),amw,gamw,htww)
        yy(2)=3d0/2d0*gf*amw**4/dsqrt(2d0)/pi/xx(2)**3*htww
        yy(3)=hvv(xx(3),amw**2/xx(3)**2)
        yy(4)=hvv(xx(4),amw**2/xx(4)**2)
        hww = fint_hdec(amhi(i),xx,yy)*ghivv(i)**2
       else
        hww=hvv(amhi(i),amw**2/amhi(i)**2)*ghivv(i)**2
       endif
      else
      dld=2D0
      dlu=2D0
      xm1 = 2D0*amw-dld
      xm2 = 2D0*amw+dlu
      if (amhi(i).le.amw) then
       hww=0
      else if (amhi(i).le.xm1) then
       cww=3.d0*gf**2*amw**4/16.d0/pi**3
       hww=hv(amw**2/amhi(i)**2)*cww*amhi(i)*ghivv(i)**2
      else if (amhi(i).lt.xm2) then
       cww=3.d0*gf**2*amw**4/16.d0/pi**3
       xx(1) = xm1-1d0
       xx(2) = xm1
       xx(3) = xm2
       xx(4) = xm2+1d0
       yy(1)=hv(amw**2/xx(1)**2)*cww*xx(1)
       yy(2)=hv(amw**2/xx(2)**2)*cww*xx(2)
       yy(3)=hvv(xx(3),amw**2/xx(3)**2)
       yy(4)=hvv(xx(4),amw**2/xx(4)**2)
       hww = fint_hdec(amhi(i),xx,yy)*ghivv(i)**2
      else
       hww=hvv(amhi(i),amw**2/amhi(i)**2)*ghivv(i)**2
      endif
      endif

      higwwc(i) = hww

c      print*,'hww',hww,i

c  Hi ---> Z Z
      if(ionwz.eq.0)then
       call htovv_hdec(0,amhi(i),amz,gamz,htzz)
       hzz = 3d0/4d0*gf*amz**4/dsqrt(2d0)/pi/amhi(i)**3*htzz*ghivv(i)**2
      elseif(ionwz.eq.-1)then
       dld=2d0
       dlu=2d0
       xm1 = 2d0*amz-dld
       xm2 = 2d0*amz+dlu
       if (amhi(i).le.xm1) then
        call htovv_hdec(0,amhi(i),amz,gamz,htzz)
        hzz = 3d0/4d0*gf*amz**4/dsqrt(2d0)/pi/amhi(i)**3*htzz*
     .       ghivv(i)**2
       elseif (amhi(i).le.xm2) then
        xx(1) = xm1-1d0
        xx(2) = xm1
        xx(3) = xm2
        xx(4) = xm2+1d0
        call htovv_hdec(0,xx(1),amz,gamz,htzz)
        yy(1)=3d0/4d0*gf*amz**4/dsqrt(2d0)/pi/xx(1)**3*htzz
        call htovv_hdec(0,xx(2),amz,gamz,htzz)
        yy(2)=3d0/4d0*gf*amz**4/dsqrt(2d0)/pi/xx(2)**3*htzz
        yy(3)=hvv(xx(3),amz**2/xx(3)**2)/2
        yy(4)=hvv(xx(4),amz**2/xx(4)**2)/2
        hzz = fint_hdec(amhi(i),xx,yy)*ghivv(i)**2
       else
        hzz=hvv(amhi(i),amz**2/amhi(i)**2)/2.d0*ghivv(i)**2
       endif
      else
      dld=2d0
      dlu=2d0
      xm1 = 2d0*amz-dld
      xm2 = 2d0*amz+dlu
      if (amhi(i).le.amz) then
       hzz=0
      else if (amhi(i).le.xm1) then
       czz=3.d0*gf**2*amz**4/192.d0/pi**3*(7-40/3.d0*ss+160/9.d0*ss**2)
       hzz=hv(amz**2/amhi(i)**2)*czz*amhi(i)*ghivv(i)**2
      else if (amhi(i).lt.xm2) then
       czz=3.d0*gf**2*amz**4/192.d0/pi**3*(7-40/3.d0*ss+160/9.d0*ss**2)
       xx(1) = xm1-1d0
       xx(2) = xm1
       xx(3) = xm2
       xx(4) = xm2+1d0
       yy(1)=hv(amz**2/xx(1)**2)*czz*xx(1)
       yy(2)=hv(amz**2/xx(2)**2)*czz*xx(2)
       yy(3)=hvv(xx(3),amz**2/xx(3)**2)/2d0
       yy(4)=hvv(xx(4),amz**2/xx(4)**2)/2d0
       hzz = fint_hdec(amhi(i),xx,yy)*ghivv(i)**2
      else
       hzz=hvv(amhi(i),amz**2/amhi(i)**2)/2.d0*ghivv(i)**2
      endif
      endif

      higzzc(i) = hzz

c      print*,'hzz',hzz,i

c =========================== SUSY decays ============================ c

      if(iofsusy.eq.0) then

c Hi ---> charginos

      do ii=1,2
         do jj=1,2
            if (amhi(i).gt.amchar(ii)+amchar(jj)) then
               whigchc(i,ii,jj)=gf*amw**2/(4*pi*dsqrt(2.d0))/amhi(i)
     .    *lamb_hdec(amchar(ii)**2/amhi(i)**2,amchar(jj)**2/amhi(i)**2)
     .          *( (cdabs(achi(i,ii,jj))**2+cdabs(aachi(i,ii,jj))**2)*
     .              (amhi(i)**2-amchar(ii)**2-amchar(jj)**2)-
     .         2.d0*(cdabs(achi(i,ii,jj))**2-cdabs(aachi(i,ii,jj))**2)* 
     .              xmchar(ii)*xmchar(jj) )
            else
               whigchc(i,ii,jj)=0.d0
            endif
            
c            print*,'char ij',whigchc(i,ii,jj),i,ii,jj

         end do
      end do

      whigchtc(i)=whigchc(i,1,1)+whigchc(i,1,2)+whigchc(i,2,1)
     .     +whigchc(i,2,2)

c      print*,'sum char',whigchtc(i),i

c  Hi ---> neutralinos 

      do ii=1,5
      do jj=1,5
      if (amhi(i).gt.amneut(ii)+amneut(jj)) then
         whignec(i,ii,jj)=gf*amw**2/(2*pi*dsqrt(2.d0))/amhi(i) 
     .        *((amhi(i)**2-xmneut(ii)**2-xmneut(jj)**2)*
     .        (anhiRre(i,ii,jj)**2+anhiLre(i,ii,jj)**2
     .        +anhiRim(i,ii,jj)**2+anhiLim(i,ii,jj)**2)/2.d0-
     .        2.d0*xmneut(ii)*xmneut(jj)*
     .        (anhiRre(i,ii,jj)*anhiLre(i,ii,jj)
     .        +anhiRim(i,ii,jj)*anhiLim(i,ii,jj)))
     .    *lamb_hdec(amneut(ii)**2/amhi(i)**2,amneut(jj)**2/amhi(i)**2)
      else 
         whignec(i,ii,jj)=0.d0
      endif

c      print*,'whignec,ij',whignec(i,ii,jj),i,ii,jj

      end do
      end do

      whignetc(i)= whignec(i,1,1)+whignec(i,1,2)+whignec(i,1,3)
     .     +whignec(i,1,4)+whignec(i,1,5)+whignec(i,2,1)+whignec(i,2,2)
     .     +whignec(i,2,3)+whignec(i,2,4)+whignec(i,2,5)+whignec(i,3,1)
     .     +whignec(i,3,2)+whignec(i,3,3)+whignec(i,3,4)+whignec(i,3,5)
     .     +whignec(i,4,1)+whignec(i,4,2)+whignec(i,4,3)+whignec(i,4,4)
     .     +whignec(i,4,5)+whignec(i,5,1)+whignec(i,5,2)+whignec(i,5,3)
     .     +whignec(i,5,4)+whignec(i,5,5)

c      print*,'sum whignetc,i',whignetc(i),i

c  Hi ---> sleptons 

      if(amhi(i).gt.2.d0*amse(1)) then
         whigslelc(i)=2.d0*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghielel(i,1,1))**2*
     .        beta_hdec(amse(1)**2/amhi(i)**2)/amhi(i)
      else
         whigslelc(i)=0.d0
      endif
      if(amhi(i).gt.2.d0*amse(2)) then
         whigslerc(i)=2.d0*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghielel(i,2,2))**2*
     .        beta_hdec(amse(2)**2/amhi(i)**2)/amhi(i)
      else
         whigslerc(i)=0.d0
      endif

      if (amhi(i).gt.2.d0*amsn(1)) then
         whigslnlc(i)=2*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghinene(i,1,1))**2*
     .        beta_hdec(amsn(1)**2/amhi(i)**2)/amhi(i)
      else
         whigslnlc(i)=0.d0
      endif

      if (amhi(i).gt.2.d0*amsnl(1)) then
         whigslnltauc(i)=gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghinene(i,1,1))**2*
     .        beta_hdec(amsnl(1)**2/amhi(i)**2)/amhi(i)
      else
         whigslnltauc(i)=0.d0
      endif

      do ii=1,2
      do jj=1,2
         if(amhi(i).gt.amsl(ii)+amsl(jj)) then
            whigstauc(i,ii,jj)=gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .           cdabs(ghiee(i,ii,jj))**2*
     . lamb_hdec(amsl(ii)**2/amhi(i)**2,amsl(jj)**2/amhi(i)**2)/amhi(i)
         else
            whigstauc(i,ii,jj)=0.d0
         endif
      end do
      end do


c      print*,'whigstau',i,whigstauc(i,1,1),whigstauc(i,2,1),
c     .     whigstauc(i,1,2),whigstauc(i,2,2)
c      print*,'whigslelc,whigslerc',whigslelc(i),whigslerc(i)
c      print*,'whigslnlc,whigslnltauc',whigslnlc(i),whigslnltauc(i)

      whigsltc(i)=whigstauc(i,1,1)+whigstauc(i,2,1)+whigstauc(i,1,2)
     .     +whigstauc(i,2,2)+whigslelc(i)+whigslerc(i)+whigslnlc(i)
     .     +whigslnltauc(i)

c      print*,'whigsltc',whigsltc(i)

c  Hi ---> squarks 

      if (amhi(i).gt.2.D0*amsu(1)) then
         whigsqulc(i)=6*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghiuu(i,1,1))**2*
     .        beta_hdec(amsu(1)**2/amhi(i)**2)/amhi(i)
      else
         whigsqulc(i)=0.D0
      endif

      if (amhi(i).gt.2.d0*amsu(2)) then
         whigsqurc(i)=6*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghiuu(i,2,2))**2*
     .        beta_hdec(amsu(2)**2/amhi(i)**2)/amhi(i)
      else
         whigsqurc(i)=0.D0
      endif

      if (amhi(i).gt.2.d0*amsd(1)) then
         whigsqdlc(i)=6*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghidd(i,1,1))**2*
     .        beta_hdec(amsd(1)**2/amhi(i)**2)/amhi(i)
      else
         whigsqdlc(i)=0.D0
      endif

      if (amhi(i).gt.2.d0*amsd(2)) then
         whigsqdrc(i)=6*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghidd(i,2,2))**2*
     .        beta_hdec(amsd(2)**2/amhi(i)**2)/amhi(i)
      else
         whigsqdrc(i)=0.D0
      endif

      whigsqc(i)=whigsqulc(i)+whigsqurc(i)+whigsqdlc(i)+whigsqdrc(i)

c      print*,'sum, i',whigsqc(i),i
c      print*,'squark',whigsqulc(i),whigsqurc(i),whigsqdlc(i),
c     .     whigsqdrc(i)

c      print*,'whisqc',whigsqc(i)

c  Hi ---> stops
      susy = 1
      do ii=1,2
      do jj=1,2
      qsq = amhi(i)
      susy = 1
      if(amhi(i).gt.ymst(ii)+ymst(jj)) then
         SUSY=1.d0
         whigstc(i,ii,jj)=3*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghitt(i,ii,jj))**2*
     .        lamb_hdec(ymst(ii)**2/amhi(i)**2,ymst(jj)**2/amhi(i)**2)
     .        /amhi(i)*susy
      else
         whigstc(i,ii,jj)=0.d0
      endif
      end do
      end do

c      do ii=1,2,1
c         do jj=1,2,1
c            print*,'Hi->stops,j,k',whigstc(i,ii,jj),i,ii,jj
c         end do
c      end do

c  Hi ---> sbottoms
      susy = 1
      do ii=1,2
      do jj=1,2

      qsq = amhi(i)
      if(amhi(i).gt.ymsb(ii)+ymsb(jj)) then
         susy = 1.d0
         whigsbc(i,ii,jj)=3*gf*amz**4/2.d0/dsqrt(2.d0)/pi*
     .        cdabs(ghibb(i,ii,jj))**2*
     .        lamb_hdec(ymsb(ii)**2/amhi(i)**2,ymsb(jj)**2/amhi(i)**2)
     .        /amhi(i)*susy
         
      else
         whigsbc(i,ii,jj)=0.d0
      endif
      end do
      end do
c

c      do ii=1,2,1
c         do jj=1,2,1
c            print*,'Hi->sbottoms,j,k',whigsbc(i,ii,jj),ii,jj
c         end do
c      end do

      whigsttc(i)=whigstc(i,1,1)+whigstc(i,1,2)+whigstc(i,2,1)
     .     +whigstc(i,2,2) 
      whigsbbc(i)=whigsbc(i,1,1)+whigsbc(i,1,2)+whigsbc(i,2,1)
     .     +whigsbc(i,2,2) 
      whigsqtc(i)=whigsttc(i)+whigsbbc(i)+whigsqc(i)

c      print*,'squarks,i',whigsttc(i),whigsbbc(i),whigsqtc(i),i

      else 
      whigchtc(i)=0.d0
      whignetc(i)=0.d0
      whigsltc(i)=0.d0
      whigsqtc(i)=0.d0
c--change thanks to elzbieta richter-was
      do ii=1,2
       do jj=1,2
        whigchc(i,ii,jj)=0.d0
        whigstc(i,ii,jj)=0.d0
        whigsbc(i,ii,jj)=0.d0
        whigstauc(i,ii,jj)=0.d0
       enddo
      enddo
      do ii=1,5
       do jj=1,5
        whignec(i,ii,jj)=0.d0
       enddo
      enddo

      endif
 
c -------------------------------------------------------------------- c
c -- total width w/o Higgs-to-Higgs and Higgs-to-gauge-Higgs decays -- c

      whitotc(i)=higllc(i)+higmmc(i)+higssc(i)+higccc(i)+higbbc(i)
     .     +higttc(i)+higggc(i)+higgac(i)+higzgac(i)+higwwc(i)+higzzc(i)
     .     +whigchtc(i)+whignetc(i)+whigsltc(i)+whigsqtc(i)

c      print*,'wtot,i',whitotc(i),i,higllc(i),higmmc(i),higssc(i),
c     .     higccc(i)+higbbc(i)
c      print*,'wtot',higttc(i),higggc(i),higgac(i),higzgac(i),
c     .     higwwc(i),higzzc(i)
c      print*,'wtot 3',whigchtc(i),whignetc(i),whigsltc(i),whigsqtc(i)

c      tmp = higllc(i)+higmmc(i)+higssc(i)+higccc(i)+higttc(i)+higggc(i)
c     .     +higbbc(i)
c
c      print*,'tmp',tmp,i

c      print*,'whitot 1',whitotc(i),i

c -------------------------------------------------------------------- c

c Hi ---> Hj Hk

      do j=1,5,1
         do k=1,5,1
            hitohjhk(i,j,k) = 0.D0
         end do
      end do

c --- on-shell decays --- c
     
      htoh(i) = 0.D0

      do j=1,5,1
         do k=1,5,1
            if(amhi(i).ge.amhi(j)+amhi(k)) then
#ifdef HHHDECAYHO            
                  if (iewh.eq.0)then
               hitohjhk(i,j,k)=gf/16.d0/dsqrt(2d0)/pi*amz**4/amhi(i)*
     .            lamb_hdec(amhi(j)**2/amhi(i)**2,amhi(k)**2/amhi(i)**2)
     .              *ghihjhk(i,j,k)**2
               htoh(i) = htoh(i) + hitohjhk(i,j,k)
                    else
c Hanna: added call to recoupHHH to calculate the loopcorrections (full
c one-loop and dominant 2-loop) to the trilinear Higgs coupling                      
            call recoupHHH(i,j,k, amhi(i)**2,amhi(j)**2,amhi(k)**2,amp,iewh,CPcon)
               hitohjhk(i,j,k)=1.d0/2d0/16.d0/pi/amhi(i)*
     .            lamb_hdec(amhi(j)**2/amhi(i)**2,amhi(k)**2/amhi(i)**2)
     .              *amp     
               htoh(i) = htoh(i) + hitohjhk(i,j,k)
                    endif 
#else
               hitohjhk(i,j,k)=gf/16.d0/dsqrt(2d0)/pi*amz**4/amhi(i)*
     .            lamb_hdec(amhi(j)**2/amhi(i)**2,amhi(k)**2/amhi(i)**2)
     .              *ghihjhk(i,j,k)**2
               htoh(i) = htoh(i) + hitohjhk(i,j,k)
#endif                                                      
c               print*,'hitohjhk on',hitohjhk(i,j,k),i,j,k
            endif
         end do
      end do




      do j=1,5,1
         hitohjz(i,j) = 0.D0
      end do

      htohz(i) = 0.D0

      deltalow = 3.D0
      deltahigh = 5.D0

      do j=1,5,1
      if(ionsh.eq.0) then
         xm1 = amhi(j)+amz - deltalow
         xm2 = amhi(j)+amz + deltahigh

         if(amhi(i).le.amhi(j).or.amhi(j).eq.0.D0) then
            hitohjz(i,j) = 0.D0
         elseif(amhi(i).le.xm1) then
            if(amhi(i).le.dabs(amz-amhi(j))) then
               hitohjz(i,j) = 0.D0
            else
               hitohjz(i,j)=9.d0*gf**2/16.d0/pi**3*amz**4*amhi(i)*
     .              gzhihj(i,j)**2*
     .              (7.d0/12.d0-10.d0/9.d0*ss+40.d0/27.d0*ss**2)
     .              *hvh((amhi(j)/amhi(i))**2,(amz/amhi(i))**2)
            endif
         elseif(amhi(i).le.xm2) then
            xx(1) = xm1-1.D0
            xx(2) = xm1
            xx(3) = xm2
            xx(4) = xm2+1.D0

            outputfile = 'interpolhihjz_1.dat'
            call MHpmfromMHi(xx(1),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,j,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)
            if(amhiv(i).ge.(amhiv(j)+amz)) then
               caz=lamb_hdec(amhiv(j)**2/xx(1)**2,amz**2/xx(1)**2)
     .         *lamb_hdec(xx(1)**2/amz**2,amhiv(j)**2/amz**2)**2
               yy(1)=gf/8.d0/dsqrt(2d0)/pi*amz**4/xx(1)*caz
            elseif(amhiv(i).le.amhiv(j)) then
               yy(1) = 0
            else
               yy(1)=9.d0*gf**2/16.d0/pi**3*amz**4*xx(1)*
     .              (7.d0/12.d0-10.d0/9.d0*ss+40.d0/27.d0*ss**2)
     .              *hvh((amhiv(j)/xx(1))**2,(amz/xx(1))**2)
            endif

            outputfile = 'interpolhihjz_2.dat'
            call MHpmfromMHi(xx(2),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,j,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv)  
            if(amhiv(i).ge.(amhiv(j)+amz)) then
               caz=lamb_hdec(amhiv(j)**2/xx(2)**2,amz**2/xx(2)**2)
     .         *lamb_hdec(xx(2)**2/amz**2,amhiv(j)**2/amz**2)**2
               yy(2)=gf/8.d0/dsqrt(2d0)/pi*amz**4/xx(2)*caz
            elseif(amhiv(i).le.amhiv(j)) then
               yy(2) = 0
            else
               yy(2)=9.d0*gf**2/16.d0/pi**3*amz**4*xx(2)*
     .              (7.d0/12.d0-10.d0/9.d0*ss+40.d0/27.d0*ss**2)
     .              *hvh((amhiv(j)/xx(2))**2,(amz/xx(2))**2)
            endif

            outputfile = 'interpolhihjz_3.dat'
            call MHpmfromMHi(xx(3),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,j,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(amhiv(i).ge.(amhiv(j)+amz)) then
               caz=lamb_hdec(amhiv(j)**2/xx(3)**2,amz**2/xx(3)**2)
     .         *lamb_hdec(xx(3)**2/amz**2,amhiv(j)**2/amz**2)**2
               yy(3)=gf/8.d0/dsqrt(2d0)/pi*amz**4/xx(3)*caz
            elseif(amhiv(i).le.amhiv(j)) then
               yy(3) = 0
            else
               yy(3)=9.d0*gf**2/16.d0/pi**3*amz**4*xx(3)*
     .              (7.d0/12.d0-10.d0/9.d0*ss+40.d0/27.d0*ss**2)
     .              *hvh((amhiv(j)/xx(3))**2,(amz/xx(3))**2)
            endif

            outputfile = 'interpolhihjz_4.dat'
            call MHpmfromMHi(xx(4),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,j,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(amhiv(i).ge.(amhiv(j)+amz)) then
               caz=lamb_hdec(amhiv(j)**2/xx(4)**2,amz**2/xx(4)**2)
     .         *lamb_hdec(xx(4)**2/amz**2,amhiv(j)**2/amz**2)**2
               yy(4)=gf/8.d0/dsqrt(2d0)/pi*amz**4/xx(4)*caz
            elseif(amhiv(i).le.amhiv(j)) then
               yy(4) = 0
            else
               yy(4)=9.d0*gf**2/16.d0/pi**3*amz**4*xx(4)*
     .              (7.d0/12.d0-10.d0/9.d0*ss+40.d0/27.d0*ss**2)
     .              *hvh((amhiv(j)/xx(4))**2,(amz/xx(4))**2)
            endif
            
            hitohjz(i,j) = fint_hdec(amhi(i),xx,yy)*gzhihj(i,j)**2
            
            end if
            end if
            end if
            end if
         else
            caz=lamb_hdec(amhi(j)**2/amhi(i)**2,amz**2/amhi(i)**2)
     .           *lamb_hdec(amhi(i)**2/amz**2,amhi(j)**2/amz**2)**2
            hitohjz(i,j)=gf/8.d0/dsqrt(2d0)/pi*amz**4/amhi(i)*caz*
     .           gzhihj(i,j)**2
         endif
         
           if(calcmasseserror) then
                if (amhi(i).lt.amz+amhi(j).or.amhi(j).eq.0.D0) then
                 hitohjz(i,j)=0.D0
                else
                 caz=lamb_hdec(amhi(j)**2/amhi(i)**2,amz**2/amhi(i)**2)
     .           *lamb_hdec(amhi(i)**2/amz**2,amhi(j)**2/amz**2)**2
                 hitohjz(i,j)=gf/8.d0/dsqrt(2d0)/pi*amz**4/amhi(i)*caz*
     .           gzhihj(i,j)**2
                 endif
                 calcmasseserror=.FALSE.
                 print*, 'Error in off-shell decay Hi->Hj Z. i,j=',i,j 
                 print*, 'Off-shell decay turned off'
           endif
         
      else
         if (amhi(i).lt.amz+amhi(j).or.amhi(j).eq.0.D0) then
            hitohjz(i,j)=0.D0
         else
            caz=lamb_hdec(amhi(j)**2/amhi(i)**2,amz**2/amhi(i)**2)
     .           *lamb_hdec(amhi(i)**2/amz**2,amhi(j)**2/amz**2)**2
            hitohjz(i,j)=gf/8.d0/dsqrt(2d0)/pi*amz**4/amhi(i)*caz*
     .           gzhihj(i,j)**2
         endif
      endif

      htohz(i) = htohz(i) + hitohjz(i,j)

c      print*,'hitohjz,i,j',hitohjz(i,j),i,j

      end do

c Hi ---> H+ W- + H- W+ on- and off-shell decays
      
      deltalow = 3.D0
      deltahigh = 5.D0
      hihw(i) = 0.D0

      if(ionsh.eq.0) then
         xm1 = amch+amw - deltalow
         xm2 = amch+amw + deltahigh

         if(amhi(i).le.amch) then
            hihw(i) = 0.D0
         elseif(amhi(i).le.xm1) then
            if(amhi(i).le.dabs(amw-amch)) then
               hihw(i) = 0.D0
            else
               hihw(i) = 9.D0*gf**2/16.d0/pi**3*amw**4*amhi(i)*
     .              (ghihpwm(i)**2+gaihpwm(i)**2)*2
     .              *hvh((amch/amhi(i))**2,(amw/amhi(i))**2)
            endif
         elseif(amhi(i).le.xm2) then
            xx(1) = xm1-1.D0
            xx(2) = xm1
            xx(3) = xm2
            xx(4) = xm2+1.D0

            outputfile = 'interpolhihcw_1.dat'
            call MHpmfromMHi(xx(1),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(xx(1).ge.amcv+amw) then
               chw=lamb_hdec(amcv**2/xx(1)**2,amw**2/xx(1)**2)
     .              *lamb_hdec(xx(1)**2/amw**2,amcv**2/amw**2)**2
               yy(1)=2.D0*gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(1)*chw
            elseif(xx(1).le.amcv) then
               yy(1) = 0
            else
               yy(1)=9.D0*gf**2/16.d0/pi**3*amw**4*xx(1)*2
     .              *hvh((amcv/xx(1))**2,(amw/xx(1))**2)
            endif

            outputfile = 'interpolhihcw_2.dat'
            call MHpmfromMHi(xx(2),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(xx(2).ge.amcv+amw) then
               chw=lamb_hdec(amcv**2/xx(2)**2,amw**2/xx(2)**2)
     .              *lamb_hdec(xx(2)**2/amw**2,amcv**2/amw**2)**2
               yy(2)=2.D0*gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(2)*chw
            elseif(xx(2).le.amcv) then
               yy(2) = 0
            else
               yy(2)=9.D0*gf**2/16.d0/pi**3*amw**4*xx(2)*2
     .              *hvh((amcv/xx(2))**2,(amw/xx(2))**2)
            endif

            outputfile = 'interpolhihcw_3.dat'
            call MHpmfromMHi(xx(3),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(xx(3).ge.amcv+amw) then
               chw=lamb_hdec(amcv**2/xx(3)**2,amw**2/xx(3)**2)
     .              *lamb_hdec(xx(3)**2/amw**2,amcv**2/amw**2)**2
               yy(3)=2.D0*gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(3)*chw
            elseif(xx(3).le.amcv) then
               yy(3) = 0
            else
               yy(3)=9.D0*gf**2/16.d0/pi**3*amw**4*xx(3)*2
     .              *hvh((amcv/xx(3))**2,(amw/xx(3))**2)
            endif

            outputfile = 'interpolhihcw_4.dat'
            call MHpmfromMHi(xx(4),i,1d-9,outputfile)
            if(.not. calcmasseserror) then
            call DecInterpolation_CNMSSM(outputfile,i,1,1,ghibv,gaibv,
     .           ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiv,amcv) 
            if(xx(4).ge.amcv+amw) then
               chw=lamb_hdec(amcv**2/xx(4)**2,amw**2/xx(4)**2)
     .              *lamb_hdec(xx(4)**2/amw**2,amcv**2/amw**2)**2
               yy(4)=2.D0*gf/8.d0/dsqrt(2d0)/pi*amw**4/xx(4)*chw
            elseif(xx(4).le.amcv) then
               yy(4) = 0
            else
               yy(4)=9.D0*gf**2/16.d0/pi**3*amw**4*xx(4)*2
     .              *hvh((amcv/xx(4))**2,(amw/xx(4))**2)
            endif

            hihw(i)=fint_hdec(amhi(i),xx,yy)*
     .           (ghihpwm(i)**2+gaihpwm(i)**2)
         else
            chw=lamb_hdec(amch**2/amhi(i)**2,amw**2/amhi(i)**2)
     .           *lamb_hdec(amhi(i)**2/amw**2,amch**2/amw**2)**2
            hihw(i)=2*gf/8.d0/dsqrt(2d0)/pi*amw**4/amhi(i)*chw*
     .           (ghihpwm(i)**2+gaihpwm(i)**2)
         endif
         
         end if
         end if
         end if
         end if
         
         if(calcmasseserror) then
           calcmasseserror=.FALSE.
           print*, 'Error in off-shell decay Hi -> H+ W- + H- W+. i=',i
           print*, 'Off-shell decay turned off'
           if (amhi(i).le.amw+amch) then
              hihw(i)=0.D0
           else
              chw=lamb_hdec(amch**2/amhi(i)**2,amw**2/amhi(i)**2)
     .             *lamb_hdec(amhi(i)**2/amw**2,amch**2/amw**2)**2
              hihw(i)=2*gf/8.d0/dsqrt(2d0)/pi*amw**4/amhi(i)*chw*
     .             (ghihpwm(i)**2+gaihpwm(i)**2)
           endif
         end if
      else
         if (amhi(i).le.amw+amch) then
            hihw(i)=0.D0
         else
            chw=lamb_hdec(amch**2/amhi(i)**2,amw**2/amhi(i)**2)
     .           *lamb_hdec(amhi(i)**2/amw**2,amch**2/amw**2)**2
            hihw(i)=2*gf/8.d0/dsqrt(2d0)/pi*amw**4/amhi(i)*chw*
     .           (ghihpwm(i)**2+gaihpwm(i)**2)
         endif
      endif

c      print*,'Hi->H+W-+H-W+',hihw(i),i

c -------------------------------------------------------------------- c

      whitotc(i) = whitotc(i) + htoh(i) + htohz(i) + hihw(i)

c      print*,'whitot 2',whitotc(i)
c      print*,''

      end do

c -------------------------------------------------------------------- c
c -------------------------------------------------------------------- c
c -------------------------------------------------------------------- c
c --- off-shell decays --- c

      do i=1,5,1
         do j=1,5,1
            do k=1,5,1
               hitohjhko(i,j,k) = 0.D0
            end do
         end do
      end do

      epsi = 0.D0
      do i=1,5,1 
         do j=1,5,1
            do k=1,5,1
c               if(i.eq.5.and.j.eq.1.and.k.eq.4) then
               if(amhi(i).lt.(amhi(j)+amhi(k))) then
                  if(ionsh.eq.0) then
            if(amhi(i).gt.amhi(j)+epsi.and.amhi(i).gt.amhi(k)+epsi) then
                        if(ghihjhk(i,j,k).ne.0.D0) then
                           iicase=0
            call htohhoffshell_cnmssm(iicase,amhi(i),amhi(j),amhi(k),
     .                    whitotc(j),whitotc(k),htohhoff,errhtohhoff)
               hitohjhko(i,j,k)=gf/16.D0/dsqrt(2D0)/pi*amz**4/amhi(i)*
     .          ghihjhk(i,j,k)**2*htohhoff
             errhitohjhko(i,j,k)=gf/16.D0/dsqrt(2D0)/pi*amz**4/amhi(i)*
     .          ghihjhk(i,j,k)**2*errhtohhoff
            else
               hitohjhko(i,j,k)=0.D0
            endif
         else
            hitohjhko(i,j,k)=0.D0
            htohhoff = 0.D0
         endif
      else
         hitohjhko(i,j,k) = 0.D0
      endif
      endif
c      endif

c      if(hitohjhko(i,j,k).ne.0.D0) then
c       print*,'off hitohjhk',hitohjhko(i,j,k),errhitohjhko(i,j,k),i,j,k
c      endif

c      if(hitohjhko(i,j,k).ne.hitohjhko(i,j,k)) then
c         print*,'There is a problem in the off-shell decays.',i,j,k
c      endif

      end do
      end do
      
      hitohhoff(i)=0d0
      
      do j=1,5,1
         do k=1,5,1
            if(hitohjhko(i,j,k).ne.hitohjhko(i,j,k)) then
               hitohjhko(i,j,k) = hitohjhko(i,k,j)
c               print*,'problem value',hitohjhko(i,j,k),i,j,k
            endif
            if(hitohjhko(i,j,k).ne.hitohjhko(i,j,k)) then
             print*,'There is a problem in the off-shell decays.',i,j,k
             hitohjhko(i,j,k)=0d0
            endif

            hitohhoff(i) = hitohhoff(i) + hitohjhko(i,j,k)
         enddo
      enddo

c      print*,'h->hh off',hitohhoff(i),i
      end do

c ================= total width and branching ratios ================= c

      do i=1,5,1
c         print*,'wtot - 1',whitotc(i),i
         whitotc(i) = whitotc(i) + hitohhoff(i)
c         print*,'wtot - 3',whitotc(i),i,hitohhoff(i)
      end do

c      print*,'wtot - 3',whitotc(i),i

c -------------------------- branching ratios ------------------------ c

c      do i=1,5,1
c         do j=1,5,1
c            do k=1,5,1
c               hitohjhko(i,j,k)=0.D0
c            end do
c         end do
c      end do

      do i=1,5,1
         brhigggc(i) = higggc(i)/whitotc(i)
         brhigmmc(i) = higmmc(i)/whitotc(i)
         brhigllc(i) = higllc(i)/whitotc(i)
         brhigssc(i) = higssc(i)/whitotc(i)
         brhigccc(i) = higccc(i)/whitotc(i)
         brhigbbc(i) = higbbc(i)/whitotc(i)
         brhigttc(i) = higttc(i)/whitotc(i)
         brhiggac(i) = higgac(i)/whitotc(i)
         brhigzgac(i) = higzgac(i)/whitotc(i)
         brhigwwc(i) = higwwc(i)/whitotc(i)
         brhigzzc(i) = higzzc(i)/whitotc(i)
         brhigtohpwmc(i) = hihw(i)/whitotc(i)

         do j=1,5,1
            do k=1,5,1
               if(hitohjhk(i,j,k).ne.0.D0) then
                  brhitohjhkc(i,j,k) = hitohjhk(i,j,k)/whitotc(i)
               endif
               if(hitohjhko(i,j,k).ne.0.D0) then
                  brhitohjhkc(i,j,k) = hitohjhko(i,j,k)/whitotc(i)
               endif
               if(j.ne.k) then
                  brhitohjhkc(i,j,k) = 2.D0*brhitohjhkc(i,j,k)
               endif
            end do
         end do

         do j=1,5,1
            brhitohjzc(i,j) = hitohjz(i,j)/whitotc(i)
         end do

         do j=1,2,1
            do k=1,2,1
               brwhigchc(i,j,k) = whigchc(i,j,k)/whitotc(i)
            end do
         end do

         do j=1,5,1
            do k=1,5,1
               brwhignec(i,j,k) = whignec(i,j,k)/whitotc(i)
            end do
         end do

      brwhigchtc(i)=whigchtc(i)/whitotc(i)
      brwhignetc(i)=whignetc(i)/whitotc(i)
      brwhigsltc(i)=whigsltc(i)/whitotc(i)
      brwhigsqc(i) =whigsqc(i)/whitotc(i)
      brwhigsqtc(i)=whigsqtc(i)/whitotc(i)

      brwhigslnlc(i)   =whigslnlc(i)/whitotc(i)
      brwhigslnltauc(i)=whigslnltauc(i)/whitotc(i)
      brwhigslelc(i)   =whigslelc(i)/whitotc(i)
      brwhigslerc(i)   =whigslerc(i)/whitotc(i)
      brwhigsqulc(i)   =whigsqulc(i)/whitotc(i)
      brwhigsqurc(i)   =whigsqurc(i)/whitotc(i)
      brwhigsqdlc(i)   =whigsqdlc(i)/whitotc(i)
      brwhigsqdrc(i)   =whigsqdrc(i)/whitotc(i)

      do j=1,2,1
         do k=1,2,1
            brwhigstc(i,j,k)   = whigstc(i,j,k)/whitotc(i)
            brwhigsbc(i,j,k)   = whigsbc(i,j,k)/whitotc(i)
            brwhigstauc(i,j,k) = whigstauc(i,j,k)/whitotc(i)
         end do
      end do

      end do
      
      RETURN
      END

c ==================================================================== c
c ==================================================================== c
 
      double precision function bij_hdec(x,y)
      implicit double precision (a-h,o-z)
      double precision lamb_hdec
      bij_hdec = (1-x-y)/lamb_hdec(x,y)*(
     .          4*sp_hdec(xi_hdec(x,y)*xi_hdec(y,x))
     .        - 2*sp_hdec(-xi_hdec(x,y)) - 2*sp_hdec(-xi_hdec(y,x))
     .        + 2*dlog(xi_hdec(x,y)*xi_hdec(y,x))
     .           *dlog(1-xi_hdec(x,y)*xi_hdec(y,x))
     .        - dlog(xi_hdec(x,y))*dlog(1+xi_hdec(x,y))
     .        - dlog(xi_hdec(y,x))*dlog(1+xi_hdec(y,x))
     .          )
     .        -4*(dlog(1-xi_hdec(x,y)*xi_hdec(y,x))
     .        +xi_hdec(x,y)*xi_hdec(y,x)/(1-xi_hdec(x,y)*xi_hdec(y,x))
     .          *dlog(xi_hdec(x,y)*xi_hdec(y,x)))
     .        +(lamb_hdec(x,y)+x-y)/lamb_hdec(x,y)*(dlog(1+xi_hdec(x,y))
     .              - xi_hdec(x,y)/(1+xi_hdec(x,y))*dlog(xi_hdec(x,y)))
     .        +(lamb_hdec(x,y)-x+y)/lamb_hdec(x,y)*(dlog(1+xi_hdec(y,x))
     .              - xi_hdec(y,x)/(1+xi_hdec(y,x))*dlog(xi_hdec(y,x)))
      return
      end

c -------------------------------------------------------------------- c

      double precision function beta_hdec(x)
      implicit double precision (a-h,o-z)
      beta_hdec=dsqrt(1.d0-4.d0*x)
      return
      end

c -------------------------------------------------------------------- c

      double precision function lamb_hdec(x,y)
      implicit double precision (a-h,o-z)
      lamb_hdec=dsqrt((1.d0-x-y)**2-4.d0*x*y)
      return
      end

c -------------------------------------------------------------------- c

      double precision function xi_hdec(x,y)
      implicit double precision (a-h,o-z)
      double precision lamb_hdec
      xi_hdec = 2*x/(1-x-y+lamb_hdec(x,y))
      return
      end

c -------------------------------------------------------------------- c

      double precision function ghself(i,j,k,sb,cb)

      implicit double precision (a-h,m,o-z)
      double precision slhahmix(5,5)

      COMMON/EXTPAR_NMSSM/xlambdapar,xkappa,Alam,Akap,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      COMMON/EXTPAR_CNMSSM_IM/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      COMMON/PARAM_HDEC/gf,alph,amtau,ammuon,amz,amw
      COMMON/SLHA_hmix_CNMSSM/slhahmix

      c2b=cb**2-sb**2
      c3b=cb*(4.d0*cb**2-3.d0)
      s2b=2.d0*cb*sb
      s3b=sb*(3.d0-4.d0*sb**2)
      v=1.d0/dsqrt(dsqrt(2.d0)*gf)

      vs=dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      xrlambda=(dcos(xphiu)*(Alam*xlamvs-Alamim*xlamvsim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam))/vs
      xilambda=(dsin(xphiu)*(Alam*xlamvs-Alamim*xlamvsim)+
     .     dcos(xphiu)*(xlamvs*Alamim+xlamvsim*Alam))/vs
      xrkappa=2.d0*((Akap*xkappa-Akapim*xkappaim)*
     .     ((xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (xlamvs**3-3.d0*xlamvs*xlamvsim**2)-
     .     (xlambdaparim**3-3.d0*xlambdapar**2*xlambdaparim)*
     .     (3.d0*xlamvs**2*xlamvsim-xlamvsim**3))-
     .     (Akapim*xkappa+Akap*xkappaim)*
     .     ((xlambdaparim**3-3.d0*xlambdapar**2*xlambdaparim)*
     .     (xlamvs**3-3.d0*xlamvs*xlamvsim**2)+
     .     (xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (3.d0*xlamvs**2*xlamvsim-xlamvsim**3)))/
     .     ((vs*(xlambdapar**2+xlambdaparim**2))**3)
      xikappa=2.d0*((Akap*xkappa-Akapim*xkappaim)*
     .     ((xlambdaparim**3-3.d0*xlambdapar**2*xlambdaparim)*
     .     (xlamvs**3-3.d0*xlamvs*xlamvsim**2)+
     .     (xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (3.d0*xlamvs**2*xlamvsim-xlamvsim**3))+
     .     (Akapim*xkappa+Akap*xkappaim)*
     .     ((xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (xlamvs**3-3.d0*xlamvs*xlamvsim**2)-
     .     (xlambdaparim**3-3.d0*xlambdapar**2*xlambdaparim)*
     .     (3.d0*xlamvs**2*xlamvsim-xlamvsim**3)))/
     .     ((vs*(xlambdapar**2+xlambdaparim**2))**3)
      xr=2.d0*((xkappa*dcos(xphiu)+xkappaim*dsin(xphiu))*
     .     (2.d0*(3.d0*xlambdapar**2*xlambdaparim-xlambdaparim**3)*
     .     xlamvs*xlamvsim+
     .     (xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (xlamvs**2-xlamvsim**2))-
     .     (xkappa*dsin(xphiu)-xkappaim*dcos(xphiu))*
     .     ((3.d0*xlambdapar**2*xlambdaparim-xlambdaparim**3)*
     .     (xlamvs**2-xlamvsim**2)-
     .     2.d0*(xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     xlamvs*xlamvsim))/
     .     ((vs*(xlambdapar**2+xlambdaparim**2))**2)
      xi=2.d0*((xkappa*dcos(xphiu)+xkappaim*dsin(xphiu))*
     .     ((3.d0*xlambdapar**2*xlambdaparim-xlambdaparim**3)*
     .     (xlamvs**2-xlamvsim**2)-
     .     2.d0*(xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     xlamvs*xlamvsim)+
     .     (xkappa*dsin(xphiu)-xkappaim*dcos(xphiu))*
     .     (2.d0*(3.d0*xlambdapar**2*xlambdaparim-xlambdaparim**3)*
     .     xlamvs*xlamvsim+
     .     (xlambdapar**3-3.d0*xlambdapar*xlambdaparim**2)*
     .     (xlamvs**2-xlamvsim**2)))/
     .     ((vs*(xlambdapar**2+xlambdaparim**2))**2)

      ghself = 2.d0*v*(xkappa**2+xkappaim**2)*vs/amz**2*
     .         (3.d0*slhahmix(i,3)*slhahmix(j,3)*slhahmix(k,3)+
     .     slhahmix(i,3)*slhahmix(j,5)*slhahmix(k,5)+slhahmix(i,5)*
     .     slhahmix(j,3)*slhahmix(k,5)+slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,3))
c
     .     +(slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,1)+slhahmix(i,1)*
     .     slhahmix(j,3)*slhahmix(k,1)+slhahmix(i,1)*slhahmix(j,1)*
     .     slhahmix(k,3)+
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,2)+slhahmix(i,2)*
     .     slhahmix(j,3)*slhahmix(k,2)+slhahmix(i,2)*slhahmix(j,2)*
     .     slhahmix(k,3)+
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,4)+slhahmix(i,4)*
     .     slhahmix(j,3)*slhahmix(k,4)+slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,3))*
     .     (xlambdapar**2+xlambdaparim**2)*v*vs/amz**2
c
     .     +(xlambdapar**2+xlambdaparim**2)*v**2/amz**2*
     .     (slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,3)*sb+slhahmix(i,3)*
     .     slhahmix(j,2)*slhahmix(k,3)*sb+slhahmix(i,3)*slhahmix(j,3)*
     .     slhahmix(k,2)*sb+
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,3)*cb+slhahmix(i,3)*
     .     slhahmix(j,1)*slhahmix(k,3)*cb+slhahmix(i,3)*slhahmix(j,3)*
     .     slhahmix(k,1)*cb+
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,1)*sb+slhahmix(i,1)*
     .     slhahmix(j,2)*slhahmix(k,1)*sb+slhahmix(i,1)*slhahmix(j,1)*
     .     slhahmix(k,2)*sb+
     .     slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,2)*cb+slhahmix(i,2)*
     .     slhahmix(j,1)*slhahmix(k,2)*cb+slhahmix(i,2)*slhahmix(j,2)*
     .     slhahmix(k,1)*cb+
     .     (slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,4)+slhahmix(i,4)*
     .     slhahmix(j,1)*slhahmix(k,4)+slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,1))*(3.d0*cb+c3b)/4.d0+
     .     (slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,4)+slhahmix(i,4)*
     .     slhahmix(j,2)*slhahmix(k,4)+slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,2))*(3.d0*sb-s3b)/4.d0+
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,5)*cb+slhahmix(i,5)*
     .     slhahmix(j,1)*slhahmix(k,5)*cb+slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,1)*cb+
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,5)*sb+slhahmix(i,5)*
     .     slhahmix(j,2)*slhahmix(k,5)*sb+slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,2)*sb)
c
     .     +(-1.D0/amz**2)*xr*v*vs*
     .     (slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,3)+
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,2)+
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,3)+
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,1)+
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,1)+
     .     slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,2)+
     .     slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,5)*sb+
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,4)*sb+
     .     slhahmix(i,4)*slhahmix(j,2)*slhahmix(k,5)*sb+
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,2)*sb+
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,2)*sb+
     .     slhahmix(i,5)*slhahmix(j,2)*slhahmix(k,4)*sb+
     .     slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,5)*cb+
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,4)*cb+
     .     slhahmix(i,4)*slhahmix(j,1)*slhahmix(k,5)*cb+
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,1)*cb+
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,1)*cb+
     .     slhahmix(i,5)*slhahmix(j,1)*slhahmix(k,4)*cb-
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,4)*s2b-
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,4)*s2b-
     .     slhahmix(i,4)*slhahmix(j,4)*slhahmix(k,3)*s2b)
c
     .     +(-1.D0/amz**2)*xr*v**2*
     .     (slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,3)*sb+slhahmix(i,3)*
     .     slhahmix(j,1)*slhahmix(k,3)*sb+slhahmix(i,3)*slhahmix(j,3)*
     .     slhahmix(k,1)*sb+
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,3)*cb+slhahmix(i,3)*
     .     slhahmix(j,2)*slhahmix(k,3)*cb+slhahmix(i,3)*slhahmix(j,3)*
     .     slhahmix(k,2)*cb+
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,5)+
     .     slhahmix(i,3)*slhahmix(j,5)*slhahmix(k,4)+
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,5)+
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,3)+
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,3)+
     .     slhahmix(i,5)*slhahmix(j,3)*slhahmix(k,4)-
     .	   slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,5)*sb-slhahmix(i,5)*
     .     slhahmix(j,1)*slhahmix(k,5)*sb-slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,1)*sb-
     .	   slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,5)*cb-slhahmix(i,5)*
     .     slhahmix(j,2)*slhahmix(k,5)*cb-slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,2)*cb)
c
     .     +2.d0/amz**2*xrkappa*v*(slhahmix(i,3)*
     .     slhahmix(j,3)*slhahmix(k,3)-slhahmix(i,3)*slhahmix(j,5)*
     .     slhahmix(k,5)-slhahmix(i,5)*slhahmix(j,3)*slhahmix(k,5)
     .     -slhahmix(i,5)*slhahmix(j,5)*slhahmix(k,3))
c
     .     +(-1.D0)/amz**2*xrlambda*v*
     .     (slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,3)+
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,2)+
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,3)+
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,1)+
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,1)+
     .     slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,2)-
     .     slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,5)*cb-
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,4)*cb-
     .     slhahmix(i,4)*slhahmix(j,1)*slhahmix(k,5)*cb-
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,1)*cb-
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,1)*cb-
     .     slhahmix(i,5)*slhahmix(j,1)*slhahmix(k,4)*cb-
     .     slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,5)*sb-
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,4)*sb-
     .     slhahmix(i,4)*slhahmix(j,2)*slhahmix(k,5)*sb-
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,2)*sb-
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,2)*sb-
     .     slhahmix(i,5)*slhahmix(j,2)*slhahmix(k,4)*sb-
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,4)*s2b-slhahmix(i,4)*
     .     slhahmix(j,3)*slhahmix(k,4)*s2b-slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,3)*s2b)
c
     .     -slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,2)*cb-slhahmix(i,2)*
     .     slhahmix(j,1)*slhahmix(k,2)*cb-slhahmix(i,2)*slhahmix(j,2)*
     .     slhahmix(k,1)*cb-
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,1)*sb-slhahmix(i,1)*
     .     slhahmix(j,2)*slhahmix(k,1)*sb-slhahmix(i,1)*slhahmix(j,1)*
     .     slhahmix(k,2)*sb+
     .     3.d0*slhahmix(i,1)*slhahmix(j,1)*slhahmix(k,1)*cb+
     .     3.d0*slhahmix(i,2)*slhahmix(j,2)*slhahmix(k,2)*sb-
     .     (slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,4)+slhahmix(i,4)*
     .     slhahmix(j,1)*slhahmix(k,4)+slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,1))*(cb+c3b)/2.d0-
     .     (slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,4)+slhahmix(i,4)*
     .     slhahmix(j,2)*slhahmix(k,4)+slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,2))*(sb-s3b)/2.d0
c
     .     +1.d0/amz**2*xi*v**2*
     .     (slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,3)+slhahmix(i,3)*
     .     slhahmix(j,4)*slhahmix(k,3)+slhahmix(i,3)*slhahmix(j,3)*
     .     slhahmix(k,4)-
     .     slhahmix(i,4)*slhahmix(j,5)*slhahmix(k,5)-slhahmix(i,5)*
     .     slhahmix(j,4)*slhahmix(k,5)-slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,4)-
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,5)*sb-
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,3)*sb-
     .     slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,5)*sb-
     .     slhahmix(i,3)*slhahmix(j,5)*slhahmix(k,1)*sb-
     .     slhahmix(i,5)*slhahmix(j,3)*slhahmix(k,1)*sb-
     .     slhahmix(i,5)*slhahmix(j,1)*slhahmix(k,3)*sb-
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,5)*cb-
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,3)*cb-
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,5)*cb-
     .     slhahmix(i,3)*slhahmix(j,5)*slhahmix(k,2)*cb-
     .     slhahmix(i,5)*slhahmix(j,3)*slhahmix(k,2)*cb-
     .     slhahmix(i,5)*slhahmix(j,2)*slhahmix(k,3)*cb)
c
     .     +(-1.d0)/amz**2*xi*v*vs*
     .     (slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,5)+
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,2)+
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,5)+
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,1)+
     .     slhahmix(i,5)*slhahmix(j,2)*slhahmix(k,1)+
     .     slhahmix(i,5)*slhahmix(j,1)*slhahmix(k,2)-
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,4)*cb-
     .     slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,3)*cb-
     .     slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,4)*cb-
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,1)*cb-
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,1)*cb-
     .     slhahmix(i,4)*slhahmix(j,1)*slhahmix(k,3)*cb-
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,4)*sb-
     .     slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,3)*sb-
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,4)*sb-
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,2)*sb-
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,2)*sb-
     .     slhahmix(i,4)*slhahmix(j,2)*slhahmix(k,3)*sb-
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,4)*s2b-slhahmix(i,4)*
     .     slhahmix(j,5)*slhahmix(k,4)*s2b-slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,5)*s2b)
c
     .     +1.d0/amz**2*xilambda*v*
     .     (slhahmix(i,1)*slhahmix(j,2)*slhahmix(k,5)+
     .     slhahmix(i,1)*slhahmix(j,5)*slhahmix(k,2)+
     .     slhahmix(i,2)*slhahmix(j,1)*slhahmix(k,5)+
     .     slhahmix(i,2)*slhahmix(j,5)*slhahmix(k,1)+
     .     slhahmix(i,5)*slhahmix(j,2)*slhahmix(k,1)+
     .     slhahmix(i,5)*slhahmix(j,1)*slhahmix(k,2)+
     .     slhahmix(i,1)*slhahmix(j,3)*slhahmix(k,4)*cb+
     .     slhahmix(i,1)*slhahmix(j,4)*slhahmix(k,3)*cb+
     .     slhahmix(i,3)*slhahmix(j,1)*slhahmix(k,4)*cb+
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,1)*cb+
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,1)*cb+
     .     slhahmix(i,4)*slhahmix(j,1)*slhahmix(k,3)*cb+
     .     slhahmix(i,2)*slhahmix(j,3)*slhahmix(k,4)*sb+
     .     slhahmix(i,2)*slhahmix(j,4)*slhahmix(k,3)*sb+
     .     slhahmix(i,3)*slhahmix(j,2)*slhahmix(k,4)*sb+
     .     slhahmix(i,3)*slhahmix(j,4)*slhahmix(k,2)*sb+
     .     slhahmix(i,4)*slhahmix(j,3)*slhahmix(k,2)*sb+
     .     slhahmix(i,4)*slhahmix(j,2)*slhahmix(k,3)*sb-
     .     slhahmix(i,5)*slhahmix(j,4)*slhahmix(k,4)*s2b-slhahmix(i,4)*
     .     slhahmix(j,5)*slhahmix(k,4)*s2b-slhahmix(i,4)*slhahmix(j,4)*
     .     slhahmix(k,5)*s2b)
c
     .     +2.d0/amz**2*xikappa*v*(slhahmix(i,5)*slhahmix(j,5)*
     .     slhahmix(k,5)-slhahmix(i,3)*slhahmix(j,3)*slhahmix(k,5)-
     .     slhahmix(i,3)*slhahmix(j,5)*slhahmix(k,3)-slhahmix(i,5)*
     .     slhahmix(j,3)*slhahmix(k,3))

      return 
      end

c ==================================================================== c
c ================ subroutine for the SUSY couplings ================= c
c ==================================================================== c

      subroutine susycp_cnmssm(tgbet)

      implicit double precision (a-h,m,o-z)
      double precision slhahmix(5,5),ghit(5),gait(5),ghib(5),gaib(5),
     .     ghivv(5),ghihpwm(5),gaihpwm(5),gzhihj(5,5),ghihjhk(5,5,5),
     .     ghipm(5)
      complex*16 myi
      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
      COMMON/HMASSR_NMSSM/amlr,amhr
      COMMON/COUP_CNMSSM/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      COMMON/SLHA_hmass_CNMSSM/slhamh1,slhamh2,slhamh3,slhamh4,slhamh5,
     .     slhamc
      COMMON/SLHA_hmix_CNMSSM/slhahmix
      COMMON/EXTPAR_NMSSM/xlambdapar,xkappa,Alam,Akap,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      COMMON/EXTPAR_CNMSSM_IM/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      COMMON/PARAM_HDEC/gf,alph,amtau,ammuon,amz,amw
      COMMON/SHORTCOUPL2_CNMSSM/ghit,ghib,gait,gaib,ghivv,ghihpwm,
     .     gaihpwm,gzhihj,ghihjhk,ghipm

c --- some parameter settings --- c
      
      myi=dcmplx(0.d0,1.d0)
      pi=4*datan(1d0)
c-- beware! here <H_SM> = v/sqrt(2) !!
      v=1.d0/dsqrt(dsqrt(2.d0)*gf)
      vs=dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      bet=datan(tgbet)
      sb = dsin(bet)
      cb = dcos(bet)
      amar = amh5

c --- setting of the Higgs masses --- c

      amlr = slhamh1
      amhr = slhamh3
      amh1  = slhamh1
      amh2  = slhamh2
      amh3  = slhamh3
      amch = slhamc

c --- setting of the Higgs couplings --- c

      b = bet
c -- hi-u-ubar -- c   
      gh1t = slhahmix(1,2)/dsin(b)
      gh2t = slhahmix(2,2)/dsin(b)
      gh3t = slhahmix(3,2)/dsin(b)
      gh4t = slhahmix(4,2)/dsin(b)
      gh5t = slhahmix(5,2)/dsin(b)
      ga1t = slhahmix(1,4)/tgbet
      ga2t = slhahmix(2,4)/tgbet
      ga3t = slhahmix(3,4)/tgbet
      ga4t = slhahmix(4,4)/tgbet
      ga5t = slhahmix(5,4)/tgbet

      ghit(1) = gh1t
      ghit(2) = gh2t
      ghit(3) = gh3t
      ghit(4) = gh4t
      ghit(5) = gh5t

      gait(1) = ga1t
      gait(2) = ga2t
      gait(3) = ga3t
      gait(4) = ga4t
      gait(5) = ga5t

c-- hi-d-dbar
      gh1b = slhahmix(1,1)/dcos(b)
      gh2b = slhahmix(2,1)/dcos(b)
      gh3b = slhahmix(3,1)/dcos(b)
      gh4b = slhahmix(4,1)/dcos(b)
      gh5b = slhahmix(5,1)/dcos(b)
      ga1b = slhahmix(1,4)*tgbet
      ga2b = slhahmix(2,4)*tgbet
      ga3b = slhahmix(3,4)*tgbet
      ga4b = slhahmix(4,4)*tgbet
      ga5b = slhahmix(5,4)*tgbet

      ghib(1) = gh1b
      ghib(2) = gh2b
      ghib(3) = gh3b
      ghib(4) = gh4b
      ghib(5) = gh5b

      gaib(1) = ga1b
      gaib(2) = ga2b
      gaib(3) = ga3b
      gaib(4) = ga4b
      gaib(5) = ga5b

c-- hi-V-V
      gh1vv = slhahmix(1,1)*dcos(b)+slhahmix(1,2)*dsin(b)
      gh2vv = slhahmix(2,1)*dcos(b)+slhahmix(2,2)*dsin(b)
      gh3vv = slhahmix(3,1)*dcos(b)+slhahmix(3,2)*dsin(b)
      gh4vv = slhahmix(4,1)*dcos(b)+slhahmix(4,2)*dsin(b)
      gh5vv = slhahmix(5,1)*dcos(b)+slhahmix(5,2)*dsin(b)

      ghivv(1) = gh1vv
      ghivv(2) = gh2vv
      ghivv(3) = gh3vv
      ghivv(4) = gh4vv
      ghivv(5) = gh5vv

c-- hi-h+-W-
c-- coup = ghihpwm + I*gaihpwm

      gh1hpwm = slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b)
      gh2hpwm = slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b)
      gh3hpwm = slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b)
      gh4hpwm = slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b)
      gh5hpwm = slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b)
      ga1hpwm = slhahmix(1,4)
      ga2hpwm = slhahmix(2,4)
      ga3hpwm = slhahmix(3,4)
      ga4hpwm = slhahmix(4,4)
      ga5hpwm = slhahmix(5,4)

      ghihpwm(1) = gh1hpwm
      ghihpwm(2) = gh2hpwm
      ghihpwm(3) = gh3hpwm
      ghihpwm(4) = gh4hpwm
      ghihpwm(5) = gh5hpwm

      gaihpwm(1) = ga1hpwm
      gaihpwm(2) = ga2hpwm
      gaihpwm(3) = ga3hpwm
      gaihpwm(4) = ga4hpwm
      gaihpwm(5) = ga5hpwm

c-- Z-hi-hj

      gzh1h1 = (slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b))*
     .     slhahmix(1,4)+dcos(b)*slhahmix(1,4)*slhahmix(1,2)-
     .     dsin(b)*slhahmix(1,4)*slhahmix(1,1)
      gzh1h2 = (slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b))*
     .     slhahmix(2,4)+dcos(b)*slhahmix(1,4)*slhahmix(2,2)-
     .     dsin(b)*slhahmix(1,4)*slhahmix(2,1)
      gzh1h3 = (slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b))*
     .     slhahmix(3,4)+dcos(b)*slhahmix(1,4)*slhahmix(3,2)-
     .     dsin(b)*slhahmix(1,4)*slhahmix(3,1)
      gzh1h4 = (slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b))*
     .     slhahmix(4,4)+dcos(b)*slhahmix(1,4)*slhahmix(4,2)-
     .     dsin(b)*slhahmix(1,4)*slhahmix(4,1)
      gzh1h5 = (slhahmix(1,1)*dsin(b)-slhahmix(1,2)*dcos(b))*
     .     slhahmix(5,4)+dcos(b)*slhahmix(1,4)*slhahmix(5,2)-
     .     dsin(b)*slhahmix(1,4)*slhahmix(5,1)
      gzh2h1 = (slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b))*
     .     slhahmix(1,4)+dcos(b)*slhahmix(2,4)*slhahmix(1,2)-
     .     dsin(b)*slhahmix(2,4)*slhahmix(1,1)
      gzh2h2 = (slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b))*
     .     slhahmix(2,4)+dcos(b)*slhahmix(2,4)*slhahmix(2,2)-
     .     dsin(b)*slhahmix(2,4)*slhahmix(2,1)
      gzh2h3 = (slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b))*
     .     slhahmix(3,4)+dcos(b)*slhahmix(2,4)*slhahmix(3,2)-
     .     dsin(b)*slhahmix(2,4)*slhahmix(3,1)
      gzh2h4 = (slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b))*
     .     slhahmix(4,4)+dcos(b)*slhahmix(2,4)*slhahmix(4,2)-
     .     dsin(b)*slhahmix(2,4)*slhahmix(4,1)
      gzh2h5 = (slhahmix(2,1)*dsin(b)-slhahmix(2,2)*dcos(b))*
     .     slhahmix(5,4)+dcos(b)*slhahmix(2,4)*slhahmix(5,2)-
     .     dsin(b)*slhahmix(2,4)*slhahmix(5,1)
      gzh3h1 = (slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b))*
     .     slhahmix(1,4)+dcos(b)*slhahmix(3,4)*slhahmix(1,2)-
     .     dsin(b)*slhahmix(3,4)*slhahmix(1,1)
      gzh3h2 = (slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b))*
     .     slhahmix(2,4)+dcos(b)*slhahmix(3,4)*slhahmix(2,2)-
     .     dsin(b)*slhahmix(3,4)*slhahmix(2,1)
      gzh3h3 = (slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b))*
     .     slhahmix(3,4)+dcos(b)*slhahmix(3,4)*slhahmix(3,2)-
     .     dsin(b)*slhahmix(3,4)*slhahmix(3,1)
      gzh3h4 = (slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b))*
     .     slhahmix(4,4)+dcos(b)*slhahmix(3,4)*slhahmix(4,2)-
     .     dsin(b)*slhahmix(3,4)*slhahmix(4,1)
      gzh3h5 = (slhahmix(3,1)*dsin(b)-slhahmix(3,2)*dcos(b))*
     .     slhahmix(5,4)+dcos(b)*slhahmix(3,4)*slhahmix(5,2)-
     .     dsin(b)*slhahmix(3,4)*slhahmix(5,1)
      gzh4h1 = (slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b))*
     .     slhahmix(1,4)+dcos(b)*slhahmix(4,4)*slhahmix(1,2)-
     .     dsin(b)*slhahmix(4,4)*slhahmix(1,1)
      gzh4h2 = (slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b))*
     .     slhahmix(2,4)+dcos(b)*slhahmix(4,4)*slhahmix(2,2)-
     .     dsin(b)*slhahmix(4,4)*slhahmix(2,1)
      gzh4h3 = (slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b))*
     .     slhahmix(3,4)+dcos(b)*slhahmix(4,4)*slhahmix(3,2)-
     .     dsin(b)*slhahmix(4,4)*slhahmix(3,1)
      gzh4h4 = (slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b))*
     .     slhahmix(4,4)+dcos(b)*slhahmix(4,4)*slhahmix(4,2)-
     .     dsin(b)*slhahmix(4,4)*slhahmix(4,1)
      gzh4h5 = (slhahmix(4,1)*dsin(b)-slhahmix(4,2)*dcos(b))*
     .     slhahmix(5,4)+dcos(b)*slhahmix(4,4)*slhahmix(5,2)-
     .     dsin(b)*slhahmix(4,4)*slhahmix(5,1)
      gzh5h1 = (slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b))*
     .     slhahmix(1,4)+dcos(b)*slhahmix(5,4)*slhahmix(1,2)-
     .     dsin(b)*slhahmix(5,4)*slhahmix(1,1)
      gzh5h2 = (slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b))*
     .     slhahmix(2,4)+dcos(b)*slhahmix(5,4)*slhahmix(2,2)-
     .     dsin(b)*slhahmix(5,4)*slhahmix(2,1)
      gzh5h3 = (slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b))*
     .     slhahmix(3,4)+dcos(b)*slhahmix(5,4)*slhahmix(3,2)-
     .     dsin(b)*slhahmix(5,4)*slhahmix(3,1)
      gzh5h4 = (slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b))*
     .     slhahmix(4,4)+dcos(b)*slhahmix(5,4)*slhahmix(4,2)-
     .     dsin(b)*slhahmix(5,4)*slhahmix(4,1)
      gzh5h5 = (slhahmix(5,1)*dsin(b)-slhahmix(5,2)*dcos(b))*
     .     slhahmix(5,4)+dcos(b)*slhahmix(5,4)*slhahmix(5,2)-
     .     dsin(b)*slhahmix(5,4)*slhahmix(5,1)

      do i=1,5,1
         do j=1,5,1
            gzhihj(i,j) = (slhahmix(i,1)*dsin(b)-slhahmix(i,2)*dcos(b))*
     .           slhahmix(j,4)+dcos(b)*slhahmix(i,4)*slhahmix(j,2)-
     .           dsin(b)*slhahmix(i,4)*slhahmix(j,1)
         end do
      end do

c -- H_i H_j H_k -- c
      gh1h1h1 = ghself(1,1,1,sb,cb)
      gh1h2h2 = ghself(1,2,2,sb,cb)
      gh2h1h1 = ghself(2,1,1,sb,cb)
      gh1h3h3 = ghself(1,3,3,sb,cb)
      gh3h1h1 = ghself(3,1,1,sb,cb)
      gh2h3h3 = ghself(2,3,3,sb,cb)
      gh3h2h2 = ghself(3,2,2,sb,cb)
      gh2h2h2 = ghself(2,2,2,sb,cb)
      gh3h3h3 = ghself(3,3,3,sb,cb)

      gh1h2h3 = ghself(1,2,3,sb,cb)

      gh1h1h4 = ghself(1,1,4,sb,cb)
      gh1h1h5 = ghself(1,1,5,sb,cb)
      gh2h1h4 = ghself(2,1,4,sb,cb)
      gh2h1h5 = ghself(2,1,5,sb,cb)
      gh2h2h4 = ghself(2,2,4,sb,cb)
      gh2h2h5 = ghself(2,2,5,sb,cb)
      gh2h4h4 = ghself(2,4,4,sb,cb)
      gh2h4h5 = ghself(2,4,5,sb,cb)
      gh2h5h5 = ghself(2,5,5,sb,cb)
      gh3h1h4 = ghself(3,1,4,sb,cb)
      gh3h1h5 = ghself(3,1,5,sb,cb)
      gh3h2h4 = ghself(3,2,4,sb,cb)
      gh3h2h5 = ghself(3,2,5,sb,cb)
      gh3h3h4 = ghself(3,3,4,sb,cb)
      gh3h3h5 = ghself(3,3,5,sb,cb)
      gh3h4h4 = ghself(3,4,4,sb,cb)
      gh3h4h5 = ghself(3,4,5,sb,cb)
      gh3h5h5 = ghself(3,5,5,sb,cb)
      gh4h1h4 = ghself(4,1,4,sb,cb)
      gh4h1h5 = ghself(4,1,5,sb,cb)
      gh4h4h4 = ghself(4,4,4,sb,cb)
      gh4h4h5 = ghself(4,4,5,sb,cb)
      gh4h5h5 = ghself(4,5,5,sb,cb)
      gh5h5h1 = ghself(5,5,1,sb,cb)
      gh5h5h5 = ghself(5,5,5,sb,cb)

      do i=1,5,1
         do j=1,5,1
            do k=1,5,1
               ghihjhk(i,j,k) = ghself(i,j,k,sb,cb)
            end do
         end do
      end do

c -- H_k H+ H- -- c

      gh1pm   = (1.d0-(xlambdapar**2+xlambdaparim**2)*v**2/2.d0/amz**2)*
     .     dcos(2.d0*b)*(dsin(b)*slhahmix(1,2)-dcos(b)*slhahmix(1,1))+
     .     (2.d0*amw**2/amz**2-(xlambdapar**2+xlambdaparim**2)*
     .     v**2/2.d0/amz**2)*
     .     (dsin(b)*slhahmix(1,2)+dcos(b)*slhahmix(1,1))
     .     +
     .     2.d0*v/vs/amz**2*(slhahmix(1,3)*(
     .     xlamvs**2+xlamvsim**2+dsin(b)*dcos(b)*(
     .     dcos(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam)+
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     (dsin(xphiu)*(xkappa*(2*xlambdapar**3*xlamvs*xlamvsim - 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     xlambdaparim**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar**2*xlambdaparim*(-xlamvs**2 + xlamvsim**2)) 
     .     + 
     .     xkappaim*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*
     .     (-xlamvs**2 + xlamvsim**2))) + 
     .     dcos(xphiu)*(xkappa*(6.d0*xlambdapar**2*
     .     xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) 
     .     + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2))))))-
     .     slhahmix(1,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) 
     .     + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu))))

      tmp = slhahmix(1,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) 
     .     + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu)))

      gh2pm   = (1.d0-(xlambdapar**2+xlambdaparim**2)*v**2/2.d0/amz**2)*
     .     dcos(2.d0*b)*(dsin(b)*slhahmix(2,2)-dcos(b)*slhahmix(2,1))+
     .     (2.d0*amw**2/amz**2-(xlambdapar**2+xlambdaparim**2)*
     .     v**2/2.d0/amz**2)*
     .     (dsin(b)*slhahmix(2,2)+dcos(b)*slhahmix(2,1))+
     .     2.d0*v/vs/amz**2*(slhahmix(2,3)*(
     .     xlamvs**2+xlamvsim**2+dsin(b)*dcos(b)*(
     .     dcos(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam)+
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     (dsin(xphiu)*(xkappa*(2*xlambdapar**3*xlamvs*xlamvsim - 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     xlambdaparim**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar**2*xlambdaparim*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*
     .     (-xlamvs**2 + xlamvsim**2))) + 
     .     dcos(xphiu)*(xkappa*(6.d0*xlambdapar**2*
     .     xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2))))))-
     .     slhahmix(2,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu))))
      gh3pm   = (1.d0-(xlambdapar**2+xlambdaparim**2)*v**2/2.d0/amz**2)*
     .     dcos(2.d0*b)*(dsin(b)*slhahmix(3,2)-dcos(b)*slhahmix(3,1))+
     .     (2.d0*amw**2/amz**2-(xlambdapar**2+xlambdaparim**2)*
     .     v**2/2.d0/amz**2)*
     .     (dsin(b)*slhahmix(3,2)+dcos(b)*slhahmix(3,1))+
     .     2.d0*v/vs/amz**2*(slhahmix(3,3)*(
     .     xlamvs**2+xlamvsim**2+dsin(b)*dcos(b)*(
     .     dcos(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam)+
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     (dsin(xphiu)*(xkappa*(2*xlambdapar**3*xlamvs*xlamvsim - 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     xlambdaparim**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar**2*xlambdaparim*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*
     .     (-xlamvs**2 + xlamvsim**2))) + 
     .     dcos(xphiu)*(xkappa*(6.d0*xlambdapar**2*
     .     xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2))))))-
     .     slhahmix(3,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu))))
      gh4pm   = (1.d0-(xlambdapar**2+xlambdaparim**2)*v**2/2.d0/amz**2)*
     .     dcos(2.d0*b)*(dsin(b)*slhahmix(4,2)-dcos(b)*slhahmix(4,1))+
     .     (2.d0*amw**2/amz**2-(xlambdapar**2+xlambdaparim**2)*
     .     v**2/2.d0/amz**2)*
     .     (dsin(b)*slhahmix(4,2)+dcos(b)*slhahmix(4,1))+
     .     2.d0*v/vs/amz**2*(slhahmix(4,3)*(
     .     xlamvs**2+xlamvsim**2+dsin(b)*dcos(b)*(
     .     dcos(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam)+
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     (dsin(xphiu)*(xkappa*(2*xlambdapar**3*xlamvs*xlamvsim - 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     xlambdaparim**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar**2*xlambdaparim*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*
     .     (-xlamvs**2 + xlamvsim**2))) + 
     .     dcos(xphiu)*(xkappa*(6.d0*xlambdapar**2*
     .     xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2))))))-
     .     slhahmix(4,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu))))
      gh5pm   = (1.d0-(xlambdapar**2+xlambdaparim**2)*v**2/2.d0/amz**2)*
     .     dcos(2.d0*b)*(dsin(b)*slhahmix(5,2)-dcos(b)*slhahmix(5,1))+
     .     (2.d0*amw**2/amz**2-(xlambdapar**2+xlambdaparim**2)*
     .     v**2/2.d0/amz**2)*
     .     (dsin(b)*slhahmix(5,2)+dcos(b)*slhahmix(5,1))+
     .     2.d0*v/vs/amz**2*(slhahmix(5,3)*(
     .     xlamvs**2+xlamvsim**2+dsin(b)*dcos(b)*(
     .     dcos(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)-
     .     dsin(xphiu)*(xlamvs*Alamim+xlamvsim*Alam)+
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     (dsin(xphiu)*(xkappa*(2*xlambdapar**3*xlamvs*xlamvsim - 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     xlambdaparim**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar**2*xlambdaparim*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*
     .     (-xlamvs**2 + xlamvsim**2))) + 
     .     dcos(xphiu)*(xkappa*(6.d0*xlambdapar**2*
     .     xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2))))))-
     .     slhahmix(5,5)*dsin(b)*dcos(b)*(
     .     dsin(xphiu)*(xlamvs*Alam-xlamvsim*Alamim)+dcos(xphiu)*
     .     (xlamvs*Alamim+xlamvsim*Alam)-
     .     2.d0/((xlambdapar**2+xlambdaparim**2)**2)*
     .     ((xkappaim*(-6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim
     .     + 2*xlambdaparim**3*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar*xlambdaparim**2*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdapar**3*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappa*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dcos(xphiu) + 
     .     (xkappa*(6.d0*xlambdapar**2*xlambdaparim*xlamvs*xlamvsim - 
     .     2.d0*xlambdaparim**3*xlamvs*xlamvsim + 
     .     xlambdapar**3*(xlamvs**2 - xlamvsim**2) + 
     .     3.d0*xlambdapar*xlambdaparim**2*(-xlamvs**2 + xlamvsim**2)) + 
     .     xkappaim*(-2.d0*xlambdapar**3*xlamvs*xlamvsim + 
     .     6.d0*xlambdapar*xlambdaparim**2*xlamvs*xlamvsim + 
     .     3.d0*xlambdapar**2*xlambdaparim*(xlamvs**2 - xlamvsim**2) + 
     .     xlambdaparim**3*(-xlamvs**2 + xlamvsim**2)))*dsin(xphiu))))

      ghipm(1) = gh1pm
      ghipm(2) = gh2pm
      ghipm(3) = gh3pm
      ghipm(4) = gh4pm
      ghipm(5) = gh5pm

      return
111   stop
      end

c -------------------------------------------------------------------- c

c ===================== the function f0 ===============
      complex*16 function f0_hdec(m1,m2,qsq)
      implicit real*8 (a-h,m,o-z)
      complex*16 cd,cr,cq2,ieps,cbet,cxx
      m1sq = m1*m1
      m2sq = m2*m2
      aqsq = dabs(qsq)
      ieps = dcmplx(1.d0,1.d-12)
      cq2 = qsq*ieps
      cd = (m1sq-m2sq)/cq2
      cr = cdsqrt((1+cd)**2 - 4*m1sq/cq2)
      if(qsq.eq.0.d0) then
       f0_hdec = 0.d0
      else
       if(m1.eq.m2) then
        f0_hdec = -2.d0 + cr*cdlog(-(1+cr)/(1-cr))
       else
        cbet = cdsqrt(1-4*m1*m2/(cq2 - (m1-m2)**2))
        cxx = (cbet-1)/(cbet+1)
        f0_hdec = -1 + ((qsq+m2sq-m1sq)/2/qsq - m2sq/(m2sq-m1sq))
     .                                           *dlog(m2sq/m1sq)
     .     - (qsq-(m1-m2)**2)/qsq*cbet*cdlog(cxx)
       endif
      endif
      RETURN
      END

c -------------------------------------------------------------------- c
c     ************************************************************
c     subroutine for Hsm ---> V*V* ---> 4f
c     ************************************************************
      subroutine htovv_hdec(iv,amh,amv,gamv,htvv)
      implicit double precision (a-h,o-z)
      common/vvoff_hdec/amh1,amv1,gamv1
      common/vvoffflag_hdec/iv1
      common/prec_hdec/ip
      external ftovv1_hdec
c     ip=20
      ip=50
      amh1=amh
      amv1=amv
      gamv1=gamv
      iv1 = iv
      dlt=1d0/ip
      sum=0d0
      do 1 i=1,ip
       uu=dlt*i
       dd=uu-dlt
       call qgaus1_hdec(ftovv1_hdec,dd,uu,res)
       sum=sum+res
1     continue
      htvv=sum
      return
      end

c -------------------------------------------------------------------- c

      double precision function ftovv1_hdec(xx)
      implicit double precision (a-h,o-z)
      common/first_hdec/x1
      common/prec_hdec/ip
      external ftovv2_hdec
      x1=xx
      dlt=1d0/ip
      sum=0d0
      do 1 i=1,ip
       uu=dlt*i
       dd=uu-dlt
       call qgaus2_hdec(ftovv2_hdec,dd,uu,res)
       sum=sum+res
1     continue
      ftovv1_hdec=sum
      return
      end

c -------------------------------------------------------------------- c

      double precision function ftovv2_hdec(xx)
      implicit double precision (a-h,o-z)
      dimension yy(2)
      common/first_hdec/x1
      yy(1)=x1
      yy(2)=xx
      ftovv2_hdec=ftovv_hdec(yy)
      return
      end

c -------------------------------------------------------------------- c

      double precision function ftovv_hdec(xx)
      implicit double precision (a-h,o-z)
      double precision lamb
      dimension xx(2)
      common/vvoff_hdec/amh,amw,gamw
      lamb(x,y)=dsqrt((1.d0-x-y)**2-4.d0*x*y)
      pi=4d0*datan(1d0)
      if(amh.lt.2*amw)then
       icase = 1
      else
       icase = 0
      endif
      if(icase.eq.0)then
       yy = amh**2
       y1 = datan((yy-amw**2)/amw/gamw)
       y2 = -datan((amw**2)/amw/gamw)
       djac = y1-y2
       t1 = tan(y1*xx(1)+y2*(1.d0-xx(1)))
       sp = amw**2 + amw*gamw*t1
       yy = (amh-dsqrt(sp))**2
       y1 = datan((yy-amw**2)/amw/gamw)
       y2 = -datan((amw**2)/amw/gamw)
       djac = djac*(y1-y2)
       t2 = tan(y1*xx(2)+y2*(1.d0-xx(2)))
       sm = amw**2 + amw*gamw*t2
       am2=amh**2
       gam = am2*lamb(sp/am2,sm/am2)*(1+lamb(sp/am2,sm/am2)**2*amh**4
     .                               /sp/sm/12)
       pro1 = sp/amw**2
       pro2 = sm/amw**2
       ftovv_hdec = pro1*pro2*gam*djac/pi**2
     .            * radvv_hdec(sp,sm)
      else
       sp = amh**2*xx(1)
       sm = (amh-dsqrt(sp))**2*xx(2)
       djac = amh**2*(amh-dsqrt(sp))**2/pi**2
       am2=amh**2
       gam = am2*lamb(sp/am2,sm/am2)*(1+lamb(sp/am2,sm/am2)**2*amh**4
     .                               /sp/sm/12)
       pro1 = sp*gamw/amw/((sp-amw**2)**2+amw**2*gamw**2)
       pro2 = sm*gamw/amw/((sm-amw**2)**2+amw**2*gamw**2)
       ftovv_hdec = pro1*pro2*gam*djac
     .            * radvv_hdec(sp,sm)
      endif
      return
      end

c -------------------------------------------------------------------- c

      double precision function radvv_hdec(q12,q22)
      implicit double precision (a-b,d-h,o-z), complex*16 (c)
      common/vvoffflag_hdec/iv
      q1 = dsqrt(q12)
      q2 = dsqrt(q22)
      if(iv.eq.0)then
       radvv_hdec=1
      elseif(iv.eq.1)then
       radvv_hdec=radww_hdec(q1,q2)
      else
       radvv_hdec=radzz_hdec(q1,q2)
      endif
      return
      end

c -------------------------------------------------------------------- c

      double precision function radww_hdec(q1w,q2w)
C     ************************************************************
C     ELECTROWEAK CORRECTIONS TO HSM ---> W*W* ---> 4F (APPROX.)
C     (A. BREDENSTEIN ET AL., PHYS. REV. D74 (2006) 013004
C                             [ARXIV:HEP-PH/0604011])
C     ************************************************************
      implicit double precision (a-b,d-h,o-z), complex*16 (c)
      double precision lamb
      common/vvoff_hdec/amh,amw,gamw
      common/param_hdec/gf,alph,amtau,ammuon,amz,amw0
      common/masses_hdec/ams0,amc0,amb0,amt
      common/wzwdth_hdec/gamc0,gamt,gamt1,gamw0,gamz

      lamb(x,y)=dsqrt((1.d0-x-y)**2-4.d0*x*y)
      pi=4d0*datan(1d0)
      cmut2 = dcmplx(amt**2,-amt*gamt)
      cmuw2 = dcmplx(amw**2,-amw*gamw)
      cmuz2 = dcmplx(amz**2,-amz*gamz*3)
      cbett = cdsqrt(1-4*cmut2/amh**2)
      cbetw = cdsqrt(1-4*cmuw2/amh**2)
      cbetz = cdsqrt(1-4*cmuz2/amh**2)
      cxt = (cbett-1)/(cbett+1)
      cthww = 8+12*cbett**2+3*cbett*(3*cbett**2-1)*cdlog(cxt)
     .      + 3/2.d0*(1-cbett**2)**2*cdlog(cxt)**2
      cbetwb = cdsqrt(dcmplx(amh**4+q1w**4+q2w**4-2*amh**2*q1w**2
     .             -2*amh**2*q2w**2-2*q1w**2*q2w**2))/amh**2
      cgw = (1-cbetwb**2)**2
      dmw = dabs(q1w**2-q2w**2)/amh**2
      cdcoul = alph/cbetwb*dimag(cdlog((cbetw-cbetwb+dmw)
     .                                /(cbetw+cbetwb+dmw)))
c     cgz = 1
      cgz = 0.7d0
      cdcoulz = alph/2/cbetz*dimag(cdlog((cbetz-cbetwb)
     .                                  /(cbetz+cbetwb)))
c     bias = 0.04d0*(1+(100-amh)/500)
      bias = 0.05d0*(1+(100-amh)/500)
      radww_hdec=dreal(1.d0
     .           +gf*cmut2/8.d0/pi**2/dsqrt(2.d0)*(-5+cthww)
     .           +gf*amh**2/16.d0/pi**2/dsqrt(2.d0)*2.800952d0
     .           +(gf*amh**2/16.d0/pi**2/dsqrt(2.d0))**2*62.0308d0
     .           +cgw*cdcoul + cgz*cdcoulz + bias)
      return
      end

c -------------------------------------------------------------------- c

      double precision function radzz_hdec(q1z,q2z)
C     ************************************************************
C     ELECTROWEAK CORRECTIONS TO HSM ---> Z*Z* ---> 4F (APPROX.)
C     (A. BREDENSTEIN ET AL., PHYS. REV. D74 (2006) 013004
C                             [ARXIV:HEP-PH/0604011])
C     ************************************************************
      implicit double precision (a-b,d-h,o-z), complex*16 (c)
      double precision lamb
      common/vvoff_hdec/amh,amz,gamz
      common/param_hdec/gf,alph,amtau,ammuon,amz0,amw
      common/masses_hdec/ams0,amc0,amb0,amt
      common/wzwdth_hdec/gamc0,gamt,gamt1,gamw,gamz0

      lamb(x,y)=dsqrt((1.d0-x-y)**2-4.d0*x*y)
      pi=4.d0*datan(1.d0)
      cmut2 = dcmplx(amt**2,-amt*gamt)
      cmuw2 = dcmplx(amw**2,-amw*gamw)
      cmuz2 = dcmplx(amz**2,-amz*gamz*2)
      cbett = cdsqrt(1-4*cmut2/amh**2)
      cbetw = cdsqrt(1-4*cmuw2/amh**2)
      cbetz = cdsqrt(1-4*cmuz2/amh**2)
      cxt = (cbett-1)/(cbett+1)
      cthzz = 20+6*cbett**2+3*cbett*(cbett**2+1)*cdlog(cxt)
     .      + 3*(1-cbett**2)*cdlog(cxt)**2
      cbetzb = cdsqrt(dcmplx(amh**4+q1z**4+q2z**4-2*amh**2*q1z**2
     .             -2*amh**2*q2z**2-2*q1z**2*q2z**2))/amh**2
c     cgw =-0.15d0 * (1-cbetw**2)**2
      cgw =-0.10d0 * (1-cbetw**2)**2
      cdcoulw = alph/2/cbetw*dimag(cdlog((cbetw-cbetzb)
     .                                  /(cbetw+cbetzb)))
      cgz = 1
      cdcoulz = alph/2/cbetz*dimag(cdlog((cbetz-cbetzb)
     .                                  /(cbetz+cbetzb)))
c     bias = 0.02d0*(1+(100-amh)/350)
      bias = 0.02d0*(1+(100-amh)/300)
      radzz_hdec=dreal(1.d0
     .           +gf*cmut2/8.d0/pi**2/dsqrt(2.d0)*(1+cthzz)
     .           +gf*amh**2/16.d0/pi**2/dsqrt(2.d0)*2.800952d0
     .           +(gf*amh**2/16.d0/pi**2/dsqrt(2.d0))**2*62.0308d0
     .           +cgw*cdcoulw + cgz*cdcoulz + bias)
      return
      end

c -------------------------------------------------------------------- c

c ****************************************************
c SUBROUTINE FOR Hi -> TT* -> TBW in the complex NMSSM
c ****************************************************
      SUBROUTINE HTOTT_CNMSSM(AMH,AMT,AMB,AMW,AMCH,TB,GHT,
     .     GAT,GHB,GAB,GHVV,GHIHPWM,GAIHPWM,HTT0)
      IMPLICIT REAL*8(A-Z)
      INTEGER K,IP
      COMMON/PREC1_HDEC/IP
      EXTERNAL FUNHTT1_COMPLEX_HDEC
      COMMON/IKSY4_HDEC/X1,X2,M1,M2,M3,ECM,S
      COMMON/TOP4_HDEC/AMH2,AMT2,AMB2,AMW2,AMCH2,TB2,GHT2,GAT2,
     .     GHB2,GAB2,GHVV2
      COMMON/TOP4_COMPLEX_NMSSM/GHIHPWM2,GAIHPWM2
c filling common blocks variables to be passed to subfunctions
      AMH2=AMH
      AMT2=AMT
      AMB2=AMB
      AMW2=AMW
      AMCH2=AMCH
      TB2=TB
      GHT2=GHT
      GAT2=GAT
      GHB2=GHB
      GAB2=GAB
      GHVV2=GHVV
      GHIHPWM2=GHIHPWM
      GAIHPWM2=GAIHPWM

      IP=5
      M1=AMB
      M2=AMT
      M3=AMW
c end filling
C     FIRST INTEGRATE OVER X2, i.e. (1+3) SYSTEM
C        CHECK WHETHER ENOUGH PHASE SPACE
      MASTOT=M1+M2+M3
      IF(MASTOT.GE.AMH) GOTO 12
      ECM=AMH
      S=ECM**2
      U1=(ECM-M2)**2
      D1=(M1+M3)**2
      U=(S-D1+M2**2)/s
      D=(S-U1+M2**2)/s
      DEL=(U-D)/IP
      U=D+DEL
      XSEC=0.D0
      DO K=1,IP
      CALL QGAUS1_HDEC(FUNHTT1_COMPLEX_HDEC,D,U,SS)
      D=U
      U=D+DEL
      XSEC=XSEC+SS
      ENDDO
      HTT0=XSEC
 12   CONTINUE
      RETURN
      END

c -------------------------------------------------------------------- c

      DOUBLE PRECISION FUNCTION FUNHTT1_COMPLEX_HDEC(XL)
      IMPLICIT REAL*8(A-Z)
      INTEGER IP,I
      COMMON/IKSY4_HDEC/X1,X2,M1,M2,M3,ECM,S
      COMMON/PREC1_HDEC/IP
      EXTERNAL FUNHTT2_COMPLEX_HDEC
      X2=XL
      S13=S-S*X2+M2**2
      TEM=2.D0*DSQRT(S13)
      E2S=(S-S13-M2**2)/TEM
      E3S=(S13+M3**2-M1**2)/TEM
C     SECOND INTEGRAL OVER X1, i.e. (2+3) SYSTEM
      U1=(E2S+E3S)**2-(DSQRT(E2S**2-M2**2)-DSQRT(E3S**2-M3**2))**2
      D1=(E2S+E3S)**2-(DSQRT(E2S**2-M2**2)+DSQRT(E3S**2-M3**2))**2
      U=(S-D1+M1**2)/s
      D=(S-U1+M1**2)/s
      DEL=(U-D)/IP
      FUNHTT1_COMPLEX_HDEC=0.d0
      U=D+DEL
      DO I=1,IP
      CALL QGAUS2_HDEC(FUNHTT2_COMPLEX_HDEC,D,U,SS)
      FUNHTT1_COMPLEX_HDEC=FUNHTT1_COMPLEX_HDEC+SS
      D=U
      U=D+DEL
      ENDDO
      RETURN
      END

c -------------------------------------------------------------------- c

      DOUBLE PRECISION FUNCTION FUNHTT2_COMPLEX_HDEC(XK)
      IMPLICIT REAL*8(A-Z)
      COMMON/IKSY4_HDEC/X1,X2,M1,M2,M3,ECM,S
      X1=XK
      CALL ELEMHTT_COMPLEX_NMSSM(SS)
      FUNHTT2_COMPLEX_HDEC=SS
      RETURN
      END

c -------------------------------------------------------------------- c

      SUBROUTINE ELEMHTT_COMPLEX_NMSSM(RES)
      IMPLICIT REAL*8(A-Z)
      integer ihtott
      COMMON/IKSY4_HDEC/X1,X2,M1,M2,M3,ECM,S
      COMMON/TOP4_HDEC/AMH,AMT,AMB,AMW,AMCH,TB,GHT,GAT,GHB,GAB,GHVV
      COMMON/WZWDTH_HDEC/GAMC0,GAMT0,GAMT1,GAMW0,GAMZ0
      COMMON/TOP4_COMPLEX_NMSSM/GHIHPWM,GAIHPWM

      GAMT=GAMT1**2*AMT**2/AMH**4
      GAMC=GAMC0**2*AMCH**2/AMH**4
      GAMW=GAMW0**2*AMW**2/AMH**4
      CH=AMCH**2/AMH**2
      W=AMW**2/AMH**2
      T=AMT**2/AMH**2
      B=AMB**2/AMH**2

      Y1=1-X1
      Y2=1-X2
      X0=2.D0-X1-X2

      W1=(1.d0-X2)
      W2=(1.d0-X0+W-CH)
      W3=(1.d0-X0)
      W4=(1.d0-X1)

      W11=1.d0/(W1**2+GAMT)
      W22=1.d0/(W2**2+GAMC)
      W33=1.d0/(W3**2+GAMW)
      W12=W1*W2*W11*W22
      W13=W1*W3*W11*W33
      W23=W2*W3*W22*W33
      W44=1.d0/W4**2
      W14=W1*W11/W4
      W24=W2*W22/W4
      W34=W3*W33/W4

      R11= 4.d0*B**2*GHT**2+4.d0*B**2*GAT**2-8.d0*B*GHT**2*T-
     .     16.d0*B**2*GHT**2*T-8.d0*B*GAT**2*T+4.d0*GHT**2*T**2+
     .     32.d0*B*GHT**2*T**2+4.d0*GAT**2*T**2-16.d0*GHT**2*T**3+
     .     4.d0*B*GHT**2*W+4.d0*B*GAT**2*W+4.d0*GHT**2*T*W-
     .     16.d0*B*GHT**2*T*W+4.d0*GAT**2*T*W-16.d0*GHT**2*T**2*W-
     .     8.d0*GHT**2*W**2-8.d0*GAT**2*W**2+32.d0*GHT**2*T*W**2-
     .     8.d0*B*GHT**2*Y2-8.d0*B*GAT**2*Y2+8.d0*GHT**2*T*Y2+
     .     32.d0*B*GHT**2*T*Y2+8.d0*GAT**2*T*Y2-32.d0*GHT**2*T**2*Y2-
     .     16.d0*GHT**2*T*W*Y2+4.d0*B*GHT**2*Y1*Y2+4.d0*B*GAT**2*Y1*Y2-
     .     4.d0*GHT**2*T*Y1*Y2-4.d0*GAT**2*T*Y1*Y2+8.d0*GHT**2*W*Y1*Y2+
     .     8.d0*GAT**2*W*Y1*Y2+4.d0*GHT**2*Y2**2+4.d0*B*GHT**2*Y2**2+
     .     4.d0*GAT**2*Y2**2+4.d0*B*GAT**2*Y2**2-20.d0*GHT**2*T*Y2**2-
     .     4.d0*GAT**2*T*Y2**2+4.d0*GHT**2*W*Y2**2+4.d0*GAT**2*W*Y2**2-
     .     4.d0*GHT**2*Y1*Y2**2-4.d0*GAT**2*Y1*Y2**2-4.d0*GHT**2*Y2**3-
     .     4.d0*GAT**2*Y2**3
      R22=-16.d0*T*W+16.d0*B*T*W+16.d0*T**2*W+64.d0*B*T*TB**2*W-
     .     16.d0*B*TB**4*W+16.d0*B**2*TB**4*W+16.d0*B*T*TB**4*W-
     .     16.d0*T*W**2-16.d0*B*TB**4*W**2+16.d0*T*W*Y1+
     .     16.d0*B*TB**4*W*Y1+4.d0*T*Y1**2-4.d0*B*T*Y1**2-
     .     4.d0*T**2*Y1**2-16.d0*B*T*TB**2*Y1**2+4.d0*B*TB**4*Y1**2-
     .     4.d0*B**2*TB**4*Y1**2-4.d0*B*T*TB**4*Y1**2+4.d0*T*W*Y1**2+
     .     4.d0*B*TB**4*W*Y1**2-4.d0*T*Y1**3-4.d0*B*TB**4*Y1**3+
     .     16.d0*T*W*Y2+16.d0*B*TB**4*W*Y2+8.d0*T*Y1*Y2-8.d0*B*T*Y1*Y2-
     .     8.d0*T**2*Y1*Y2-32.d0*B*T*TB**2*Y1*Y2+8.d0*B*TB**4*Y1*Y2-
     .     8.d0*B**2*TB**4*Y1*Y2-8.d0*B*T*TB**4*Y1*Y2+8.d0*T*W*Y1*Y2+
     .     8.d0*B*TB**4*W*Y1*Y2-12.d0*T*Y1**2*Y2-12.d0*B*TB**4*Y1**2*Y2+
     .     4.d0*T*Y2**2-4.d0*B*T*Y2**2-4.d0*T**2*Y2**2-
     .     16.d0*B*T*TB**2*Y2**2+4.d0*B*TB**4*Y2**2-
     .     4.d0*B**2*TB**4*Y2**2-4.d0*B*T*TB**4*Y2**2+4.d0*T*W*Y2**2+
     .     4.d0*B*TB**4*W*Y2**2-12.d0*T*Y1*Y2**2-
     .     12.d0*B*TB**4*Y1*Y2**2-4.d0*T*Y2**3-4.d0*B*TB**4*Y2**3
      R33=-16.d0*B*W+16.d0*B**2*W-16.d0*T*W-32.d0*B*T*W+16.d0*T**2*W+
     .     16.d0*B*W**2-16.d0*B**2*W**2+16.d0*T*W**2+32.d0*B*T*W**2-
     .     16.d0*T**2*W**2+16.d0*W**3-16.d0*B*W**3-16.d0*T*W**3+
     .     32.d0*W**4+16.d0*B*W*Y1-16.d0*B**2*W*Y1+16.d0*T*W*Y1+
     .     32.d0*B*T*W*Y1-16.d0*T**2*W*Y1-32.d0*W**3*Y1+4.d0*B*Y1**2-
     .     4.d0*B**2*Y1**2+4.d0*T*Y1**2+8.d0*B*T*Y1**2-4.d0*T**2*Y1**2-
     .     12.d0*B*W*Y1**2+4.d0*T*W*Y1**2-4.d0*B*Y1**3-4.d0*T*Y1**3+
     .     16.d0*B*W*Y2-16.d0*B**2*W*Y2+16.d0*T*W*Y2+32.d0*B*T*W*Y2-
     .     16.d0*T**2*W*Y2-32.d0*W**3*Y2+8.d0*B*Y1*Y2-8.d0*B**2*Y1*Y2+
     .     8.d0*T*Y1*Y2+16.d0*B*T*Y1*Y2-8.d0*T**2*Y1*Y2-8.d0*B*W*Y1*Y2-
     .     8.d0*T*W*Y1*Y2+16.d0*W**2*Y1*Y2-12.d0*B*Y1**2*Y2-
     .     12.d0*T*Y1**2*Y2+4.d0*B*Y2**2-4.d0*B**2*Y2**2+4.d0*T*Y2**2+
     .     8.d0*B*T*Y2**2-4.d0*T**2*Y2**2+4.d0*B*W*Y2**2-
     .     12.d0*T*W*Y2**2-12.d0*B*Y1*Y2**2-12.d0*T*Y1*Y2**2-
     .     4.d0*B*Y2**3-4.d0*T*Y2**3
      R44= 4.d0*B**2*GHB**2-16.d0*B**3*GHB**2+4.d0*B**2*GAB**2-
     .     8.d0*B*GHB**2*T+32.d0*B**2*GHB**2*T-8.d0*B*GAB**2*T+
     .     4.d0*GHB**2*T**2-16.d0*B*GHB**2*T**2+4.d0*GAB**2*T**2+
     .     4.d0*B*GHB**2*W-16.d0*B**2*GHB**2*W+4.d0*B*GAB**2*W+
     .     4.d0*GHB**2*T*W-16.d0*B*GHB**2*T*W+4.d0*GAB**2*T*W-
     .     8.d0*GHB**2*W**2+32.d0*B*GHB**2*W**2-8.d0*GAB**2*W**2+
     .     8.d0*B*GHB**2*Y1-32.d0*B**2*GHB**2*Y1+8.d0*B*GAB**2*Y1-
     .     8.d0*GHB**2*T*Y1+32.d0*B*GHB**2*T*Y1-8.d0*GAB**2*T*Y1-
     .     16.d0*B*GHB**2*W*Y1+4.d0*GHB**2*Y1**2-20.d0*B*GHB**2*Y1**2+
     .     4.d0*GAB**2*Y1**2-4.d0*B*GAB**2*Y1**2+4.d0*GHB**2*T*Y1**2+
     .     4.d0*GAB**2*T*Y1**2+4.d0*GHB**2*W*Y1**2+4.d0*GAB**2*W*Y1**2-
     .     4.d0*GHB**2*Y1**3-4.d0*GAB**2*Y1**3-4.d0*B*GHB**2*Y1*Y2-
     .     4.d0*B*GAB**2*Y1*Y2+4.d0*GHB**2*T*Y1*Y2+4.d0*GAB**2*T*Y1*Y2+
     .     8.d0*GHB**2*W*Y1*Y2+8.d0*GAB**2*W*Y1*Y2-4.d0*GHB**2*Y1**2*Y2-
     .     4*GAB**2*Y1**2*Y2
      R12even=8.d0*W-8.d0*B*W-24.d0*T*W+8.d0*W**2+4.d0*B*Y1-4.d0*T*Y1-
     .     8.d0*B*T*Y1+8.d0*T**2*Y1-8.d0*B**2*TB**2*Y1+
     .     8.d0*B*T*TB**2*Y1-8.d0*W*Y1+8.d0*T*W*Y1+8.d0*B*TB**2*W*Y1+
     .     4.d0*T*Y1**2-4.d0*B*TB**2*Y1**2+4.d0*B*Y2-4.d0*T*Y2-
     .     8.d0*B*T*Y2+8.d0*T**2*Y2-8.d0*B**2*TB**2*Y2+
     .     8.d0*B*T*TB**2*Y2-8.d0*W*Y2-8.d0*T*W*Y2-8.d0*B*TB**2*W*Y2-
     .     4.d0*Y1*Y2+16.d0*T*Y1*Y2-4.d0*W*Y1*Y2+4.d0*Y1**2*Y2-
     .     4.d0*Y2**2+12.d0*T*Y2**2+4.d0*B*TB**2*Y2**2-4.d0*W*Y2**2+ 
     .     8.d0*Y1*Y2**2+4.d0*Y2**3
      R12odd=8.d0*W-8.d0*B*W-8.d0*T*W-16.d0*B*TB**2*W+8.d0*W**2+
     .     4.d0*B*Y1-4.d0*T*Y1-8.d0*W*Y1+4.d0*T*Y1**2+
     .     4.d0*B*TB**2*Y1**2+4.d0*B*Y2-4.d0*T*Y2-8.d0*W*Y2-4.d0*Y1*Y2+
     .     8.d0*T*Y1*Y2+8.d0*B*TB**2*Y1*Y2-4.d0*W*Y1*Y2+4.d0*Y1**2*Y2-
     .     4.d0*Y2**2+4.d0*T*Y2**2+4.d0*B*TB**2*Y2**2-4.d0*W*Y2**2+
     .     8.d0*Y1*Y2**2+4.d0*Y2**3
      R13=-8.d0*W+8.d0*B*W-16.d0*B**2*W+24.d0*T*W+32.d0*B*T*W-
     .     16.d0*T**2*W-16.d0*B*W**2-16.d0*T*W**2+32.d0*W**3-4.d0*B*Y1-
     .     8.d0*B**2*Y1+4.d0*T*Y1+16.d0*B*T*Y1-8.d0*T**2*Y1+8.d0*W*Y1-
     .     16.d0*W**2*Y1-4.d0*B*Y1**2-4.d0*T*Y1**2-4.d0*B*Y2-
     .     8.d0*B**2*Y2+4.d0*T*Y2+16.d0*B*T*Y2-8.d0*T**2*Y2+8.d0*W*Y2+
     .     16.d0*B*W*Y2-16.d0*T*W*Y2-24.d0*W**2*Y2+4.d0*Y1*Y2-
     .     16.d0*T*Y1*Y2+12.d0*W*Y1*Y2-4.d0*Y1**2*Y2+4.d0*Y2**2+
     .     4.d0*B*Y2**2-12.d0*T*Y2**2-4.d0*W*Y2**2-8.d0*Y1*Y2**2-
     .     4.d0*Y2**3
      R14=-16.d0*B**2*GHT*GHB+32.d0*B*GHT*GHB*T-16.d0*GHT*GHB*T**2+
     .     8.d0*GHT*GHB*W-16.d0*B*GHT*GHB*W-8.d0*GAT*GAB*W-
     .     16.d0*GHT*GHB*T*W+32.d0*GHT*GHB*W**2-16.d0*B*GHT*GHB*Y1+
     .     16.d0*GHT*GHB*T*Y1-8.d0*GHT*GHB*W*Y1-4.d0*GHT*GHB*Y1**2-
     .     4.d0*GAT*GAB*Y1**2+16.d0*B*GHT*GHB*Y2-16.d0*GHT*GHB*T*Y2-
     .     8.d0*GHT*GHB*W*Y2+8.d0*GHT*GHB*Y1*Y2-8.d0*GAT*GAB*Y1*Y2-
     .     4.d0*GHT*GHB*Y2**2-4.d0*GAT*GAB*Y2**2
      R23= 16.d0*T*W+16.d0*B*T*W-16.d0*T**2*W-16.d0*B*TB**2*W+
     .     16.d0*B**2*TB**2*W-16.d0*B*T*TB**2*W-16.d0*T*W*Y1-
     .     8.d0*B*T*W*Y1+8.d0*T**2*W*Y1+16.d0*B*TB**2*W*Y1-
     .     8.d0*B**2*TB**2*W*Y1+8.d0*B*T*TB**2*W*Y1+8.d0*T*W**2*Y1+
     .     8.d0*B*TB**2*W**2*Y1-4.d0*T*Y1**2-4.d0*B*T*Y1**2+
     .     4.d0*T**2*Y1**2+4.d0*B*TB**2*Y1**2-4.d0*B**2*TB**2*Y1**2+
     .     4.d0*B*T*TB**2*Y1**2-4.d0*T*W*Y1**2-4.d0*B*TB**2*W*Y1**2+
     .     4.d0*T*Y1**3-4.d0*B*TB**2*Y1**3-16.d0*T*W*Y2-8.d0*B*T*W*Y2+
     .     8.d0*T**2*W*Y2+16.d0*B*TB**2*W*Y2-8.d0*B**2*TB**2*W*Y2+
     .     8.d0*B*T*TB**2*W*Y2-8.d0*T*W**2*Y2-8.d0*B*TB**2*W**2*Y2-
     .     8.d0*T*Y1*Y2-8.d0*B*T*Y1*Y2+8.d0*T**2*Y1*Y2+
     .     8.d0*B*TB**2*Y1*Y2-8.d0*B**2*TB**2*Y1*Y2+
     .     8.d0*B*T*TB**2*Y1*Y2+12.d0*T*Y1**2*Y2-12.d0*B*TB**2*Y1**2*Y2-
     .     4.d0*T*Y2**2-4.d0*B*T*Y2**2+4.d0*T**2*Y2**2+
     .     4.d0*B*TB**2*Y2**2-4.d0*B**2*TB**2*Y2**2+
     .     4.d0*B*T*TB**2*Y2**2+4.d0*T*W*Y2**2+4.d0*B*TB**2*W*Y2**2+
     .     12.d0*T*Y1*Y2**2-12.d0*B*TB**2*Y1*Y2**2+4.d0*T*Y2**3-
     .     4.d0*B*TB**2*Y2**3
      R24even=-8.d0*TB**2*W+24.d0*B*TB**2*W+8.d0*T*TB**2*W-
     .     8.d0*TB**2*W**2-8.d0*B*T*Y1+8.d0*T**2*Y1+4.d0*B*TB**2*Y1-
     .     8.d0*B**2*TB**2*Y1-4.d0*T*TB**2*Y1+8.d0*B*T*TB**2*Y1+
     .     8.d0*T*W*Y1+8.d0*TB**2*W*Y1+8.d0*B*TB**2*W*Y1-4.d0*T*Y1**2+
     .     4.d0*TB**2*Y1**2-12.d0*B*TB**2*Y1**2+4.d0*TB**2*W*Y1**2-
     .     4.d0*TB**2*Y1**3-8.d0*B*T*Y2+8.d0*T**2*Y2+4.d0*B*TB**2*Y2-
     .     8.d0*B**2*TB**2*Y2-4.d0*T*TB**2*Y2+8.d0*B*T*TB**2*Y2-
     .     8.d0*T*W*Y2+8.d0*TB**2*W*Y2-8.d0*B*TB**2*W*Y2+
     .     4.d0*TB**2*Y1*Y2-16.d0*B*TB**2*Y1*Y2+4.d0*TB**2*W*Y1*Y2-
     .     8.d0*TB**2*Y1**2*Y2+4.d0*T*Y2**2-4.d0*B*TB**2*Y2**2-
     .     4.d0*TB**2*Y1*Y2**2
      R24odd=-16.d0*T*W+8.d0*TB**2*W-8.d0*B*TB**2*W-8.d0*T*TB**2*W+
     .     8.d0*TB**2*W**2-4.d0*B*TB**2*Y1+4.d0*T*TB**2*Y1-
     .     8.d0*TB**2*W*Y1+4.d0*T*Y1**2-4.d0*TB**2*Y1**2+
     .     4.d0*B*TB**2*Y1**2-4.d0*TB**2*W*Y1**2+4.d0*TB**2*Y1**3-
     .     4.d0*B*TB**2*Y2+4.d0*T*TB**2*Y2-8.d0*TB**2*W*Y2+8.d0*T*Y1*Y2-
     .     4.d0*TB**2*Y1*Y2+8.d0*B*TB**2*Y1*Y2-4.d0*TB**2*W*Y1*Y2+
     .     8.d0*TB**2*Y1**2*Y2+4.d0*T*Y2**2+4.d0*B*TB**2*Y2**2+
     .     4.d0*TB**2*Y1*Y2**2
      R34=-8.d0*W+24.d0*B*W-16.d0*B**2*W+8.d0*T*W+32.d0*B*T*W-
     .     16.d0*T**2*W-16.d0*B*W**2-16.d0*T*W**2+32.d0*W**3+4.d0*B*Y1-
     .     8.d0*B**2*Y1-4.d0*T*Y1+16.d0*B*T*Y1-8.d0*T**2*Y1+8.d0*W*Y1-
     .     16.d0*B*W*Y1+16.d0*T*W*Y1-24.d0*W**2*Y1+4.d0*Y1**2-
     .     12.d0*B*Y1**2+4.d0*T*Y1**2-4.d0*W*Y1**2-4.d0*Y1**3+4.d0*B*Y2-
     .     8.d0*B**2*Y2-4.d0*T*Y2+16.d0*B*T*Y2-8.d0*T**2*Y2+8.d0*W*Y2-
     .     16.d0*W**2*Y2+4.d0*Y1*Y2-16.d0*B*Y1*Y2+12.d0*W*Y1*Y2-
     .     8.d0*Y1**2*Y2-4.d0*B*Y2**2-4.d0*T*Y2**2-4.d0*Y1*Y2**2
      
c - take off the charged H+ and W+ exchange -
      W22 = 0.D0
      W33 = 0.D0
      W12 = 0.D0
      W23 = 0.D0
      W13 = 0.D0
      W24 = 0.D0
      W34 = 0.D0
c -------------------------------------------

      RES= R11*W11+(GHIHPWM**2+GAIHPWM**2)*R22*W22/T/TB**2+
     .     GHVV**2*R33*W33/T+R44*W44*B/T+
     .     2.d0*(GHT*GHIHPWM*R12even+GAT*GAIHPWM*R12odd)*W12/TB+
     .     2.d0*GHT*GHVV*R13*W13+2.d0*B*R14*W14+
     .     2.d0*GHVV*GHIHPWM*R23*W23/TB/T+
     .     2.d0*(GHB*GHIHPWM*R24even+GAB*GAIHPWM*R24odd)*W24/TB*B/T+
     .     2.d0*GHB*GHVV*R34*W34*B/T

      RETURN
      END

c -------------------------------------------------------------------- c

      subroutine htohhoffshell_cnmssm(iicase,amhi,amhj,amhk,gamtotj,
     .     gamtotk,htohhoff,errhtohhoff)

      implicit double precision (a-h,o-z)
      integer ivegas(4)
      common/DECPARAMETERSC/ijcase,amhi1,amhj1,amhk1,gamtotj1,gamtotk1

      external hitohjhk_cnmssm

      amhi1 = amhi
      amhj1 = amhj
      amhk1 = amhk
      gamtotj1 = gamtotj
      gamtotk1 = gamtotk
      ijcase= iicase

c ---- VEGAS parameters ----

      iprint = 0

c      ivegas(1) = 600000
c      ivegas(2) = 5
c      ivegas(3) = 24000000
c      ivegas(4) = 10

cc      ivegas(1) = 30000
cc      ivegas(2) = 5
cc      ivegas(3) = 120000
cc      ivegas(4) = 10

      if(iicase.eq.0) then
         ivegas(1) = 50000
         ivegas(2) = 5
         ivegas(3) = 40000
         ivegas(4) = 10
      else
         ivegas(1) = 600000
         ivegas(2) = 5
         ivegas(3) = 24000000
         ivegas(4) = 10
      endif

c ---- initialization of VEGAS ----

      call RSTART(12,34,56,78)

c ---- the off-shell decay Hi->Hj Hk ----
         
      call INTEG(hitohjhk_cnmssm,2,iprint,ivegas,result,relative)

      htohhoff = result

      errhtohhoff = result*relative

cc      print*,'result',result,relative

      return

      end

c -------------------------------------------------------------------- c

      double precision function hitohjhk_cnmssm(dum)

      implicit double precision (a-h,o-z)
      double precision dum(2),lamb

      common/DECPARAMETERSC/ijcase,amhi,amhj,amhk,gamtotj,gamtotk

      lamb(x,y)=dsqrt((1.d0-x-y)**2-4.d0*x*y)
c      lamb(x,y)=((1.d0-x-y)**2-4.d0*x*y)
      pi=4d0*datan(1d0)

c      icase = 0

      if(dabs(amhi-amhj).le.5.D0.or.dabs(amhi-amhk).le.5.D0) then
         eps=1.D-04
      else
         eps=0.D0
      endif

      if(ijcase.eq.0)then
       yy = amhi**2-eps
       y1 = datan((yy-amhj**2)/amhj/gamtotj)
       y2 = -datan((amhj**2)/amhj/gamtotj)
       djac = y1-y2
       t1 = tan(y1*dum(1)+y2*(1.d0-dum(1)))
       sp = amhj**2 + amhj*gamtotj*t1
cc       print*,'val1',sp/amhi**2
       yy = (amhi-dsqrt(sp))**2-eps
       y1 = datan((yy-amhk**2)/amhk/gamtotk)
       y2 = -datan((amhk**2)/amhk/gamtotk)
       djac = djac*(y1-y2)
       t2 = tan(y1*dum(2)+y2*(1.d0-dum(2)))
       sm = amhk**2 + amhk*gamtotk*t2
cc       print*,'val2',sm/amhi**2
       am2=amhi**2
       gam = lamb(sp/am2,sm/am2)
cc       print*,'val3',gam,sp,sm
       pro1 = sp
       pro2 = sm
       hitohjhk_cnmssm = pro1*pro2*gam*djac/pi**2/amhj**2/amhk**2
cc       print*,'val4',hitohjhk_cnmssm,pro1,pro2,gam,djac,pi
      
       else

c ---- the integration limits ----
c --- the x1 integration ---------
      x1m = 0.D0
      x1p = amhi**2
      x1 = (x1p-x1m)*dum(1)+x1m 
      sp = x1
c --- the x2 integration ---------
      x2m = 0.D0
      x2p = (amhi-dsqrt(x1))**2
      x2 = (x2p-x2m)*dum(2)+x2m
      sm = x2

      djac = amhi**2*(amhi-dsqrt(sp))**2/pi**2

      am2=amhi**2
      gam = lamb(sp/am2,sm/am2)
      pro1 = sp*gamtotj*amhj/((sp-amhj**2)**2+amhj**2*gamtotj**2)
      pro2 = sm*gamtotk*amhk/((sm-amhk**2)**2+amhk**2*gamtotk**2)

c      print*,'values',amhi,amhj,amhk,gamtotj,gamtotk
c      print*,'valls',pro1,pro2,gam,djac
c      print*,'vall',x1,amhi**2

      hitohjhk_cnmssm = pro1*pro2*gam*djac/amhj**2/amhk**2

      endif

      return

      end

c -------------------------------------------------------------------- c
C     ************************************************************
C     SUBROUTINE FOR H+ ---> BT* ---> BBW
C     ************************************************************
      subroutine ctott_hdec(amch,amt,amb,amw,tanb,ctt0)
      implicit real*8(a-z)
      integer ip,k
      common/prec1_hdec/ip
      external functt1_hdec
      common/iksy3_hdec/x1,x2,m1,m2,m3,ecm,s
      common/top3_hdec/amh3,amt3,amb3,amw3
      common/top5_hdec/tanb3
      amh3=amch
      amt3=amt
      amb3=amb
      amw3=amw
      tanb3=tanb
      ip=5
      m1=amb
      m2=amb
      m3=amw
c     first integrate over x2, i.e. (1+3) system
c        check whether enough phase space
      mastot=m1+m2+m3
      if(mastot.ge.amch) goto 12
      ecm=amch
      s=ecm**2
      u1=(ecm-m2)**2
      d1=(m1+m3)**2
      u=(s-d1+m2**2)/s
      d=(s-u1+m2**2)/s
      del=(u-d)/ip
      u=d+del
      xsec=0.d0
      do k=1,ip
      call qgaus1_hdec(functt1_hdec,d,u,ss)
      d=u
      u=d+del
      xsec=xsec+ss
      enddo
      ctt0=xsec
12    continue
      return
      end

c -------------------------------------------------------------------- c

      double precision function functt1_hdec(xl)
      implicit real*8(a-z)
      integer ip,i
      common/iksy3_hdec/x1,x2,m1,m2,m3,ecm,s
      common/prec1_hdec/ip
      external functt2_hdec
      x2=xl
      s13=s-s*x2+m2**2
      tem=2.d0*dsqrt(s13)
      e2s=(s-s13-m2**2)/tem
      e3s=(s13+m3**2-m1**2)/tem
c     second integral over x1, i.e. (2+3) system
      u1=(e2s+e3s)**2-(dsqrt(e2s**2-m2**2)-dsqrt(e3s**2-m3**2))**2
      d1=(e2s+e3s)**2-(dsqrt(e2s**2-m2**2)+dsqrt(e3s**2-m3**2))**2
      u=(s-d1+m1**2)/s
      d=(s-u1+m1**2)/s
      del=(u-d)/ip
      functt1_hdec=0.d0
      u=d+del
      do i=1,ip
      call qgaus2_hdec(functt2_hdec,d,u,ss)
      functt1_hdec=functt1_hdec+ss
      d=u
      u=d+del
      enddo
      return
      end

c -------------------------------------------------------------------- c

      double precision function functt2_hdec(xk)
      implicit real*8(a-z)
      common/iksy3_hdec/x1,x2,m1,m2,m3,ecm,s
      x1=xk
      call elemctt_hdec(ss)
      functt2_hdec=ss
      return
      end

c -------------------------------------------------------------------- c

      subroutine elemctt_hdec(res)
      implicit real*8(a-z)
      common/iksy3_hdec/x1,x2,m1,m2,m3,ecm,s
      common/top3_hdec/amch,amt,amb,amw
      common/top5_hdec/tanb
      common/wzwdth_hdec/gamc0,gamt0,gamt1,gamw,gamz
      gamt=gamt1**2*amt**2/amch**4
      w=amw**2/amch**2
      t=amt**2/amch**2
      b=amb**2/amch**2

c ---- with b-quark mass dependence ----
      res=(-2.d0*b*t*tanb**2*(1.d0+w+2.d0*b*w-2.d0*w**2-
     .     (2.d0+w)*x2+x2**2)+t**2*(2.d0*w**2+(-1.d0+x1)*(-1.d0+x2)+
     .     w*(-3.d0-2.d0*b+2.d0*x1+2.d0*x2))+b*tanb**4*(-2.d0*b**2*w-
     .     2.d0*w**2+(-1.d0+x2)**2*(-1.d0+x1+x2)+w*(-1.d0+x2)*
     .     (-3.d0+2.d0*x1+x2)+b*(2.d0*w**2+w*(3.d0-2.d0*x1)-
     .     (-1.d0+x2)*(-3.d0+x1+2.d0*x2))))/((1.d0-x2+b-t)**2+gamt)/t**2

      return
      end

c -------------------------------------------------------------------- c
c   *****************  integration routine ***********************
c    returns ss as integral of func from a to b, by 10-point gauss-
c    legendre integration
      subroutine qgaus1_hdec(func,a,b,ss)
      implicit real*8(a-z)
      integer j
      dimension x(5),w(5)
      external func
      data x/.1488743389d0,.4333953941d0,.6794095682d0
     .  ,.8650633666d0,.9739065285d0/
      data w/.2955242247d0,.2692667193d0,.2190863625d0
     .  ,.1494513491d0,.0666713443d0/
      xm=0.5d0*(b+a)
      xr=0.5d0*(b-a)
      ss=0.d0
      do 11 j=1,5
        dx=xr*x(j)
        ss=ss+w(j)*(func(xm+dx)+func(xm-dx))
11    continue
      ss=xr*ss
      return
      end

c -------------------------------------------------------------------- c
C -- Returns SS as integral of FUNC from A to B, by 10-point Gauss-
C -- Legendre integration

      subroutine qgaus2_hdec(func,a,b,ss)
      implicit real*8(a-z)
      integer j
      dimension x(5),w(5)
      external func
      data x/.1488743389d0,.4333953941d0,.6794095682d0
     .  ,.8650633666d0,.9739065285d0/
      data w/.2955242247d0,.2692667193d0,.2190863625d0
     .  ,.1494513491d0,.0666713443d0/
      xm=0.5d0*(b+a)
      xr=0.5d0*(b-a)
      ss=0.d0
      do 11 j=1,5
        dx=xr*x(j)
        ss=ss+w(j)*(func(xm+dx)+func(xm-dx))
11    continue
      ss=xr*ss
      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE AMHAMA_NMSSM_HDEC(ICASE,MH,TANB)
C--CALCULATION OF PSEUDOSCALAR HIGGS MASS FROM HIGGS MASS MH
C--ICASE=0: MH=PSEUDOSCALAR MASS
c maggie changed 4/9/2011
c--icase=1: mh=light scalar mass h1
c--icase=2: mh=heavy scalar mass h2
c--icase=3: mh=heavy scalar mass h3
c--icase=4: mh=charged Higgs mass
c end maggie changed 4/9/2011
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT REAL*8(A-H,L,M,O-Z)
      DIMENSION VH(2,2),M2(2,2),M2P(2,2)
c maggie changed 4/9/2011
c      COMMON/HMASS_HDEC/AMSM,AMA,AML,AMH,AMCH,AMAR
      COMMON/HMASS_CNMSSM/amh1,amh2,amh3,amh4,amh5,amch,amar
c end maggie changed 4/9/2011
      IF(ICASE.EQ.0)THEN
       MA = MH
      ELSE
       DEL0 = 1.D-4
       MA0 = 1.D0
       MA1 = 1.D4
1      MA = (MA0+MA1)/2
       AMA = MA
c maggie changed 4/9/2011
c       CALL SUSYCP_HDEC(TANB)
       CALL SUSYCP_CNMSSM(TANB)
       if(icase.eq.1)then
        mx = amh1
       elseif(icase.eq.2)then
        mx = amh2
       elseif(icase.eq.3)then
        mx = amh3
       elseif(icase.eq.4)then
        mx = amch
       endif
c end maggie changed 4/9/2011
       DEL = DABS(MA1 - MA0)/MA
       IF(DEL.GT.DEL0) THEN
        IF(MX.GT.MH) MA1 = MA
        IF(MX.LT.MH) MA0 = MA
        GOTO 1
       ENDIF
       FAC = 1
       MAX = DINT(FAC*MA+0.5D0)/FAC
       AMA = MAX
c maggie changed 4/9/2011
c       CALL SUSYCP_HDEC(TANB)
       CALL SUSYCP_CNMSSM(TANB)
       if(icase.eq.1)then
        mx = amh1
       elseif(icase.eq.2)then
        mx = amh2
       elseif(icase.eq.3)then
        mx = amh3
       elseif(icase.eq.4)then
        mx = amch
       endif
c end maggie changed 4/9/2011
       IF(MX.EQ.MH)THEN
        MA = MAX
       ELSE
        DEL0 = 1.D-8
2       MA = (MA0+MA1)/2
        AMA = MA
c maggie changed 4/9/2011
c        CALL SUSYCP_HDEC(TANB)
        CALL SUSYCP_CNMSSM(TANB)
        if(icase.eq.1)then
         mx = amh1
        elseif(icase.eq.2)then
         mx = amh2
        elseif(icase.eq.3)then
         mx = amh3
        elseif(icase.eq.4)then
         mx = amch
        endif
c end maggie changed 4/9/2011
        DEL = DABS(MA1 - MA0)/MA
        IF(DEL.GT.DEL0) THEN
         IF(MX.GT.MH) MA1 = MA
         IF(MX.LT.MH) MA0 = MA
         GOTO 2
        ENDIF
       ENDIF
      ENDIF
      AMA = MA
c maggie changed 4/9/2011
c      CALL SUSYCP_HDEC(TANB)
      CALL SUSYCP_CNMSSM(TANB)
c end maggie changed 4/9/2011
      RETURN
      END

c ======================================================================
c	  chargino and neutralino mass matrices and couplings
c ======================================================================
      subroutine gaugino_cnmssm(mu,m2,b,mc,mn,xmn,ach1,ach2,ach3,ach4,
     .     ach5,aach1,aach2,aach3,aach4,aach5,anh1Rre,anh2Rre,anh3Rre,
     .     anh4Rre,anh5Rre,anh1Rim,anh2Rim,anh3Rim,anh4Rim,anh5Rim,
     .     anh1Lre,anh2Lre,anh3Lre,anh4Lre,anh5Lre,anh1Lim,anh2Lim,
     .     anh3Lim,anh4Lim,anh5Lim,acnl,acnr)

      implicit real*8(a-h,k-z)
      double precision mc(2),mn(5)
      complex*16 ach1,ach2,ach3,ach4,ach5,aach1,aach2,aach3,aach4,
     .     aach5,acnl,acnr
      complex*16 q,s,r
      complex*16 myi
      complex*16 myconjugate_nmssm
      complex*16 achi(5,2,2),aachi(5,2,2)
      dimension xmn(5),z(5,5),zx(5,5),u(2,2),v(2,2)
      dimension zxim(5,5),uim(2,2),vim(2,2)
      dimension ymn(5),yz(5,5)
      dimension slhaneut(5),slhaxneut(5),slhachar(2),slhau(2,2),
     .          slhav(2,2),slhaz(5,5),slhaxchar(2)
      double precision slhauim(2,2),slhavim(2,2),slhazim(5,5)
      dimension q(2,2),s(2,2),r(2,2),qqre(5,5),ssre(5,5),rrre(5,5),
     .     ttre(5,5),uure(5,5),qqim(5,5),ssim(5,5),rrim(5,5),
     .     ttim(5,5),uuim(5,5)
      dimension ach1(2,2),ach2(2,2),ach3(2,2),ach4(2,2),ach5(2,2),
     .     acnl(2,5),acnr(2,5),aach1(2,2),aach2(2,2),aach3(2,2),
     .     aach4(2,2),aach5(2,2),anh1Rre(5,5),anh2Rre(5,5),anh3Rre(5,5),
     .     anh4Rre(5,5),anh5Rre(5,5),anh1Rim(5,5),anh2Rim(5,5),
     .     anh3Rim(5,5),anh4Rim(5,5),anh5Rim(5,5),anh1Lre(5,5),
     .     anh2Lre(5,5),anh3Lre(5,5),anh4Lre(5,5),anh5Lre(5,5),
     .     anh1Lim(5,5),anh2Lim(5,5),anh3Lim(5,5),anh4Lim(5,5),
     .     anh5Lim(5,5)
      dimension anhiRre(5,5,5),anhiLre(5,5,5),anhiRim(5,5,5),
     .     anhiLim(5,5,5)
      dimension slhahmix(5,5)

      COMMON/PARAM_HDEC/gf,alph,amtau,ammuon,mz,mw
      COMMON/GAUGINOMIX_CNMSSM/zx,u,v,zxim,uim,vim
      COMMON/SLHA_VALS_HDEC/islhai,islhao
      COMMON/SLHA_M1_HDEC/am1
      COMMON/SLHA_gaug_CNMSSM/slhaneut,slhaxneut,slhachar,slhau,slhav,
     .                        slhaz,slhaxchar,slhauim,slhavim,slhazim
      COMMON/NMSSMFLAG/inmssm,inmssmhi
      COMMON/EXTPAR_NMSSM/xlambdapar,xkappa,Alam,Akap,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      COMMON/EXTPAR_CNMSSM_IM/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      COMMON/SLHA_hmix_CNMSSM/slhahmix
      COMMON/VEV_NMSSM/vewsb
      COMMON/SHORTCOUPL3_CNMSSM/achi,aachi,anhiRre,anhiLre,anhiRim,
     .     anhiLim

      myi=dcmplx(0.d0,1.d0)
      cw=mw/mz
      sw=dsqrt(1-cw**2)
      pi=4.d0*datan(1.d0)
      vs=dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      sb=dsin(b)
      cb=dcos(b)
      tw=sw/cw
c      if(islhai.eq.0) then
c         m1=5.d0/3.d0*tw**2*m2
c      else
         m1 = am1
c      endif

c ================ neutralino masses and matrix elements ===============
c ======================= masses and couplings =========================

      do i=1,5,1
         xmn(i) = slhaxneut(i)
         mn(i)  = dabs(xmn(i))
         ymn(i) = xmn(i)
         do j=1,5,1
            zx(i,j) = slhaz(i,j)
            zxim(i,j) = slhazim(i,j)
            z(i,j) = zx(i,j)
         end do
         yz(i,1)=zx(i,1)
         yz(i,2)=zx(i,2)
         yz(i,3)=zx(i,3)
         yz(i,4)=zx(i,4)
         yz(i,5)=zx(i,5)
      end do

c ===============  neutralino couplings to Higgs bosons ================
c  g(h neut_i neut_k) = (gLre + I*gLim)*PL + (gRre + I*gRim)*PR

      do i=1,5,1
         do j=1,5,1
            qqre(i,j)=1.d0/2.d0*(z(i,3)*(z(j,2)-tw*z(j,1))+z(j,3)*
     .           (z(i,2)-tw*z(i,1))-zxim(i,3)*(zxim(j,2)-tw*zxim(j,1))-
     .           zxim(j,3)*(zxim(i,2)-tw*zxim(i,1)))-dsqrt(2.d0)*(
     .           xlambdapar*(z(i,5)*z(j,4)+z(j,5)*z(i,4)-zxim(i,5)*
     .           zxim(j,4)-zxim(j,5)*zxim(i,4))+xlambdaparim*
     .           (z(i,5)*zxim(j,4)+zxim(i,5)*z(j,4)+z(j,5)*zxim(i,4)+
     .           zxim(j,5)*z(i,4)))*vewsb/4.d0/mw ! done, for gR
            qqim(i,j)=1.d0/2.d0*(z(i,3)*(zxim(j,2)-tw*zxim(j,1))+z(j,3)*
     .           (zxim(i,2)-tw*zxim(i,1))+zxim(i,3)*(z(j,2)-tw*z(j,1))+
     .           zxim(j,3)*(z(i,2)-tw*z(i,1)))+dsqrt(2.d0)*(
     .           xlambdaparim*(z(i,5)*z(j,4)+z(j,5)*z(i,4)-zxim(i,5)*
     .           zxim(j,4)-zxim(j,5)*zxim(i,4))-xlambdapar*
     .           (z(i,5)*zxim(j,4)+zxim(i,5)*z(j,4)+z(j,5)*zxim(i,4)+
     .           zxim(j,5)*z(i,4)))*vewsb/4.d0/mw ! done, for gR

            ssre(i,j)=1.d0/2.d0*(dcos(xphiu)*(z(i,4)*(z(j,2)-tw*z(j,1))
     .           +z(j,4)*(z(i,2)-tw*z(i,1))-zxim(i,4)*(zxim(j,2)-tw*
     .           zxim(j,1))-zxim(j,4)*(zxim(i,2)-tw*zxim(i,1)))-
     .           dsin(xphiu)*(z(i,4)*(zxim(j,2)-tw*zxim(j,1))+
     .           z(j,4)*(zxim(i,2)-tw*zxim(i,1))+zxim(i,4)*(
     .           z(j,2)-tw*z(j,1))+zxim(j,4)*(z(i,2)-tw*z(i,1))))+
     .           dsqrt(2.d0)*(dcos(xphiu)*(xlambdapar*(z(i,5)*z(j,3)+
     .           z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-zxim(j,5)*zxim(i,3))+
     .           xlambdaparim*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3)))-dsin(xphiu)*(
     .           xlambdaparim*(z(i,5)*z(j,3)+z(j,5)*z(i,3)-zxim(i,5)*
     .           zxim(j,3)-zxim(j,5)*zxim(i,3))-xlambdapar*
     .           (z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*zxim(i,3)+
     .           zxim(j,5)*z(i,3))))*vewsb/4.d0/mw ! done fo gR
            ssim(i,j)=1.d0/2.d0*(dcos(xphiu)*(z(i,4)*(zxim(j,2)-
     .           tw*zxim(j,1))+z(j,4)*(zxim(i,2)-tw*zxim(i,1))+
     .           zxim(i,4)*(z(j,2)-tw*z(j,1))+zxim(j,4)*(z(i,2)-
     .           tw*z(i,1)))+dsin(xphiu)*(z(i,4)*(z(j,2)-tw*z(j,1))
     .           +z(j,4)*(z(i,2)-tw*z(i,1))-zxim(i,4)*(zxim(j,2)-tw*
     .           zxim(j,1))-zxim(j,4)*(zxim(i,2)-tw*zxim(i,1))))-
     .           dsqrt(2.d0)*(dcos(xphiu)*(xlambdaparim*(z(i,5)*z(j,3)+
     .           z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-zxim(j,5)*zxim(i,3))-
     .           xlambdapar*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3)))+dsin(xphiu)*(
     .           xlambdaparim*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3))+xlambdapar*
     .           (z(i,5)*z(j,3)+z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-
     .           zxim(j,5)*zxim(i,3))))*vewsb/4.d0/mw ! done for gR

            rrre(i,j)=1.d0/2.d0/mw/vs*vewsb*
     .           (xlamvs*(z(i,4)*z(j,3)+z(j,4)*z(i,3)-zxim(i,4)*
     .           zxim(j,3)-zxim(j,4)*zxim(i,3))+xlamvsim*
     .           (z(i,4)*zxim(j,3)+zxim(i,4)*z(j,3)+z(j,4)*zxim(i,3)+
     .           zxim(j,4)*z(i,3))-2.d0*(
     .           (z(i,5)*z(j,5)-zxim(i,5)*zxim(j,5))*
     .           (xlamvs*(xlambdapar*xkappa+xlambdaparim*xkappaim)+
     .           xlamvsim*(xlambdaparim*xkappa-xlambdapar*xkappaim))-
     .           (z(i,5)*zxim(j,5)+zxim(i,5)*z(j,5))*
     .           (xlamvs*(xlambdaparim*xkappa-xlambdapar*xkappaim)-
     .           xlamvsim*(xlambdapar*xkappa+xlambdaparim*xkappaim))
     .           )/(xlambdapar**2+xlambdaparim**2)) ! done for gR
            rrim(i,j)=1.d0/2.d0/mw/vs*vewsb*
     .           (xlamvs*(z(i,4)*zxim(j,3)+z(j,4)*zxim(i,3)+zxim(i,4)*
     .           z(j,3)+zxim(j,4)*z(i,3))-xlamvsim*
     .           (z(i,4)*z(j,3)+z(j,4)*z(i,3)-zxim(i,4)*zxim(j,3)-
     .           zxim(j,4)*zxim(i,3))-2.d0*(
     .           (z(i,5)*z(j,5)-zxim(i,5)*zxim(j,5))*
     .           (xlamvs*(xlambdaparim*xkappa-xlambdapar*xkappaim)-
     .           xlamvsim*(xlambdapar*xkappa+xlambdaparim*xkappaim))+
     .           (z(i,5)*zxim(j,5)+zxim(i,5)*z(j,5))*
     .           (xlamvs*(xlambdapar*xkappa+xlambdaparim*xkappaim)+
     .           xlamvsim*(xlambdaparim*xkappa-xlambdapar*xkappaim))
     .           )/(xlambdapar**2+xlambdaparim**2)) ! done for gR

            ttre(i,j)=dcos(b)*(
     .           1.d0/2.d0*(dcos(xphiu)*(z(i,4)*(zxim(j,2)-
     .           tw*zxim(j,1))+z(j,4)*(zxim(i,2)-tw*zxim(i,1))+
     .           zxim(i,4)*(z(j,2)-tw*z(j,1))+zxim(j,4)*(z(i,2)-
     .           tw*z(i,1)))+dsin(xphiu)*(z(i,4)*(z(j,2)-tw*z(j,1))
     .           +z(j,4)*(z(i,2)-tw*z(i,1))-zxim(i,4)*(zxim(j,2)-tw*
     .           zxim(j,1))-zxim(j,4)*(zxim(i,2)-tw*zxim(i,1))))+
     .           dsqrt(2.d0)*(dcos(xphiu)*(xlambdaparim*(z(i,5)*z(j,3)+
     .           z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-zxim(j,5)*zxim(i,3))-
     .           xlambdapar*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3)))+dsin(xphiu)*(
     .           xlambdaparim*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3))+xlambdapar*
     .           (z(i,5)*z(j,3)+z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-
     .           zxim(j,5)*zxim(i,3))))*vewsb/4.d0/mw)-dsin(b)*(
     .           1.d0/2.d0*(z(i,3)*(zxim(j,2)-tw*zxim(j,1))+z(j,3)*
     .           (zxim(i,2)-tw*zxim(i,1))+zxim(i,3)*(z(j,2)-tw*z(j,1))+
     .           zxim(j,3)*(z(i,2)-tw*z(i,1)))-dsqrt(2.d0)*(
     .           xlambdaparim*(z(i,5)*z(j,4)+z(j,5)*z(i,4)-zxim(i,5)*
     .           zxim(j,4)-zxim(j,5)*zxim(i,4))-xlambdapar*
     .           (z(i,5)*zxim(j,4)+zxim(i,5)*z(j,4)+z(j,5)*zxim(i,4)+
     .           zxim(j,5)*z(i,4)))*vewsb/4.d0/mw) ! done for gR
            ttim(i,j)=dsin(b)*(
     .           1.d0/2.d0*(z(i,3)*(z(j,2)-tw*z(j,1))+z(j,3)*
     .           (z(i,2)-tw*z(i,1))-zxim(i,3)*(zxim(j,2)-tw*zxim(j,1))-
     .           zxim(j,3)*(zxim(i,2)-tw*zxim(i,1)))+dsqrt(2.d0)*(
     .           xlambdapar*(z(i,5)*z(j,4)+z(j,5)*z(i,4)-zxim(i,5)*
     .           zxim(j,4)-zxim(j,5)*zxim(i,4))+xlambdaparim*
     .           (z(i,5)*zxim(j,4)+zxim(i,5)*z(j,4)+z(j,5)*zxim(i,4)+
     .           zxim(j,5)*z(i,4)))*vewsb/4.d0/mw)-dcos(b)*(
     .           1.d0/2.d0*(dcos(xphiu)*(z(i,4)*(z(j,2)-tw*z(j,1))
     .           +z(j,4)*(z(i,2)-tw*z(i,1))-zxim(i,4)*(zxim(j,2)-tw*
     .           zxim(j,1))-zxim(j,4)*(zxim(i,2)-tw*zxim(i,1)))-
     .           dsin(xphiu)*(z(i,4)*(zxim(j,2)-tw*zxim(j,1))+
     .           z(j,4)*(zxim(i,2)-tw*zxim(i,1))+zxim(i,4)*(
     .           z(j,2)-tw*z(j,1))+zxim(j,4)*(z(i,2)-tw*z(i,1))))-
     .           dsqrt(2.d0)*(dcos(xphiu)*(xlambdapar*(z(i,5)*z(j,3)+
     .           z(j,5)*z(i,3)-zxim(i,5)*zxim(j,3)-zxim(j,5)*zxim(i,3))+
     .           xlambdaparim*(z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*
     .           zxim(i,3)+zxim(j,5)*z(i,3)))-dsin(xphiu)*(
     .           xlambdaparim*(z(i,5)*z(j,3)+z(j,5)*z(i,3)-zxim(i,5)*
     .           zxim(j,3)-zxim(j,5)*zxim(i,3))-xlambdapar*
     .           (z(i,5)*zxim(j,3)+zxim(i,5)*z(j,3)+z(j,5)*zxim(i,3)+
     .           zxim(j,5)*z(i,3))))*vewsb/4.d0/mw) ! done for gR

            uure(i,j)=(-1.d0)/2.d0/mw/vs*vewsb* ! to be simplified
     .           (xlamvs*(z(i,4)*zxim(j,3)+z(j,4)*zxim(i,3)+zxim(i,4)*
     .           z(j,3)+zxim(j,4)*z(i,3))-xlamvsim*
     .           (z(i,4)*z(j,3)+z(j,4)*z(i,3)-zxim(i,4)*zxim(j,3)-
     .           zxim(j,4)*zxim(i,3))-2.d0*(
     .           xkappa*xlambdaparim*xlamvs*z(i,5)*z(j,5) -
     .           xkappaim*xlambdapar*xlamvs*z(i,5)*z(j,5) - 
     .           xkappa*xlambdapar*xlamvsim*z(i,5)*z(j,5) - 
     .           xkappaim*xlambdaparim*xlamvsim*z(i,5)*z(j,5) + 
     .           xkappa*xlambdapar*xlamvs*zxim(i,5)*z(j,5) + 
     .           xkappaim*xlambdaparim*xlamvs*zxim(i,5)*z(j,5) - 
     .           xkappaim*xlambdapar*xlamvsim*zxim(i,5)*z(j,5) + 
     .           xkappa*xlambdaparim*xlamvsim*zxim(i,5)*z(j,5) + 
     .           xkappa*xlambdapar*xlamvs*z(i,5)*zxim(j,5) + 
     .           xkappaim*xlambdaparim*xlamvs*z(i,5)*zxim(j,5) - 
     .           xkappaim*xlambdapar*xlamvsim*z(i,5)*zxim(j,5) + 
     .           xkappa*xlambdaparim*xlamvsim*z(i,5)*zxim(j,5) + 
     .           xkappaim*xlambdapar*xlamvs*zxim(i,5)*zxim(j,5) - 
     .           xkappa*xlambdaparim*xlamvs*zxim(i,5)*zxim(j,5) + 
     .           xkappa*xlambdapar*xlamvsim*zxim(i,5)*zxim(j,5) + 
     .           xkappaim*xlambdaparim*xlamvsim*zxim(i,5)*zxim(j,5))/
     .           (xlambdapar**2+xlambdaparim**2)) ! done for gR
            uuim(i,j)=1.d0/2.d0/mw/vs*vewsb*
     .           (xlamvs*(z(i,4)*z(j,3)+z(j,4)*z(i,3)-zxim(i,4)*
     .           zxim(j,3)-zxim(j,4)*zxim(i,3))+xlamvsim*
     .           (z(i,4)*zxim(j,3)+zxim(i,4)*z(j,3)+z(j,4)*zxim(i,3)+
     .           zxim(j,4)*z(i,3))-2.d0*(
     .           xkappa*xlambdapar*xlamvs*z(i,5)*z(j,5) + 
     .           xkappaim*xlambdaparim*xlamvs*z(i,5)*z(j,5) - 
     .           xkappaim*xlambdapar*xlamvsim*z(i,5)*z(j,5) + 
     .           xkappa*xlambdaparim*xlamvsim*z(i,5)*z(j,5) + 
     .           xkappaim*xlambdapar*xlamvs*zxim(i,5)*z(j,5) - 
     .           xkappa*xlambdaparim*xlamvs*zxim(i,5)*z(j,5) + 
     .           xkappa*xlambdapar*xlamvsim*zxim(i,5)*z(j,5) + 
     .           xkappaim*xlambdaparim*xlamvsim*zxim(i,5)*z(j,5) + 
     .           xkappaim*xlambdapar*xlamvs*z(i,5)*zxim(j,5) - 
     .           xkappa*xlambdaparim*xlamvs*z(i,5)*zxim(j,5) + 
     .           xkappa*xlambdapar*xlamvsim*z(i,5)*zxim(j,5) + 
     .           xkappaim*xlambdaparim*xlamvsim*z(i,5)*zxim(j,5) - 
     .           xkappa*xlambdapar*xlamvs*zxim(i,5)*zxim(j,5) - 
     .           xkappaim*xlambdaparim*xlamvs*zxim(i,5)*zxim(j,5) + 
     .           xkappaim*xlambdapar*xlamvsim*zxim(i,5)*zxim(j,5) - 
     .           xkappa*xlambdaparim*xlamvsim*zxim(i,5)*zxim(j,5))/
     .           (xlambdapar**2+xlambdaparim**2)) ! done for gR
         end do
      end do

      do i=1,5,1
         do j=1,5,1
            anh1Rre(i,j)=slhahmix(1,1)*qqre(i,j)-slhahmix(1,2)*
     .           ssre(i,j)-slhahmix(1,3)*rrre(i,j)+ttre(i,j)*
     .           slhahmix(1,4)+uure(i,j)*slhahmix(1,5)
            anh1Rim(i,j)=slhahmix(1,1)*qqim(i,j)-slhahmix(1,2)*
     .           ssim(i,j)-slhahmix(1,3)*rrim(i,j)+ttim(i,j)*
     .           slhahmix(1,4)+uuim(i,j)*slhahmix(1,5)
            anh2Rre(i,j)=slhahmix(2,1)*qqre(i,j)-slhahmix(2,2)*
     .           ssre(i,j)-slhahmix(2,3)*rrre(i,j)+ttre(i,j)*
     .           slhahmix(2,4)+uure(i,j)*slhahmix(2,5)
            anh2Rim(i,j)=slhahmix(2,1)*qqim(i,j)-slhahmix(2,2)*
     .           ssim(i,j)-slhahmix(2,3)*rrim(i,j)+ttim(i,j)*
     .           slhahmix(2,4)+uuim(i,j)*slhahmix(2,5)
            anh3Rre(i,j)=slhahmix(3,1)*qqre(i,j)-slhahmix(3,2)*
     .           ssre(i,j)-slhahmix(3,3)*rrre(i,j)+ttre(i,j)*
     .           slhahmix(3,4)+uure(i,j)*slhahmix(3,5)
            anh3Rim(i,j)=slhahmix(3,1)*qqim(i,j)-slhahmix(3,2)*
     .           ssim(i,j)-slhahmix(3,3)*rrim(i,j)+ttim(i,j)*
     .           slhahmix(3,4)+uuim(i,j)*slhahmix(3,5)
            anh4Rre(i,j)=slhahmix(4,1)*qqre(i,j)-slhahmix(4,2)*
     .           ssre(i,j)-slhahmix(4,3)*rrre(i,j)+ttre(i,j)*
     .           slhahmix(4,4)+uure(i,j)*slhahmix(4,5)
            anh4Rim(i,j)=slhahmix(4,1)*qqim(i,j)-slhahmix(4,2)*
     .           ssim(i,j)-slhahmix(4,3)*rrim(i,j)+ttim(i,j)*
     .           slhahmix(4,4)+uuim(i,j)*slhahmix(4,5)
            anh5Rre(i,j)=slhahmix(5,1)*qqre(i,j)-slhahmix(5,2)*
     .           ssre(i,j)-slhahmix(5,3)*rrre(i,j)+ttre(i,j)*
     .           slhahmix(5,4)+uure(i,j)*slhahmix(5,5)
            anh5Rim(i,j)=slhahmix(5,1)*qqim(i,j)-slhahmix(5,2)*
     .           ssim(i,j)-slhahmix(5,3)*rrim(i,j)+ttim(i,j)*
     .           slhahmix(5,4)+uuim(i,j)*slhahmix(5,5)

            anh1Lre(i,j)=anh1Rre(i,j)
            anh1Lim(i,j)=-1.d0*anh1Rim(i,j)
            anh2Lre(i,j)=anh2Rre(i,j)
            anh2Lim(i,j)=-1.d0*anh2Rim(i,j)
            anh3Lre(i,j)=anh3Rre(i,j)
            anh3Lim(i,j)=-1.d0*anh3Rim(i,j)
            anh4Lre(i,j)=anh4Rre(i,j)
            anh4Lim(i,j)=-1.d0*anh4Rim(i,j)
            anh5Lre(i,j)=anh5Rre(i,j)
            anh5Lim(i,j)=-1.d0*anh5Rim(i,j)
         end do
      end do

      do j=1,5,1
         do ik=1,5,1
            anhiRre(1,j,ik) = anh1Rre(j,ik)
            anhiLre(1,j,ik) = anh1Rre(j,ik)
            anhiRim(1,j,ik) = anh1Rim(j,ik)
            anhiLim(1,j,ik) = -1.d0*anh1Rim(j,ik)

            anhiRre(2,j,ik) = anh2Rre(j,ik)
            anhiLre(2,j,ik) = anh2Rre(j,ik)
            anhiRim(2,j,ik) = anh2Rim(j,ik)
            anhiLim(2,j,ik) = -1.d0*anh2Rim(j,ik)

            anhiRre(3,j,ik) = anh3Rre(j,ik)
            anhiLre(3,j,ik) = anh3Rre(j,ik)
            anhiRim(3,j,ik) = anh3Rim(j,ik)
            anhiLim(3,j,ik) = -1.d0*anh3Rim(j,ik)

            anhiRre(4,j,ik) = anh4Rre(j,ik)
            anhiLre(4,j,ik) = anh4Rre(j,ik)
            anhiRim(4,j,ik) = anh4Rim(j,ik)
            anhiLim(4,j,ik) = -1.d0*anh4Rim(j,ik)

            anhiRre(5,j,ik) = anh5Rre(j,ik)
            anhiLre(5,j,ik) = anh5Rre(j,ik)
            anhiRim(5,j,ik) = anh5Rim(j,ik)
            anhiLim(5,j,ik) = -1.d0*anh5Rim(j,ik)
         end do
      end do

c ================ chargino masses and matrix elements =============== c

      mc(1) = slhachar(1)
      mc(2) = slhachar(2)
      do i=1,2,1
         do j=1,2,1
            u(i,j) = slhau(i,j)
            uim(i,j) = slhauim(i,j)
            v(i,j) = slhav(i,j)
            vim(i,j) = slhavim(i,j)
         end do
      end do
      
c ================= chargino couplings to Higgs bosons =================
c julien modified 20/01/12

      do i=1,2,1
         do j=1,2,1
            q(i,j)=dsqrt(1.d0/2.d0)*(u(j,2)*v(i,1)-uim(j,2)*vim(i,1)+
     .           myi*(u(j,2)*vim(i,1)+uim(j,2)*v(i,1)))
            s(i,j)=dsqrt(1.d0/2.d0)*(dcos(xphiu)*(u(j,1)*v(i,2)-
     .           uim(j,1)*vim(i,2))-dsin(xphiu)*(uim(j,1)*v(i,2)+
     .           u(j,1)*vim(i,2))+myi*(dcos(xphiu)*(u(j,1)*vim(i,2)+
     .           uim(j,1)*v(i,2))+dsin(xphiu)*(u(j,1)*v(i,2)-
     .           uim(j,1)*vim(i,2))))
            r(i,j)=(xlamvs*(u(j,2)*v(i,2)-uim(j,2)*vim(i,2))+
     .           xlamvsim*(u(j,2)*vim(i,2)+uim(j,2)*v(i,2))+myi*(
     .           xlamvs*(u(j,2)*vim(i,2)+uim(j,2)*v(i,2))-
     .           xlamvsim*(u(j,2)*v(i,2)-uim(j,2)*vim(i,2))))*
     .           vewsb/vs/mw/2.d0
         enddo
      enddo

c --- g(cha cha higgs)= ach + gamma5* aach --- c

      do i=1,2,1
         do j=1,2,1
            ach1(i,j)=slhahmix(1,1)*(myconjugate_nmssm(q(i,j))+q(j,i))+
     .           slhahmix(1,2)*(myconjugate_nmssm(s(i,j))+s(j,i))+
     .           slhahmix(1,3)*(myconjugate_nmssm(r(i,j))+r(j,i))-
     .           myi*slhahmix(1,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           -s(j,i))+sb*(myconjugate_nmssm(q(i,j))-q(j,i)))+
     .           myi*slhahmix(1,5)*(myconjugate_nmssm(r(i,j))-r(j,i))
            aach1(i,j)=slhahmix(1,1)*(q(j,i)-myconjugate_nmssm(q(i,j)))+
     .           slhahmix(1,2)*(s(j,i)-myconjugate_nmssm(s(i,j)))+
     .           slhahmix(1,3)*(r(j,i)-myconjugate_nmssm(r(i,j)))+
     .           myi*slhahmix(1,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           +s(j,i))+sb*(myconjugate_nmssm(q(i,j))+q(j,i)))-
     .           myi*slhahmix(1,5)*(myconjugate_nmssm(r(i,j))+r(j,i))
            ach2(i,j)=slhahmix(2,1)*(myconjugate_nmssm(q(i,j))+q(j,i))+
     .           slhahmix(2,2)*(myconjugate_nmssm(s(i,j))+s(j,i))+
     .           slhahmix(2,3)*(myconjugate_nmssm(r(i,j))+r(j,i))-
     .           myi*slhahmix(2,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           -s(j,i))+sb*(myconjugate_nmssm(q(i,j))-q(j,i)))+
     .           myi*slhahmix(2,5)*(myconjugate_nmssm(r(i,j))-r(j,i))
            aach2(i,j)=slhahmix(2,1)*(q(j,i)-myconjugate_nmssm(q(i,j)))+
     .           slhahmix(2,2)*(s(j,i)-myconjugate_nmssm(s(i,j)))+
     .           slhahmix(2,3)*(r(j,i)-myconjugate_nmssm(r(i,j)))+
     .           myi*slhahmix(2,4)*(cb*(myconjugate_nmssm(s(i,j))+
     .           s(j,i))+sb*(myconjugate_nmssm(q(i,j))+q(j,i)))-
     .           myi*slhahmix(2,5)*(myconjugate_nmssm(r(i,j))+r(j,i))
            ach3(i,j)=slhahmix(3,1)*(myconjugate_nmssm(q(i,j))+q(j,i))+
     .           slhahmix(3,2)*(myconjugate_nmssm(s(i,j))+s(j,i))+
     .           slhahmix(3,3)*(myconjugate_nmssm(r(i,j))+r(j,i))-
     .           myi*slhahmix(3,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           -s(j,i))+sb*(myconjugate_nmssm(q(i,j))-q(j,i)))+
     .           myi*slhahmix(3,5)*(myconjugate_nmssm(r(i,j))-r(j,i))
            aach3(i,j)=slhahmix(3,1)*(q(j,i)-myconjugate_nmssm(q(i,j)))+
     .           slhahmix(3,2)*(s(j,i)-myconjugate_nmssm(s(i,j)))+
     .           slhahmix(3,3)*(r(j,i)-myconjugate_nmssm(r(i,j)))+
     .           myi*slhahmix(3,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           +s(j,i))+sb*(myconjugate_nmssm(q(i,j))+q(j,i)))-
     .           myi*slhahmix(3,5)*(myconjugate_nmssm(r(i,j))+r(j,i))
            ach4(i,j)=slhahmix(4,1)*(myconjugate_nmssm(q(i,j))+q(j,i))+
     .           slhahmix(4,2)*(myconjugate_nmssm(s(i,j))+s(j,i))+
     .           slhahmix(4,3)*(myconjugate_nmssm(r(i,j))+r(j,i))-
     .           myi*slhahmix(4,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           -s(j,i))+sb*(myconjugate_nmssm(q(i,j))-q(j,i)))+
     .           myi*slhahmix(4,5)*(myconjugate_nmssm(r(i,j))-r(j,i))
            aach4(i,j)=slhahmix(4,1)*(q(j,i)-myconjugate_nmssm(q(i,j)))+
     .           slhahmix(4,2)*(s(j,i)-myconjugate_nmssm(s(i,j)))+
     .           slhahmix(4,3)*(r(j,i)-myconjugate_nmssm(r(i,j)))+
     .           myi*slhahmix(4,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           +s(j,i))+sb*(myconjugate_nmssm(q(i,j))+q(j,i)))-
     .           myi*slhahmix(4,5)*(myconjugate_nmssm(r(i,j))+r(j,i))
            ach5(i,j)=slhahmix(5,1)*(myconjugate_nmssm(q(i,j))+q(j,i))+
     .           slhahmix(5,2)*(myconjugate_nmssm(s(i,j))+s(j,i))+
     .           slhahmix(5,3)*(myconjugate_nmssm(r(i,j))+r(j,i))-
     .           myi*slhahmix(5,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           -s(j,i))+sb*(myconjugate_nmssm(q(i,j))-q(j,i)))+
     .           myi*slhahmix(5,5)*(myconjugate_nmssm(r(i,j))-r(j,i))
            aach5(i,j)=slhahmix(5,1)*(q(j,i)-myconjugate_nmssm(q(i,j)))+
     .           slhahmix(5,2)*(s(j,i)-myconjugate_nmssm(s(i,j)))+
     .           slhahmix(5,3)*(r(j,i)-myconjugate_nmssm(r(i,j)))+
     .           myi*slhahmix(5,4)*(cb*(myconjugate_nmssm(s(i,j))
     .           +s(j,i))+sb*(myconjugate_nmssm(q(i,j))+q(j,i)))-
     .           myi*slhahmix(5,5)*(myconjugate_nmssm(r(i,j))+r(j,i))
         enddo
      enddo

      do j=1,2,1
         do ik=1,2,1
            achi(1,j,ik) = ach1(j,ik)
            achi(2,j,ik) = ach2(j,ik)
            achi(3,j,ik) = ach3(j,ik)
            achi(4,j,ik) = ach4(j,ik)
            achi(5,j,ik) = ach5(j,ik)

            aachi(1,j,ik) = aach1(j,ik)
            aachi(2,j,ik) = aach2(j,ik)
            aachi(3,j,ik) = aach3(j,ik)
            aachi(4,j,ik) = aach4(j,ik)
            aachi(5,j,ik) = aach5(j,ik)
         end do
      end do

c ======= chargino-neutralino couplings to charged Higgs bosons ====== c
      do i=1,2,1
         do j=1,5,1
            acnl(i,j)=dcos(xphiu)*dcos(b)
     . 		 *(-z(j,4)*v(i,1)+zxim(j,4)*
     .           vim(i,1)+((-z(j,2)-z(j,1)*tw)*v(i,2)+(zxim(j,2)+
     .           zxim(j,1)*tw)*vim(i,2))/dsqrt(2.d0))+dsin(xphiu)*
     .           dcos(b)*
     .		 (z(j,4)*vim(i,1)+zxim(j,4)*v(i,1)+
     .           ((z(j,2)+z(j,1)*tw)*vim(i,2)+(zxim(j,2)+zxim(j,1)*tw)*
     .           v(i,2))/dsqrt(2.d0))-
     .           (xlambdapar*(z(j,5)*v(i,2)-zxim(j,5)*vim(i,2))+
     .           xlambdaparim*(z(j,5)*vim(i,2)+zxim(j,5)*v(i,2)))*
     .           dsin(b)*vewsb/2.d0/mw-myi*(
     .           dsin(xphiu)*dcos(b)*
     .		 (-z(j,4)*v(i,1)+zxim(j,4)*
     .           vim(i,1)+((-z(j,2)-z(j,1)*tw)*v(i,2)+(zxim(j,2)+
     .           zxim(j,1)*tw)*vim(i,2))/dsqrt(2.d0))+dcos(xphiu)*
     .           dcos(b)*
     .		 (-z(j,4)*vim(i,1)-zxim(j,4)*v(i,1)+
     .           ((-z(j,2)-z(j,1)*tw)*vim(i,2)+(-zxim(j,2)
     .		 -zxim(j,1)*tw)*
     .           v(i,2))/dsqrt(2.d0))-
     .           (xlambdapar*(z(j,5)*vim(i,2)+zxim(j,5)*v(i,2))-
     .           xlambdaparim*(z(j,5)*v(i,2)-zxim(j,5)*vim(i,2)))*
     .           dsin(b)*vewsb/2.d0/mw) !checked by ramona 8/5/13

            acnr(i,j)=-dsin(b)*(z(j,3)*u(i,1)-zxim(j,3)*uim(i,1)-
     .           ((z(j,2)+z(j,1)*tw)*u(i,2)-(zxim(j,2)+zxim(j,1)*tw)*
     .           uim(i,2))/dsqrt(2.d0))-dcos(b)*vewsb/2.d0/mw*
     .		 ((xlambdapar*dcos(xphiu)-
     .           xlambdaparim*dsin(xphiu))*(u(i,2)*z(j,5)-uim(i,2)*
     .           zxim(j,5))+(xlambdapar*dsin(xphiu)+xlambdaparim*
     .           dcos(xphiu))*(u(i,2)*zxim(j,5)+uim(i,2)*z(j,5)))-myi*(
     .           dsin(b)*(z(j,3)*uim(i,1)+zxim(j,3)*u(i,1)-
     .           ((z(j,2)+z(j,1)*tw)*uim(i,2)+(zxim(j,2)+zxim(j,1)*tw)*
     .           u(i,2))/dsqrt(2.d0))-dcos(b)*vewsb/2.d0/mw*
     .		 ((xlambdapar*dsin(xphiu)+
     .           xlambdaparim*dcos(xphiu))*(u(i,2)*z(j,5)-uim(i,2)*
     .           zxim(j,5))-(xlambdapar*dcos(xphiu)-xlambdaparim*
     .           dsin(xphiu))*(u(i,2)*zxim(j,5)+uim(i,2)*z(j,5))))
         enddo
      enddo

      return
      end

c -------------------------------------------------------------------- c

      complex*16 function myconjugate_nmssm(myz)
      
      implicit none
      complex*16 myz,myRe,myIm,myI
      myI=dcmplx(0.d0,1.d0)
      myRe=dreal(myz)
      myIm=dreal(myI*myz)

      myconjugate_nmssm=myRe+myI*myIm

      end function

c ==================================================================== c
c         subroutine for sfermion masses, mixing and couplings 
c ==================================================================== c

      subroutine sfermion_cnmssm(mst,msb,msl,msu,msd,mse,msn,msnl,gh1ee,
     .     gh1tt,gh1bb,gh1elel,gh1nene,gh1uu,gh1dd,gh2ee,gh2tt,gh2bb,
     .     gh2elel,gh2nene,gh2uu,gh2dd,gh3ee,gh3tt,gh3bb,gh3elel,
     .     gh3nene,gh3uu,gh3dd,gh4ee,gh4tt,gh4bb,gh4elel,gh4nene,gh4uu,
     .     gh4dd,gh5ee,gh5tt,gh5bb,gh5elel,gh5nene,gh5uu,gh5dd,ghcen,
     .     ghctb,ghcelne,ghcud,al,at,ab,alim,atim,abim,aphiu)

      implicit real*8(a-h,k-z)
      complex*16 ghcen,ghctb,ghcelne,ghcud,gh1elel,
     .     gh1nene,gh1uu,gh1dd,gh1ee,gh1tt,
     .     gh1bb,gh2elel,gh2nene,gh2uu,gh2dd,
     .     gh2ee,gh2tt,gh2bb,gh3elel,gh3nene,
     .     gh3uu,gh3dd,gh3ee,gh3tt,gh3bb,
     .     gh4elel,gh4nene,gh4uu,gh4dd,gh4ee,
     .     gh4tt,gh4bb,gh5elel,gh5nene,gh5uu,
     .     gh5dd,gh5ee,gh5tt,gh5bb
      complex*16 yh1tt,yh1bb,yh2tt,yh2bb,yh3tt,yh3bb,
     .     yh4tt,yh4bb,yh5tt,yh5bb
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      complex*16 myi
      double precision slhastmix(2,2),slhasbmix(2,2),slhastaumix(2,2),
     .                 slhastmixim(2,2),slhasbmixim(2,2),
     .                 slhastaumixim(2,2)
      complex*16 ghitt(5,2,2),ghibb(5,2,2),ghiee(5,2,2),
     .     ghiuu(5,2,2),ghidd(5,2,2),ghielel(5,2,2),ghinene(5,2,2)
      dimension mst(2),msb(2),msl(2),msu(2),msd(2),mse(2),msn(2),
     .     msnl(2),
     .     ghcen(2,2),ghctb(2,2),ghcelne(2,2),ghcud(2,2),gh1elel(2,2),
     .     gh1nene(2,2),gh1uu(2,2),gh1dd(2,2),gh1ee(2,2),gh1tt(2,2),
     .     gh1bb(2,2),gh2elel(2,2),gh2nene(2,2),gh2uu(2,2),gh2dd(2,2),
     .     gh2ee(2,2),gh2tt(2,2),gh2bb(2,2),gh3elel(2,2),gh3nene(2,2),
     .     gh3uu(2,2),gh3dd(2,2),gh3ee(2,2),gh3tt(2,2),gh3bb(2,2),
     .     gh4elel(2,2),gh4nene(2,2),gh4uu(2,2),gh4dd(2,2),gh4ee(2,2),
     .     gh4tt(2,2),gh4bb(2,2),gh5elel(2,2),gh5nene(2,2),gh5uu(2,2),
     .     gh5dd(2,2),gh5ee(2,2),gh5tt(2,2),gh5bb(2,2)
      dimension slhast(2),slhasb(2),slhasu(2),slhasd(2),slhase(2),
     .          slhasl(2),slhasn(2),slhasnl(2)
      dimension slhahmix(5,5)

      COMMON/GLUINO_CNMSSM/amgluino,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      COMMON/SLHA_sfer_CNMSSM/slhast,slhasb,slhasu,slhasd,slhase,slhasl,
     .                 slhasn,slhasnl,slhastmix,slhasbmix,slhastaumix,
     .                 slhastmixim,slhasbmixim,slhastaumixim
      COMMON/SQUARKHIGGS_HDEC/THEB,AMG,JONSH,JDTH
      COMMON/SQNLO_CNMSSM/ymsb(2),ysbmix(2,2),ysbmixim(2,2),yh1bb(2,2),
     .     yh2bb(2,2),yh3bb(2,2),yh4bb(2,2),yh5bb(2,2),ymst(2),
     .     ystmix(2,2),ystmixim(2,2),yh1tt(2,2),yh2tt(2,2),yh3tt(2,2),
     .     yh4tt(2,2),yh5tt(2,2)
      COMMON/BREAKSCALE_HDEC/SUSYSCALE
      COMMON/COUP_CNMSSM/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      COMMON/SHORTCOUPL1_CNMSSM/ghitt,ghibb,ghiee,ghiuu,ghidd,ghielel,
     .     ghinene
      COMMON/SLHA_hmix_CNMSSM/slhahmix
      COMMON/EXTPAR_NMSSM/xlambdapar,xkappa,Alam,Akap,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      COMMON/EXTPAR_CNMSSM_IM/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      COMMON/VEV_NMSSM/vewsb
      COMMON/PARAM_HDEC/gf,alph,amtau,ammuon,amz,amw
      COMMON/MASSES_HDEC/AMS,AMC,AMB,AMT

      tb=dtan(b)

      amg = amgluino
      v = vewsb
      vs=dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      sw2 = 1.D0-amw**2/amz**2

      mt = amt
      mb = amb
      ml = amtau

      mw = amw
      mz = amz

      myi = dcmplx(0.d0,1.d0)

c -- sfermion masses and mixing angles --

      do i=1,2,1
         msu(i) = slhasu(i)
         msd(i) = slhasd(i)
         mse(i) = slhase(i)
         msn(i) = slhasn(i)
         msnl(i) = slhasnl(i)
         mst(i) = slhast(i)
         msb(i) = slhasb(i)
         msl(i) = slhasl(i)
      end do

c --- the NMSSM Higgs sfermion sfermion couplings --- c

      gh1tt(1,1)=(slhastmix(1,1)**2+slhastmixim(1,1)**2+
     .     slhastmix(1,2)**2+slhastmixim(1,2)**2)*
     .     mt**2/mz**2*slhahmix(1,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (0.5d0*(slhastmix(1,1)**2+slhastmixim(1,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(1,1)**2+slhastmixim(1,1)**2-slhastmix(1,2)**2-
     .     slhastmixim(1,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(1,1)*
     .     slhastmix(1,2)+slhastmixim(1,1)*slhastmixim(1,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(1,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(1,4)-
     .     (xlamvs*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(1,4)+
     .     v*dcos(b)*slhahmix(1,5)))/vs)-
c
     .     (slhastmix(1,1)*slhastmixim(1,2)-slhastmixim(1,1)*
     .     slhastmix(1,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(1,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(1,2)+(xlamvsim*(vs*slhahmix(1,1)+
     .     v*dcos(b)*slhahmix(1,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+
     .     v*dcos(b)*slhahmix(1,5)))/vs))

      gh1tt(1,2)=mt**2*slhahmix(1,2)*(slhastmix(1,1)*slhastmix(2,1)+
     .     slhastmixim(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmix(2,2)+slhastmixim(1,2)*slhastmixim(2,2)+myi*
     .     (slhastmix(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmixim(2,2)-slhastmixim(1,1)*slhastmix(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(0.5d0*
     .     (slhastmix(1,1)*slhastmix(2,1)+slhastmixim(1,1)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmixim(1,1)*slhastmix(2,1)))-2.d0*sw2*(slhastmix(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmix(2,2)-slhastmixim(1,2)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmixim(2,2)-slhastmixim(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,2)*slhastmix(2,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(1,1)*slhastmix(2,2)+slhastmixim(1,1)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,2)-
     .     slhastmixim(1,1)*slhastmix(2,2)))*((slhahmix(1,2)+myi*
     .     dcos(b)*slhahmix(1,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+
     .     xlamvsim*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))))/vs)+
c
     .     (slhastmix(1,2)*slhastmix(2,1)+slhastmixim(1,2)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,2)*slhastmixim(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,1)))*((slhahmix(1,2)-myi*
     .     dcos(b)*slhahmix(1,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+
     .     xlamvsim*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))))/vs))
      gh1tt(2,1)=mt**2*slhahmix(1,2)*(slhastmix(2,1)*slhastmix(1,1)+
     .     slhastmixim(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmix(1,2)+slhastmixim(2,2)*slhastmixim(1,2)+myi*
     .     (slhastmix(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmixim(1,2)-slhastmixim(2,1)*slhastmix(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(0.5d0*
     .     (slhastmix(2,1)*slhastmix(1,1)+slhastmixim(2,1)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmixim(2,1)*slhastmix(1,1)))-2.d0*sw2*(slhastmix(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmix(1,2)-slhastmixim(2,2)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmixim(1,2)-slhastmixim(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,2)*slhastmix(1,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(2,1)*slhastmix(1,2)+slhastmixim(2,1)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,2)-
     .     slhastmixim(2,1)*slhastmix(1,2)))*((slhahmix(1,2)+myi*
     .     dcos(b)*slhahmix(1,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+
     .     xlamvsim*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))))/vs)+
c
     .     (slhastmix(2,2)*slhastmix(1,1)+slhastmixim(2,2)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,2)*slhastmixim(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,1)))*((slhahmix(1,2)-myi*
     .     dcos(b)*slhahmix(1,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+v*dcos(b)*slhahmix(1,5))+
     .     xlamvsim*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))))/vs))
      gh1tt(2,2)=(slhastmix(2,1)**2+slhastmixim(2,1)**2+
     .     slhastmix(2,2)**2+slhastmixim(2,2)**2)*
     .     mt**2/mz**2*slhahmix(1,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (0.5d0*(slhastmix(2,1)**2+slhastmixim(2,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(2,1)**2+slhastmixim(2,1)**2-slhastmix(2,2)**2-
     .     slhastmixim(2,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(2,1)*
     .     slhastmix(2,2)+slhastmixim(2,1)*slhastmixim(2,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(1,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(1,4)-
     .     (xlamvs*(vs*slhahmix(1,1)+v*dcos(b)*slhahmix(1,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(1,4)+
     .     v*dcos(b)*slhahmix(1,5)))/vs)-
c
     .     (slhastmix(2,1)*slhastmixim(2,2)-slhastmixim(2,1)*
     .     slhastmix(2,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(1,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(1,2)+(xlamvsim*(vs*slhahmix(1,1)+
     .     v*dcos(b)*slhahmix(1,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(1,4)+
     .     v*dcos(b)*slhahmix(1,5)))/vs))

      gh2tt(1,1)=(slhastmix(1,1)**2+slhastmixim(1,1)**2+
     .     slhastmix(1,2)**2+slhastmixim(1,2)**2)*
     .     mt**2/mz**2*slhahmix(2,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (0.5d0*(slhastmix(1,1)**2+slhastmixim(1,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(1,1)**2+slhastmixim(1,1)**2-slhastmix(1,2)**2-
     .     slhastmixim(1,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(1,1)*
     .     slhastmix(1,2)+slhastmixim(1,1)*slhastmixim(1,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(2,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(2,4)-
     .     (xlamvs*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(2,4)+
     .     v*dcos(b)*slhahmix(2,5)))/vs)-
c
     .     (slhastmix(1,1)*slhastmixim(1,2)-slhastmixim(1,1)*
     .     slhastmix(1,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(2,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(2,2)+(xlamvsim*(vs*slhahmix(2,1)+
     .     v*dcos(b)*slhahmix(2,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+
     .     v*dcos(b)*slhahmix(2,5)))/vs))
      gh2tt(1,2)=mt**2*slhahmix(2,2)*(slhastmix(1,1)*slhastmix(2,1)+
     .     slhastmixim(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmix(2,2)+slhastmixim(1,2)*slhastmixim(2,2)+myi*
     .     (slhastmix(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmixim(2,2)-slhastmixim(1,1)*slhastmix(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(0.5d0*
     .     (slhastmix(1,1)*slhastmix(2,1)+slhastmixim(1,1)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmixim(1,1)*slhastmix(2,1)))-2.d0*sw2*(slhastmix(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmix(2,2)-slhastmixim(1,2)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmixim(2,2)-slhastmixim(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,2)*slhastmix(2,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(1,1)*slhastmix(2,2)+slhastmixim(1,1)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,2)-
     .     slhastmixim(1,1)*slhastmix(2,2)))*((slhahmix(2,2)+myi*
     .     dcos(b)*slhahmix(2,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+
     .     xlamvsim*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))))/vs)+
c
     .     (slhastmix(1,2)*slhastmix(2,1)+slhastmixim(1,2)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,2)*slhastmixim(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,1)))*((slhahmix(2,2)-myi*
     .     dcos(b)*slhahmix(2,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+
     .     xlamvsim*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))))/vs))
      gh2tt(2,1)=mt**2*slhahmix(2,2)*(slhastmix(2,1)*slhastmix(1,1)+
     .     slhastmixim(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmix(1,2)+slhastmixim(2,2)*slhastmixim(1,2)+myi*
     .     (slhastmix(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmixim(1,2)-slhastmixim(2,1)*slhastmix(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(0.5d0*
     .     (slhastmix(2,1)*slhastmix(1,1)+slhastmixim(2,1)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmixim(2,1)*slhastmix(1,1)))-2.d0*sw2*(slhastmix(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmix(1,2)-slhastmixim(2,2)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmixim(1,2)-slhastmixim(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,2)*slhastmix(1,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(2,1)*slhastmix(1,2)+slhastmixim(2,1)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,2)-
     .     slhastmixim(2,1)*slhastmix(1,2)))*((slhahmix(2,2)+myi*
     .     dcos(b)*slhahmix(2,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+
     .     xlamvsim*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))))/vs)+
c
     .     (slhastmix(2,2)*slhastmix(1,1)+slhastmixim(2,2)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,2)*slhastmixim(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,1)))*((slhahmix(2,2)-myi*
     .     dcos(b)*slhahmix(2,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+v*dcos(b)*slhahmix(2,5))+
     .     xlamvsim*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))))/vs))
      gh2tt(2,2)=(slhastmix(2,1)**2+slhastmixim(2,1)**2+
     .     slhastmix(2,2)**2+slhastmixim(2,2)**2)*
     .     mt**2/mz**2*slhahmix(2,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (0.5d0*(slhastmix(2,1)**2+slhastmixim(2,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(2,1)**2+slhastmixim(2,1)**2-slhastmix(2,2)**2-
     .     slhastmixim(2,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(2,1)*
     .     slhastmix(2,2)+slhastmixim(2,1)*slhastmixim(2,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(2,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(2,4)-
     .     (xlamvs*(vs*slhahmix(2,1)+v*dcos(b)*slhahmix(2,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(2,4)+
     .     v*dcos(b)*slhahmix(2,5)))/vs)-
c
     .     (slhastmix(2,1)*slhastmixim(2,2)-slhastmixim(2,1)*
     .     slhastmix(2,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(2,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(2,2)+(xlamvsim*(vs*slhahmix(2,1)+
     .     v*dcos(b)*slhahmix(2,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(2,4)+
     .     v*dcos(b)*slhahmix(2,5)))/vs))

      gh3tt(1,1)=(slhastmix(1,1)**2+slhastmixim(1,1)**2+
     .     slhastmix(1,2)**2+slhastmixim(1,2)**2)*
     .     mt**2/mz**2*slhahmix(3,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (0.5d0*(slhastmix(1,1)**2+slhastmixim(1,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(1,1)**2+slhastmixim(1,1)**2-slhastmix(1,2)**2-
     .     slhastmixim(1,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(1,1)*
     .     slhastmix(1,2)+slhastmixim(1,1)*slhastmixim(1,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(3,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(3,4)-
     .     (xlamvs*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(3,4)+
     .     v*dcos(b)*slhahmix(3,5)))/vs)-
c
     .     (slhastmix(1,1)*slhastmixim(1,2)-slhastmixim(1,1)*
     .     slhastmix(1,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(3,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(3,2)+(xlamvsim*(vs*slhahmix(3,1)+
     .     v*dcos(b)*slhahmix(3,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+
     .     v*dcos(b)*slhahmix(3,5)))/vs))
      gh3tt(1,2)=mt**2*slhahmix(3,2)*(slhastmix(1,1)*slhastmix(2,1)+
     .     slhastmixim(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmix(2,2)+slhastmixim(1,2)*slhastmixim(2,2)+myi*
     .     (slhastmix(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmixim(2,2)-slhastmixim(1,1)*slhastmix(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(0.5d0*
     .     (slhastmix(1,1)*slhastmix(2,1)+slhastmixim(1,1)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmixim(1,1)*slhastmix(2,1)))-2.d0*sw2*(slhastmix(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmix(2,2)-slhastmixim(1,2)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmixim(2,2)-slhastmixim(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,2)*slhastmix(2,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(1,1)*slhastmix(2,2)+slhastmixim(1,1)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,2)-
     .     slhastmixim(1,1)*slhastmix(2,2)))*((slhahmix(3,2)+myi*
     .     dcos(b)*slhahmix(3,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+
     .     xlamvsim*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))))/vs)+
c
     .     (slhastmix(1,2)*slhastmix(2,1)+slhastmixim(1,2)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,2)*slhastmixim(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,1)))*((slhahmix(3,2)-myi*
     .     dcos(b)*slhahmix(3,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+
     .     xlamvsim*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))))/vs))
      gh3tt(2,1)=mt**2*slhahmix(3,2)*(slhastmix(2,1)*slhastmix(1,1)+
     .     slhastmixim(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmix(1,2)+slhastmixim(2,2)*slhastmixim(1,2)+myi*
     .     (slhastmix(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmixim(1,2)-slhastmixim(2,1)*slhastmix(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(0.5d0*
     .     (slhastmix(2,1)*slhastmix(1,1)+slhastmixim(2,1)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmixim(2,1)*slhastmix(1,1)))-2.d0*sw2*(slhastmix(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmix(1,2)-slhastmixim(2,2)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmixim(1,2)-slhastmixim(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,2)*slhastmix(1,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(2,1)*slhastmix(1,2)+slhastmixim(2,1)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,2)-
     .     slhastmixim(2,1)*slhastmix(1,2)))*((slhahmix(3,2)+myi*
     .     dcos(b)*slhahmix(3,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+
     .     xlamvsim*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))))/vs)+
c
     .     (slhastmix(2,2)*slhastmix(1,1)+slhastmixim(2,2)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,2)*slhastmixim(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,1)))*((slhahmix(3,2)-myi*
     .     dcos(b)*slhahmix(3,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+v*dcos(b)*slhahmix(3,5))+
     .     xlamvsim*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))))/vs))
      gh3tt(2,2)=(slhastmix(2,1)**2+slhastmixim(2,1)**2+
     .     slhastmix(2,2)**2+slhastmixim(2,2)**2)*
     .     mt**2/mz**2*slhahmix(3,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (0.5d0*(slhastmix(2,1)**2+slhastmixim(2,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(2,1)**2+slhastmixim(2,1)**2-slhastmix(2,2)**2-
     .     slhastmixim(2,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(2,1)*
     .     slhastmix(2,2)+slhastmixim(2,1)*slhastmixim(2,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(3,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(3,4)-
     .     (xlamvs*(vs*slhahmix(3,1)+v*dcos(b)*slhahmix(3,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(3,4)+
     .     v*dcos(b)*slhahmix(3,5)))/vs)-
c
     .     (slhastmix(2,1)*slhastmixim(2,2)-slhastmixim(2,1)*
     .     slhastmix(2,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(3,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(3,2)+(xlamvsim*(vs*slhahmix(3,1)+
     .     v*dcos(b)*slhahmix(3,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(3,4)+
     .     v*dcos(b)*slhahmix(3,5)))/vs))

      gh4tt(1,1)=(slhastmix(1,1)**2+slhastmixim(1,1)**2+
     .     slhastmix(1,2)**2+slhastmixim(1,2)**2)*
     .     mt**2/mz**2*slhahmix(4,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (0.5d0*(slhastmix(1,1)**2+slhastmixim(1,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(1,1)**2+slhastmixim(1,1)**2-slhastmix(1,2)**2-
     .     slhastmixim(1,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(1,1)*
     .     slhastmix(1,2)+slhastmixim(1,1)*slhastmixim(1,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(4,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(4,4)-
     .     (xlamvs*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(4,4)+
     .     v*dcos(b)*slhahmix(4,5)))/vs)-
c
     .     (slhastmix(1,1)*slhastmixim(1,2)-slhastmixim(1,1)*
     .     slhastmix(1,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(4,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(4,2)+(xlamvsim*(vs*slhahmix(4,1)+
     .     v*dcos(b)*slhahmix(4,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+
     .     v*dcos(b)*slhahmix(4,5)))/vs))
      gh4tt(1,2)=mt**2*slhahmix(4,2)*(slhastmix(1,1)*slhastmix(2,1)+
     .     slhastmixim(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmix(2,2)+slhastmixim(1,2)*slhastmixim(2,2)+myi*
     .     (slhastmix(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmixim(2,2)-slhastmixim(1,1)*slhastmix(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(0.5d0*
     .     (slhastmix(1,1)*slhastmix(2,1)+slhastmixim(1,1)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmixim(1,1)*slhastmix(2,1)))-2.d0*sw2*(slhastmix(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmix(2,2)-slhastmixim(1,2)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmixim(2,2)-slhastmixim(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,2)*slhastmix(2,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(1,1)*slhastmix(2,2)+slhastmixim(1,1)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,2)-
     .     slhastmixim(1,1)*slhastmix(2,2)))*((slhahmix(4,2)+myi*
     .     dcos(b)*slhahmix(4,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+
     .     xlamvsim*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))))/vs)+
c
     .     (slhastmix(1,2)*slhastmix(2,1)+slhastmixim(1,2)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,2)*slhastmixim(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,1)))*((slhahmix(4,2)-myi*
     .     dcos(b)*slhahmix(4,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+
     .     xlamvsim*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))))/vs))
      gh4tt(2,1)=mt**2*slhahmix(4,2)*(slhastmix(2,1)*slhastmix(1,1)+
     .     slhastmixim(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmix(1,2)+slhastmixim(2,2)*slhastmixim(1,2)+myi*
     .     (slhastmix(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmixim(1,2)-slhastmixim(2,1)*slhastmix(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(0.5d0*
     .     (slhastmix(2,1)*slhastmix(1,1)+slhastmixim(2,1)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmixim(2,1)*slhastmix(1,1)))-2.d0*sw2*(slhastmix(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmix(1,2)-slhastmixim(2,2)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmixim(1,2)-slhastmixim(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,2)*slhastmix(1,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(2,1)*slhastmix(1,2)+slhastmixim(2,1)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,2)-
     .     slhastmixim(2,1)*slhastmix(1,2)))*((slhahmix(4,2)+myi*
     .     dcos(b)*slhahmix(4,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+
     .     xlamvsim*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))))/vs)+
c
     .     (slhastmix(2,2)*slhastmix(1,1)+slhastmixim(2,2)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,2)*slhastmixim(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,1)))*((slhahmix(4,2)-myi*
     .     dcos(b)*slhahmix(4,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+v*dcos(b)*slhahmix(4,5))+
     .     xlamvsim*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))))/vs))
      gh4tt(2,2)=(slhastmix(2,1)**2+slhastmixim(2,1)**2+
     .     slhastmix(2,2)**2+slhastmixim(2,2)**2)*
     .     mt**2/mz**2*slhahmix(4,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (0.5d0*(slhastmix(2,1)**2+slhastmixim(2,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(2,1)**2+slhastmixim(2,1)**2-slhastmix(2,2)**2-
     .     slhastmixim(2,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(2,1)*
     .     slhastmix(2,2)+slhastmixim(2,1)*slhastmixim(2,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(4,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(4,4)-
     .     (xlamvs*(vs*slhahmix(4,1)+v*dcos(b)*slhahmix(4,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(4,4)+
     .     v*dcos(b)*slhahmix(4,5)))/vs)-
c
     .     (slhastmix(2,1)*slhastmixim(2,2)-slhastmixim(2,1)*
     .     slhastmix(2,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(4,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(4,2)+(xlamvsim*(vs*slhahmix(4,1)+
     .     v*dcos(b)*slhahmix(4,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(4,4)+
     .     v*dcos(b)*slhahmix(4,5)))/vs))

      gh5tt(1,1)=(slhastmix(1,1)**2+slhastmixim(1,1)**2+
     .     slhastmix(1,2)**2+slhastmixim(1,2)**2)*
     .     mt**2/mz**2*slhahmix(5,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (0.5d0*(slhastmix(1,1)**2+slhastmixim(1,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(1,1)**2+slhastmixim(1,1)**2-slhastmix(1,2)**2-
     .     slhastmixim(1,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(1,1)*
     .     slhastmix(1,2)+slhastmixim(1,1)*slhastmixim(1,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(5,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(5,4)-
     .     (xlamvs*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(5,4)+
     .     v*dcos(b)*slhahmix(5,5)))/vs)-
c
     .     (slhastmix(1,1)*slhastmixim(1,2)-slhastmixim(1,1)*
     .     slhastmix(1,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(5,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(5,2)+(xlamvsim*(vs*slhahmix(5,1)+
     .     v*dcos(b)*slhahmix(5,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+
     .     v*dcos(b)*slhahmix(5,5)))/vs))
      gh5tt(1,2)=mt**2*slhahmix(5,2)*(slhastmix(1,1)*slhastmix(2,1)+
     .     slhastmixim(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmix(2,2)+slhastmixim(1,2)*slhastmixim(2,2)+myi*
     .     (slhastmix(1,1)*slhastmixim(2,1)+slhastmix(1,2)*
     .     slhastmixim(2,2)-slhastmixim(1,1)*slhastmix(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(0.5d0*
     .     (slhastmix(1,1)*slhastmix(2,1)+slhastmixim(1,1)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmixim(1,1)*slhastmix(2,1)))-2.d0*sw2*(slhastmix(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmix(2,2)-slhastmixim(1,2)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,1)-
     .     slhastmix(1,2)*slhastmixim(2,2)-slhastmixim(1,1)*
     .     slhastmix(2,1)+slhastmixim(1,2)*slhastmix(2,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(1,1)*slhastmix(2,2)+slhastmixim(1,1)*
     .     slhastmixim(2,2)+myi*(slhastmix(1,1)*slhastmixim(2,2)-
     .     slhastmixim(1,1)*slhastmix(2,2)))*((slhahmix(5,2)+myi*
     .     dcos(b)*slhahmix(5,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+
     .     xlamvsim*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))))/vs)+
c
     .     (slhastmix(1,2)*slhastmix(2,1)+slhastmixim(1,2)*
     .     slhastmixim(2,1)+myi*(slhastmix(1,2)*slhastmixim(2,1)-
     .     slhastmixim(1,2)*slhastmix(2,1)))*((slhahmix(5,2)-myi*
     .     dcos(b)*slhahmix(5,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+
     .     xlamvsim*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))))/vs))
      gh5tt(2,1)=mt**2*slhahmix(5,2)*(slhastmix(2,1)*slhastmix(1,1)+
     .     slhastmixim(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmix(1,2)+slhastmixim(2,2)*slhastmixim(1,2)+myi*
     .     (slhastmix(2,1)*slhastmixim(1,1)+slhastmix(2,2)*
     .     slhastmixim(1,2)-slhastmixim(2,1)*slhastmix(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,2)))/dsin(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(0.5d0*
     .     (slhastmix(2,1)*slhastmix(1,1)+slhastmixim(2,1)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmixim(2,1)*slhastmix(1,1)))-2.d0*sw2*(slhastmix(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmix(1,2)-slhastmixim(2,2)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,1)-
     .     slhastmix(2,2)*slhastmixim(1,2)-slhastmixim(2,1)*
     .     slhastmix(1,1)+slhastmixim(2,2)*slhastmix(1,2)))/3.d0)+
c
     .     mt/dsin(b)/2.d0/mz**2*(
     .     (slhastmix(2,1)*slhastmix(1,2)+slhastmixim(2,1)*
     .     slhastmixim(1,2)+myi*(slhastmix(2,1)*slhastmixim(1,2)-
     .     slhastmixim(2,1)*slhastmix(1,2)))*((slhahmix(5,2)+myi*
     .     dcos(b)*slhahmix(5,4))*(at*dcos(aphiu)-atim*dsin(aphiu)+
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))-myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+
     .     xlamvsim*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))))/vs)+
c
     .     (slhastmix(2,2)*slhastmix(1,1)+slhastmixim(2,2)*
     .     slhastmixim(1,1)+myi*(slhastmix(2,2)*slhastmixim(1,1)-
     .     slhastmixim(2,2)*slhastmix(1,1)))*((slhahmix(5,2)-myi*
     .     dcos(b)*slhahmix(5,4))*(at*dcos(aphiu)-atim*dsin(aphiu)-
     .     myi*(at*dsin(aphiu)+atim*dcos(aphiu)))-(xlamvs*(
     .     vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-xlamvsim*(
     .     vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+myi*(
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+v*dcos(b)*slhahmix(5,5))+
     .     xlamvsim*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))))/vs))
      gh5tt(2,2)=(slhastmix(2,1)**2+slhastmixim(2,1)**2+
     .     slhastmix(2,2)**2+slhastmixim(2,2)**2)*
     .     mt**2/mz**2*slhahmix(5,2)/dsin(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (0.5d0*(slhastmix(2,1)**2+slhastmixim(2,1)**2)-2.d0/3.d0*sw2*
     .     (slhastmix(2,1)**2+slhastmixim(2,1)**2-slhastmix(2,2)**2-
     .     slhastmixim(2,2)**2))+
c
     .     mt/dsin(b)/mz**2*((slhastmix(2,1)*
     .     slhastmix(2,2)+slhastmixim(2,1)*slhastmixim(2,2))*(
     .     (at*dcos(aphiu)-atim*dsin(aphiu))*slhahmix(5,2)-
     .     (at*dsin(aphiu)+atim*dcos(aphiu))*dcos(b)*slhahmix(5,4)-
     .     (xlamvs*(vs*slhahmix(5,1)+v*dcos(b)*slhahmix(5,3))-
     .     xlamvsim*(vs*dsin(b)*slhahmix(5,4)+
     .     v*dcos(b)*slhahmix(5,5)))/vs)-
c
     .     (slhastmix(2,1)*slhastmixim(2,2)-slhastmixim(2,1)*
     .     slhastmix(2,2))*((at*dcos(aphiu)-atim*dsin(aphiu))*
     .     dcos(b)*slhahmix(5,4)+(at*dsin(aphiu)+atim*dcos(aphiu))*
     .     slhahmix(5,2)+(xlamvsim*(vs*slhahmix(5,1)+
     .     v*dcos(b)*slhahmix(5,3))+
     .     xlamvs*(vs*dsin(b)*slhahmix(5,4)+
     .     v*dcos(b)*slhahmix(5,5)))/vs))

      do j=1,2,1
         do ik=1,2,1
            ghitt(1,j,ik) = gh1tt(j,ik)
            ghitt(2,j,ik) = gh2tt(j,ik)
            ghitt(3,j,ik) = gh3tt(j,ik)
            ghitt(4,j,ik) = gh4tt(j,ik)
            ghitt(5,j,ik) = gh5tt(j,ik)
         end do
      end do

      gh1bb(1,1)=(slhasbmix(1,1)**2+slhasbmixim(1,1)**2+
     .     slhasbmix(1,2)**2+slhasbmixim(1,2)**2)*
     .     mb**2/mz**2*slhahmix(1,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (sw2/3.d0*(slhasbmix(1,1)**2+slhasbmixim(1,1)**2-
     .     slhasbmix(1,2)**2-slhasbmixim(1,2)**2)-0.5d0*(
     .     slhasbmix(1,1)**2+slhasbmixim(1,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(1,1)*
     .     slhasbmix(1,2)+slhasbmixim(1,1)*slhasbmixim(1,2))*(
     .     ab*slhahmix(1,1)-abim*dsin(b)*slhahmix(1,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs)-
c
     .     (slhasbmix(1,1)*slhasbmixim(1,2)-slhasbmixim(1,1)*
     .     slhasbmix(1,2))*(ab*dsin(b)*slhahmix(1,4)+abim*
     .     slhahmix(1,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs))
      gh1bb(1,2)=mb**2*slhahmix(1,1)*(slhasbmix(1,1)*slhasbmix(2,1)+
     .     slhasbmixim(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmix(2,2)+slhasbmixim(1,2)*slhasbmixim(2,2)+myi*
     .     (slhasbmix(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmixim(2,2)-slhasbmixim(1,1)*slhasbmix(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(sw2*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmix(2,2)-
     .     slhasbmixim(1,2)*slhasbmixim(2,2)+myi*(slhasbmix(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmix(2,2)))/3.d0-0.5d0*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,1)*slhasbmixim(2,1)-
     .     slhasbmixim(1,1)*slhasbmix(2,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(1,1)*slhasbmix(2,2)+slhasbmixim(1,1)*
     .     slhasbmixim(2,2)+myi*(slhasbmix(1,1)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,2)))*((slhahmix(1,1)+myi*
     .     dsin(b)*slhahmix(1,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs)+
c
     .     (slhasbmix(1,2)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,2)*slhasbmixim(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,1)))*((slhahmix(1,1)-myi*
     .     dsin(b)*slhahmix(1,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs))
      gh1bb(2,1)=mb**2*slhahmix(1,1)*(slhasbmix(2,1)*slhasbmix(1,1)+
     .     slhasbmixim(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmix(1,2)+slhasbmixim(2,2)*slhasbmixim(1,2)+myi*
     .     (slhasbmix(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmixim(1,2)-slhasbmixim(2,1)*slhasbmix(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(sw2*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmix(1,2)-
     .     slhasbmixim(2,2)*slhasbmixim(1,2)+myi*(slhasbmix(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmix(1,2)))/3.d0-0.5d0*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,1)*slhasbmixim(1,1)-
     .     slhasbmixim(2,1)*slhasbmix(1,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(2,1)*slhasbmix(1,2)+slhasbmixim(2,1)*
     .     slhasbmixim(1,2)+myi*(slhasbmix(2,1)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,2)))*((slhahmix(1,1)+myi*
     .     dsin(b)*slhahmix(1,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs)+
c
     .     (slhasbmix(2,2)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,2)*slhasbmixim(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,1)))*((slhahmix(1,1)-myi*
     .     dsin(b)*slhahmix(1,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs))
      gh1bb(2,2)=(slhasbmix(2,1)**2+slhasbmixim(2,1)**2+
     .     slhasbmix(2,2)**2+slhasbmixim(2,2)**2)*
     .     mb**2/mz**2*slhahmix(1,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (sw2/3.d0*(slhasbmix(2,1)**2+slhasbmixim(2,1)**2-
     .     slhasbmix(2,2)**2-slhasbmixim(2,2)**2)-0.5d0*(
     .     slhasbmix(2,1)**2+slhasbmixim(2,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(2,1)*
     .     slhasbmix(2,2)+slhasbmixim(2,1)*slhasbmixim(2,2))*(
     .     ab*slhahmix(1,1)-abim*dsin(b)*slhahmix(1,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs)-
c
     .     (slhasbmix(2,1)*slhasbmixim(2,2)-slhasbmixim(2,1)*
     .     slhasbmix(2,2))*(ab*dsin(b)*slhahmix(1,4)+abim*
     .     slhahmix(1,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs))

      gh2bb(1,1)=(slhasbmix(1,1)**2+slhasbmixim(1,1)**2+
     .     slhasbmix(1,2)**2+slhasbmixim(1,2)**2)*
     .     mb**2/mz**2*slhahmix(2,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (sw2/3.d0*(slhasbmix(1,1)**2+slhasbmixim(1,1)**2-
     .     slhasbmix(1,2)**2-slhasbmixim(1,2)**2)-0.5d0*(
     .     slhasbmix(1,1)**2+slhasbmixim(1,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(1,1)*
     .     slhasbmix(1,2)+slhasbmixim(1,1)*slhasbmixim(1,2))*(
     .     ab*slhahmix(2,1)-abim*dsin(b)*slhahmix(2,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs)-
c
     .     (slhasbmix(1,1)*slhasbmixim(1,2)-slhasbmixim(1,1)*
     .     slhasbmix(1,2))*(ab*dsin(b)*slhahmix(2,4)+abim*
     .     slhahmix(2,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs))
      gh2bb(1,2)=mb**2*slhahmix(2,1)*(slhasbmix(1,1)*slhasbmix(2,1)+
     .     slhasbmixim(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmix(2,2)+slhasbmixim(1,2)*slhasbmixim(2,2)+myi*
     .     (slhasbmix(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmixim(2,2)-slhasbmixim(1,1)*slhasbmix(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(sw2*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmix(2,2)-
     .     slhasbmixim(1,2)*slhasbmixim(2,2)+myi*(slhasbmix(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmix(2,2)))/3.d0-0.5d0*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,1)*slhasbmixim(2,1)-
     .     slhasbmixim(1,1)*slhasbmix(2,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(1,1)*slhasbmix(2,2)+slhasbmixim(1,1)*
     .     slhasbmixim(2,2)+myi*(slhasbmix(1,1)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,2)))*((slhahmix(2,1)+myi*
     .     dsin(b)*slhahmix(2,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs)+
c
     .     (slhasbmix(1,2)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,2)*slhasbmixim(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,1)))*((slhahmix(2,1)-myi*
     .     dsin(b)*slhahmix(2,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs))
      gh2bb(2,1)=mb**2*slhahmix(2,1)*(slhasbmix(2,1)*slhasbmix(1,1)+
     .     slhasbmixim(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmix(1,2)+slhasbmixim(2,2)*slhasbmixim(1,2)+myi*
     .     (slhasbmix(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmixim(1,2)-slhasbmixim(2,1)*slhasbmix(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(sw2*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmix(1,2)-
     .     slhasbmixim(2,2)*slhasbmixim(1,2)+myi*(slhasbmix(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmix(1,2)))/3.d0-0.5d0*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,1)*slhasbmixim(1,1)-
     .     slhasbmixim(2,1)*slhasbmix(1,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(2,1)*slhasbmix(1,2)+slhasbmixim(2,1)*
     .     slhasbmixim(1,2)+myi*(slhasbmix(2,1)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,2)))*((slhahmix(2,1)+myi*
     .     dsin(b)*slhahmix(2,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs)+
c
     .     (slhasbmix(2,2)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,2)*slhasbmixim(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,1)))*((slhahmix(2,1)-myi*
     .     dsin(b)*slhahmix(2,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs))
      gh2bb(2,2)=(slhasbmix(2,1)**2+slhasbmixim(2,1)**2+
     .     slhasbmix(2,2)**2+slhasbmixim(2,2)**2)*
     .     mb**2/mz**2*slhahmix(2,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (sw2/3.d0*(slhasbmix(2,1)**2+slhasbmixim(2,1)**2-
     .     slhasbmix(2,2)**2-slhasbmixim(2,2)**2)-0.5d0*(
     .     slhasbmix(2,1)**2+slhasbmixim(2,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(2,1)*
     .     slhasbmix(2,2)+slhasbmixim(2,1)*slhasbmixim(2,2))*(
     .     ab*slhahmix(2,1)-abim*dsin(b)*slhahmix(2,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs)-
c
     .     (slhasbmix(2,1)*slhasbmixim(2,2)-slhasbmixim(2,1)*
     .     slhasbmix(2,2))*(ab*dsin(b)*slhahmix(2,4)+abim*
     .     slhahmix(2,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs))
      
      gh3bb(1,1)=(slhasbmix(1,1)**2+slhasbmixim(1,1)**2+
     .     slhasbmix(1,2)**2+slhasbmixim(1,2)**2)*
     .     mb**2/mz**2*slhahmix(3,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (sw2/3.d0*(slhasbmix(1,1)**2+slhasbmixim(1,1)**2-
     .     slhasbmix(1,2)**2-slhasbmixim(1,2)**2)-0.5d0*(
     .     slhasbmix(1,1)**2+slhasbmixim(1,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(1,1)*
     .     slhasbmix(1,2)+slhasbmixim(1,1)*slhasbmixim(1,2))*(
     .     ab*slhahmix(3,1)-abim*dsin(b)*slhahmix(3,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs)-
c
     .     (slhasbmix(1,1)*slhasbmixim(1,2)-slhasbmixim(1,1)*
     .     slhasbmix(1,2))*(ab*dsin(b)*slhahmix(3,4)+abim*
     .     slhahmix(3,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs))
      gh3bb(1,2)=mb**2*slhahmix(3,1)*(slhasbmix(1,1)*slhasbmix(2,1)+
     .     slhasbmixim(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmix(2,2)+slhasbmixim(1,2)*slhasbmixim(2,2)+myi*
     .     (slhasbmix(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmixim(2,2)-slhasbmixim(1,1)*slhasbmix(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(sw2*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmix(2,2)-
     .     slhasbmixim(1,2)*slhasbmixim(2,2)+myi*(slhasbmix(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmix(2,2)))/3.d0-0.5d0*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,1)*slhasbmixim(2,1)-
     .     slhasbmixim(1,1)*slhasbmix(2,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(1,1)*slhasbmix(2,2)+slhasbmixim(1,1)*
     .     slhasbmixim(2,2)+myi*(slhasbmix(1,1)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,2)))*((slhahmix(3,1)+myi*
     .     dsin(b)*slhahmix(3,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs)+
c
     .     (slhasbmix(1,2)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,2)*slhasbmixim(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,1)))*((slhahmix(3,1)-myi*
     .     dsin(b)*slhahmix(3,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs))
      gh3bb(2,1)=mb**2*slhahmix(3,1)*(slhasbmix(2,1)*slhasbmix(1,1)+
     .     slhasbmixim(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmix(1,2)+slhasbmixim(2,2)*slhasbmixim(1,2)+myi*
     .     (slhasbmix(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmixim(1,2)-slhasbmixim(2,1)*slhasbmix(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(sw2*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmix(1,2)-
     .     slhasbmixim(2,2)*slhasbmixim(1,2)+myi*(slhasbmix(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmix(1,2)))/3.d0-0.5d0*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,1)*slhasbmixim(1,1)-
     .     slhasbmixim(2,1)*slhasbmix(1,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(2,1)*slhasbmix(1,2)+slhasbmixim(2,1)*
     .     slhasbmixim(1,2)+myi*(slhasbmix(2,1)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,2)))*((slhahmix(3,1)+myi*
     .     dsin(b)*slhahmix(3,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs)+
c
     .     (slhasbmix(2,2)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,2)*slhasbmixim(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,1)))*((slhahmix(3,1)-myi*
     .     dsin(b)*slhahmix(3,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs))
      gh3bb(2,2)=(slhasbmix(2,1)**2+slhasbmixim(2,1)**2+
     .     slhasbmix(2,2)**2+slhasbmixim(2,2)**2)*
     .     mb**2/mz**2*slhahmix(3,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (sw2/3.d0*(slhasbmix(2,1)**2+slhasbmixim(2,1)**2-
     .     slhasbmix(2,2)**2-slhasbmixim(2,2)**2)-0.5d0*(
     .     slhasbmix(2,1)**2+slhasbmixim(2,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(2,1)*
     .     slhasbmix(2,2)+slhasbmixim(2,1)*slhasbmixim(2,2))*(
     .     ab*slhahmix(3,1)-abim*dsin(b)*slhahmix(3,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs)-
c
     .     (slhasbmix(2,1)*slhasbmixim(2,2)-slhasbmixim(2,1)*
     .     slhasbmix(2,2))*(ab*dsin(b)*slhahmix(3,4)+abim*
     .     slhahmix(3,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs))

      gh4bb(1,1)=(slhasbmix(1,1)**2+slhasbmixim(1,1)**2+
     .     slhasbmix(1,2)**2+slhasbmixim(1,2)**2)*
     .     mb**2/mz**2*slhahmix(4,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (sw2/3.d0*(slhasbmix(1,1)**2+slhasbmixim(1,1)**2-
     .     slhasbmix(1,2)**2-slhasbmixim(1,2)**2)-0.5d0*(
     .     slhasbmix(1,1)**2+slhasbmixim(1,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(1,1)*
     .     slhasbmix(1,2)+slhasbmixim(1,1)*slhasbmixim(1,2))*(
     .     ab*slhahmix(4,1)-abim*dsin(b)*slhahmix(4,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs)-
c
     .     (slhasbmix(1,1)*slhasbmixim(1,2)-slhasbmixim(1,1)*
     .     slhasbmix(1,2))*(ab*dsin(b)*slhahmix(4,4)+abim*
     .     slhahmix(4,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs))
      gh4bb(1,2)=mb**2*slhahmix(4,1)*(slhasbmix(1,1)*slhasbmix(2,1)+
     .     slhasbmixim(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmix(2,2)+slhasbmixim(1,2)*slhasbmixim(2,2)+myi*
     .     (slhasbmix(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmixim(2,2)-slhasbmixim(1,1)*slhasbmix(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(sw2*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmix(2,2)-
     .     slhasbmixim(1,2)*slhasbmixim(2,2)+myi*(slhasbmix(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmix(2,2)))/3.d0-0.5d0*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,1)*slhasbmixim(2,1)-
     .     slhasbmixim(1,1)*slhasbmix(2,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(1,1)*slhasbmix(2,2)+slhasbmixim(1,1)*
     .     slhasbmixim(2,2)+myi*(slhasbmix(1,1)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,2)))*((slhahmix(4,1)+myi*
     .     dsin(b)*slhahmix(4,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs)+
c
     .     (slhasbmix(1,2)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,2)*slhasbmixim(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,1)))*((slhahmix(4,1)-myi*
     .     dsin(b)*slhahmix(4,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs))
      gh4bb(2,1)=mb**2*slhahmix(4,1)*(slhasbmix(2,1)*slhasbmix(1,1)+
     .     slhasbmixim(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmix(1,2)+slhasbmixim(2,2)*slhasbmixim(1,2)+myi*
     .     (slhasbmix(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmixim(1,2)-slhasbmixim(2,1)*slhasbmix(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(sw2*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmix(1,2)-
     .     slhasbmixim(2,2)*slhasbmixim(1,2)+myi*(slhasbmix(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmix(1,2)))/3.d0-0.5d0*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,1)*slhasbmixim(1,1)-
     .     slhasbmixim(2,1)*slhasbmix(1,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(2,1)*slhasbmix(1,2)+slhasbmixim(2,1)*
     .     slhasbmixim(1,2)+myi*(slhasbmix(2,1)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,2)))*((slhahmix(4,1)+myi*
     .     dsin(b)*slhahmix(4,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs)+
c
     .     (slhasbmix(2,2)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,2)*slhasbmixim(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,1)))*((slhahmix(4,1)-myi*
     .     dsin(b)*slhahmix(4,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs))
      gh4bb(2,2)=(slhasbmix(2,1)**2+slhasbmixim(2,1)**2+
     .     slhasbmix(2,2)**2+slhasbmixim(2,2)**2)*
     .     mb**2/mz**2*slhahmix(4,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (sw2/3.d0*(slhasbmix(2,1)**2+slhasbmixim(2,1)**2-
     .     slhasbmix(2,2)**2-slhasbmixim(2,2)**2)-0.5d0*(
     .     slhasbmix(2,1)**2+slhasbmixim(2,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(2,1)*
     .     slhasbmix(2,2)+slhasbmixim(2,1)*slhasbmixim(2,2))*(
     .     ab*slhahmix(4,1)-abim*dsin(b)*slhahmix(4,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs)-
c
     .     (slhasbmix(2,1)*slhasbmixim(2,2)-slhasbmixim(2,1)*
     .     slhasbmix(2,2))*(ab*dsin(b)*slhahmix(4,4)+abim*
     .     slhahmix(4,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs))

      gh5bb(1,1)=(slhasbmix(1,1)**2+slhasbmixim(1,1)**2+
     .     slhasbmix(1,2)**2+slhasbmixim(1,2)**2)*
     .     mb**2/mz**2*slhahmix(5,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (sw2/3.d0*(slhasbmix(1,1)**2+slhasbmixim(1,1)**2-
     .     slhasbmix(1,2)**2-slhasbmixim(1,2)**2)-0.5d0*(
     .     slhasbmix(1,1)**2+slhasbmixim(1,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(1,1)*
     .     slhasbmix(1,2)+slhasbmixim(1,1)*slhasbmixim(1,2))*(
     .     ab*slhahmix(5,1)-abim*dsin(b)*slhahmix(5,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs)-
c
     .     (slhasbmix(1,1)*slhasbmixim(1,2)-slhasbmixim(1,1)*
     .     slhasbmix(1,2))*(ab*dsin(b)*slhahmix(5,4)+abim*
     .     slhahmix(5,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs))
      gh5bb(1,2)=mb**2*slhahmix(5,1)*(slhasbmix(1,1)*slhasbmix(2,1)+
     .     slhasbmixim(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmix(2,2)+slhasbmixim(1,2)*slhasbmixim(2,2)+myi*
     .     (slhasbmix(1,1)*slhasbmixim(2,1)+slhasbmix(1,2)*
     .     slhasbmixim(2,2)-slhasbmixim(1,1)*slhasbmix(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(sw2*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmix(2,2)-
     .     slhasbmixim(1,2)*slhasbmixim(2,2)+myi*(slhasbmix(1,1)*
     .     slhasbmixim(2,1)-slhasbmix(1,2)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmix(2,2)))/3.d0-0.5d0*
     .     (slhasbmix(1,1)*slhasbmix(2,1)+slhasbmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,1)*slhasbmixim(2,1)-
     .     slhasbmixim(1,1)*slhasbmix(2,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(1,1)*slhasbmix(2,2)+slhasbmixim(1,1)*
     .     slhasbmixim(2,2)+myi*(slhasbmix(1,1)*slhasbmixim(2,2)-
     .     slhasbmixim(1,1)*slhasbmix(2,2)))*((slhahmix(5,1)+myi*
     .     dsin(b)*slhahmix(5,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs)+
c
     .     (slhasbmix(1,2)*slhasbmix(2,1)+slhasbmixim(1,2)*
     .     slhasbmixim(2,1)+myi*(slhasbmix(1,2)*slhasbmixim(2,1)-
     .     slhasbmixim(1,2)*slhasbmix(2,1)))*((slhahmix(5,1)-myi*
     .     dsin(b)*slhahmix(5,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs))
      gh5bb(2,1)=mb**2*slhahmix(5,1)*(slhasbmix(2,1)*slhasbmix(1,1)+
     .     slhasbmixim(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmix(1,2)+slhasbmixim(2,2)*slhasbmixim(1,2)+myi*
     .     (slhasbmix(2,1)*slhasbmixim(1,1)+slhasbmix(2,2)*
     .     slhasbmixim(1,2)-slhasbmixim(2,1)*slhasbmix(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(sw2*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmix(1,2)-
     .     slhasbmixim(2,2)*slhasbmixim(1,2)+myi*(slhasbmix(2,1)*
     .     slhasbmixim(1,1)-slhasbmix(2,2)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmix(1,2)))/3.d0-0.5d0*
     .     (slhasbmix(2,1)*slhasbmix(1,1)+slhasbmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,1)*slhasbmixim(1,1)-
     .     slhasbmixim(2,1)*slhasbmix(1,1))))+
c
     .     mb/dcos(b)/2.d0/mz**2*(
     .     (slhasbmix(2,1)*slhasbmix(1,2)+slhasbmixim(2,1)*
     .     slhasbmixim(1,2)+myi*(slhasbmix(2,1)*slhasbmixim(1,2)-
     .     slhasbmixim(2,1)*slhasbmix(1,2)))*((slhahmix(5,1)+myi*
     .     dsin(b)*slhahmix(5,4))*(ab+myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs)+
c
     .     (slhasbmix(2,2)*slhasbmix(1,1)+slhasbmixim(2,2)*
     .     slhasbmixim(1,1)+myi*(slhasbmix(2,2)*slhasbmixim(1,1)-
     .     slhasbmixim(2,2)*slhasbmix(1,1)))*((slhahmix(5,1)-myi*
     .     dsin(b)*slhahmix(5,4))*(ab-myi*abim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs))
      gh5bb(2,2)=(slhasbmix(2,1)**2+slhasbmixim(2,1)**2+
     .     slhasbmix(2,2)**2+slhasbmixim(2,2)**2)*
     .     mb**2/mz**2*slhahmix(5,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (sw2/3.d0*(slhasbmix(2,1)**2+slhasbmixim(2,1)**2-
     .     slhasbmix(2,2)**2-slhasbmixim(2,2)**2)-0.5d0*(
     .     slhasbmix(2,1)**2+slhasbmixim(2,1)**2))+
c
     .     mb/dcos(b)/mz**2*((slhasbmix(2,1)*
     .     slhasbmix(2,2)+slhasbmixim(2,1)*slhasbmixim(2,2))*(
     .     ab*slhahmix(5,1)-abim*dsin(b)*slhahmix(5,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs)-
c
     .     (slhasbmix(2,1)*slhasbmixim(2,2)-slhasbmixim(2,1)*
     .     slhasbmix(2,2))*(ab*dsin(b)*slhahmix(5,4)+abim*
     .     slhahmix(5,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs))
c

      do j=1,2,1
         do ik=1,2,1
            ghibb(1,j,ik) = gh1bb(j,ik)
            ghibb(2,j,ik) = gh2bb(j,ik)
            ghibb(3,j,ik) = gh3bb(j,ik)
            ghibb(4,j,ik) = gh4bb(j,ik)
            ghibb(5,j,ik) = gh5bb(j,ik)
         end do
      end do

c --- CP-even Higgs couplings to staus --- c

      gh1ee(1,1)=(slhastaumix(1,1)**2+slhastaumixim(1,1)**2+
     .     slhastaumix(1,2)**2+slhastaumixim(1,2)**2)*
     .     ml**2/mz**2*slhahmix(1,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (sw2*(slhastaumix(1,1)**2+slhastaumixim(1,1)**2-
     .     slhastaumix(1,2)**2-slhastaumixim(1,2)**2)-0.5d0*(
     .     slhastaumix(1,1)**2+slhastaumixim(1,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(1,1)*
     .     slhastaumix(1,2)+slhastaumixim(1,1)*slhastaumixim(1,2))*(
     .     al*slhahmix(1,1)-alim*dsin(b)*slhahmix(1,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs)-
c
     .     (slhastaumix(1,1)*slhastaumixim(1,2)-slhastaumixim(1,1)*
     .     slhastaumix(1,2))*(al*dsin(b)*slhahmix(1,4)+alim*
     .     slhahmix(1,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs))

      gh1ee(1,2)=ml**2*slhahmix(1,1)*(slhastaumix(1,1)*slhastaumix(2,1)+
     .     slhastaumixim(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumix(2,2)+slhastaumixim(1,2)*slhastaumixim(2,2)+myi*
     .     (slhastaumix(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumixim(2,2)-slhastaumixim(1,1)*slhastaumix(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(sw2*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumix(2,2)-
     .     slhastaumixim(1,2)*slhastaumixim(2,2)+myi*(slhastaumix(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumix(2,2)))-0.5d0*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,1)*slhastaumixim(2,1)-
     .     slhastaumixim(1,1)*slhastaumix(2,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(1,1)*slhastaumix(2,2)+slhastaumixim(1,1)*
     .     slhastaumixim(2,2)+myi*(slhastaumix(1,1)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,2)))*((slhahmix(1,1)+myi*
     .     dsin(b)*slhahmix(1,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs)+
c
     .     (slhastaumix(1,2)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,2)*slhastaumixim(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,1)))*((slhahmix(1,1)-myi*
     .     dsin(b)*slhahmix(1,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs))
      gh1ee(2,1)=ml**2*slhahmix(1,1)*(slhastaumix(2,1)*slhastaumix(1,1)+
     .     slhastaumixim(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumix(1,2)+slhastaumixim(2,2)*slhastaumixim(1,2)+myi*
     .     (slhastaumix(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumixim(1,2)-slhastaumixim(2,1)*slhastaumix(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*(sw2*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumix(1,2)-
     .     slhastaumixim(2,2)*slhastaumixim(1,2)+myi*(slhastaumix(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumix(1,2)))-0.5d0*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,1)*slhastaumixim(1,1)-
     .     slhastaumixim(2,1)*slhastaumix(1,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(2,1)*slhastaumix(1,2)+slhastaumixim(2,1)*
     .     slhastaumixim(1,2)+myi*(slhastaumix(2,1)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,2)))*((slhahmix(1,1)+myi*
     .     dsin(b)*slhahmix(1,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs)+
c
     .     (slhastaumix(2,2)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,2)*slhastaumixim(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,1)))*((slhahmix(1,1)-myi*
     .     dsin(b)*slhahmix(1,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))))/vs))
      gh1ee(2,2)=(slhastaumix(2,1)**2+slhastaumixim(2,1)**2+
     .     slhastaumix(2,2)**2+slhastaumixim(2,2)**2)*
     .     ml**2/mz**2*slhahmix(1,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(1,1)-dsin(b)*slhahmix(1,2))*
     .     (sw2*(slhastaumix(2,1)**2+slhastaumixim(2,1)**2-
     .     slhastaumix(2,2)**2-slhastaumixim(2,2)**2)-0.5d0*(
     .     slhastaumix(2,1)**2+slhastaumixim(2,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(2,1)*
     .     slhastaumix(2,2)+slhastaumixim(2,1)*slhastaumixim(2,2))*(
     .     al*slhahmix(1,1)-alim*dsin(b)*slhahmix(1,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs)-
c
     .     (slhastaumix(2,1)*slhastaumixim(2,2)-slhastaumixim(2,1)*
     .     slhastaumix(2,2))*(al*dsin(b)*slhahmix(1,4)+alim*
     .     slhahmix(1,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(1,2)+v*dsin(b)*slhahmix(1,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(1,4)+v*dsin(b)*slhahmix(1,5)))/vs))

      gh2ee(1,1)=(slhastaumix(1,1)**2+slhastaumixim(1,1)**2+
     .     slhastaumix(1,2)**2+slhastaumixim(1,2)**2)*
     .     ml**2/mz**2*slhahmix(2,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (sw2*(slhastaumix(1,1)**2+slhastaumixim(1,1)**2-
     .     slhastaumix(1,2)**2-slhastaumixim(1,2)**2)-0.5d0*(
     .     slhastaumix(1,1)**2+slhastaumixim(1,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(1,1)*
     .     slhastaumix(1,2)+slhastaumixim(1,1)*slhastaumixim(1,2))*(
     .     al*slhahmix(2,1)-alim*dsin(b)*slhahmix(2,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs)-
c
     .     (slhastaumix(1,1)*slhastaumixim(1,2)-slhastaumixim(1,1)*
     .     slhastaumix(1,2))*(al*dsin(b)*slhahmix(2,4)+alim*
     .     slhahmix(2,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs))
      gh2ee(1,2)=ml**2*slhahmix(2,1)*(slhastaumix(1,1)*slhastaumix(2,1)+
     .     slhastaumixim(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumix(2,2)+slhastaumixim(1,2)*slhastaumixim(2,2)+myi*
     .     (slhastaumix(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumixim(2,2)-slhastaumixim(1,1)*slhastaumix(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(sw2*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumix(2,2)-
     .     slhastaumixim(1,2)*slhastaumixim(2,2)+myi*(slhastaumix(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumix(2,2)))-0.5d0*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,1)*slhastaumixim(2,1)-
     .     slhastaumixim(1,1)*slhastaumix(2,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(1,1)*slhastaumix(2,2)+slhastaumixim(1,1)*
     .     slhastaumixim(2,2)+myi*(slhastaumix(1,1)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,2)))*((slhahmix(2,1)+myi*
     .     dsin(b)*slhahmix(2,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs)+
c
     .     (slhastaumix(1,2)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,2)*slhastaumixim(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,1)))*((slhahmix(2,1)-myi*
     .     dsin(b)*slhahmix(2,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs))
      gh2ee(2,1)=ml**2*slhahmix(2,1)*(slhastaumix(2,1)*slhastaumix(1,1)+
     .     slhastaumixim(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumix(1,2)+slhastaumixim(2,2)*slhastaumixim(1,2)+myi*
     .     (slhastaumix(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumixim(1,2)-slhastaumixim(2,1)*slhastaumix(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*(sw2*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumix(1,2)-
     .     slhastaumixim(2,2)*slhastaumixim(1,2)+myi*(slhastaumix(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumix(1,2)))-0.5d0*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,1)*slhastaumixim(1,1)-
     .     slhastaumixim(2,1)*slhastaumix(1,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(2,1)*slhastaumix(1,2)+slhastaumixim(2,1)*
     .     slhastaumixim(1,2)+myi*(slhastaumix(2,1)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,2)))*((slhahmix(2,1)+myi*
     .     dsin(b)*slhahmix(2,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs)+
c
     .     (slhastaumix(2,2)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,2)*slhastaumixim(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,1)))*((slhahmix(2,1)-myi*
     .     dsin(b)*slhahmix(2,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))))/vs))
      gh2ee(2,2)=(slhastaumix(2,1)**2+slhastaumixim(2,1)**2+
     .     slhastaumix(2,2)**2+slhastaumixim(2,2)**2)*
     .     ml**2/mz**2*slhahmix(2,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(2,1)-dsin(b)*slhahmix(2,2))*
     .     (sw2*(slhastaumix(2,1)**2+slhastaumixim(2,1)**2-
     .     slhastaumix(2,2)**2-slhastaumixim(2,2)**2)-0.5d0*(
     .     slhastaumix(2,1)**2+slhastaumixim(2,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(2,1)*
     .     slhastaumix(2,2)+slhastaumixim(2,1)*slhastaumixim(2,2))*(
     .     al*slhahmix(2,1)-alim*dsin(b)*slhahmix(2,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))+
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs)-
c
     .     (slhastaumix(2,1)*slhastaumixim(2,2)-slhastaumixim(2,1)*
     .     slhastaumix(2,2))*(al*dsin(b)*slhahmix(2,4)+alim*
     .     slhahmix(2,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(2,2)+v*dsin(b)*slhahmix(2,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(2,4)+v*dsin(b)*slhahmix(2,5)))/vs))
      
      gh3ee(1,1)=(slhastaumix(1,1)**2+slhastaumixim(1,1)**2+
     .     slhastaumix(1,2)**2+slhastaumixim(1,2)**2)*
     .     ml**2/mz**2*slhahmix(3,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (sw2*(slhastaumix(1,1)**2+slhastaumixim(1,1)**2-
     .     slhastaumix(1,2)**2-slhastaumixim(1,2)**2)-0.5d0*(
     .     slhastaumix(1,1)**2+slhastaumixim(1,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(1,1)*
     .     slhastaumix(1,2)+slhastaumixim(1,1)*slhastaumixim(1,2))*(
     .     al*slhahmix(3,1)-alim*dsin(b)*slhahmix(3,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs)-
c
     .     (slhastaumix(1,1)*slhastaumixim(1,2)-slhastaumixim(1,1)*
     .     slhastaumix(1,2))*(al*dsin(b)*slhahmix(3,4)+alim*
     .     slhahmix(3,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs))
      gh3ee(1,2)=ml**2*slhahmix(3,1)*(slhastaumix(1,1)*slhastaumix(2,1)+
     .     slhastaumixim(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumix(2,2)+slhastaumixim(1,2)*slhastaumixim(2,2)+myi*
     .     (slhastaumix(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumixim(2,2)-slhastaumixim(1,1)*slhastaumix(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(sw2*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumix(2,2)-
     .     slhastaumixim(1,2)*slhastaumixim(2,2)+myi*(slhastaumix(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumix(2,2)))-0.5d0*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,1)*slhastaumixim(2,1)-
     .     slhastaumixim(1,1)*slhastaumix(2,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(1,1)*slhastaumix(2,2)+slhastaumixim(1,1)*
     .     slhastaumixim(2,2)+myi*(slhastaumix(1,1)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,2)))*((slhahmix(3,1)+myi*
     .     dsin(b)*slhahmix(3,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs)+
c
     .     (slhastaumix(1,2)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,2)*slhastaumixim(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,1)))*((slhahmix(3,1)-myi*
     .     dsin(b)*slhahmix(3,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs))
      gh3ee(2,1)=ml**2*slhahmix(3,1)*(slhastaumix(2,1)*slhastaumix(1,1)+
     .     slhastaumixim(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumix(1,2)+slhastaumixim(2,2)*slhastaumixim(1,2)+myi*
     .     (slhastaumix(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumixim(1,2)-slhastaumixim(2,1)*slhastaumix(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*(sw2*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumix(1,2)-
     .     slhastaumixim(2,2)*slhastaumixim(1,2)+myi*(slhastaumix(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumix(1,2)))-0.5d0*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,1)*slhastaumixim(1,1)-
     .     slhastaumixim(2,1)*slhastaumix(1,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(2,1)*slhastaumix(1,2)+slhastaumixim(2,1)*
     .     slhastaumixim(1,2)+myi*(slhastaumix(2,1)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,2)))*((slhahmix(3,1)+myi*
     .     dsin(b)*slhahmix(3,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs)+
c
     .     (slhastaumix(2,2)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,2)*slhastaumixim(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,1)))*((slhahmix(3,1)-myi*
     .     dsin(b)*slhahmix(3,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))))/vs))
      gh3ee(2,2)=(slhastaumix(2,1)**2+slhastaumixim(2,1)**2+
     .     slhastaumix(2,2)**2+slhastaumixim(2,2)**2)*
     .     ml**2/mz**2*slhahmix(3,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(3,1)-dsin(b)*slhahmix(3,2))*
     .     (sw2*(slhastaumix(2,1)**2+slhastaumixim(2,1)**2-
     .     slhastaumix(2,2)**2-slhastaumixim(2,2)**2)-0.5d0*(
     .     slhastaumix(2,1)**2+slhastaumixim(2,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(2,1)*
     .     slhastaumix(2,2)+slhastaumixim(2,1)*slhastaumixim(2,2))*(
     .     al*slhahmix(3,1)-alim*dsin(b)*slhahmix(3,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs)-
c
     .     (slhastaumix(2,1)*slhastaumixim(2,2)-slhastaumixim(2,1)*
     .     slhastaumix(2,2))*(al*dsin(b)*slhahmix(3,4)+alim*
     .     slhahmix(3,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(3,2)+v*dsin(b)*slhahmix(3,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(3,4)+v*dsin(b)*slhahmix(3,5)))/vs))

      gh4ee(1,1)=(slhastaumix(1,1)**2+slhastaumixim(1,1)**2+
     .     slhastaumix(1,2)**2+slhastaumixim(1,2)**2)*
     .     ml**2/mz**2*slhahmix(4,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (sw2*(slhastaumix(1,1)**2+slhastaumixim(1,1)**2-
     .     slhastaumix(1,2)**2-slhastaumixim(1,2)**2)-0.5d0*(
     .     slhastaumix(1,1)**2+slhastaumixim(1,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(1,1)*
     .     slhastaumix(1,2)+slhastaumixim(1,1)*slhastaumixim(1,2))*(
     .     al*slhahmix(4,1)-alim*dsin(b)*slhahmix(4,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs)-
c
     .     (slhastaumix(1,1)*slhastaumixim(1,2)-slhastaumixim(1,1)*
     .     slhastaumix(1,2))*(al*dsin(b)*slhahmix(4,4)+alim*
     .     slhahmix(4,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs))
      gh4ee(1,2)=ml**2*slhahmix(4,1)*(slhastaumix(1,1)*slhastaumix(2,1)+
     .     slhastaumixim(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumix(2,2)+slhastaumixim(1,2)*slhastaumixim(2,2)+myi*
     .     (slhastaumix(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumixim(2,2)-slhastaumixim(1,1)*slhastaumix(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(sw2*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumix(2,2)-
     .     slhastaumixim(1,2)*slhastaumixim(2,2)+myi*(slhastaumix(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumix(2,2)))-0.5d0*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,1)*slhastaumixim(2,1)-
     .     slhastaumixim(1,1)*slhastaumix(2,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(1,1)*slhastaumix(2,2)+slhastaumixim(1,1)*
     .     slhastaumixim(2,2)+myi*(slhastaumix(1,1)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,2)))*((slhahmix(4,1)+myi*
     .     dsin(b)*slhahmix(4,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs)+
c
     .     (slhastaumix(1,2)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,2)*slhastaumixim(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,1)))*((slhahmix(4,1)-myi*
     .     dsin(b)*slhahmix(4,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs))
      gh4ee(2,1)=ml**2*slhahmix(4,1)*(slhastaumix(2,1)*slhastaumix(1,1)+
     .     slhastaumixim(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumix(1,2)+slhastaumixim(2,2)*slhastaumixim(1,2)+myi*
     .     (slhastaumix(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumixim(1,2)-slhastaumixim(2,1)*slhastaumix(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*(sw2*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumix(1,2)-
     .     slhastaumixim(2,2)*slhastaumixim(1,2)+myi*(slhastaumix(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumix(1,2)))-0.5d0*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,1)*slhastaumixim(1,1)-
     .     slhastaumixim(2,1)*slhastaumix(1,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(2,1)*slhastaumix(1,2)+slhastaumixim(2,1)*
     .     slhastaumixim(1,2)+myi*(slhastaumix(2,1)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,2)))*((slhahmix(4,1)+myi*
     .     dsin(b)*slhahmix(4,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs)+
c
     .     (slhastaumix(2,2)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,2)*slhastaumixim(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,1)))*((slhahmix(4,1)-myi*
     .     dsin(b)*slhahmix(4,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))))/vs))
      gh4ee(2,2)=(slhastaumix(2,1)**2+slhastaumixim(2,1)**2+
     .     slhastaumix(2,2)**2+slhastaumixim(2,2)**2)*
     .     ml**2/mz**2*slhahmix(4,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(4,1)-dsin(b)*slhahmix(4,2))*
     .     (sw2*(slhastaumix(2,1)**2+slhastaumixim(2,1)**2-
     .     slhastaumix(2,2)**2-slhastaumixim(2,2)**2)-0.5d0*(
     .     slhastaumix(2,1)**2+slhastaumixim(2,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(2,1)*
     .     slhastaumix(2,2)+slhastaumixim(2,1)*slhastaumixim(2,2))*(
     .     al*slhahmix(4,1)-alim*dsin(b)*slhahmix(4,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs)-
c
     .     (slhastaumix(2,1)*slhastaumixim(2,2)-slhastaumixim(2,1)*
     .     slhastaumix(2,2))*(al*dsin(b)*slhahmix(4,4)+alim*
     .     slhahmix(4,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(4,2)+v*dsin(b)*slhahmix(4,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(4,4)+v*dsin(b)*slhahmix(4,5)))/vs))

      gh5ee(1,1)=(slhastaumix(1,1)**2+slhastaumixim(1,1)**2+
     .     slhastaumix(1,2)**2+slhastaumixim(1,2)**2)*
     .     ml**2/mz**2*slhahmix(5,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (sw2*(slhastaumix(1,1)**2+slhastaumixim(1,1)**2-
     .     slhastaumix(1,2)**2-slhastaumixim(1,2)**2)-0.5d0*(
     .     slhastaumix(1,1)**2+slhastaumixim(1,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(1,1)*
     .     slhastaumix(1,2)+slhastaumixim(1,1)*slhastaumixim(1,2))*(
     .     al*slhahmix(5,1)-alim*dsin(b)*slhahmix(5,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs)-
c
     .     (slhastaumix(1,1)*slhastaumixim(1,2)-slhastaumixim(1,1)*
     .     slhastaumix(1,2))*(al*dsin(b)*slhahmix(5,4)+alim*
     .     slhahmix(5,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs))
      gh5ee(1,2)=ml**2*slhahmix(5,1)*(slhastaumix(1,1)*slhastaumix(2,1)+
     .     slhastaumixim(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumix(2,2)+slhastaumixim(1,2)*slhastaumixim(2,2)+myi*
     .     (slhastaumix(1,1)*slhastaumixim(2,1)+slhastaumix(1,2)*
     .     slhastaumixim(2,2)-slhastaumixim(1,1)*slhastaumix(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(sw2*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumix(2,2)-
     .     slhastaumixim(1,2)*slhastaumixim(2,2)+myi*(slhastaumix(1,1)*
     .     slhastaumixim(2,1)-slhastaumix(1,2)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumix(2,2)))-0.5d0*
     .     (slhastaumix(1,1)*slhastaumix(2,1)+slhastaumixim(1,1)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,1)*slhastaumixim(2,1)-
     .     slhastaumixim(1,1)*slhastaumix(2,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(1,1)*slhastaumix(2,2)+slhastaumixim(1,1)*
     .     slhastaumixim(2,2)+myi*(slhastaumix(1,1)*slhastaumixim(2,2)-
     .     slhastaumixim(1,1)*slhastaumix(2,2)))*((slhahmix(5,1)+myi*
     .     dsin(b)*slhahmix(5,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs)+
c
     .     (slhastaumix(1,2)*slhastaumix(2,1)+slhastaumixim(1,2)*
     .     slhastaumixim(2,1)+myi*(slhastaumix(1,2)*slhastaumixim(2,1)-
     .     slhastaumixim(1,2)*slhastaumix(2,1)))*((slhahmix(5,1)-myi*
     .     dsin(b)*slhahmix(5,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs))
      gh5ee(2,1)=ml**2*slhahmix(5,1)*(slhastaumix(2,1)*slhastaumix(1,1)+
     .     slhastaumixim(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumix(1,2)+slhastaumixim(2,2)*slhastaumixim(1,2)+myi*
     .     (slhastaumix(2,1)*slhastaumixim(1,1)+slhastaumix(2,2)*
     .     slhastaumixim(1,2)-slhastaumixim(2,1)*slhastaumix(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,2)))/dcos(b)/mz**2+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*(sw2*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumix(1,2)-
     .     slhastaumixim(2,2)*slhastaumixim(1,2)+myi*(slhastaumix(2,1)*
     .     slhastaumixim(1,1)-slhastaumix(2,2)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumix(1,2)))-0.5d0*
     .     (slhastaumix(2,1)*slhastaumix(1,1)+slhastaumixim(2,1)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,1)*slhastaumixim(1,1)-
     .     slhastaumixim(2,1)*slhastaumix(1,1))))+
c
     .     ml/dcos(b)/2.d0/mz**2*(
     .     (slhastaumix(2,1)*slhastaumix(1,2)+slhastaumixim(2,1)*
     .     slhastaumixim(1,2)+myi*(slhastaumix(2,1)*slhastaumixim(1,2)-
     .     slhastaumixim(2,1)*slhastaumix(1,2)))*((slhahmix(5,1)+myi*
     .     dsin(b)*slhahmix(5,4))*(al+myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))-myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs)+
c
     .     (slhastaumix(2,2)*slhastaumix(1,1)+slhastaumixim(2,2)*
     .     slhastaumixim(1,1)+myi*(slhastaumix(2,2)*slhastaumixim(1,1)-
     .     slhastaumixim(2,2)*slhastaumix(1,1)))*((slhahmix(5,1)-myi*
     .     dsin(b)*slhahmix(5,4))*(al-myi*alim)-(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+myi*(
     .     (dcos(aphiu)*xlamvs-dsin(aphiu)*xlamvsim)*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5))+
     .     (dcos(aphiu)*xlamvsim+dsin(aphiu)*xlamvs)*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))))/vs))
      gh5ee(2,2)=(slhastaumix(2,1)**2+slhastaumixim(2,1)**2+
     .     slhastaumix(2,2)**2+slhastaumixim(2,2)**2)*
     .     ml**2/mz**2*slhahmix(5,1)/dcos(b)+
c
     .     (dcos(b)*slhahmix(5,1)-dsin(b)*slhahmix(5,2))*
     .     (sw2*(slhastaumix(2,1)**2+slhastaumixim(2,1)**2-
     .     slhastaumix(2,2)**2-slhastaumixim(2,2)**2)-0.5d0*(
     .     slhastaumix(2,1)**2+slhastaumixim(2,1)**2))+
c
     .     ml/dcos(b)/mz**2*((slhastaumix(2,1)*
     .     slhastaumix(2,2)+slhastaumixim(2,1)*slhastaumixim(2,2))*(
     .     al*slhahmix(5,1)-alim*dsin(b)*slhahmix(5,4)-
     .     ((xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*(
     .     vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))-
     .     (xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs)-
c
     .     (slhastaumix(2,1)*slhastaumixim(2,2)-slhastaumixim(2,1)*
     .     slhastaumix(2,2))*(al*dsin(b)*slhahmix(5,4)+alim*
     .     slhahmix(5,1)+((xlamvs*dsin(aphiu)+xlamvsim*dcos(aphiu))*
     .     (vs*slhahmix(5,2)+v*dsin(b)*slhahmix(5,3))+
     .     (xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu))*
     .     (vs*dcos(b)*slhahmix(5,4)+v*dsin(b)*slhahmix(5,5)))/vs))

      do j=1,2,1
         do ik=1,2,1
            ghiee(1,j,ik) = gh1ee(j,ik)
            ghiee(2,j,ik) = gh2ee(j,ik)
            ghiee(3,j,ik) = gh3ee(j,ik)
            ghiee(4,j,ik) = gh4ee(j,ik)
            ghiee(5,j,ik) = gh5ee(j,ik)
         end do
      end do

c --- CP-even Higgs couplings to sups --- c

      gh1uu(1,1)=(slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (0.5d0-2.d0/3.d0*sw2) 
      gh1uu(2,2)=(slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (2.d0/3.d0*sw2) 
      gh1uu(1,2)=0.D0
      gh1uu(2,1)=0.D0


      gh2uu(1,1)=(slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (0.5d0-2.d0/3.d0*sw2) 
      gh2uu(2,2)=(slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (2.d0/3.d0*sw2) 
      gh2uu(1,2)=0.D0
      gh2uu(2,1)=0.D0

      gh3uu(1,1)=(slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (0.5d0-2.d0/3.d0*sw2) 
      gh3uu(2,2)=(slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (2.d0/3.d0*sw2) 
      gh3uu(1,2)=0.D0
      gh3uu(2,1)=0.D0

      gh4uu(1,1)=(slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (0.5d0-2.d0/3.d0*sw2) 
      gh4uu(2,2)=(slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (2.d0/3.d0*sw2) 
      gh4uu(1,2)=0.D0
      gh4uu(2,1)=0.D0

      gh5uu(1,1)=(slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (0.5d0-2.d0/3.d0*sw2) 
      gh5uu(2,2)=(slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (2.d0/3.d0*sw2) 
      gh5uu(1,2)=0.D0
      gh5uu(2,1)=0.D0

      do j=1,2,1
         do ik=1,2,1
            ghiuu(1,j,ik) = gh1uu(j,ik)
            ghiuu(2,j,ik) = gh2uu(j,ik)
            ghiuu(3,j,ik) = gh3uu(j,ik)
            ghiuu(4,j,ik) = gh4uu(j,ik)
            ghiuu(5,j,ik) = gh5uu(j,ik)
         end do
      end do

c --- CP-even Higgs couplings to sdowns --- c

      gh1dd(1,1) = (slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (-0.5D0+1.D0/3.D0*sw2) 
      gh1dd(2,2) = (slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (-1.D0/3.D0*sw2) 
      gh1dd(1,2) = 0.D0
      gh1dd(2,1) = 0.D0

      gh2dd(1,1) = (slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (-0.5D0+1.D0/3.D0*sw2) 
      gh2dd(2,2) = (slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (-1.D0/3.D0*sw2) 
      gh2dd(1,2) = 0.D0
      gh2dd(2,1) = 0.D0

      gh3dd(1,1) = (slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (-0.5D0+1.D0/3.D0*sw2) 
      gh3dd(2,2) = (slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (-1.D0/3.D0*sw2) 
      gh3dd(1,2) = 0.D0
      gh3dd(2,1) = 0.D0

      gh4dd(1,1) = (slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (-0.5D0+1.D0/3.D0*sw2) 
      gh4dd(2,2) = (slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (-1.D0/3.D0*sw2) 
      gh4dd(1,2) = 0.D0
      gh4dd(2,1) = 0.D0

      gh5dd(1,1) = (slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (-0.5D0+1.D0/3.D0*sw2) 
      gh5dd(2,2) = (slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (-1.D0/3.D0*sw2) 
      gh5dd(1,2) = 0.D0
      gh5dd(2,1) = 0.D0

      do j=1,2,1
         do ik=1,2,1
            ghidd(1,j,ik) = gh1dd(j,ik)
            ghidd(2,j,ik) = gh2dd(j,ik)
            ghidd(3,j,ik) = gh3dd(j,ik)
            ghidd(4,j,ik) = gh4dd(j,ik)
            ghidd(5,j,ik) = gh5dd(j,ik)
         end do
      end do

c --- CP-even Higgs couplings to selectrons --- c

      gh1elel(1,1) = (slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (-0.5D0+sw2)
      gh1elel(2,2) = (slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (-sw2)
      gh1elel(1,2) = 0.D0
      gh1elel(2,1) = 0.D0

      gh2elel(1,1) = (slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (-0.5D0+sw2)
      gh2elel(2,2) = (slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (-sw2)
      gh2elel(1,2) = 0.D0
      gh2elel(2,1) = 0.D0

      gh3elel(1,1) = (slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (-0.5D0+sw2)
      gh3elel(2,2) = (slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (-sw2)
      gh3elel(1,2) = 0.D0
      gh3elel(2,1) = 0.D0

      gh4elel(1,1) = (slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (-0.5D0+sw2)
      gh4elel(2,2) = (slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (-sw2)
      gh4elel(1,2) = 0.D0
      gh4elel(2,1) = 0.D0

      gh5elel(1,1) = (slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (-0.5D0+sw2)
      gh5elel(2,2) = (slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (-sw2)
      gh5elel(1,2) = 0.D0
      gh5elel(2,1) = 0.D0

      do j=1,2,1
         do ik=1,2,1
            ghielel(1,j,ik) = gh1elel(j,ik)
            ghielel(2,j,ik) = gh2elel(j,ik)
            ghielel(3,j,ik) = gh3elel(j,ik)
            ghielel(4,j,ik) = gh4elel(j,ik)
            ghielel(5,j,ik) = gh5elel(j,ik)
         end do
      end do

c --- CP-even Higgs couplings to sneutrinos --- c

      gh1nene(1,1)=(slhahmix(1,1)*dcos(b)-slhahmix(1,2)*dsin(b))*
     .     (0.5d0)
      gh1nene(2,2)=0.D0
      gh1nene(1,2)=0.D0
      gh1nene(2,1)=0.D0

      gh2nene(1,1)=(slhahmix(2,1)*dcos(b)-slhahmix(2,2)*dsin(b))*
     .     (0.5d0)
      gh2nene(2,2)=0.D0
      gh2nene(1,2)=0.D0
      gh2nene(2,1)=0.D0

      gh3nene(1,1)=(slhahmix(3,1)*dcos(b)-slhahmix(3,2)*dsin(b))*
     .     (0.5d0)
      gh3nene(2,2)=0.D0
      gh3nene(1,2)=0.D0
      gh3nene(2,1)=0.D0

      gh4nene(1,1)=(slhahmix(4,1)*dcos(b)-slhahmix(4,2)*dsin(b))*
     .     (0.5d0)
      gh4nene(2,2)=0.D0
      gh4nene(1,2)=0.D0
      gh4nene(2,1)=0.D0

      gh5nene(1,1)=(slhahmix(5,1)*dcos(b)-slhahmix(5,2)*dsin(b))*
     .     (0.5d0)
      gh5nene(2,2)=0.D0
      gh5nene(1,2)=0.D0
      gh5nene(2,1)=0.D0

      do j=1,2,1
         do ik=1,2,1
            ghinene(1,j,ik) = gh1nene(j,ik)
            ghinene(2,j,ik) = gh2nene(j,ik)
            ghinene(3,j,ik) = gh3nene(j,ik)
            ghinene(4,j,ik) = gh4nene(j,ik)
            ghinene(5,j,ik) = gh5nene(j,ik)
         end do
      end do

c ---------------- the charged Higgs boson couplings ----------------- c

      cll=(mw**2*dsin(2*b)-mt**2/dtan(b)-mb**2*dtan(b))
     .     /dsqrt(2.D0)/mw**2
      crrre=-mt*mb*(1.D0/dtan(b)+dtan(b))*dcos(aphiu)/dsqrt(2.D0)/mw**2
      crrim=mt*mb*(1.D0/dtan(b)+dtan(b))*dsin(aphiu)/dsqrt(2.D0)/mw**2

      clrre=-mb*(xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu)+ab*dtan(b))
     ./dsqrt(2.D0)/mw**2
      clrim=-mb*(abim*dtan(b)-xlamvsim*dcos(aphiu)-dsin(aphiu)*xlamvs)
     ./dsqrt(2.D0)/mw**2

      crlre=-mt*(xlamvs+(at*dcos(aphiu)-atim*dsin(aphiu))/dtan(b))/
     .     dsqrt(2.D0)/mw**2
      crlim=-mt*(xlamvsim-(at*dsin(aphiu)+atim*dcos(aphiu))/dtan(b))
     .     /dsqrt(2.D0)/mw**2

      ghctb(1,1)=(slhastmix(1,1)*slhasbmix(1,1)+slhastmixim(1,1)*
     .     slhasbmixim(1,1)+myi*(slhastmix(1,1)*slhasbmixim(1,1)-
     .     slhastmixim(1,1)*slhasbmix(1,1)))*cll+
c
     .     (slhastmix(1,2)*slhasbmix(1,2)+slhastmixim(1,2)*
     .     slhasbmixim(1,2))*crrre-(slhastmix(1,2)*slhasbmixim(1,2)-
     .     slhastmixim(1,2)*slhasbmix(1,2))*crrim+myi*(
     .     (slhastmix(1,2)*slhasbmixim(1,2)-slhastmixim(1,2)*
     .     slhasbmix(1,2))*crrre+(slhastmix(1,2)*slhasbmix(1,2)+
     .     slhastmixim(1,2)*slhasbmixim(1,2))*crrim)+
c
     .     (slhastmix(1,2)*slhasbmix(1,1)+slhastmixim(1,2)*
     .     slhasbmixim(1,1))*crlre-(slhastmix(1,2)*slhasbmixim(1,1)-
     .     slhastmixim(1,2)*slhasbmix(1,1))*crlim+myi*((slhastmix(1,2)*
     .     slhasbmixim(1,1)-slhastmixim(1,2)*slhasbmix(1,1))*crlre+
     .     (slhastmix(1,2)*slhasbmix(1,1)+slhastmixim(1,2)*
     .     slhasbmixim(1,1))*crlim)+
c
     .     (slhastmix(1,1)*slhasbmix(1,2)+slhastmixim(1,1)*
     .     slhasbmixim(1,2))*clrre-(slhastmix(1,1)*slhasbmixim(1,2)-
     .     slhastmixim(1,1)*slhasbmix(1,2))*clrim+myi*((slhastmix(1,1)*
     .     slhasbmixim(1,2)-slhastmixim(1,1)*slhasbmix(1,2))*clrre+
     .     (slhastmix(1,1)*slhasbmix(1,2)+slhastmixim(1,1)*
     .     slhasbmixim(1,2))*clrim) 

      ghctb(1,2)=(slhastmix(1,1)*slhasbmix(2,1)+slhastmixim(1,1)*
     .     slhasbmixim(2,1)+myi*(slhastmix(1,1)*slhasbmixim(2,1)-
     .     slhastmixim(1,1)*slhasbmix(2,1)))*cll+
c
     .     (slhastmix(1,2)*slhasbmix(2,2)+slhastmixim(1,2)*
     .     slhasbmixim(2,2))*crrre-(slhastmix(1,2)*slhasbmixim(2,2)-
     .     slhastmixim(1,2)*slhasbmix(2,2))*crrim+myi*(
     .     (slhastmix(1,2)*slhasbmixim(2,2)-slhastmixim(1,2)*
     .     slhasbmix(2,2))*crrre+(slhastmix(1,2)*slhasbmix(2,2)+
     .     slhastmixim(1,2)*slhasbmixim(2,2))*crrim)+
c
     .     (slhastmix(1,2)*slhasbmix(2,1)+slhastmixim(1,2)*
     .     slhasbmixim(2,1))*crlre-(slhastmix(1,2)*slhasbmixim(2,1)-
     .     slhastmixim(1,2)*slhasbmix(2,1))*crlim+myi*((slhastmix(1,2)*
     .     slhasbmixim(2,1)-slhastmixim(1,2)*slhasbmix(2,1))*crlre+
     .     (slhastmix(1,2)*slhasbmix(2,1)+slhastmixim(1,2)*
     .     slhasbmixim(2,1))*crlim)+
c
     .     (slhastmix(1,1)*slhasbmix(2,2)+slhastmixim(1,1)*
     .     slhasbmixim(2,2))*clrre-(slhastmix(1,1)*slhasbmixim(2,2)-
     .     slhastmixim(1,1)*slhasbmix(2,2))*clrim+myi*((slhastmix(1,1)*
     .     slhasbmixim(2,2)-slhastmixim(1,1)*slhasbmix(2,2))*clrre+
     .     (slhastmix(1,1)*slhasbmix(2,2)+slhastmixim(1,1)*
     .     slhasbmixim(2,2))*clrim)
      ghctb(2,1)=(slhastmix(2,1)*slhasbmix(1,1)+slhastmixim(2,1)*
     .     slhasbmixim(1,1)+myi*(slhastmix(2,1)*slhasbmixim(1,1)-
     .     slhastmixim(2,1)*slhasbmix(1,1)))*cll+
c
     .     (slhastmix(2,2)*slhasbmix(1,2)+slhastmixim(2,2)*
     .     slhasbmixim(1,2))*crrre-(slhastmix(2,2)*slhasbmixim(1,2)-
     .     slhastmixim(2,2)*slhasbmix(1,2))*crrim+myi*(
     .     (slhastmix(2,2)*slhasbmixim(1,2)-slhastmixim(2,2)*
     .     slhasbmix(1,2))*crrre+(slhastmix(2,2)*slhasbmix(1,2)+
     .     slhastmixim(2,2)*slhasbmixim(1,2))*crrim)+
c
     .     (slhastmix(2,2)*slhasbmix(1,1)+slhastmixim(2,2)*
     .     slhasbmixim(1,1))*crlre-(slhastmix(2,2)*slhasbmixim(1,1)-
     .     slhastmixim(2,2)*slhasbmix(1,1))*crlim+myi*((slhastmix(2,2)*
     .     slhasbmixim(1,1)-slhastmixim(2,2)*slhasbmix(1,1))*crlre+
     .     (slhastmix(2,2)*slhasbmix(1,1)+slhastmixim(2,2)*
     .     slhasbmixim(1,1))*crlim)+
c
     .     (slhastmix(2,1)*slhasbmix(1,2)+slhastmixim(2,1)*
     .     slhasbmixim(1,2))*clrre-(slhastmix(2,1)*slhasbmixim(1,2)-
     .     slhastmixim(2,1)*slhasbmix(1,2))*clrim+myi*((slhastmix(2,1)*
     .     slhasbmixim(1,2)-slhastmixim(2,1)*slhasbmix(1,2))*clrre+
     .     (slhastmix(2,1)*slhasbmix(1,2)+slhastmixim(2,1)*
     .     slhasbmixim(1,2))*clrim)
      ghctb(2,2)=(slhastmix(2,1)*slhasbmix(2,1)+slhastmixim(2,1)*
     .     slhasbmixim(2,1)+myi*(slhastmix(2,1)*slhasbmixim(2,1)-
     .     slhastmixim(2,1)*slhasbmix(2,1)))*cll+
c
     .     (slhastmix(2,2)*slhasbmix(2,2)+slhastmixim(2,2)*
     .     slhasbmixim(2,2))*crrre-(slhastmix(2,2)*slhasbmixim(2,2)-
     .     slhastmixim(2,2)*slhasbmix(2,2))*crrim+myi*(
     .     (slhastmix(2,2)*slhasbmixim(2,2)-slhastmixim(2,2)*
     .     slhasbmix(2,2))*crrre+(slhastmix(2,2)*slhasbmix(2,2)+
     .     slhastmixim(2,2)*slhasbmixim(2,2))*crrim)+
c
     .     (slhastmix(2,2)*slhasbmix(2,1)+slhastmixim(2,2)*
     .     slhasbmixim(2,1))*crlre-(slhastmix(2,2)*slhasbmixim(2,1)-
     .     slhastmixim(2,2)*slhasbmix(2,1))*crlim+myi*((slhastmix(2,2)*
     .     slhasbmixim(2,1)-slhastmixim(2,2)*slhasbmix(2,1))*crlre+
     .     (slhastmix(2,2)*slhasbmix(2,1)+slhastmixim(2,2)*
     .     slhasbmixim(2,1))*crlim)+
c
     .     (slhastmix(2,1)*slhasbmix(2,2)+slhastmixim(2,1)*
     .     slhasbmixim(2,2))*clrre-(slhastmix(2,1)*slhasbmixim(2,2)-
     .     slhastmixim(2,1)*slhasbmix(2,2))*clrim+myi*((slhastmix(2,1)*
     .     slhasbmixim(2,2)-slhastmixim(2,1)*slhasbmix(2,2))*clrre+
     .     (slhastmix(2,1)*slhasbmix(2,2)+slhastmixim(2,1)*
     .     slhasbmixim(2,2))*clrim)


      cll=(mw**2*dsin(2*b))/dsqrt(2.D0)/mw**2
      ghcud(1,1)=cll
      ghcud(1,2)=0.D0
      ghcud(2,1)=0.D0
      ghcud(2,2)=0.D0

      clrre=-ml*(xlamvs*dcos(aphiu)-xlamvsim*dsin(aphiu)
     .+al*dtan(b))/dsqrt(2.D0)/mw**2
      clrim=-ml*(alim*dtan(b)-xlamvsim*dcos(aphiu)-xlamvs*dsin(aphiu)
     .)/dsqrt(2.D0)/mw**2 
      cll=(mw**2*dsin(2*b)-ml**2*dtan(b))/dsqrt(2.D0)/mw**2
      ghcen(1,1)=(slhastaumix(1,1)+myi*slhastaumixim(1,1))*cll+
     .     slhastaumix(1,2)*clrre-slhastaumixim(1,2)*clrim+
     .     myi*(slhastaumixim(1,2)*clrre+slhastaumix(1,2)*clrim)
      ghcen(1,2)=(slhastaumix(2,1)+myi*slhastaumixim(2,1))*cll+
     .     slhastaumix(2,2)*clrre-slhastaumixim(2,2)*clrim+
     .     myi*(slhastaumixim(2,2)*clrre+slhastaumix(2,2)*clrim)
      ghcen(2,1)=0.d0
      ghcen(2,2)=0.d0

      cll=(mw**2*dsin(2*b))/dsqrt(2.D0)/mw**2

      ghcelne(1,1)=cll
      ghcelne(1,2)=0.D0
      ghcelne(2,1)=0.D0
      ghcelne(2,2)=0.D0 

c -------------------------------------------------------------------- c

      do i = 1,2
         ymst(i) = mst(i)
         ymsb(i) = msb(i)
         do j = 1,2
            ystmix(i,j) = slhastmix(i,j)
            ysbmix(i,j) = slhasbmix(i,j)
            ystmixim(i,j) = slhastmixim(i,j)
            ysbmixim(i,j) = slhasbmixim(i,j)
            yh1tt(i,j) = gh1tt(i,j)
            yh2tt(i,j) = gh2tt(i,j)
            yh3tt(i,j) = gh3tt(i,j)
            yh4tt(i,j) = gh4tt(i,j)
            yh5tt(i,j) = gh5tt(i,j)
            yh1bb(i,j) = gh1bb(i,j)
            yh2bb(i,j) = gh2bb(i,j)
            yh3bb(i,j) = gh3bb(i,j)
            yh4bb(i,j) = gh4bb(i,j)
            yh5bb(i,j) = gh5bb(i,j)
         enddo
      enddo

C--FILL COMMON BLOCK GLUINO_CNMSSM FOR SUSY-QCD CORRECTIONS TO
C  HIGGS -> BB, SQUARKS

      xmst1 = mst(1)
      xmst2 = mst(2)
      xmsb1 = msb(1)
      xmsb2 = msb(2)

      do i=1,2
         do j=1,2
            xsbmix(i,j) = slhasbmix(i,j)
            xstmix(i,j) = slhastmix(i,j)
            xsbmixim(i,j) = slhasbmixim(i,j)
            xstmixim(i,j) = slhastmixim(i,j)
            xh1bb(i,j) = gh1bb(i,j)
            xh2bb(i,j) = gh2bb(i,j)
            xh3bb(i,j) = gh3bb(i,j)
            xh4bb(i,j) = gh4bb(i,j)
            xh5bb(i,j) = gh5bb(i,j)
            xh1tt(i,j) = gh1tt(i,j)
            xh2tt(i,j) = gh2tt(i,j)
            xh3tt(i,j) = gh3tt(i,j)
            xh4tt(i,j) = gh4tt(i,j)
            xh5tt(i,j) = gh5tt(i,j)
         enddo
      enddo

      return
111   stop
      end  

c ==================================================================== c
c subroutine for the interpolation of off-shell Higgs-to-Higgs decays  c
c ==================================================================== c

      subroutine DecInterpolation_CNMSSM(inputfile,i,j,k,ghibv,gaibv,
     .     ghitv,gaitv,ghivvv,ghihpwmv,gaihpwmv,amhiggsv,amcv)

      implicit double precision (a-h,m,o-z)
      parameter(nintmp=111)
      character inputfile*100
      character spinfo1*100,spinfo2*100,mincom(1:20)*20,
     .          extcom(0:100)*20,softcom(1:100)*20,hmixcom(1:10)*20
      character imextcom(0:100)*20,imsoftcom(1:100)*20,
     .          cmplxvcom(1:10)*20
      character ospinfo1*100,ospinfo2*100,
     .          omincom(1:20)*20,oextcom(0:100)*20,osoftcom(1:100)*20,
     .          ohmixcom(1:10)*20
      character oimextcom(0:100)*20,oimsoftcom(1:100)*20,
     .          ocmplxvcom(1:10)*20
      integer imod(1:2),ioimod(1:2)
      integer modselval(15),omodselval(15)
      double precision ghibv(5),gaibv(5),ghivvv(5),ghihpwmv(5),
     .     gaihpwmv(5),ghitv(5),gaitv(5),amhiggsv(5)
      double precision minval(1:20),smval(1:24),massval(1:50),
     .                 nmixval(5,5),umixval(2,2),vmixval(2,2),
     .                 stopmixval(2,2),sbotmixval(2,2),staumixval(2,2),
     .                 hmixval(1:10),gaugeval(1:3),msoftval(1:100),
     .                 auval(3,3),adval(3,3),aeval(3,3),yuval(3,3),
     .                 ydval(3,3),yeval(3,3),qvalue(1:20),extval(0:100),
     .                 m_softval(1:100),cmplxv(1:10),vckmval(4)
      double precision imnmixval(5,5),imumixval(2,2),imvmixval(2,2),
     .                 imstopmixval(2,2),imsbotmixval(2,2),
     .                 imstaumixval(2,2),imextval(0:100),
     .                 immsoftval(1:100)
      double precision ominval(1:20),osmval(1:24),omassval(1:50),
     .                 onmixval(5,5),oumixval(2,2),ovmixval(2,2),
     .                 ostopmixval(2,2),osbotmixval(2,2),
     .                 ostaumixval(2,2),ohmixval(1:10),ogaugeval(1:3),
     .                 omsoftval(1:100),oauval(3,3),oadval(3,3),
     .                 oaeval(3,3),oyuval(3,3),oydval(3,3),oyeval(3,3),
     .                 oqvalue(1:20),oextval(0:100),om_softval(1:100),
     .                 ocmplxv(1:10),ovckmval(4)
      double precision oimnmixval(5,5),oimumixval(2,2),oimvmixval(2,2),
     .                 oimstopmixval(2,2),oimsbotmixval(2,2),
     .                 oimstaumixval(2,2),oimextval(0:100),
     .                 oimmsoftval(1:100)
      double precision nmhmixval(5,5),slhahmix(5,5)
      double precision onmhmixval(5,5),oslhahmix(5,5)
      integer check(1:34),ocheck(1:34)

      COMMON/PARAM_HDEC/gf,alph,amtau,ammuon,amz,amw
c -------------- common block given by read_leshouches -------------- c
      COMMON/SLHA_leshouches0_NMSSM/spinfo1,spinfo2,modselval
      COMMON/SLHA_leshouches1_NMSSM/extcom,mincom,softcom,hmixcom
      COMMON/SLHA_leshouches1_CNMSSM/imextcom,imsoftcom,cmplxvcom
      COMMON/SLHA_leshouches2_NMSSM/minval,extval,smval,massval,
     .                   nmixval,umixval,vmixval,stopmixval,sbotmixval,
     .                   staumixval,hmixval,gaugeval,msoftval,auval,
     .                   adval,aeval,yuval,ydval,yeval,qvalue,imod
      COMMON/SLHA_leshouches2_CNMSSM/cmplxv
      COMMON/SLHA_leshouches3_CNMSSM/nmhmixval
      COMMON/SLHA_leshouches4_CNMSSM/imextval,imnmixval,imumixval,
     .     imvmixval,imstopmixval,imsbotmixval,imstaumixval,immsoftval
      COMMON/SLHA_checkval_CNMSSM/check
      COMMON/SLHA_leshouches3_HDEC/vckmval
c -------------------------------------------------------------------- c

c -- save the previous parameters -- c

      ospinfo1 = spinfo1
      ospinfo2 = spinfo2
      omodselval = modselval

      do ii=1,2,1
         ioimod(ii) = imod(ii)
      end do

      do ii=1,10,1
         ocmplxv(ii) = cmplxv(ii)
         ocmplxvcom(ii) = cmplxvcom(ii)
      end do
      do ii=1,20,1
         ominval(ii) = minval(ii)
         omincom(ii) = mincom(ii)
         oqvalue(ii) = qvalue(ii)
      end do
      do ii=1,24,1
         osmval(ii) = smval(ii)
      end do
      do ii=1,50,1
         omassval(ii) = massval(ii)
      end do
      do ii=1,5,1
         do jj=1,5,1
            onmixval(ii,jj) = nmixval(ii,jj)
            oimnmixval(ii,jj) = imnmixval(ii,jj)
         end do
      end do
      do ii=1,2,1
         do jj=1,2,1
            oumixval(ii,jj) = umixval(ii,jj)
            ovmixval(ii,jj) = vmixval(ii,jj)
            oimumixval(ii,jj) = imumixval(ii,jj)
            oimvmixval(ii,jj) = imvmixval(ii,jj)
            ostopmixval(ii,jj) = stopmixval(ii,jj)
            oimstopmixval(ii,jj) = imstopmixval(ii,jj)
            osbotmixval(ii,jj) = sbotmixval(ii,jj)
            oimsbotmixval(ii,jj) = imsbotmixval(ii,jj)
            ostaumixval(ii,jj) = staumixval(ii,jj)
            oimstaumixval(ii,jj) = imstaumixval(ii,jj)
         end do
      end do
      do ii=1,10,1
         ohmixval(ii) = hmixval(ii)
         ohmixcom(ii) = hmixcom(ii)
      end do
      do ii=1,3,1
         ogaugeval(ii) = gaugeval(ii)
      end do
      do ii=1,100,1
         omsoftval(ii) = msoftval(ii)
         osoftcom(ii) = softcom(ii)
         oimmsoftval(ii) = immsoftval(ii)
         oimsoftcom(ii) = imsoftcom(ii)
      end do
      do ii=1,3,1
         do jj=1,3,1
            oauval(ii,jj) = auval(ii,jj)
            oadval(ii,jj) = adval(ii,jj)
            oaeval(ii,jj) = aeval(ii,jj)
            oyuval(ii,jj) = yuval(ii,jj)
            oydval(ii,jj) = ydval(ii,jj)
            oyeval(ii,jj) = yeval(ii,jj)
         end do
      end do
      do ii=0,100,1
         oextval(ii) = extval(ii)
         oextcom(ii) = extcom(ii)
         oimextval(ii) = imextval(ii)
         oimextcom(ii) = imextcom(ii)
      end do
      do ii=1,5,1
         do jj=1,5,1
            onmhmixval(ii,jj) = nmhmixval(ii,jj)
         end do
      end do
      do ii=1,4,1
         ovckmval(ii) = vckmval(ii)
      end do

      do ii=1,34,1
         ocheck(ii) = check(ii)
      end do

c ---------------------------------- c

      open(nintmp,file=inputfile)

      call SLHA_read_leshouches_NMSSM(nintmp)

c -- setting of parameters -- c

      unlikely = -123456789D0

      v=1.d0/dsqrt(dsqrt(2.d0)*gf)

      if(hmixval(2).ne.unlikely) then
         TGBET = hmixval(2)
      else
         tgbet = minval(3)
      endif
      b = datan(tgbet)

      sb = dsin(b)
      cb = dcos(b)

      if(extval(61).ne.unlikely) then
         xlambdapar = extval(61)
         xlambdaparim = imextval(61)
      endif
      if(extval(62).ne.unlikely) then
         xkappa = extval(62)
         xkappaim = imextval(62)
      endif
      if(extval(63).ne.unlikely) then
         Alam = extval(63)
         Alamim = imextval(63)
      endif
      if(extval(64).ne.unlikely) then
         Akap = extval(64)
         Akapim = imextval(64)
      endif
      if(extval(65).ne.unlikely) then
         xlamvs = extval(65)
         xlamvsim = imextval(65)
      endif
      do ii=1,5,1
         do jj=1,5,1
            slhahmix(ii,jj)=nmhmixval(ii,jj)
         end do
      end do

      vs = xlamvs/xlambdapar*dsqrt(2.D0)

c --- the couplings --- c

      do ii=1,5,1
         ghibv(ii) = slhahmix(ii,1)/dcos(b)
         gaibv(ii) = slhahmix(ii,4)*tgbet

         ghitv(ii) = slhahmix(ii,2)/dsin(b)
         gaitv(ii) = slhahmix(ii,4)/tgbet

         ghivvv(ii) = slhahmix(ii,1)*dcos(b)+slhahmix(ii,2)*dsin(b) 
         ghihpwmv(ii) = (slhahmix(ii,1)*dsin(b)-slhahmix(ii,2)*dcos(b))
         gaihpwmv(ii) = slhahmix(ii,4)
      end do

      ghict = 1.D0/tgbet

c --- the masses --- c

      amhiggsv(1) = massval(2)
      amhiggsv(2) = massval(34)
      amhiggsv(3) = massval(3)
      amhiggsv(4) = massval(35)
      if(massval(4).ne.0.D0) then
         amhiggsv(5) = massval(4)
      elseif(extval(26).ne.unlikely) then
         amhiggsv(5) = extval(26)
      elseif(extval(24).ne.unlikely) then
         amhiggsv(5) = dsqrt(extval(24))
      endif

      amcv = massval(5)

c -- put back original parameters -- c

      spinfo1 = ospinfo1
      spinfo2 = ospinfo2
      modselval = omodselval

      do ii=1,2,1
         imod(ii) = ioimod(ii)
      end do

      do ii=1,10,1
         cmplxv(ii) = ocmplxv(ii)
         cmplxvcom(ii) = ocmplxvcom(ii)
      end do
      do ii=1,20,1
         minval(ii) = ominval(ii)
         mincom(ii) = omincom(ii)
         qvalue(ii) = oqvalue(ii)
      end do
      do ii=1,24,1
         smval(ii) = osmval(ii)
      end do
      do ii=1,50,1
         massval(ii) = omassval(ii)
      end do
      do ii=1,5,1
         do jj=1,5,1
            nmixval(ii,jj) = onmixval(ii,jj)
            imnmixval(ii,jj) = oimnmixval(ii,jj)
         end do
      end do
      do ii=1,2,1
         do jj=1,2,1
            umixval(ii,jj) = oumixval(ii,jj)
            imumixval(ii,jj) = oimumixval(ii,jj)
            vmixval(ii,jj) = ovmixval(ii,jj)
            imvmixval(ii,jj) = oimvmixval(ii,jj)
            stopmixval(ii,jj) = ostopmixval(ii,jj)
            imstopmixval(ii,jj) = oimstopmixval(ii,jj)
            sbotmixval(ii,jj) = osbotmixval(ii,jj)
            imsbotmixval(ii,jj) = oimsbotmixval(ii,jj)
            staumixval(ii,jj) = ostaumixval(ii,jj)
            imstaumixval(ii,jj) = oimstaumixval(ii,jj)
         end do
      end do
      do ii=1,10,1
         hmixval(ii) = ohmixval(ii)
         hmixcom(ii) = ohmixcom(ii)
      end do
      do ii=1,3,1
         gaugeval(ii) = ogaugeval(ii)
      end do
      do ii=1,100,1
         msoftval(ii) = omsoftval(ii)
         softcom(ii) = osoftcom(ii)
         immsoftval(ii) = oimmsoftval(ii)
         imsoftcom(ii) = oimsoftcom(ii)
      end do
      do ii=1,3,1
         do jj=1,3,1
            auval(ii,jj) = oauval(ii,jj)
            adval(ii,jj) = oadval(ii,jj)
            aeval(ii,jj) = oaeval(ii,jj)
            yuval(ii,jj) = oyuval(ii,jj)
            ydval(ii,jj) = oydval(ii,jj)
            yeval(ii,jj) = oyeval(ii,jj)
         end do
      end do
      do ii=0,100,1
         extval(ii) = oextval(ii)
         extcom(ii) = oextcom(ii)
         imextval(ii) = oimextval(ii)
         imextcom(ii) = oimextcom(ii)
      end do
      do ii=1,3,1
         do jj=1,3,1
            nmhmixval(ii,jj) = onmhmixval(ii,jj)
         end do
      end do
      do ii=1,4,1
         vckmval(ii) = ovckmval(ii)
      end do

      do ii=1,34,1
         check(ii) = ocheck(ii)
      end do

c ---------------------------------- c

      return

      end

c -------------------------------------------------------------------- c

      double precision function runm_hdec(q,nf0)
      implicit double precision (a-h,o-z)
      parameter (nn=8)
      parameter (zeta3 = 1.202056903159594d0)
      dimension am(nn),ymsb(nn)
      common/als_hdec/xlambda,amca,amba,amta,n0a
      common/masses_hdec/ams,amc,amb,amt
      common/strange_hdec/amsb
      common/run_hdec/xmsb,xmhat,xkfac
      common/flag_hdec/ihiggs,nnlo
      save istrange

      b0(nf)=(33.d0-2.d0*nf)/12d0
      b1(nf) = (102d0-38d0/3d0*nf)/16d0
      b2(nf) = (2857d0/2d0-5033d0/18d0*nf+325d0/54d0*nf**2)/64d0
      g0(nf) = 1d0
      g1(nf) = (202d0/3d0-20d0/9d0*nf)/16d0
      g2(nf) = (1249d0-(2216d0/27d0+160d0/3d0*zeta3)*nf
     .       - 140d0/81d0*nf**2)/64d0
      c1(nf) = g1(nf)/b0(nf) - b1(nf)*g0(nf)/b0(nf)**2
      c2(nf) = ((g1(nf)/b0(nf) - b1(nf)*g0(nf)/b0(nf)**2)**2
     .       + g2(nf)/b0(nf) + b1(nf)**2*g0(nf)/b0(nf)**3
     .       - b1(nf)*g1(nf)/b0(nf)**2 - b2(nf)*g0(nf)/b0(nf)**2)/2d0
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
c     c1(nf) = 1.175d0
c     c2(nf) = 1.501d0
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      tran(x,xk)=1d0+4d0/3d0*alphas_hdec(x,3)/pi
     .              +xk*(alphas_hdec(x,3)/pi)**2
      cq(x,nf)=(2d0*b0(nf)*x)**(g0(nf)/b0(nf))
     .            *(1d0+loop2*c1(nf)*x+loop3*c2(nf)*x**2)
      data istrange/0/
c maggie changed 9/9/2011
      ism4 = 0
c end maggie changed
      nf = nf0
      loop = 3
      loop2 = 1
      loop3 = 1
      if(loop.le.2)loop3 = 0
      if(loop.le.1)loop2 = 0
      pi=4d0*datan(1d0)
      acc = 1.d-8
      am(1) = 0
      am(2) = 0
c--scale of strange msbar-mass
c     qqs = 1.d0
      qqs = 2.d0
c--------------------------------------------
      imsbar = 0
      if(imsbar.eq.1)then
       if(istrange.eq.0)then
c--strange pole mass from msbar-mass at qqs
        amsd = xlambda
        amsu = 1.d8
123     ams  = (amsu+amsd)/2
        am(3) = ams
        xmsb = ams/cq(alphas_hdec(ams,3)/pi,3)
     .            *cq(alphas_hdec(qqs,3)/pi,3)/tran(ams,0d0)
        dd = (xmsb-amsb)/amsb
        if(dabs(dd).ge.acc)then
         if(dd.le.0.d0)then
          amsd = am(3)
         else
          amsu = am(3)
         endif
         goto 123
        endif
        istrange=1
       endif
       am(3) = amsb
      else
       ams=amsb
       am(3) = ams
      endif
c--------------------------------------------
      am(3) = amsb
      am(4) = amc
      am(5) = amb
      am(6) = amt
      am(7) = 100*amt
      am(8) = 200*amt
      if(ism4.ne.0)then
       if(ambp.le.amtp)then
        am(7) = ambp
        am(8) = amtp
       else
        am(7) = amtp
        am(8) = ambp
        if(nf0.eq.7)then
         nf = 8
        else
         nf = 7
        endif
       endif
      endif
      xk = 16.11d0
      do 1 i=1,nf-1
       xk = xk - 1.04d0*(1.d0-am(i)/am(nf))
1     continue
      if(nf.ge.4)then
       xmsb = am(nf)/tran(am(nf),0d0)
       xmhat = xmsb/cq(alphas_hdec(am(nf),3)/pi,nf)
      else
       xmsb = 0
       xmhat = 0
      endif
      ymsb(3) = amsb
      if(nf.eq.3)then
       if(qqs.lt.amc)then
        ymsb(4) = ymsb(3)*cq(alphas_hdec(am(4),3)/pi,3)/
     .                    cq(alphas_hdec(qqs,3)/pi,3)
       else
        ymsb(4) = amsb*cq(alphas_hdec(am(4),3)/pi,4)/
     .                    cq(alphas_hdec(qqs,3)/pi,4)
        ymsb(3) = ymsb(4)
       endif
       ymsb(5) = ymsb(4)*cq(alphas_hdec(am(5),3)/pi,4)/
     .                   cq(alphas_hdec(am(4),3)/pi,4)
       ymsb(6) = ymsb(5)*cq(alphas_hdec(am(6),3)/pi,5)/
     .                   cq(alphas_hdec(am(5),3)/pi,5)
       ymsb(7) = ymsb(6)*cq(alphas_hdec(am(7),3)/pi,6)/
     .                   cq(alphas_hdec(am(6),3)/pi,6)
       ymsb(8) = ymsb(7)*cq(alphas_hdec(am(8),3)/pi,7)/
     .                   cq(alphas_hdec(am(7),3)/pi,7)
      elseif(nf.eq.4)then
       ymsb(4) = xmsb
       ymsb(3) = ymsb(4)*cq(alphas_hdec(qqs,3)/pi,3)/
     .                   cq(alphas_hdec(am(4),3)/pi,3)
       ymsb(5) = ymsb(4)*cq(alphas_hdec(am(5),3)/pi,4)/
     .                   cq(alphas_hdec(am(4),3)/pi,4)
       ymsb(6) = ymsb(5)*cq(alphas_hdec(am(6),3)/pi,5)/
     .                   cq(alphas_hdec(am(5),3)/pi,5)
       ymsb(7) = ymsb(6)*cq(alphas_hdec(am(7),3)/pi,6)/
     .                   cq(alphas_hdec(am(6),3)/pi,6)
       ymsb(8) = ymsb(7)*cq(alphas_hdec(am(8),3)/pi,7)/
     .                   cq(alphas_hdec(am(7),3)/pi,7)
      elseif(nf.eq.5)then
       ymsb(5) = xmsb
       ymsb(4) = ymsb(5)*cq(alphas_hdec(am(4),3)/pi,4)/
     .                   cq(alphas_hdec(am(5),3)/pi,4)
       ymsb(3) = ymsb(4)*cq(alphas_hdec(qqs,3)/pi,3)/
     .                   cq(alphas_hdec(am(4),3)/pi,3)
       ymsb(6) = ymsb(5)*cq(alphas_hdec(am(6),3)/pi,5)/
     .                   cq(alphas_hdec(am(5),3)/pi,5)
       ymsb(7) = ymsb(6)*cq(alphas_hdec(am(7),3)/pi,6)/
     .                   cq(alphas_hdec(am(6),3)/pi,6)
       ymsb(8) = ymsb(7)*cq(alphas_hdec(am(8),3)/pi,7)/
     .                   cq(alphas_hdec(am(7),3)/pi,7)
      elseif(nf.eq.6)then
       ymsb(6) = xmsb
       ymsb(5) = ymsb(6)*cq(alphas_hdec(am(5),3)/pi,5)/
     .                   cq(alphas_hdec(am(6),3)/pi,5)
       ymsb(4) = ymsb(5)*cq(alphas_hdec(am(4),3)/pi,4)/
     .                   cq(alphas_hdec(am(5),3)/pi,4)
       ymsb(3) = ymsb(4)*cq(alphas_hdec(qqs,3)/pi,3)/
     .                   cq(alphas_hdec(am(4),3)/pi,3)
       ymsb(7) = ymsb(6)*cq(alphas_hdec(am(7),3)/pi,6)/
     .                   cq(alphas_hdec(am(6),3)/pi,6)
       ymsb(8) = ymsb(7)*cq(alphas_hdec(am(8),3)/pi,7)/
     .                   cq(alphas_hdec(am(7),3)/pi,7)
      elseif(nf.eq.7)then
       ymsb(7) = xmsb
       ymsb(6) = ymsb(7)*cq(alphas_hdec(am(6),3)/pi,6)/
     .                   cq(alphas_hdec(am(7),3)/pi,6)
       ymsb(5) = ymsb(6)*cq(alphas_hdec(am(5),3)/pi,5)/
     .                   cq(alphas_hdec(am(6),3)/pi,5)
       ymsb(4) = ymsb(5)*cq(alphas_hdec(am(4),3)/pi,4)/
     .                   cq(alphas_hdec(am(5),3)/pi,4)
       ymsb(3) = ymsb(4)*cq(alphas_hdec(qqs,3)/pi,3)/
     .                   cq(alphas_hdec(am(4),3)/pi,3)
       ymsb(8) = ymsb(7)*cq(alphas_hdec(am(8),3)/pi,7)/
     .                   cq(alphas_hdec(am(7),3)/pi,7)
      elseif(nf.eq.8)then
       ymsb(8) = xmsb
       ymsb(7) = ymsb(8)*cq(alphas_hdec(am(7),3)/pi,7)/
     .                   cq(alphas_hdec(am(8),3)/pi,7)
       ymsb(6) = ymsb(7)*cq(alphas_hdec(am(6),3)/pi,6)/
     .                   cq(alphas_hdec(am(7),3)/pi,6)
       ymsb(5) = ymsb(6)*cq(alphas_hdec(am(5),3)/pi,5)/
     .                   cq(alphas_hdec(am(6),3)/pi,5)
       ymsb(4) = ymsb(5)*cq(alphas_hdec(am(4),3)/pi,4)/
     .                   cq(alphas_hdec(am(5),3)/pi,4)
       ymsb(3) = ymsb(4)*cq(alphas_hdec(qqs,3)/pi,3)/
     .                   cq(alphas_hdec(am(4),3)/pi,3)
      endif
      if(q.lt.amc)then
       n0=3
c      if(qqs.lt.amc)then
        q0 = qqs
c      else
c       q0 = amc
c      endif
      elseif(q.le.amb)then
       n0=4
       q0 = amc
      elseif(q.le.amt)then
       n0=5
       q0 = amb
      else
       n0=6
       q0 = amt
       if(ism4.ne.0)then
        if(q.gt.am(7))then
         if(q.le.am(8))then
          n0=7
          q0 = am(7)
         else
          n0=8
          q0 = am(8)
         endif
        endif
       endif
      endif
      if(nnlo.eq.1.and.nf.gt.3)then
       xkfac = tran(am(nf),0d0)/tran(am(nf),xk)
      else
       xkfac = 1d0
      endif
      runm_hdec = ymsb(n0)*cq(alphas_hdec(q,3)/pi,n0)/
     .               cq(alphas_hdec(q0,3)/pi,n0)
     .       * xkfac
      return
      end

c -------------------------------------------------------------------- c

      double precision function alphas_hdec(q,n)
      implicit double precision (a-h,o-z)
      dimension xlb(6)
      common/alslam_hdec/xlb1(6),xlb2(6),xlb3(6)
      common/als_hdec/xlambda,amc,amb,amt,n0

      b0(nf)=33.d0-2.d0*nf
      b1(nf)=6.d0*(153.d0-19.d0*nf)/b0(nf)**2
      b2(nf)=27/2.d0*(2857-5033/9.d0*nf+325/27.d0*nf**2)/b0(nf)**3
      als1(nf,x)=12.d0*pi/(b0(nf)*dlog(x**2/xlb(nf)**2))
      als2(nf,x)=12.d0*pi/(b0(nf)*dlog(x**2/xlb(nf)**2))
     .          *(1.d0-b1(nf)*dlog(dlog(x**2/xlb(nf)**2))
     .           /dlog(x**2/xlb(nf)**2))
      als3(nf,x)=12.d0*pi/(b0(nf)*dlog(x**2/xlb(nf)**2))
     .          *(1.d0-b1(nf)*dlog(dlog(x**2/xlb(nf)**2))
     .           /dlog(x**2/xlb(nf)**2)
     .           +(b1(nf)**2*(dlog(dlog(x**2/xlb(nf)**2))**2
     .                      -dlog(dlog(x**2/xlb(nf)**2))-1)+b2(nf))
     .           /dlog(x**2/xlb(nf)**2)**2)
      pi=4.d0*datan(1.d0)
c     write(6,*)'als param: ',xlambda,amc,amb,amt,n0
      if(n.eq.1)then
       do 1 i=1,6
        xlb(i)=xlb1(i)
1      continue
      elseif(n.eq.2)then
       do 2 i=1,6
        xlb(i)=xlb2(i)
2      continue
      else
       do 3 i=1,6
        xlb(i)=xlb3(i)
3      continue
      endif
      if(q.lt.amc)then
       nf=3
      elseif(q.le.amb)then
       nf=4
      elseif(q.le.amt)then
       nf=5
      else
       nf=6
      endif
      if(n.eq.1)then
        alphas_hdec=als1(nf,q)
      elseif(n.eq.2)then
        alphas_hdec=als2(nf,q)
      else
        alphas_hdec=als3(nf,q)
      endif
      return
      end

c -------------------------------------------------------------------- c

      subroutine alsini_hdec(acc)
      implicit double precision (a-h,o-z)
      dimension xlb(6)
      common/alslam_hdec/xlb1(6),xlb2(6),xlb3(6)
      common/als_hdec/xlambda,amc,amb,amt,n0

      pi=4.d0*datan(1.d0)
      xlb1(1)=0d0
      xlb1(2)=0d0
      xlb2(1)=0d0
      xlb2(2)=0d0
      if(n0.eq.3)then
       xlb(3)=xlambda
       xlb(4)=xlb(3)*(xlb(3)/amc)**(2.d0/25.d0)
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
      elseif(n0.eq.4)then
       xlb(4)=xlambda
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
      elseif(n0.eq.5)then
       xlb(5)=xlambda
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
      elseif(n0.eq.6)then
       xlb(6)=xlambda
       xlb(5)=xlb(6)*(xlb(6)/amt)**(-2.d0/23.d0)
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
      endif
      do 1 i=3,6
       xlb1(i)=xlb(i)
1     continue
      if(n0.eq.3)then
       xlb(3)=xlambda
       xlb(4)=xlb(3)*(xlb(3)/amc)**(2.d0/25.d0)
     .             *(2.d0*dlog(amc/xlb(3)))**(-107.d0/1875.d0)
       xlb(4)=xiter_hdec(amc,xlb(3),3,xlb(4),4,acc)
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
     .             *(2.d0*dlog(amb/xlb(4)))**(-963.d0/13225.d0)
       xlb(5)=xiter_hdec(amb,xlb(4),4,xlb(5),5,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.4)then
       xlb(4)=xlambda
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
     .             *(2.d0*dlog(amb/xlb(4)))**(-963.d0/13225.d0)
       xlb(5)=xiter_hdec(amb,xlb(4),4,xlb(5),5,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter_hdec(amc,xlb(4),4,xlb(3),3,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.5)then
       xlb(5)=xlambda
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
     .             *(2.d0*dlog(amb/xlb(5)))**(963.d0/14375.d0)
       xlb(4)=xiter_hdec(amb,xlb(5),5,xlb(4),4,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter_hdec(amc,xlb(4),4,xlb(3),3,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.6)then
       xlb(6)=xlambda
       xlb(5)=xlb(6)*(xlb(6)/amt)**(-2.d0/23.d0)
     .            *(2.d0*dlog(amt/xlb(6)))**(321.d0/3703.d0)
       xlb(5)=xiter_hdec(amt,xlb(6),6,xlb(5),5,acc)
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
     .             *(2.d0*dlog(amb/xlb(5)))**(963.d0/14375.d0)
       xlb(4)=xiter_hdec(amb,xlb(5),5,xlb(4),4,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter_hdec(amc,xlb(4),4,xlb(3),3,acc)
      endif
      do 2 i=3,6
       xlb2(i)=xlb(i)
2     continue
      if(n0.eq.3)then
       xlb(3)=xlambda
       xlb(4)=xlb(3)*(xlb(3)/amc)**(2.d0/25.d0)
     .             *(2.d0*dlog(amc/xlb(3)))**(-107.d0/1875.d0)
       xlb(4)=xiter3_hdec(amc,xlb(3),3,xlb(4),4,acc)
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
     .             *(2.d0*dlog(amb/xlb(4)))**(-963.d0/13225.d0)
       xlb(5)=xiter3_hdec(amb,xlb(4),4,xlb(5),5,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter3_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.4)then
       xlb(4)=xlambda
       xlb(5)=xlb(4)*(xlb(4)/amb)**(2.d0/23.d0)
     .             *(2.d0*dlog(amb/xlb(4)))**(-963.d0/13225.d0)
       xlb(5)=xiter3_hdec(amb,xlb(4),4,xlb(5),5,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter3_hdec(amc,xlb(4),4,xlb(3),3,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter3_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.5)then
       xlb(5)=xlambda
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
     .             *(2.d0*dlog(amb/xlb(5)))**(963.d0/14375.d0)
       xlb(4)=xiter3_hdec(amb,xlb(5),5,xlb(4),4,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter3_hdec(amc,xlb(4),4,xlb(3),3,acc)
       xlb(6)=xlb(5)*(xlb(5)/amt)**(2.d0/21.d0)
     .            *(2.d0*dlog(amt/xlb(5)))**(-321.d0/3381.d0)
       xlb(6)=xiter3_hdec(amt,xlb(5),5,xlb(6),6,acc)
      elseif(n0.eq.6)then
       xlb(6)=xlambda
       xlb(5)=xlb(6)*(xlb(6)/amt)**(-2.d0/23.d0)
     .            *(2.d0*dlog(amt/xlb(6)))**(321.d0/3703.d0)
       xlb(5)=xiter3_hdec(amt,xlb(6),6,xlb(5),5,acc)
       xlb(4)=xlb(5)*(xlb(5)/amb)**(-2.d0/25.d0)
     .             *(2.d0*dlog(amb/xlb(5)))**(963.d0/14375.d0)
       xlb(4)=xiter3_hdec(amb,xlb(5),5,xlb(4),4,acc)
       xlb(3)=xlb(4)*(xlb(4)/amc)**(-2.d0/27.d0)
     .             *(2.d0*dlog(amc/xlb(4)))**(107.d0/2025.d0)
       xlb(3)=xiter3_hdec(amc,xlb(4),4,xlb(3),3,acc)
      endif
      do 3 i=3,6
       xlb3(i)=xlb(i)
3     continue
      return
      end

c -------------------------------------------------------------------- c

      double precision function xiter_hdec(q,xlb1,nf1,xlb,nf2,acc)
      implicit double precision (a-h,o-z)

      b0(nf)=33.d0-2.d0*nf
      b1(nf)=6.d0*(153.d0-19.d0*nf)/b0(nf)**2
      als2(nf,x,xlb)=12.d0*pi/(b0(nf)*dlog(x**2/xlb**2))
     .              *(1.d0-b1(nf)*dlog(dlog(x**2/xlb**2))
     .              /dlog(x**2/xlb**2))
      aa(nf)=12d0*pi/b0(nf)
      bb(nf)=b1(nf)/aa(nf)
      xit(a,b,x)=a/2.d0*(1d0+dsqrt(1d0-4d0*b*dlog(x)))
      pi=4.d0*datan(1.d0)
      xlb2=xlb
      ii=0
1     ii=ii+1
      x=dlog(q**2/xlb2**2)
      alp=als2(nf1,q,xlb1)
      a=aa(nf2)/alp
      b=bb(nf2)*alp
      xx=xit(a,b,x)
      xlb2=q*dexp(-xx/2.d0)
      y1=als2(nf1,q,xlb1)
      y2=als2(nf2,q,xlb2)
      dy=dabs(y2-y1)/y1
      if(dy.ge.acc) goto 1
       xiter_hdec=xlb2
      return
      end

c -------------------------------------------------------------------- c

      double precision function xiter3_hdec(q,xlb1,nf1,xlb,nf2,acc)
      implicit double precision (a-h,o-z)

      b0(nf)=33.d0-2.d0*nf
      b1(nf)=6.d0*(153.d0-19.d0*nf)/b0(nf)**2
      b2(nf)=27/2.d0*(2857-5033/9.d0*nf+325/27.d0*nf**2)/b0(nf)**3
      als3(nf,x,xlb)=12.d0*pi/(b0(nf)*dlog(x**2/xlb**2))
     .          *(1.d0-b1(nf)*dlog(dlog(x**2/xlb**2))
     .           /dlog(x**2/xlb**2)
     .           +(b1(nf)**2*(dlog(dlog(x**2/xlb**2))**2
     .                      -dlog(dlog(x**2/xlb**2))-1)+b2(nf))
     .           /dlog(x**2/xlb**2)**2)
      aa(nf)=12d0*pi/b0(nf)
      bb(nf)=b1(nf)/aa(nf)
      cc(nf)=b2(nf)/aa(nf)
      xit(a,b,c,x)=a/2.d0*(1d0+dsqrt(1d0-4d0*b*dlog(x)
     .          *(1-(a*b*(dlog(x)**2-dlog(x)-1)+c/b)/x/dlog(x))))
      pi=4.d0*datan(1.d0)
      xlb2=xlb
      ii=0
1     ii=ii+1
      x=dlog(q**2/xlb2**2)
      if(nf1.lt.nf2)then
       delta = 7*als3(nf1,q,xlb1)**2/pi**2/24
       alp=als3(nf1,q,xlb1)*(1+delta)
      else
       delta = 7*als3(nf1,q,xlb1)**2/pi**2/24
       alp=als3(nf1,q,xlb1)/(1+delta)
      endif
      a=aa(nf2)/alp
      b=bb(nf2)*alp
      c=cc(nf2)*alp
      xx=xit(a,b,c,x)
      xlb2=q*dexp(-xx/2.d0)
      if(nf1.lt.nf2)then
       delta = 7*als3(nf1,q,xlb1)**2/pi**2/24
       y1=als3(nf1,q,xlb1)*(1+delta)
       y2=als3(nf2,q,xlb2)
      else
       delta = 7*als3(nf1,q,xlb1)**2/pi**2/24
       y1=als3(nf1,q,xlb1)/(1+delta)
       y2=als3(nf2,q,xlb2)
      endif
      dy=dabs(y2-y1)/y1
      if(dy.ge.acc) goto 1
       xiter3_hdec=xlb2
      return
      end

c -------------------------------------------------------------------- c

      double precision function fint_hdec(z,xx,yy)
C--ONE-DIMENSIONAL CUBIC INTERPOLATION
C--Z  = WANTED POINT
C--XX = ARRAY OF 4 DISCRETE X-VALUES AROUND Z
C--YY = ARRAY OF 4 DISCRETE FUNCTION-VALUES AROUND Z
      implicit double precision (a-h,o-z)
      dimension xx(4),yy(4)

      x = dlog(z)
      x0=dlog(xx(1))
      x1=dlog(xx(2))
      x2=dlog(xx(3))
      x3=dlog(xx(4))
      y0=dlog(yy(1))
      y1=dlog(yy(2))
      y2=dlog(yy(3))
      y3=dlog(yy(4))
      a0=(x-x1)*(x-x2)*(x-x3)/(x0-x1)/(x0-x2)/(x0-x3)
      a1=(x-x0)*(x-x2)*(x-x3)/(x1-x0)/(x1-x2)/(x1-x3)
      a2=(x-x0)*(x-x1)*(x-x3)/(x2-x0)/(x2-x1)/(x2-x3)
      a3=(x-x0)*(x-x1)*(x-x2)/(x3-x0)/(x3-x1)/(x3-x2)
      fint_hdec=dexp(a0*y0+a1*y1+a2*y2+a3*y3)
      return
      end

c -------------------------------------------------------------------- c

      double precision function sp_hdec(x)
c--real dilogarithm (spence-function)
      implicit double precision (a-h,o-z)
      complex*16 cx,li2_hdec
      cx = dcmplx(x,0.d0)
      sp_hdec = dreal(li2_hdec(cx))
      return
      end
 
c -------------------------------------------------------------------- c

      complex*16 function li2_hdec(x)
c--complex dilogarithm (spence-function)
      implicit double precision (a-h,o-z)
      complex*16 x,y,cli2_hdec
      common/const_hdec/zeta2,zeta3
      zero=1.d-16
      xr=dreal(x)
      xi=dimag(x)
      r2=xr*xr+xi*xi
      li2_hdec=0
      if(r2.le.zero)then
        li2_hdec=x
        return
      endif
      rr=xr/r2
      if(r2.eq.1.d0.and.xi.eq.0.d0)then
        if(xr.eq.1.d0)then
          li2_hdec=dcmplx(zeta2)
        else
          li2_hdec=-dcmplx(zeta2/2.d0)
        endif
        return
      elseif(r2.gt.1.d0.and.rr.gt.0.5d0)then
        y=(x-1.d0)/x
        li2_hdec=cli2_hdec(y)+zeta2-cdlog(x)*cdlog(1.d0-x)
     .          +0.5d0*cdlog(x)**2
        return
      elseif(r2.gt.1.d0.and.rr.le.0.5d0)then
        y=1.d0/x
        li2_hdec=-cli2_hdec(y)-zeta2-0.5d0*cdlog(-x)**2
        return
      elseif(r2.le.1.d0.and.xr.gt.0.5d0)then
        y=1.d0-x
        li2_hdec=-cli2_hdec(y)+zeta2-cdlog(x)*cdlog(1.d0-x)
       return
      elseif(r2.le.1.d0.and.xr.le.0.5d0)then
        y=x
        li2_hdec=cli2_hdec(y)
        return
      endif
      end
 
c -------------------------------------------------------------------- c

      complex*16 function cli2_hdec(x)
c--taylor-expansion for complex dilogarithm (spence-function)
      implicit double precision (a-h,o-z)
      complex*16 x,z
      common/bernoulli_hdec/b2(18),b12(18),b3(18)
      common/poly_hdec/nber
      n=nber-1
      z=-cdlog(1.d0-x)
      cli2_hdec=b2(nber)
      do 111 i=n,1,-1
        cli2_hdec=z*cli2_hdec+b2(i)
111   continue
      cli2_hdec=z**2*cli2_hdec+z
      return
      end

c -------------------------------------------------------------------- c
 
      double precision function factrl_hdec(n)
c--double precision version of factorial
      implicit double precision (a-h,o-z)
      factrl_hdec=1.d0
      if(n.eq.0)return
      do 999 i=1,n
        factrl_hdec=factrl_hdec*dfloat(i)
999   continue
      return
      end
 
c -------------------------------------------------------------------- c

      subroutine bernini_hdec(n)
c--initialization of coefficients for polylogarithms
      implicit double precision (a-h,o-z)
      dimension b(18),pb(19)
      common/bernoulli_hdec/b2(18),b12(18),b3(18)
      common/const_hdec/zeta2,zeta3
      common/poly_hdec/nber
 
      nber=n
      pi=4.d0*datan(1.d0)
 
      b(1)=-1.d0/2.d0
      b(2)=1.d0/6.d0
      b(3)=0.d0
      b(4)=-1.d0/30.d0
      b(5)=0.d0
      b(6)=1.d0/42.d0
      b(7)=0.d0
      b(8)=-1.d0/30.d0
      b(9)=0.d0
      b(10)=5.d0/66.d0
      b(11)=0.d0
      b(12)=-691.d0/2730.d0
      b(13)=0.d0
      b(14)=7.d0/6.d0
      b(15)=0.d0
      b(16)=-3617.d0/510.d0
      b(17)=0.d0
      b(18)=43867.d0/798.d0
      zeta2=pi**2/6.d0
      zeta3=1.202056903159594d0
 
      do  i=1,18
        b2(i)=b(i)/factrl_hdec(i+1)
        b12(i)=dfloat(i+1)/factrl_hdec(i+2)*b(i)/2.d0
        pb(i+1)=b(i)
        b3(i)=0.d0
      enddo
      pb(1)=1.d0
      do  i=1,18
      do  j=0,i
        b3(i)=b3(i)+pb(j+1)*pb(i-j+1)/factrl_hdec(i-j)/factrl_hdec(j+1)
     .                                            /dfloat(i+1)
      enddo
      enddo
 
      return
      end

c -------------------------------------------------------------------- c

      double precision function qqint_hdec(rat,h1,h2)
      implicit double precision (a-h,o-z)
      n = 2
      qqint_hdec = rat**n * h1 + (1-rat**n) * h2
      return
      end

c -------------------------------------------------------------------- c

      double precision function xitla_hdec(no,alp,acc)
c--iteration routine to determine improved lambdas
      implicit double precision (a-h,o-z)
      common/param_hdec/gf,alph,amtau,ammuon,amz,amw
      b0(nf)=33.d0-2.d0*nf
      b1(nf)=6.d0*(153.d0-19.d0*nf)/b0(nf)**2
      b2(nf)=27/2.d0*(2857-5033/9.d0*nf+325/27.d0*nf**2)/b0(nf)**3
      als2(nf,x,xlb)=12.d0*pi/(b0(nf)*dlog(x**2/xlb**2))
     .              *(1.d0-b1(nf)*dlog(dlog(x**2/xlb**2))
     .              /dlog(x**2/xlb**2))
      als3(nf,x,xlb)=12.d0*pi/(b0(nf)*dlog(x**2/xlb**2))
     .          *(1.d0-b1(nf)*dlog(dlog(x**2/xlb**2))
     .           /dlog(x**2/xlb**2)
     .           +(b1(nf)**2*(dlog(dlog(x**2/xlb**2))**2
     .                      -dlog(dlog(x**2/xlb**2))-1)+b2(nf))
     .           /dlog(x**2/xlb**2)**2)
      aa(nf)=12d0*pi/b0(nf)
      bb(nf)=b1(nf)/aa(nf)
      cc(nf)=b2(nf)/aa(nf)
      xit(a,b,x)=a/2.d0*(1d0+dsqrt(1d0-4d0*b*dlog(x)))
      xit3(a,b,c,x)=a/2.d0*(1d0+dsqrt(1d0-4d0*b*dlog(x)
     .          *(1-(a*b*(dlog(x)**2-dlog(x)-1)+c/b)/x/dlog(x))))
      pi=4.d0*datan(1.d0)
      nf=5
      q=amz
      xlb=q*dexp(-aa(nf)/alp/2.d0)
      if(no.eq.1)goto 111
      ii=0
1     ii=ii+1
      x=dlog(q**2/xlb**2)
      a=aa(nf)/alp
      b=bb(nf)*alp
      c=cc(nf)*alp
      if(no.eq.2)then
       xx=xit(a,b,x)
      else
       xx=xit3(a,b,c,x)
      endif
      xlb=q*dexp(-xx/2.d0)
      y1=alp
      if(no.eq.2)then
       y2=als2(nf,q,xlb)
      else
       y2=als3(nf,q,xlb)
      endif
      dy=dabs(y2-y1)/y1
      if(dy.ge.acc) goto 1
111   xitla_hdec=xlb
      return
      end

c -------------------------------------------------------------------- c

      subroutine botsusy_cnmssm_hdec(gh1b,gh2b,gh3b,gh4b,gh5b,
     .     ga1b,ga2b,ga3b,ga4b,ga5b,xgh1b,xgh2b,xgh3b,xgh4b,
     .     xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,xghpm,tgbet,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm,xghpm
      icase = 0
      call dmbapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,dgh5b,
     .     dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      xgh1b = gh1b*(1+dgh1b)
      xgh2b = gh2b*(1+dgh2b)
      xgh3b = gh3b*(1+dgh3b)
      xgh4b = gh4b*(1+dgh4b)
      xgh5b = gh5b*(1+dgh5b)
      xga1b = ga1b*(1+dga1b)
      xga2b = ga2b*(1+dga2b)
      xga3b = ga3b*(1+dga3b)
      xga4b = ga4b*(1+dga4b)
      xga5b = ga5b*(1+dga5b)
      xghpm = tgbet*(1+dghpm)

      return
      end
 
c -------------------------------------------------------------------- c

      subroutine dmbapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,
     .     dgh5b,dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      complex*16 myi,deltab,aL1,aL2,aL3,aL4,aL5
      dimension amchar(2),amneut(5),xmneut(5),
     .          xmst(2),xmsb(2),amsl(2),
     .          amsu(2),amsd(2),amse(2),amsn(2),amsnl(2)
      dimension slhahmix(5,5)
      common/param_hdec/gf,alph,amtau,ammuon,amz,amw
      common/masses_hdec/ams,amc,amb,amt
      common/hmass_cnmssm/amh1,amh2,amh3,amh4,amh5,amch,amar
      common/gluino_cnmssm/amg,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      common/coup_cnmssm/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      common/break_cnmssm/amel,amer,amsq,amur,amdr,al,au,ad,alam,akap,
     .     aamu,am2,alim,auim,adim,aphiu,xphiglu
c- replace amu by real(lambda*S)=xlamvs and imaginary(lambda*S)=xlamvsim
      common/extpar_nmssm/xlambdapar,xkappa,Alam2,Akap2,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      common/extpart_cnmssm_im/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      common/smass_nmssm/amneut,xmneut,amchar,xmst,xmsb,amsl,
     .              amsu,amsd,amse,amsn,amsnl
      common/slha_hmix_cnmssm/slhahmix
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      common/david/qsusy1,qsusy2,loop
      common/alslam_hdec/xlb1(6),xlb2(6),xlb3(6)
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      COMMON/M1M2VALUES_CNMSSM/am1realval,am1imval,am2realval,am2imval
      
      myi = dcmplx(0.d0,1.d0)
      pi = 4*datan(1.d0)
      v = 1/dsqrt(gf*dsqrt(2.d0))
      vs = dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      tanb = dtan(b)
      sb = tanb/dsqrt(1+tanb**2)
      cb = 1.d0/dsqrt(1+tanb**2)

      amu = dsqrt(xlamvs**2+xlamvsim**2)

      at = au
      ab = ad
      atim = auim
      abim = adim
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      scalelw = qsusy2*(amst1+amst2+amu)/3
      scalqcd = qsusy1*(amsb1+amsb2+dabs(amg))/3
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      rmtop   = runm_hdec(scalelw,6)
      ht = dsqrt(2.d0)*rmtop/v/sb
      stop1 = xmst1
      stop2 = xmst2
      sbot1 = xmsb1
      sbot2 = xmsb2

      ash = alphas_hdec(scalqcd,3)
      deltab = (2*ash/3.d0/pi*amg*(
     .     xlamvs*dcos(xphiglu)-xlamvsim*dsin(xphiglu)-
     .     myi*(xlamvsim*dcos(xphiglu)+xlamvs*dsin(xphiglu)))*
     .     tanb*t_hdec(sbot1,sbot2,amg)+ht**2/(4.d0*pi)**2*(
     .     xlamvs*at-xlamvsim*atim-myi*(xlamvsim*at+xlamvs*atim))*
     .     tanb*t_hdec(stop1,stop2,amu))
     .     /(1-2*ash/3/pi*amg*(
     .     ab*dcos(xphiglu)+abim*dsin(xphiglu)+
     .     myi*(abim*dcos(xphiglu)-ab*dsin(xphiglu)))*
     .     t_hdec(sbot1,sbot2,amg))

      aL1 = (slhahmix(1,1)/cb+slhahmix(1,2)*deltab/sb+
     .     deltab*(slhahmix(1,3)-myi*slhahmix(1,5))*v/vs+
     .     myi*tanb*slhahmix(1,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL2 = (slhahmix(2,1)/cb+slhahmix(2,2)*deltab/sb+
     .     deltab*(slhahmix(2,3)-myi*slhahmix(2,5))*v/vs+
     .     myi*tanb*slhahmix(2,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL3 = (slhahmix(3,1)/cb+slhahmix(3,2)*deltab/sb+
     .     deltab*(slhahmix(3,3)-myi*slhahmix(3,5))*v/vs+
     .     myi*tanb*slhahmix(3,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL4 = (slhahmix(4,1)/cb+slhahmix(4,2)*deltab/sb+
     .     deltab*(slhahmix(4,3)-myi*slhahmix(4,5))*v/vs+
     .     myi*tanb*slhahmix(4,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL5 = (slhahmix(5,1)/cb+slhahmix(5,2)*deltab/sb+
     .     deltab*(slhahmix(5,3)-myi*slhahmix(5,5))*v/vs+
     .     myi*tanb*slhahmix(5,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      
      dgh1b = dreal(aL1+dconjg(aL1))*cb/slhahmix(1,1)-1
      dgh2b = dreal(aL2+dconjg(aL2))*cb/slhahmix(2,1)-1
      dgh3b = dreal(aL3+dconjg(aL3))*cb/slhahmix(3,1)-1
      dgh4b = dreal(aL4+dconjg(aL4))*cb/slhahmix(4,1)-1
      dgh5b = dreal(aL5+dconjg(aL5))*cb/slhahmix(5,1)-1

      dga1b = dreal(myi*(dconjg(aL1)-aL1))/tanb/slhahmix(1,4)-1
      dga2b = dreal(myi*(dconjg(aL2)-aL2))/tanb/slhahmix(2,4)-1
      dga3b = dreal(myi*(dconjg(aL3)-aL3))/tanb/slhahmix(3,4)-1
      dga4b = dreal(myi*(dconjg(aL4)-aL4))/tanb/slhahmix(4,4)-1
      dga5b = dreal(myi*(dconjg(aL5)-aL5))/tanb/slhahmix(5,4)-1

      dghpm = -deltab/(1+deltab)*(1+1/tanb**2)
      
      return
      end

c -------------------------------------------------------------------- c

      subroutine staususy_cnmssm_hdec(gh1b,gh2b,gh3b,gh4b,gh5b,
     .     ga1b,ga2b,ga3b,ga4b,ga5b,xgh1b,xgh2b,xgh3b,xgh4b,
     .     xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,xghpm,tgbet,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm,xghpm
      icase = 0
      call dmtauapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,dgh5b,
     .     dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      xgh1b = gh1b*(1+dgh1b)
      xgh2b = gh2b*(1+dgh2b)
      xgh3b = gh3b*(1+dgh3b)
      xgh4b = gh4b*(1+dgh4b)
      xgh5b = gh5b*(1+dgh5b)
      xga1b = ga1b*(1+dga1b)
      xga2b = ga2b*(1+dga2b)
      xga3b = ga3b*(1+dga3b)
      xga4b = ga4b*(1+dga4b)
      xga5b = ga5b*(1+dga5b)
      xghpm = tgbet*(1+dghpm)

      return
      end 

c -------------------------------------------------------------------- c

      subroutine dmtauapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,
     .     dgh5b,dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      complex*16 myi,deltab,aL1,aL2,aL3,aL4,aL5
      dimension amchar(2),amneut(5),xmneut(5),
     .          xmst(2),xmsb(2),amsl(2),
     .          amsu(2),amsd(2),amse(2),amsn(2),amsnl(2)
      dimension slhahmix(5,5)
      common/param_hdec/gf,alph,amtau,ammuon,amz,amw
      common/masses_hdec/ams,amc,amb,amt
      common/hmass_cnmssm/amh1,amh2,amh3,amh4,amh5,amch,amar
      common/gluino_cnmssm/amg,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      common/coup_cnmssm/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      common/break_cnmssm/amel,amer,amsq,amur,amdr,al,au,ad,alam,akap,
     .     aamu,am2,alim,auim,adim,aphiu,xphiglu
c- replace amu by real(lambda*S)=xlamvs and imaginary(lambda*S)=xlamvsim
      common/extpar_nmssm/xlambdapar,xkappa,Alam2,Akap2,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      common/extpart_cnmssm_im/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      common/smass_nmssm/amneut,xmneut,amchar,xmst,xmsb,amsl,
     .              amsu,amsd,amse,amsn,amsnl
      common/slha_hmix_cnmssm/slhahmix
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      common/david/qsusy1,qsusy2,loop
      common/alslam_hdec/xlb1(6),xlb2(6),xlb3(6)
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      COMMON/M1M2VALUES_CNMSSM/am1realval,am1imval,am2realval,am2imval

      myi = dcmplx(0.d0,1.d0)
      pi = 4*datan(1.d0)
      v = 1/dsqrt(gf*dsqrt(2.d0))
      vs = dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      tanb = dtan(b)
      sb = tanb/dsqrt(1+tanb**2)
      cb = 1.d0/dsqrt(1+tanb**2)

      amu = dsqrt(xlamvs**2+xlamvsim**2)

      at = au
      ab = ad
      atim = auim
      abim = adim

      if(il.eq.0) then
         stau1 = amse(1)
         stau2 = amse(2)
         sneut = amsn(1)
      else
         stau1 = amsl(1)
         stau2 = amsl(2)
         sneut = amsnl(1)
      endif

      cw = amw**2/amz**2
      sw = 1-cw
      alpha2 = (2*amw/v)**2/4/pi
      alpha1 = alpha2*sw/cw
      am2abs = dsqrt(am2realval**2+am2imval**2) 
      am1abs = dsqrt(am1realval**2+am1imval**2) 

      xphim2 = datan(am2imval/am2realval)
      xphim1 = datan(am1imval/am1realval)

      deltab = alpha1/4/pi*am1abs*(
     .     xlamvs*dcos(xphim1)-xlamvsim*dsin(xphim1)-
     .     myi*(xlamvsim*dcos(xphim1)+xlamvs*dsin(xphim1)))*
     .     tanb*t_hdec(stau1,stau2,am1abs)
c --- corrected 21/1/2014
     .     - alpha2/4/pi*am2abs*(
     .     xlamvs*dcos(xphim2)-xlamvsim*dsin(xphim2)-
     .     myi*(xlamvsim*dcos(xphim2)+xlamvs*dsin(xphim2)))*
     .     tanb*t_hdec(sneut,am2abs,amu)
c --- end corrected 21/1/2014

      aL1 = (slhahmix(1,1)/cb+slhahmix(1,2)*deltab/sb+
     .     deltab*(slhahmix(1,3)-myi*slhahmix(1,5))*v/vs+
     .     myi*tanb*slhahmix(1,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL2 = (slhahmix(2,1)/cb+slhahmix(2,2)*deltab/sb+
     .     deltab*(slhahmix(2,3)-myi*slhahmix(2,5))*v/vs+
     .     myi*tanb*slhahmix(2,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL3 = (slhahmix(3,1)/cb+slhahmix(3,2)*deltab/sb+
     .     deltab*(slhahmix(3,3)-myi*slhahmix(3,5))*v/vs+
     .     myi*tanb*slhahmix(3,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL4 = (slhahmix(4,1)/cb+slhahmix(4,2)*deltab/sb+
     .     deltab*(slhahmix(4,3)-myi*slhahmix(4,5))*v/vs+
     .     myi*tanb*slhahmix(4,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL5 = (slhahmix(5,1)/cb+slhahmix(5,2)*deltab/sb+
     .     deltab*(slhahmix(5,3)-myi*slhahmix(5,5))*v/vs+
     .     myi*tanb*slhahmix(5,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      
      dgh1b = dreal(aL1+dconjg(aL1))*cb/slhahmix(1,1)-1
      dgh2b = dreal(aL2+dconjg(aL2))*cb/slhahmix(2,1)-1
      dgh3b = dreal(aL3+dconjg(aL3))*cb/slhahmix(3,1)-1
      dgh4b = dreal(aL4+dconjg(aL4))*cb/slhahmix(4,1)-1
      dgh5b = dreal(aL5+dconjg(aL5))*cb/slhahmix(5,1)-1

      dga1b = dreal(myi*(dconjg(aL1)-aL1))/tanb/slhahmix(1,4)-1
      dga2b = dreal(myi*(dconjg(aL2)-aL2))/tanb/slhahmix(2,4)-1
      dga3b = dreal(myi*(dconjg(aL3)-aL3))/tanb/slhahmix(3,4)-1
      dga4b = dreal(myi*(dconjg(aL4)-aL4))/tanb/slhahmix(4,4)-1
      dga5b = dreal(myi*(dconjg(aL5)-aL5))/tanb/slhahmix(5,4)-1

      dghpm = -deltab/(1+deltab)*(1+1/tanb**2)
      
      return
      end

c -------------------------------------------------------------------- c

      subroutine strsusy_cnmssm_hdec(gh1b,gh2b,gh3b,gh4b,gh5b,
     .     ga1b,ga2b,ga3b,ga4b,ga5b,xgh1b,xgh2b,xgh3b,xgh4b,
     .     xgh5b,xga1b,xga2b,xga3b,xga4b,xga5b,xghpm,tgbet,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm,xghpm
      icase = 0
      call dmsapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,dgh5b,
     .     dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      xgh1b = gh1b*(1+dgh1b)
      xgh2b = gh2b*(1+dgh2b)
      xgh3b = gh3b*(1+dgh3b)
      xgh4b = gh4b*(1+dgh4b)
      xgh5b = gh5b*(1+dgh5b)
      xga1b = ga1b*(1+dga1b)
      xga2b = ga2b*(1+dga2b)
      xga3b = ga3b*(1+dga3b)
      xga4b = ga4b*(1+dga4b)
      xga5b = ga5b*(1+dga5b)
      xghpm = tgbet*(1+dghpm)

      return
      end

c -------------------------------------------------------------------- c

      subroutine dmsapp_cnmssm_hdec(icase,dgh1b,dgh2b,dgh3b,dgh4b,
     .     dgh5b,dga1b,dga2b,dga3b,dga4b,dga5b,dghpm,scale,il)
      implicit double precision (a-h,o-z)
      complex*16 dghpm
      complex*16 xh1tt,xh1bb,xh2tt,xh2bb,xh3tt,xh3bb,
     .     xh4tt,xh4bb,xh5tt,xh5bb
      complex*16 myi,deltab,aL1,aL2,aL3,aL4,aL5
      dimension amchar(2),amneut(5),xmneut(5),
     .          xmst(2),xmsb(2),amsl(2),
     .          amsu(2),amsd(2),amse(2),amsn(2),amsnl(2)
      dimension slhahmix(5,5)
      common/param_hdec/gf,alph,amtau,ammuon,amz,amw
      common/masses_hdec/ams,amc,amb,amt
      common/hmass_cnmssm/amh1,amh2,amh3,amh4,amh5,amch,amar
      common/gluino_cnmssm/amg,xmsb1,xmsb2,xsbmix(2,2),
     .     xsbmixim(2,2),xh1bb(2,2),xh2bb(2,2),xh3bb(2,2),xh4bb(2,2),
     .     xh5bb(2,2),xmst1,xmst2,xstmix(2,2),xstmixim(2,2),xh1tt(2,2),
     .     xh2tt(2,2),xh3tt(2,2),xh4tt(2,2),xh5tt(2,2)
      common/coup_cnmssm/ga1t,ga1b,ga2t,ga2b,ga3t,ga3b,ga4t,ga4b,
     .     ga5t,ga5b,gh1t,gh1b,gh2t,gh2b,gh3t,gh3b,gh4t,gh4b,gh5t,
     .     gh5b,gzh1h1,gzh1h2,gzh1h3,gzh1h4,gzh1h5,gzh2h1,gzh2h2,
     .     gzh2h3,gzh2h4,gzh2h5,gzh3h1,gzh3h2,gzh3h3,gzh3h4,gzh3h5,
     .     gzh4h1,gzh4h2,gzh4h3,gzh4h4,gzh4h5,gzh5h1,gzh5h2,gzh5h3,
     .     gzh5h4,gzh5h5,gh1h1h1,gh1h2h2,gh2h1h1,gh1h3h3,gh3h1h1,
     .     gh2h3h3,gh3h2h2,gh2h2h2,gh3h3h3,gh1h1h4,gh1h1h5,gh2h1h4,
     .     gh2h1h5,gh2h2h4,gh2h2h5,gh2h4h4,gh2h4h5,gh2h5h5,gh3h1h4,
     .     gh3h1h5,gh3h2h4,gh3h2h5,gh3h3h4,gh3h3h5,gh3h4h4,gh3h4h5,
     .     gh3h5h5,gh4h1h4,gh4h1h5,gh4h4h4,gh4h4h5,gh4h5h5,gh5h5h1,
     .     gh5h5h5,gh1h2h3,gh1vv,gh2vv,gh3vv,gh4vv,gh5vv,gh1pm,gh2pm,
     .     gh3pm,gh4pm,gh5pm,gh1hpwm,gh2hpwm,gh3hpwm,gh4hpwm,gh5hpwm,
     .     ga1hpwm,ga2hpwm,ga3hpwm,ga4hpwm,ga5hpwm,b
      common/break_cnmssm/amel,amer,amsq,amur,amdr,al,au,ad,alam,akap,
     .     aamu,am2,alim,auim,adim,aphiu,xphiglu
c- replace amu by real(lambda*S)=xlamvs and imaginary(lambda*S)=xlamvsim
      common/extpar_nmssm/xlambdapar,xkappa,Alam2,Akap2,xlamvs,xif,xis,
     .     xmuprime,amsph2,amsh2
      common/extpart_cnmssm_im/xlambdaparim,xkappaim,Alamim,Akapim,
     .     xlamvsim,xifim,xisim,xmuprimeim,amsph2im,amsh2im,xphiu
      common/smass_nmssm/amneut,xmneut,amchar,xmst,xmsb,amsl,
     .              amsu,amsd,amse,amsn,amsnl
      common/slha_hmix_cnmssm/slhahmix
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      common/david/qsusy1,qsusy2,loop
      common/alslam_hdec/xlb1(6),xlb2(6),xlb3(6)
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      myi = dcmplx(0.d0,1.d0)
      pi = 4*datan(1.d0)
      v  = 1/dsqrt(gf*dsqrt(2.d0))
      vs = dsqrt(2.d0*(xlamvs**2+xlamvsim**2)/
     .     (xlambdapar**2+xlambdaparim**2))
      tanb = dtan(b)
      sb = tanb/dsqrt(1+tanb**2)
      cb = 1.d0/dsqrt(1+tanb**2)

      at = au
      ab = ad
      atim = auim
      abim = adim
      sbot1 = amsd(1)
      sbot2 = amsd(2)

      scalqcd = (sbot1+sbot2+dabs(amg))/3
      ash = alphas_hdec(scalqcd,3)

      deltab = 2*ash/3.d0/pi*amg*(
     .     xlamvs*dcos(xphiglu)-xlamvsim*dsin(xphiglu)-
     .     myi*(xlamvsim*dcos(xphiglu)+xlamvs*dsin(xphiglu)))*
     .     tanb*t_hdec(sbot1,sbot2,amg)
     .     /(1-2*ash/3/pi*amg*(
     .     ab*dcos(xphiglu)+abim*dsin(xphiglu)+
     .     myi*(abim*dcos(xphiglu)-ab*dsin(xphiglu)))*
     .     t_hdec(sbot1,sbot2,amg))

      aL1 = (slhahmix(1,1)/cb+slhahmix(1,2)*deltab/sb+
     .     deltab*(slhahmix(1,3)-myi*slhahmix(1,5))*v/vs+
     .     myi*tanb*slhahmix(1,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL2 = (slhahmix(2,1)/cb+slhahmix(2,2)*deltab/sb+
     .     deltab*(slhahmix(2,3)-myi*slhahmix(2,5))*v/vs+
     .     myi*tanb*slhahmix(2,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL3 = (slhahmix(3,1)/cb+slhahmix(3,2)*deltab/sb+
     .     deltab*(slhahmix(3,3)-myi*slhahmix(3,5))*v/vs+
     .     myi*tanb*slhahmix(3,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL4 = (slhahmix(4,1)/cb+slhahmix(4,2)*deltab/sb+
     .     deltab*(slhahmix(4,3)-myi*slhahmix(4,5))*v/vs+
     .     myi*tanb*slhahmix(4,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      aL5 = (slhahmix(5,1)/cb+slhahmix(5,2)*deltab/sb+
     .     deltab*(slhahmix(5,3)-myi*slhahmix(5,5))*v/vs+
     .     myi*tanb*slhahmix(5,4)*(1-deltab/tanb**2))/(2.d0+2.d0*deltab)
      
      dgh1b = dreal(aL1+dconjg(aL1))*cb/slhahmix(1,1)-1
      dgh2b = dreal(aL2+dconjg(aL2))*cb/slhahmix(2,1)-1
      dgh3b = dreal(aL3+dconjg(aL3))*cb/slhahmix(3,1)-1
      dgh4b = dreal(aL4+dconjg(aL4))*cb/slhahmix(4,1)-1
      dgh5b = dreal(aL5+dconjg(aL5))*cb/slhahmix(5,1)-1

      dga1b = dreal(myi*(dconjg(aL1)-aL1))/tanb/slhahmix(1,4)-1
      dga2b = dreal(myi*(dconjg(aL2)-aL2))/tanb/slhahmix(2,4)-1
      dga3b = dreal(myi*(dconjg(aL3)-aL3))/tanb/slhahmix(3,4)-1
      dga4b = dreal(myi*(dconjg(aL4)-aL4))/tanb/slhahmix(4,4)-1
      dga5b = dreal(myi*(dconjg(aL5)-aL5))/tanb/slhahmix(5,4)-1

      dghpm = -deltab/(1+deltab)*(1+1/tanb**2)
      
      return
      end

c -------------------------------------------------------------------- c
***********************************************************************
        function eta_hdec(c1,c2)
***********************************************************************
*       COMPLEX ETA-FUNKTION                                           
*---------------------------------------------------------------------*
*       8.06.90    ANSGAR DENNER                                       
***********************************************************************
        implicit   logical(a-z)                                        
        complex*16 eta_hdec,c1,c2
        real*8     pi,im1,im2,im12                                     
                                                                       
        pi     = 4d0*datan(1d0)                                        
        im1    = dimag(c1)                                             
        im2    = dimag(c2)                                             
        im12   = dimag(c1*c2)                                          
                                                                       
        if(im1.lt.0d0.and.im2.lt.0d0.and.im12.gt.0d0) then             
            eta_hdec = dcmplx(0d0,2d0*pi)
        else if (im1.gt.0d0.and.im2.gt.0d0.and.im12.lt.0d0) then       
            eta_hdec = dcmplx(0d0,-2d0*pi)
        else                                                           
            eta_hdec = dcmplx(0d0)
        end if                                                         
        end                                                            

***********************************************************************
        function etas_hdec(y,r,rs)
***********************************************************************
*       MODIFIED ETA-FUNKTION                                           
*---------------------------------------------------------------------*
*       18.1.94   SD                                       
***********************************************************************
        implicit   logical(a-z)                                        
        complex*16 eta_hdec,etas_hdec,y,r,rs
        real*8     pi,imy,imrs
                                                                       
        pi     = 4d0*datan(1d0)                                        

	if( dimag(r).ne.0d0 ) then
	    etas_hdec = eta_hdec(y,r)
	else	    
	    if( dreal(r).gt.0d0 ) then
		etas_hdec = dcmplx(0d0,0d0)
	    else
	 	imy  = dimag(y)
		imrs = dimag(rs)
		etas_hdec = 2d0*dcmplx(0d0,pi)*(
     *			(1d0+sign(1d0,-imy))*(1d0+sign(1d0,-imrs))-
     *			(1d0+sign(1d0, imy))*(1d0+sign(1d0, imrs))
     *					  )/4d0
	    endif
	endif
        end                                                            

***********************************************************************
        function sqe_hdec(a,b,c)
***********************************************************************
*       SOLUTION OF QUADRATIC EQUATION				      *
*---------------------------------------------------------------------*
*       13.1.92  SD						      *
***********************************************************************
        implicit real*8 (a-z)                                        
        complex*16 a,b,c,sqe_hdec,x1,x2

	x1=(-b+sqrt(b**2-4d0*a*c))/2d0/a
	x2=(-b-sqrt(b**2-4d0*a*c))/2d0/a

	if (abs(x1).gt.abs(x2)) then
	   sqe_hdec=x1
	else
	   sqe_hdec=x2
	endif

        end                                                            

************************************************************************
        function d04_hdec(p1,p2,p3,p4,p12,p23,m1,m2,m3,m4)
************************************************************************
*  SCALAR 4-POINT FUNCTION WITH AT LEAST ONE MASS ZERO                 *
*  P1,P2,P3,P4 = SQUARED EXTERNAL MOMENTA			       *
*  P12 = (p1+p2)**2,  P23 = (p2+p3)**2				       *
*----------------------------------------------------------------------*
*  2.1.92  SD	         					       *
************************************************************************
        implicit real*8 (a-z)
	real*8 m(4),p(4,4),k(4,4)
	complex*16 a1,a2,a3,a4,swap
	complex*16 ss(4), xx(2), x(2,4),rs(4,4)
	complex*16 s0(4),xx0(2),x0(2,4), r(4,4),g(2)
        complex*16 c04,d04_hdec,cspen_hdec,eta_hdec,sqe_hdec,etas_hdec
	complex*16 aa,bb,cc,dd,ieps,h,hh,l1,l2,l3,l4
        complex*16 z2,b,sc,tc,wp,wm,bs,xs
	integer gen,i,j

        pi = 4*datan(1.d0)

        mm1=m1
        mm2=m2
        mm3=m3
        mm4=m4
        m12=m1*m1
        m22=m2*m2
        m32=m3*m3
        m42=m4*m4
        q1=p1
        q2=p2
        q3=p3
	q4=p4
        q12=p12
        q23=p23

c	is at least one mass zero ???
	if (mm1*mm2*mm3*mm4.ne.0d0) goto 130

c	permutate until mm3=0d0
	goto 20
10	continue
	mm0=mm1
	mm1=mm2
	mm2=mm3
	mm3=mm4
	mm4=mm0
	m02=m12
	m12=m22
	m22=m32
	m32=m42
	m42=m02
	q00=q12
	q12=q23
	q23=q00
	q0=q1
	q1=q2
	q2=q3
	q3=q4
	q4=q0
20	if (mm3.ne.0d0) goto 10
c	only mm3 is zero
	if (mm1*mm2*mm4.ne.0d0) goto 30
c	only mm3 and mm4 are zero ==> 3->2, 4->3...
	if ((mm1*mm2.ne.0d0).and.(mm4.eq.0d0)) goto 10
c	only mm2 and mm3 are zero
	if ((mm1*mm4.ne.0d0).and.(mm2.eq.0d0)) goto 40
	write(*,*)'case of this special d0-function not implemented!'
	stop

c	****** no mass equal to zero ******
130	continue
	eps=1d-18
	ieps=dcmplx(0d0,eps)

	if( abs((mm1**2+mm3**2-q12)/mm1/mm3).lt.2d0 ) then
c	r13 would be not real. -> permutation! -> r(2,4) is not real.
	   m(1)=mm2
	   m(2)=mm3
	   m(3)=mm4
	   m(4)=mm1
	   p(1,2)=q2
	   p(1,3)=q23
	   p(1,4)=q1
	   p(2,3)=q3
	   p(2,4)=q12
	   p(3,4)=q4
	else
c	r(1,3) is real.
	   m(1)=mm1
	   m(2)=mm2
	   m(3)=mm3
	   m(4)=mm4
	   p(1,2)=q1
	   p(1,3)=q12
	   p(1,4)=q4
	   p(2,3)=q2
	   p(2,4)=q23
	   p(3,4)=q3
	endif

	do  j=2,4
	do  i=1,j-1
	k(i,j)=(m(i)**2+m(j)**2-p(i,j))/m(i)/m(j)
	r(i,j) =sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),0d0),
     *	            dcmplx(1d0,0d0))
	if( dimag(r(i,j)).eq.0d0 ) then
	   rs(i,j)=sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),eps),
     *	               dcmplx(1d0,0d0))
	else
	   rs(i,j)=r(i,j)
	endif
	enddo
	enddo

	ss(1)=rs(1,2)
	ss(2)=rs(2,3)
	ss(3)=rs(3,4)
	ss(4)=rs(1,4)
	s0(1)=r(1,2)
	s0(2)=r(2,3)
	s0(3)=r(3,4)
	s0(4)=r(1,4)
	aa=k(3,4)/r(2,4)+r(1,3)*k(1,2)-k(1,4)*r(1,3)/r(2,4)-k(2,3)
	bb=(r(2,4)-1d0/r(2,4))*(r(1,3)-1d0/r(1,3))
     *		+k(1,2)*k(3,4)-k(1,4)*k(2,3)
	cc=k(1,2)/r(1,3)+r(2,4)*k(3,4)-k(1,4)*r(2,4)/r(1,3)-k(2,3)
	dd=k(2,3)-r(1,3)*k(1,2)-r(2,4)*k(3,4)+r(1,3)*r(2,4)*k(1,4)
	xx(1)=sqe_hdec(aa,bb,cc+ieps*dd)
	xx(2)=(cc+ieps*dd)/aa/xx(1)
	xx0(1)=sqe_hdec(aa,bb,cc)
	xx0(2)=cc/aa/xx0(1)
c	if (abs(dreal(xx0(1)-xx(2))).lt.abs(dreal(xx0(1)-xx(1)))) then
	if (abs(xx0(1)-xx(2)).lt.abs(xx0(1)-xx(1))) then
	  swap  =xx0(1)
	  xx0(1)=xx0(2)
	  xx0(2)=swap
	endif

	do  i=1,2
	g(i)  =sign( 1d0,dreal(aa*(xx(i)-xx(3-i))) )
	 x(i,1)= xx(i)/r(2,4)
	x0(i,1)=xx0(i)/r(2,4)
	 x(i,2)= xx(i)/r(2,4)*r(1,3)
	x0(i,2)=xx0(i)/r(2,4)*r(1,3)
	 x(i,3)= xx(i)*r(1,3)
	x0(i,3)=xx0(i)*r(1,3)
	 x(i,4)= xx(i)
	x0(i,4)=xx0(i)
	enddo    

	d04_hdec = dcmplx(0d0,0d0)
	do  i=1,2
	do  j=1,4
	a1 = 1d0+x0(i,j)*s0(j) + abs(1d0+x0(i,j)*s0(j))*ieps*
     *				  sign(1d0,dimag(x(i,j)*ss(j)))
	a2 = 1d0+x0(i,j)/s0(j) + abs(1d0+x0(i,j)/s0(j))*ieps*
     *				  sign(1d0,dimag(x(i,j)/ss(j)))
	d04_hdec = d04_hdec + (-1d0)**(i+j)*(
     *		cspen_hdec(a1)+eta_hdec(-x(i,j),ss(j))*log(a1)
     *	       +cspen_hdec(a2)+eta_hdec(-x(i,j),1d0/ss(j))*log(a2))
	enddo
	enddo

	if( dimag(r(1,3)).eq.0d0 ) then
	do i=1,2
	   a1 = (k(1,3)-2d0*r(1,3))/xx0(i)
     *		      -r(1,3)*k(1,4)+k(3,4)
     	   a2 = ((k(2,4)-2d0*r(2,4))*r(1,3)*xx0(i)
     *		      -r(2,4)*k(3,4)+k(2,3))/dd
	   a3 = (k(1,3)-2d0*r(1,3))*r(2,4)/xx0(i)
     *		      -r(1,3)*k(1,2)+k(2,3)
	   a4 = ((k(2,4)-2d0*r(2,4))*xx0(i)
     *		      -r(2,4)*k(1,4)+k(1,2))/dd
	   l1 = log( a1-abs(a1)*ieps )
     	   l2 = log( a2+abs(a2)*ieps*g(i)*sign(1d0,dreal(r(1,3))
     *				        	  *dimag(rs(2,4))) )
	   l3 = log( a3-abs(a3)*ieps )
	   l4 = log( a4+abs(a4)*ieps*g(i)*sign(1d0,dimag(rs(2,4))) )

	   d04_hdec = d04_hdec + (3d0-2d0*i)*(
     *		 etas_hdec(-xx(i),r(1,3),rs(1,3))
     *		   *( log(r(1,3)*xx(i)) + l1 + l2 )
     *		+etas_hdec(-xx(i),1d0/r(2,4),1d0/rs(2,4))
     *		   *( log(xx(i)/r(2,4)) + l3 + l4 )
     *		-( etas_hdec(-xx(i),r(1,3)/r(2,4),rs(1,3)/rs(2,4))
     *		  +eta_hdec(rs(1,3),1d0/rs(2,4)) )
     *		   *( log(xx(i)*r(1,3)/r(2,4)) + l3 + l2 )
     *	  	+eta_hdec(rs(1,3),1d0/rs(2,4))
     *		  *etas_hdec(-xx(i),-r(1,3)/r(2,4),-rs(1,3)/rs(2,4))   )
	enddo
	else
	do i=1,2
	   l1 = log( r(2,4)/xx0(i)+xx0(i)/r(2,4)+k(1,2)
     *		     -xx0(i)/r(2,4)*eps*bb*g(i) )
	   l2 = log( r(1,3)*xx0(i)+1d0/xx0(i)/r(1,3)+k(3,4)
     *		     -xx0(i)*r(1,3)*eps*bb*g(i) )
	   l3 = log( r(1,3)/r(2,4)*xx0(i)+r(2,4)/xx0(i)/r(1,3)+k(2,3)
     *		     -xx0(i)*r(1,3)/r(2,4)*eps*bb*g(i) )

	   d04_hdec = d04_hdec + (3d0-2d0*i)*(
     *		+eta_hdec(-xx(i),1d0/r(2,4))
     *		   *( log(xx(i)/r(2,4)) + l1 )
     *		+eta_hdec(-xx(i),r(1,3))
     *		   *( log(r(1,3)*xx(i)) + l2 )
     *		-( eta_hdec(-xx(i),r(1,3)/r(2,4))
     *		  +eta_hdec(r(1,3),1d0/r(2,4)) )
     *		   *( log(xx(i)*r(1,3)/r(2,4)) + l3 )
     *	  	+eta_hdec(r(1,3),1d0/r(2,4))
     *		   *eta_hdec(-xx(i),-r(1,3)/r(2,4))
     *		   *(1d0-g(i)*sign(1d0,dreal(bb)))	    )
	enddo
	endif

	d04_hdec = d04_hdec/m(1)/m(2)/m(3)/m(4)/aa/(xx(1)-xx(2))
	return


C--->	***************** SPEZIELL ( --> T.SACK-PROMOTION )
C	D1=Q12-M12
C	D2=Q2 -M22
C	D3=Q3 -M42
C	IF ((D1*D2.LE.0D0).OR.(D2*D3.LE.0D0)) THEN
C	   WRITE(*,*) 'THE CASE OF DIFFERENT SIGNS OF THE D1,D2,D3'
C	   WRITE(*,*) 'IN D04(...) IS NOT IMPLEMENTED !!!'
C	   STOP
C	ENDIF
C	NM1=ABS(MM1/D1)
C	NM2=ABS(MM2/D2)
C	NM3=ABS(MM4/D3)
C	NP1=Q2/D2**2+Q12/D1**2+(Q1-Q2-Q12)/D1/D2
C	NP2=Q2/D2**2+ Q3/D3**2+(Q23-Q2-Q3)/D2/D3
C	NP3=Q3/D3**2+Q12/D1**2+(Q4-Q3-Q12)/D1/D3
C	D04_HDEC=C04(NP1,NP2,NP3,NM1,NM2,NM3)/D1/D2/D3

C	*************** ALLGEMEIN


C	****** ONLY MM3 IS ZERO ******
30	continue
	eps=1d-17
	ieps=dcmplx(0d0,eps)
	m(1)=mm1
	m(2)=mm2
	m(3)=10d0
	m(4)=mm4
	p(1,2)=q1
	p(1,3)=q12
	p(1,4)=q4
	p(2,3)=q2
	p(2,4)=q23
	p(3,4)=q3
	do j=2,4
	do i=1,j-1
	k(i,j)=(m(i)**2+m(j)**2-p(i,j))/m(i)/m(j)
	if (i.eq.3) k(i,j)=k(i,j)-m(i)/m(j)
	if (j.eq.3) k(i,j)=k(i,j)-m(j)/m(i)
	r(i,j) =sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),0d0),
     *	            dcmplx(1d0,0d0))
	if( dimag(r(i,j)).eq.0d0 ) then
	   rs(i,j)=sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),eps),
     *	               dcmplx(1d0,0d0))
	else
	   rs(i,j)=r(i,j)
	endif
	enddo
	enddo
	ss(1)=rs(1,2)
	ss(2)=rs(2,3)
	ss(3)=rs(3,4)
	ss(4)=rs(1,4)
	aa=k(3,4)/r(2,4)-k(2,3)
	bb=k(1,3)*(1d0/r(2,4)-r(2,4))+k(1,2)*k(3,4)-k(1,4)*k(2,3)
	cc=k(1,2)*k(1,3)-k(1,3)*k(1,4)*r(2,4)+r(2,4)*k(3,4)-k(2,3)
	dd=k(2,3)-r(2,4)*k(3,4)
	xx(1)=sqe_hdec(aa,bb,cc+ieps*dd)
	xx(2)=(cc+ieps*dd)/aa/xx(1)
	do  i=1,2
	x(i,1)=xx(i)/r(2,4)
	x(i,2)=xx(i)/r(2,4)*r(1,3)
	x(i,3)=xx(i)*r(1,3)
	x(i,4)=xx(i)
	enddo
	d04_hdec = dcmplx(0d0,0d0)
	do 3 i=1,2
	d04_hdec = d04_hdec + (2d0*i-3d0)*(
     *		cspen_hdec(1d0+ss(4)*x(i,4))
     *	       -cspen_hdec(1d0+ss(1)*x(i,1))
     *	       +cspen_hdec(1d0+x(i,4)/ss(4))
     *	       -cspen_hdec(1d0+x(i,1)/ss(1))
     *	       +eta_hdec(-x(i,4),ss(4))*log(1d0+ss(4)*x(i,4))
     *	       -eta_hdec(-x(i,1),ss(1))*log(1d0+ss(1)*x(i,1))
     *	       +eta_hdec(-x(i,4),1d0/ss(4))*log(1d0+x(i,4)/ss(4))
     *	       -eta_hdec(-x(i,1),1d0/ss(1))*log(1d0+x(i,1)/ss(1))
     *	       -cspen_hdec(1d0+x(i,4)*(k(3,4)-ieps)/(k(1,3)-ieps))
     *	       +cspen_hdec(1d0+x(i,1)*(k(2,3)-ieps)/(k(1,3)-ieps))
     *	       -eta_hdec(-x(i,4),(k(3,4)-ieps)/(k(1,3)-ieps))
     *	           *log(1d0+x(i,4)*(k(3,4)-ieps)/(k(1,3)-ieps))
     *	       +eta_hdec(-x(i,1),(k(2,3)-ieps)/(k(1,3)-ieps))
     *	           *log(1d0+x(i,1)*(k(2,3)-ieps)/(k(1,3)-ieps))   )
	if (dimag(r(2,4)).ne.0d0) then
	   h=eta_hdec(-1d0/xx(i),r(2,4))
	else
	   h=dcmplx(0d0,0d0)
	   if (dreal(r(2,4)).lt.0d0) then
	      hh=-1d0/xx(i)
	      im1=dimag(hh)
	      im2=dimag(rs(2,4))
	      if ((im1.gt.0d0).and.(im2.gt.0d0)) then
	         h=-dcmplx(0d0,2d0*pi)
	      endif
	      if ((im1.lt.0d0).and.(im2.lt.0d0)) then
	         h=+dcmplx(0d0,2d0*pi)
	      endif
	   endif
	endif
	d04_hdec = d04_hdec + (2d0*i-3d0)*
     *	          h*( log( (k(1,2)-r(2,4)*k(1,4)
     *			  +xx(i)*(1d0/r(2,4)-r(2,4)))/dd )
     *		     +log(k(1,3)-ieps) )
3	continue
	d04_hdec = d04_hdec/m(1)/m(2)/m(3)/m(4)/aa/(xx(1)-xx(2))
	return

c	****** only mm2 and mm3 are zero ******
40	continue
	eps=1d-17
	ieps=dcmplx(0d0,eps)

	m(1)=mm1
	m(2)=10d0
	m(3)=10d0
	m(4)=mm4
	p(1,2)=q1
	p(1,3)=q12
	p(1,4)=q4
	p(2,3)=q2
	p(2,4)=q23
	p(3,4)=q3
	do  j=2,4
	do  i=1,j-1
	k(i,j)=(m(i)**2+m(j)**2-p(i,j))/m(i)/m(j)
	if (i.eq.2) k(i,j)=k(i,j)-m(i)/m(j)
	if (j.eq.2) k(i,j)=k(i,j)-m(j)/m(i)
	if (i.eq.3) k(i,j)=k(i,j)-m(i)/m(j)
	if (j.eq.3) k(i,j)=k(i,j)-m(j)/m(i)
	r(i,j) =sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),0d0),
     *	            dcmplx(1d0,0d0))
	if( dimag(r(i,j)).eq.0d0 ) then
	   rs(i,j)=sqe_hdec(dcmplx(1d0,0d0),dcmplx(-k(i,j),eps),
     *	               dcmplx(1d0,0d0))
	else
	   rs(i,j)=r(i,j)
	endif
	enddo
	enddo
	ss(1)=rs(1,2)
	ss(2)=rs(2,3)
	ss(3)=rs(3,4)
	ss(4)=rs(1,4)
	aa=k(2,4)*k(3,4)-k(2,3)
	bb=k(1,3)*k(2,4)+k(1,2)*k(3,4)-k(1,4)*k(2,3)
	cc=k(1,2)*k(1,3)-k(2,3)
	dd=k(2,3)
	xx(1)=sqe_hdec(aa,bb,cc+ieps*dd)
	xx(2)=(cc+ieps*dd)/aa/xx(1)
	do  i=1,2
	x(i,1)=xx(i)/r(2,4)
	x(i,2)=xx(i)/r(2,4)*r(1,3)
	x(i,3)=xx(i)*r(1,3)
	x(i,4)=xx(i)
	enddo
	d04_hdec = dcmplx(0d0,0d0)
	do  i=1,2
	d04_hdec = d04_hdec + (2d0*i-3d0)*(
     *		cspen_hdec(1d0+ss(4)*x(i,4))
     *	       +cspen_hdec(1d0+x(i,4)/ss(4))
     *	       +eta_hdec(-x(i,4),ss(4))*log(1d0+ss(4)*x(i,4))
     *	       +eta_hdec(-x(i,4),1d0/ss(4))*log(1d0+x(i,4)/ss(4))
     *	       -cspen_hdec(1d0+xx(i)*(k(3,4)-ieps)/(k(1,3)-ieps))
     *	       -cspen_hdec(1d0+xx(i)*(k(2,4)-ieps)/(k(1,2)-ieps))
     *	       -eta_hdec(-xx(i),(k(3,4)-ieps)/(k(1,3)-ieps))
     *	           *log(1d0+xx(i)*(k(3,4)-ieps)/(k(1,3)-ieps))
     *	       -eta_hdec(-xx(i),(k(2,4)-ieps)/(k(1,2)-ieps))
     *	           *log(1d0+xx(i)*(k(2,4)-ieps)/(k(1,2)-ieps))
     *	       +log(-xx(i))*( log(k(1,2)-ieps)
     *			     +log(k(1,3)-ieps)-log(k(2,3)-ieps) ) )
	enddo
	d04_hdec = d04_hdec/m(1)/m(2)/m(3)/m(4)/aa/(xx(1)-xx(2))

	return

	end

************************************************************************
        function c03_hdec(p1,p2,p3,m1,m2,m3)
************************************************************************
*  SCALAR 3-POINT FUNCTION                                             *
*  P1,P2,P3 = SQUARED EXTERNAL MOMENTA  			       *
*----------------------------------------------------------------------*
*  5.12.96  M. SPIRA    					       *
************************************************************************
      implicit real*8 (a-h,o-z)
      real*8 m1,m2,m3
      real*8 r(0:2)
      complex*16 c03_hdec,cspen_hdec,eta_hdec,ieps,im
      complex*16 alp(0:2),x(0:2,2),y0(0:2),y(0:2,2)
      complex*16 cdum
c     real*8 kappa
      complex*16 kappa
c     kappa(a,b,c) = dsqrt(a**2+b**2+c**2-2*(a*b+a*c+b*c))
c     kappa(a,b,c) = dsqrt(dabs(a**2+b**2+c**2-2*(a*b+a*c+b*c)))
c     kappa(a,b,c) = cdsqrt(dcmplx(a**2+b**2+c**2-2*(a*b+a*c+b*c)))
      kappa(a,b,c,d) = cdsqrt((a**2+b**2+c**2-2*(a*b+a*c+b*c))
     .               * (1+ieps*d))
      eps = 1.d-8*(p1+p2+p3)
      im = dcmplx(0.d0,1.d0)
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ieps = dcmplx(0.d0,1.d-17)
c     ieps = dcmplx(0.d0,1.d-20)
      pi = 4*datan(1.d0)
      xx = 0.d0
c     if(p1.lt.0.d0.or.p2.lt.0.d0.or.p3.lt.0.d0) xx=1.d0
      if(p1.ne.0.d0.or.xx.ne.0.d0)then
       q10 = p1
      else
       q10 = eps
      endif
      if(p3.ne.0.d0.or.xx.ne.0.d0)then
       q20 = p3
      else
       q20 = eps
      endif
      if(p2.ne.0.d0.or.xx.ne.0.d0)then
       q21 = p2
      else
       q21 = eps
      endif
      r(0) = p2
      r(1) = p3
      r(2) = p1
      sm0 = m1**2
      sm1 = m2**2
      sm2 = m3**2
c>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
c     alpha  = kappa(q10,q21,q20)
c     alp(0) = kappa(q21,sm1,sm2)*(1+ieps*q21)
c     alp(1) = kappa(q20,sm2,sm0)*(1+ieps*q20)
c     alp(2) = kappa(q10,sm0,sm1)*(1+ieps*q10)
      alpha  = kappa(q10,q21,q20,1.d0)
      alp(0) = kappa(q21,sm1,sm2,dsign(1.d0,q21))
      alp(1) = kappa(q20,sm2,sm0,dsign(1.d0,q20))
      alp(2) = kappa(q10,sm0,sm1,dsign(1.d0,q10))
      x(0,1) = (q21 - sm1 + sm2 + alp(0))/2/q21
      x(0,2) = (q21 - sm1 + sm2 - alp(0))/2/q21
      x(1,1) = (q20 - sm2 + sm0 + alp(1))/2/q20
      x(1,2) = (q20 - sm2 + sm0 - alp(1))/2/q20
      x(2,1) = (q10 - sm0 + sm1 + alp(2))/2/q10
      x(2,2) = (q10 - sm0 + sm1 - alp(2))/2/q10
      y0(0) = (q21*(q21-q20-q10+2*sm0-sm1-sm2) - (q20-q10)*(sm1-sm2)
     .      + alpha*(q21-sm1+sm2))/2/alpha/q21
      y0(1) = (q20*(q20-q10-q21+2*sm1-sm2-sm0) - (q10-q21)*(sm2-sm0)
     .      + alpha*(q20-sm2+sm0))/2/alpha/q20
      y0(2) = (q10*(q10-q21-q20+2*sm2-sm0-sm1) - (q21-q20)*(sm0-sm1)
     .      + alpha*(q10-sm0+sm1))/2/alpha/q10
      y(0,1) = y0(0) - x(0,1)
      y(0,2) = y0(0) - x(0,2)
      y(1,1) = y0(1) - x(1,1)
      y(1,2) = y0(1) - x(1,2)
      y(2,1) = y0(2) - x(2,1)
      y(2,2) = y0(2) - x(2,2)
      cdum=0.d0
      do i=0,2
       do j=1,2
        cdum = cdum + cspen_hdec((y0(i)-1)/y(i,j))
     .              - cspen_hdec(y0(i)/y(i,j))
        cx = eta_hdec(1-x(i,j),1/y(i,j))
        if(cx.ne.0.d0)then
         cdum = cdum + cx*cdlog((y0(i)-1)/y(i,j))
        endif
        cy = eta_hdec(-x(i,j),1/y(i,j))
        if(cy.ne.0.d0)then
         cdum = cdum - cy*cdlog(y0(i)/y(i,j))
        endif
       enddo
       cx = eta_hdec(-x(i,1),-x(i,2))
       if(cx.ne.0.d0)then
        cdum = cdum - cx*cdlog((1-y0(i))/(-y0(i)))
       endif
       cy = eta_hdec(y(i,1),y(i,2))
       if(cy.ne.0.d0)then
        cdum = cdum + cy*cdlog((1-y0(i))/(-y0(i)))
       endif
       a = -r(i)
       b = -dimag(y(i,1)*y(i,2))
       if(a.gt.0.d0.and.b.gt.0.d0) then
        cdum = cdum + 2*pi*im*cdlog((1-y0(i))/(-y0(i)))
       endif
      enddo
      c03_hdec = cdum/alpha
      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C        SUBROUTINE CALCULATING THE FINITE REAL PART OF THE           C
C          GENERAL MASSIVE TWO POINT FUNCTION                         C
C                                                                     C
C           B02(P.P,M1,M2,MU**2)                                      C
C           BP02(P.P,M1,M2,MU**2)                                     C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

c ---------------------------------------------------------------------
      real*8 function B02_HDEC(s,m1,m2,mu2)

      implicit none 

      real*8     s,m1,m2,mu2,m12,m22 
      complex*16 zkappa,x1,x2 

      m12 = m1**2 
      m22 = m2**2 

      zkappa=cdsqrt(dcmplx(s**2+m12**2+m22**2
     &                     -2.D0*(s*m12+s*m22+m12*m22)))

      if (s.eq.0.D0) then
         if (m12.eq.m22) then
            B02_HDEC=-dlog(m12/mu2) 
         else
          if (m22.eq.0.D0) then
           if (m12.eq.0.D0) then
            B02_HDEC=1.D0
           else
            B02_HDEC=1.D0 - m12/(m12-m22)*dlog(m12/mu2)
           endif
          else
           if (m12.eq.0.D0) then
            B02_HDEC=1.D0 + m22/(m12-m22)*dlog(m22/mu2) 
           else
            B02_HDEC=1.D0 - m12/(m12-m22)*dlog(m12/mu2)
     &                 + m22/(m12-m22)*dlog(m22/mu2) 
           endif
          endif
         endif
      else 
         if ((m12.eq.0.D0).and.(m22.eq.0.D0)) then 
            B02_HDEC=2.D0 - dlog(s/mu2)
         elseif ((m12.eq.s).and.(m22.eq.0.D0)) then 
            B02_HDEC=2.D0 - dlog(m12/mu2)
         elseif ((m22.eq.s).and.(m12.eq.0.D0)) then 
            B02_HDEC=2.D0 - dlog(m22/mu2)
         elseif (m12.eq.0.D0) then
            B02_HDEC=2.D0 - (s-m22)/s*dlog( dabs(m22-s)/m22 )
     &                 - dlog(m22/mu2)
         elseif (m22.eq.0.D0) then
            B02_HDEC=2.D0 - (s-m12)/s*dlog( dabs(m12-s)/m12 ) 
     &                 - dlog(m12/mu2)
         else
            x1=dcmplx( (s-m22+m12+zkappa)/(2.D0*s) )
            x2=dcmplx( (s-m22+m12-zkappa)/(2.D0*s) )
            B02_HDEC=dreal( 2.D0+ dlog(mu2/m22) 
     &                       + x1*cdlog(1.D0-1.D0/x1) 
     &                       + x2*cdlog(1.D0-1.D0/x2))
         endif
      endif 

      return
      end



c ---------------------------------------------------------------------
      real*8 function BP02_HDEC(s,m1,m2,mu2)
      
      implicit none 

      real*8     s,m1,m2,mu2,m12,m22 
      complex*16 zkappa,x1,x2
      
      m12 = m1**2
      m22 = m2**2 

      zkappa=cdsqrt(dcmplx(s**2+m12**2+m22**2
     &                    -2.D0*(s*m12+s*m22+m12*m22)))

      if (s.eq.0.D0) then
         if (m12.eq.m22) then
            BP02_HDEC=1.D0/(6.D0*m12)
         else
            BP02_HDEC=( (m12+m22)/2.D0 
     &        - m12*m22/(m12-m22)*dlog(m12/m22) )/(m12-m22)**2 
         endif
      elseif ((s.eq.m12).and.(m22.eq.0.D0)) then 
         BP02_HDEC=( -1.D0 + dlog(m12/mu2)/2.D0 )/m12
      elseif ((s.eq.m22).and.(m12.eq.0.D0)) then 
         BP02_HDEC=( -1.D0 + dlog(m22/mu2)/2.D0 )/m22
      else 
         x1=dcmplx( (s-m22+m12+zkappa)/(2.D0*s) )
         x2=dcmplx( (s-m22+m12-zkappa)/(2.D0*s) )
         BP02_HDEC=dreal( -1.D0 + ( x1*(1.D0-x1)*cdlog(1.D0-1.D0/x1)
     &                     - x2*(1.D0-x2)*cdlog(1.D0-1.D0/x2) )  
     &                                                  /(x1-x2) )/s
      endif 

      return
      end

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
        function cspen_hdec(z)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C       SPENCE-FUNKTION KOMPLEX, FREI NACH HOLLIK                     C
C---------------------------------------------------------------------C
C       20.07.83    LAST CHANGED 10.05.89        ANSGAR DENNER        C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
        complex*16 cspen_hdec,w,sum,z,u
        real*8 rz,az,a1
        real*8 b(9)/
     1   0.1666666666666666666666666667d0,
     2  -0.0333333333333333333333333333d0,
     3   0.0238095238095238095238095238d0,
     4  -0.0333333333333333333333333333d0,
     5   0.0757575757575757575757575758d0,
     6  -0.2531135531135531135531135531d0,
     7   1.1666666666666666666666666667d0,
     8  -7.09215686274509804d0         ,
     9  54.97117794486215539d0         /
C     BEACHTE:                 B(N)=B2N
C     B(1)=1./6.
C     B(2)=-1./30.
C     B(3)=1./42.
C     B(4)=-1./30.
C     B(5)=5./66.
C     B(6)=-691./2730.
C     B(7)=7./6.
C     B(8)=-3617./510.
C     B(9)=43867./798.
C     B(10)=-174611./330.
C     B(11)=854513./138.
C     PI=3.1415926535897932384
C     PI*PI/6.=1.6449..., PI*PI/3=3.28986...
C
c      write(*,*) 'z:',z
      z =z*dcmplx(1d0)
      rz=dreal(z)
      az=cdabs(z)
      a1=cdabs(1d0-z)
c      write(*,*)'z, rz, az, a1:',z,rz,az,a1
C     IF((SNGL(RZ) .EQ. 0.0) .AND. (SNGL(DIMAG(Z)) .EQ. 0.0)) THEN
C ---> CHANGED  10.5.89
      if(az .lt. 1d-20) then
        cspen_hdec=-cdlog(1d0-z)
c        write(*,*) 'cspen:', cspen_hdec
        return
      end if
      if((sngl(rz) .eq. 1.0) .and. (sngl(dimag(z)) .eq. 0.0)) then
        cspen_hdec=1.64493406684822643d0
c        write(*,*) 'cspen:', cspen_hdec
        return
      end if
      if(rz.gt.5d-1) goto 20
      if(az.gt.1d0) goto 10
      w=-cdlog(1d0-z)
      sum=w-0.25d0*w*w
      u=w
      if(cdabs(u).lt.1d-10) goto 2
c      write(*,*) 'u:',u
c      write(*,*) 'sum:',sum
      do 1 k=1,9
      u=u*w*w/dfloat(2*k*(2*k+1))
      if(cdabs(u*b(k)/sum).lt.1d-20) goto 2
      sum=sum+u*b(k)
 1    continue
 2    cspen_hdec=sum
c        write(*,*) 'cspen:', cspen_hdec
      return
10    w=-cdlog(1d0-1d0/z)
      sum=w-0.25d0*w*w
      u=w
      if(cdabs(u).lt.1d-10) goto 12

      do 11 k=1,9
      u=u*w*w/dfloat(2*k*(2*k+1))
      if(cdabs(b(k)*u/sum).lt.1d-20) goto 12
      sum=sum+u*b(k)
11    continue
12    cspen_hdec=-sum-1.64493406684822643d0-.5d0*cdlog(-z)**2
c        write(*,*) 'cspen:', cspen_hdec
      return
20    if(a1.gt.1d0) goto 30
      w=-cdlog(z)
      sum=w-0.25d0*w*w
      u=w
      if(cdabs(u).lt.1d-10) goto 22
      do 21 k=1,9
      u=u*w*w/dfloat(2*k*(2*k+1))
      if(cdabs(u*b(k)/sum).lt.1d-20) goto 22
      sum=sum+u*b(k)
21    continue
22    cspen_hdec=-sum+1.64493406684822643d0-cdlog(z)*cdlog(1d0-z)
c        write(*,*) 'cspen:', cspen_hdec
      return
30    w=cdlog(1d0-1d0/z)
      sum=w-0.25d0*w*w
      u=w
      if(cdabs(u).lt.1d-10) goto 32
      do 31 k=1,9
      u=u*w*w/dfloat(2*k*(2*k+1))
      if(cdabs(u*b(k)/sum).lt.1d-20) goto 32
      sum=sum+u*b(k)
31    continue
32    cspen_hdec=sum+3.28986813369645287d0
     *               +.5d0*cdlog(z-1d0)**2-cdlog(z)*cdlog(1d0-z)
50    continue
c        write(*,*) 'cspen:', cspen_hdec
      end

c -------------------------------------------------------------------- c

      function t_hdec(x,y,z)
      implicit real*8(a-h,l,m,o-z)
      if(x.eq.y) x = x - 0.00001
      if(x.eq.z) x = x - 0.00002
      if(y.eq.z) y = y - 0.00003
c       write(*,*) 'xyz',x,y,z
      t_hdec = (x**2*y**2*log(x**2/y**2) + x**2*z**2*log(z**2/x**2)
     * + y**2*z**2*log(y**2/z**2))/((x**2-y**2)*(y**2-z**2)*(x**2-z**2))
      return
      end


